function Get_roi_parameters(infile,tracer,option,np1,np2,w)
% Usage Get_roi_parameters('infile', 'tracer', option, frame1, frame2,window)
%
% This function performs ROI-based graphic analysis
% option = 1 Simple plot gives regional SOR values
% option = 2 Patlak plot gives regional Ki values
% option = 3 Logan plot gives regional DVR values
%
% Program note:
%    Written at NSUH by Yilong Ma PhD
%    First evaluation in March 2000
%    Report problems to yma@nshs.edu
%	Revision: Remove mean SOR output 5/1/07 Yilong Ma

%define parameters
n = 1; 
N = 4;
t0 = 0.0;
decay_correction = 1;
old_data = 0;
load_time = 0; % perform linear interpolation

if tracer == 'RAC'
   title_string = 'C-11 Raclopride';
   % k = 11; hd and gween
   % k = 5; dystonia
   k = np1;
   k2 = 0.163;
   Th = 20.;
elseif tracer == 'CIT'
   title_string = 'F-18 FP-BCIT';
   n = 1;
   k = np1;
   k2 = 0.037;
   Th = 110.;
else
   title_string = 'F-18 FluoroDopa';
   k = 12;  % porcine 
   if tracer == 'FET'
      k = 1;
      decay_correction = 0;
      t0 = input('Enter time-delay (min): ');
   end
   % 'DOPA' PS
   if tracer == 'DOP'
      k = np1;
   end
   Th = 110.;
end
disp(title_string)

if option == 1
   disp('SOR')
elseif option == 2
   disp('Ki')
else
   disp('DVR')
end
structure = {'Left Caudate' 'Right Caudate' 'Left Putamen' 'Right Putamen' 'Occipital Cortex'};

if old_data
   fd = fopen(infile,'r');
   S = fgetl(fd);         
   D = fscanf(fd,'%f',[8 np2])';
   fclose(fd);
else
   [s,name,a,b,c,d,e,f,g] = textread(infile,'%d %s %f %f %f %f %f %f %f',np2);
   D = [s,a,b,c,d,e,f,g];
end

j = length(D(:,1));
t1 = D(n:j,2);
t2 = D(n:j,3) + t0;
t = t2;
A = D(n:j,4:8);
C = D(n:j,4:8);
j = length(A(:,1));

if load_time
   load midtime.txt
   t = midtime;
   At = interp1(t2,A,t);
   [t At];
end

% linear fit of tissue curves
if option == 1 & tracer == 'FET'
   z = log(A);
   for i = 1:j,
      t(i) = 45 + (i-1)*10;
   end
  
   for i = 1:5,
      p = polyfit(t2,z(:,i),1);
      A(:,i) = exp(polyval(p,t));
   end
end

% linear fit of tissue curves
if option == 1 & tracer == 'FIT'
   z = log(A(k:j,:));
   ta = t2(k:j);
   for i = 1:5,
      p = polyfit(ta,z(:,i),1);
      P(i,:) = [exp(p(2)) -p(1)];
   end
   Coeff = P
end

% do decay correction 
% sum(t1(1:i))-t1(i)/2;

if decay_correction
   disp('decay correction')
   for i = 1:j,
       df(i) = exp(t2(i)*log(2)/Th);
       A(i,:) = A(i,:)*df(i);
       C(i,:) = C(i,:)*df(i);
   end 
end
   
figure(w)
plot(t2,C)
xlabel('Time (min)')
ylabel('Activity (uCi/cc)')
title(title_string);
legend(structure);

% partition tissue TAC
A1 = A(:,1);
A2 = A(:,2);
A3 = A(:,3);
A4 = A(:,4);
A5 = A(:,5);

% perform graphic analysis
B = [A1.*t1 A2.*t1 A3.*t1 A4.*t1 A5.*t1];
for m = 1:N
   if option == 2  % Patlak plot 
      for i = 1:j,
          x(i) = sum(B(1:i,5))./A(i,5);
          y(i) = (A(i,m)-A(i,5))./A(i,5);
      end
   elseif option == 3  % Logan plot
      for i = 1:j,
          x(i) = (sum(B(1:i,5)) + A(i,5)/k2)./A(i,m);
          y(i) = sum(B(1:i,m))./A(i,m);
      end
   else   % SOR values
      for i = 1:j
          y2(i) = C(i,m)./C(i,5);
%          y(i) = A(i,m)./A(i,5);
          y(i) = A(i,m)./A(i,5) -1;
      end
   end
   
   if option == 1
       figure(w+1)
       subplot(2,2,m);
       plot(t2,C(:,m),'ro',t,A(:,m),'g-')
       %title PS
       title(structure(m),'color','b');
       hold on
       figure(w+2)
       subplot(2,2,m);
       plot(t2,y2,'ro',t,y,'g-')
       hold on
       SOR(m,:) = y(k:j);
       %title PS
       title(structure(m),'color','b');
   else
       x1 = x(k:j);
       y1 = y(k:j);
       figure(w+1)
       subplot(2,2,m)
       %title('caudate','color','b');
       p = polyfit(x1,y1,1);
       y2 = polyval(p,x1);
       plot(x,y,'ro',x1,y2,'g-')
       P(m,:) = p;
       %title PS
       title(structure(m),'color','b');
    end
 end
 
 q = length(infile)-4;
 tim_str = [num2str(t(k)), ' - ', num2str(t(j))];
 if option == 1
    SOR = [t(k:j) SOR']
    %mn = mean(SOR(2:6,:))
    dat = SOR;
    outfile = [infile(1:q) '_SOR.txt'];
 elseif option == 2
    Ki = P'
    dat = Ki;
    outfile = [infile(1:q) '_Ki.txt'];
 else
    DVR = P'
    dat = DVR;
    outfile = [infile(1:q) '_DVR.txt'];
end

ofd = fopen(outfile,'A');
fprintf(ofd, 'Time range = %s (min) \n', tim_str);
label = 'Time(min) Lcaudate Rcaudate Lputamen Rputamen';
format = '%d %8.4f %8.4f %8.4f %8.4f \n';
if option > 1 
   label = label(11:length(label));
   format = format(4:length(format));
end
fprintf(ofd, '%s \n',label);
fprintf(ofd, format,dat');
fclose(ofd);
