% ScAnVP Scan Analysis and Visualization Processor
% -Version 7.0w  (C)2016 - Center for Neurosciences, Feinstein Institute
%
% ScAnVP is a set of MATLAB routines intended primarily 
% for the image processing, visualization, region of interest
% statistics and analysis of PET functional brain images or other
% single volume images such as perfusion ASL fMRI or VBM MRI. 
% Images can be input in Analyze or in most cases Nifti format but ouput
% images are in Analyze format. They can be used on a Windows PC
% or other processors that support MATLAB. ScAnVP is a free distribution
% that is not intended for commercial use. It is an in-house package that
% was developed in collaboration with members of the PET Functional
% Brain Imaging Laboratory of North Shore-LIJ Research Institute (now
% Northwell Health) directed by Dr. David Eidelberg and is designed to be
% used as a set of research tools in conjunction with other biomedical and
% statistical research packages. A major portion of the software implements
% the SSM-PCA model for the derivation and application of characteristic
% spatial covariance imaging biomarkers of neurofunctional disorders such
% as Parkinson's Disease. 
% ScAnVP is available as copyright free software distributed under the
% terms of the GNU General Public Licence (either version 2 or any later version)
% as published by the Free Software Foundation. Licence terms can be
% read by visiting http://www.gnu.org/copyleft/. 
% These contents list in-house software, masks, color maps and executable
% programs. They may also include publicly distributed utilities or images
% such as SPM\sample mri or pet images and a modified brain atlas based on 
% an aal_MNI_V4 image.
% General documentation and help routines are available on the ScAnVP
% menu and in a separate directory. In addition the user can
% set the 'Help' mode button ON and point to main menu items or invoke 
% help on individual routines. Button 'tooltips' and run time 'HELP'
% buttons are also provided.
%
%			Phoebe Spetsieris, Ph.D.
%			Research Associate Investigator
%			Functional Brain Imaging Laboratory	
%			Center for Neurosciences
%			Feinstein Institute for Medical Research
%			Northwell Health
%			350 Community Drive
%			Manhasset, New York 11030
%
%			Send comments to:
%			pspetsie@northwell.edu
%
%Directory of ...\scanvp
%
% vpm\
% bin\
% col\
% mri\
% pet\
% work\
% masks\
% networks\
% templates\
% documentation\
% 
% scanvp\documentation\:
% GNU GENERAL PUBLIC LICENSE.doc
% README7.0w.txt
% Upgrade7.0w.txt
% Upgrades.txt
% ContentsScAnVP7.0w.doc
% GeneralDescription7.0w.doc
% Crop_Pad_Normal.doc
% ScAnVP_SSM_ExampleOutline.txt
% ScAnVP_Step_by_step_Instructions_2016.doc
% ScAnVP_PCA_output_examples.xls
% Selected_Help_Topics7.0.m
% spm_defaults.m.txt
% SSMreferences.doc
% SSMPCA_Overview.docx
% TPR_WARNING.txt
% License.txt
% NEUROLOGICAL_RADIOLOGICAL_Orientation7.0.doc
%
% scanvp\vpm:
% contents.m
% dbh.h
% ftest_levene.m
% get_file.m
% Get_roi_parameters.m
% scanvp.m
% tutest2.m
% vp_anahdr.m
% vp_animask.m
% vp_aniroi.m
% vp_append.m
% vp_aspect.m
% vp_atlaslabel.m
% vp_axorigin.m
% vp_basicop.m
% vp_birange.m
% vp_checkNIFU.m
% vp_colgui.m
% vp_colorbar.m
% vp_colrange.m
% vp_compress.m
% vp_controls.m
% vp_convertge.m
% vp_cropvol.m
% vp_cslices.m
% vp_cslicespro.m
% vp_cvolfuns.c
% vp_cvolfuns.dll
% vp_cvtNIF2ANA.m
% vp_cvtunix.m
% vp_cvtype.m
% vp_defaults.m
% vp_dispfile.m
% vp_displayinfo.m
% vp_dos.m
% vp_errata.m
% vp_filesui.m
% vp_fimage.m
% vp_fimg.m
% vp_fixhdr.m
% vp_fixorigins.m
% vp_fixoriginspro.m
% vp_fixtimes.m
% vp_fixtimespro.m
% vp_flipim.m
% vp_general.m
% vp_genmri.m
% vp_getroiparams.m
% vp_getvoxparams.m
% vp_GIS_coeff.m
% vp_GISAimg.m
% vp_giscorr.m
% vp_gisfun.m
% vp_GISimg.m
% vp_gismap.m
% vp_GISpro.m
% vp_globhdr.m
% vp_gmask.m
% vp_graphics.m
% vp_groi.m
% vp_groupmask.m
% vp_groupro.m
% vp_grouproi.m
% vp_grouprpt.m
% vp_help.m
% vp_helpbutton.m
% vp_hemimage.m
% vp_hemipro.m
% vp_hread.m
% vp_hwrite.m
% vp_imageop.m
% vp_imcvt.m
% vp_imflip.m
% vp_imframe.m
% vp_imfun.m
% vp_imfun3.m
% vp_imfun7.m
% vp_impnt.m
% vp_imsave.m
% vp_imtext.m
% vp_imui.m
% vp_imutil.m
% vp_imvalue.m
% vp_imview.m
% vp_imviewpro.m
% vp_imvorth.m
% vp_imz.m
% vp_imzorth.m
% vp_imzpro.m
% vp_interbatch.m
% vp_interp.m
% vp_interp2D.m
% vp_interpro.m
% vp_invcol.m
% vp_keyin.m
% vp_License.m
% vp_lineplot.m
% vp_marker.m
% vp_mask.m
% vp_maskcb.m
% vp_maskimgs.m
% vp_matcolor.m
% vp_math.m
% vp_message.m
% vp_mimpro.m
% vp_mkTmask.m
% vp_movie.m
% vp_multi_imageop.m
% vp_naming.m
% vp_nm.m
% vp_norm.m
% vp_note.m
% vp_num3str.m
% vp_opt.m
% vp_pair_imageop.m
% vp_plot.m
% vp_ratiomap.m
% vp_read_grprpt.m
% vp_readatlas.m
% vp_readgis.m
% vp_readrpt.m
% vp_remclust.m
% vp_rethresh.m
% vp_revisions.m
% vp_roi.m
% vp_roicb.m
% vp_roidisp.m
% vp_roidrpt.m
% vp_roifuns.m
% vp_roigrpt.m
% vp_roilab.m
% vp_roimap.m
% vp_roirpt.m
% vp_roissm.m
% vp_roistat.m
% vp_roithresh.m
% vp_rotmovie.m
% vp_rotview.m
% vp_rotvol.m
% vp_rvolfuns.m
% vp_savaslice.m
% vp_savmask.m
% vp_scalarfactors.m
% vp_scatternplot.m
% vp_scatterplot.m
% vp_screengui.m
% vp_scrncolor.m
% vp_semirange.m
% vp_smooth.m
% vp_spmlike.m
% vp_spmrender.m
% vp_spmresults.m
% vp_spmsections.m
% vp_spmtranslices.m
% vp_spmtranslicesN.m
% vp_spmtransui.m
% vp_spmtransverse.m
% vp_SSM.m
% vp_ssm_autoroirecal.m
% vp_ssm_autoroitpr.m
% vp_ssm_autovoxrecal.m
% vp_ssm_autovoxtpr.m
% vp_ssm_GisCombo.m
% vp_ssm_means.m
% vp_ssm_prediagnrpt.m
% vp_ssm_ROC.m
% vp_ssm_roiOpca.m
% vp_ssm_roipca.m
% vp_ssm_roitpr.m
% vp_ssm_roitprpro.m
% vp_ssm_scores.m
% vp_ssm_subvoxpca.m
% vp_ssm_voxOpca.m
% vp_ssm_voxOtpr.m
% vp_ssm_voxpca.m
% vp_ssm_voxpcapro.m
% vp_ssm_voxtpr.m
% vp_ssm_voxtprpro.m
% vp_ssm_voxtprrepeat.m
% vp_ssminfo.m
% vp_ssmlist.m
% vp_ssmpca.m
% vp_statbar.m
% vp_statmap.m
% vp_statmapro.m
% vp_surfplot.m
% vp_tapergui.m
% vp_tfactgui.m
% vp_thmin.m
% vp_thresh.m
% vp_transp.m
% vp_transpro.m
% vp_unixcvt.c
% vp_unixcvt.dll
% vp_VOIfun.m
% vp_VOIvalues.m
% vp_volfuns.m
% vp_voxssm.m
% vp_windows.m
% vp_write_srpfile.m
% vp_write_ssmfile.m
% vp_write_XYfile.m
% vp_write_XYZfile.m
% vp_xyzcoord.m
% vp_xyzmarker.m
% vp_zeronegs.m
%
% scanvp\bin:
% anahdr.exe
% convertge.exe
% gzip.exe
% imfun.exe
% imfun4.exe
% vpgenmri.exe
% vprename.exe
%
% scanvp\col:
% BiCol128
% bone.mat
% col21.mat
% coolmap.mat
% GE.mat
% GEmap64.mat
% GEmap221.mat
% graybicol.mat
% graybicol10.mat
% graybicol10a.mat
% graybicol10b.mat
% graybicola.mat
% graybicolb.mat
% graybicolc.mat
% graybicold.mat
% graycols.mat
% graycols10.mat
% graycols256.mat
% graycool.mat
% graycoola.mat
% graycoolb.mat
% grayhot.mat
% grayhot128.mat
% grayhot256.mat
% grayjet.mat
% grayjet256.mat
% grayjethot.mat
% graypink.mat
% graypink256.mat
% gy.mat
% gy256.mat
% gy64.mat
% hot.mat
% hot256.mat
% hot64.mat
% hsv.mat
% jet.mat
% jet2.mat
% jet256.mat
% jetbk64.mat
% jetred64.mat
% jetred129.mat
% newGE.mat
% pink.mat
% tekcol21.mat
% usermap.mat
%
% scanvp\mri:
% single_subj_T1_LR.img
% single_subj_T1_LR.hdr
% rsingle_subj_T1_spm99LR.img
% rsingle_subj_T1_spm99LR.hdr
% rsingle_subj_T1_spm5RL69.img
% rsingle_subj_T1_spm5RL69.hdr
% rsingle_subj_T1_spm5RL68.img
% rsingle_subj_T1_spm5RL68.hdr
% rsingle_subj_T1_spm5LR69.img
% rsingle_subj_T1_spm5LR69.hdr
%
% scanvp\pet:
% rcsf99.img
% rcsf99.hdr
% rgray99.img
% rgray99.hdr
% rwhite99.img
% rwhite99.hdr
% rrgrey00_79_95_69.img
% rrgrey00_79_95_69.hdr
% PET5.nii
% PET5.img
% PET5.hdr
% PET5_75_95_69.img
% PET5_75_95_69.hdr
%
% scanvp\masks:
% PETMask.img
% PETMask.hdr
% PETMask5_38.img
% PETMask5_38.hdr
% PETMask5_40.img
% PETMask5_40.hdr
% PETMask5_91_109_91.img
% PETMask5_91_109_91.hdr
% PETMask99.img
% PETMask99.hdr
% wholebrainmask99.img
% wholebrainmask99.hdr
%
% scanvp\networks:
% .\COND1:
% ROI	VOX
%
% .\COND1\ROI:
% STUDY1\
%  STUDY1Note.txt
% 
% .\COND1\VOX:
% STUDY1\
%  STUDY1Note.txt
% 
% STUDY2\
%  STUDY2Note.txt
%
% scanvp\templates:
%  ROI_Templates\
%    ROINote.txt
%
% Brain_Atlas
%    ROIAtlasC_LR68.img ROIAtlasC_LR68.hdr ROIAtlasC_LR68Labs.txt ROIAtlasC_LR68Notes.txt
%    ROIAtlasC_RL69.img ROIAtlasC_RL69.hdr ROIAtlasC_RL69Labs.txt ROIAtlasC_RL69Notes.txt
%
% scanvp\work:
%    pwdlast.mat
%
% 1/28/16

