% vp_GISAimg.m
% Creates a GIS weighted ATLAS ROI Image Map.
%___________________________________________________________________________
% 
% This routine creates an ANALYZE image map of a ROI GIS PC resulting from 
% SSM ROI PCA of ATLAS based GROUP-ROI data by mappig each each roi's gis
% weight to the corresponding ATLAS roi's voxels. The resulting weighted voxel
% image map can be input into the 'Statistical Map' routine to create PET/MRI 
% maps or into 'SPM-like Results' routines or can be used as a ROI based 
% voxel mask once GIS weight values are converted to 0/1 (see below).
%
% The user specifies 1) a GIS file (namegis.txt) listing 
% region names and their corresponding weights and 2) an ATLAS image of 
% the original topography of voxels with the value of each index specified
% in the corresponding Label file listing ROI Names and their index.
%
% The GIS file has the following format: 
% a) The file may be a formatted output file from a previous ATLAS based
% ROI pca analysis. The ATLAS should correspond to the one used to generate
% the group data that was analyzed to create the GIS file.
%
% The program outputs an ANALYZE format image file 'namegisroi.img'. The
% output volume has all voxels outside of regional and threshold limits set
% to zero. Internal regional voxels are set to a constant corresponding to
% the region weight. The output image will have the same orientation as the
% Atlas file on disk. The correct RL or LR "Input" file designation on the
% menu does not affect processing but is needed for proper Neurological (LR)
% display of the resulting GIS image.
%
% The complete gis weighted 'namegisroi.img' ANALYZE image is saved without 
% background but can be input into the 'Statistical Map' and mapped onto
% a background (MRI) image to create a 'statmap.img' representing the GIS, 
% This volume can then be viewed with axial, sagittal or coronal multiplanar
% viewing options. In this representation the upper half of the colormap
% is assigned to the statistical map values and the lower half to background.
% and can be manipulated separately using the 'semirange' routine.
% See also (vp_grouproi.m, vp_statmap.m & vp_semirange.m).
%
% VOXEL MASK
% For a 0/1 output mask, the output image can be converted to 0/1 values using
% Image Processing threshold options or the input "GIS" file weights can be 
% previously set to 1 for selected regions.
%___________________________________________________________________________
% vp_GISAimg.m	ScAnVP ver. 6.4 	P. Spetsieris	Jan 20, 2015
%               ScAnVP Rev. 7.0 	P. Spetsieris	Jan 16, 2016

global HelpMode GisFName Message
global FI FNames FName gisAgui hgiserr Automatic PlaneNo0 PlaneNo
global ThreshMode FixedThresh FixedThMin
global htemp Ecolor
global GisOri GisLab GisWeight GisId
global BgrndFName GMax3 GMin3 RangeMin RangeMax RI 
global herror
global ALabNames ALabNos AVolXYZ LabAIds Keyin
global LabNames LabIds RoiNo

WndNo=0;
WndScl=4;
Message0=['............................................ '];
Message=Message0;

if HelpMode, vp_help('vp_GISAimg'), return ; end;


delete(findobj('Name','GROUP ROIgui'));
delete(findobj('Name','grprogui'));
delete(findobj('Name','ROIgui'));
delete(findobj('Name','gROIgui'));
delete(findobj('Name','gisprogui'));
delete(findobj('Name','GIS gui'));

delete(findobj('Name','GISA gui'));

LabNames=[]; LabIds=[];
LabNames=str2mat(blanks(40),blanks(40));
LabIds=str2mat(blanks(4),blanks(4)); 
RoiNo=0;

vp_imframe;

FName=[];

GisFName=[];
IdentGIS=0;
IdentAtlas=0;

IdentBgrnd=0;
BgrndFName=[];

PlaneNo=1;
Automatic=0;
DefTemplate=0;

ThreshMode=1;
FixedThresh=100;
FixedThMin=0;

Bcolor = [.8,.8,.8];
Kcolor = [.8,1,1];
Fcolor = [.8,.8,.9];

gisAgui = figure('Color',Fcolor,'Name','GISA gui',...
'NumberTitle','off','Position',[100,200,250,285],...
'Units','Pixels');
	

cbtext= ['text(0,70,''Region Fill Type Constant'',''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''FontName'',''Times'',''FontSize'',10,''HorizontalAlignment'',''left'');'] ;

cbtext2= ['text(0,95,''Threshold 100%'',''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''FontName'',''Times'',''FontSize'',10,''HorizontalAlignment'',''left'');'] ;

eval(cbtext);

eval(cbtext2);

%
%	'  IdentRois=0; if IdentAtlas, ',...
%	'    for pln=1:DIM(3), if vp_readatlas(FName,pln) >=0, IdentRois=IdentRois+1; end; end;',...
%	'  else, vp_note(''Atlas read error'',3); end; ',...
%

cbmapgis = ['nats=size(ALabNames,1); nrois=size(GisLab,1); GisId=zeros(nrois,1);',...
           ' for ng=1:nrois, roiname= deblank(GisLab(ng,:)); if GisOri(ng) ~=''C'',',...
	   '    roiname=[roiname,''_'',GisOri(ng)]; end;',...
	   '    for na=1:nats, alabname=deblank( ALabNames(na,:)); ',...
	   '     if strcmp(roiname, alabname), GisId(ng)=ALabNos(1,na); break; end; ',...
           ' end; end;',...
	   ' [out1 AVolXYZ]=vp_volfuns(''xyzdata'',FName); ngfound=0;  ',...
       ' if out1~=1, vp_note(Message); set(hgiserr,''string'',Message); ',...
       ' else, gismapA=double(zeros(DIM));',...
       '   for ng=1:nrois, if GisId(ng) ~= 0, ngfound=ngfound+1;',...
       '   gismapA=gismapA + GisWeight(ng).*(double((AVolXYZ==GisId(ng)))); ',...
       '   else, vp_note([''Roi No.='',num2str(ng),'', '',GisLab(ng,:),'' Not Found''],2); end; end;',... 
       ' if ngfound>0, [gisname,dnm,dirnm]=vp_nm(''nm'',GisFName);',...
       '   gisname=strrep(gisname,''.'',''-''); FName=[dirnm,gisname,''.img'']; ',...
	   '   TYPE=16; MATYPE=''float''; DESCRIP=[''ScAnVP GIS Atlas Map''];',...
	   '   vp_imsave(FName,gismapA,1); vp_note(Message);',...
       ' else, vp_note(''NO ROIS FOUND''); end; set(hgiserr,''string'',Message);  end; '];

axis off;

uicontrol(gisAgui,'string', 'Help',...
	'TooltipString','Help displayed in MATLAB window',...
	'BackgroundColor',Ecolor,...
	'position',[180 265 40 17],'callback','vp_help(''vp_GISAimg'');');

pcbgis=['GisFName=get_file(1,''*gis*.txt'',''please select GIS file.'',[]); ',...
	'if ~isempty(GisFName),',...
	'IdentGIS=vp_readgis(1,GisFName);',...
	'if IdentGIS==2, vp_note(''ERROR: GIS FILE MUST BE FORMATTED'');',...
	'else GisId=[]; end;',...
    'figure(findobj(''Name'',''GISA gui''));',...
	'set(hgiserr,''string'',Message); end;'];
	
	
%pcbgrnd=['BgrndFName=get_file(1,''.img'',''please select background image'',[]), ',...
%	'if ~isempty(BgrndFName),',...
%	'FName=BgrndFName; vp_fimage;',...
%	'[GMax3 GMin3]=vp_roifuns(''gminmax'');',...
%	'if isempty(Message), IdentBgrnd=1; PlaneNo=max(PlaneNo-1,1); Message=[''BGRND :  '',FName]; end;',...
%	'if strcmp(Message,''Maximum Plane Reached''), IdentBgrnd=1; end;',...
%	'set(hgiserr,''string'',['' '',Message]); end;'];
%	

pcatlas=['FNames=get_file(1,''.img'',''please select Atlas image'',[]), ',...
	'if ~isempty(FNames), IdentAtlas=0; ALabNames=[]; ALabNos=[];',...
	'  if vp_readatlas(FNames(1,:), 0) < 0, vp_note(''INVALID ATLAS''); ',...
    '  set(hgiserr,''string'',['' '',Message]); return; end;',...
	'  FName=FNames(1,:); PlaneNo=round(DIM(3)/2); vp_fimage;',...
    '  set(hplane,''string'',PlaneNo); ',...
	'  figure(gisAgui); eval(cbtext); axis off;',...
	'  if isempty(Message), IdentAtlas=1; PlaneNo=max(PlaneNo-1,1); Message=FName; end;',...
	'  if strcmp(Message,''Maximum Plane Reached''), IdentAtlas=1; end; ',...
	'  set(hgiserr,''string'',['' '',Message]); end;'];
	
uicontrol(gisAgui,'string', 'GIS FILE',...
	'TooltipString','Select SSM GIS File (Region Names vs. Weight)',...
	'position',[10 238 80 25],'BackgroundColor',Bcolor,'callback',pcbgis);
	

%uicontrol(gisAgui,'string', 'BGRND IMAGE',...
%	'TooltipString','Pick Background Image file (MRI).',...
%	'position',[140 238 100 25],'BackgroundColor',Bcolor,'callback',pcbgrnd);
	
uicontrol(gisAgui,'string', 'ATLAS IMAGE',...
	'TooltipString','Select ATLAS image corresponding to GIS file',...
	'position',[10 213 100 25],'BackgroundColor',Bcolor,'callback',pcatlas);
	
	
pcbplanedn=['Message=Message0; PlaneNo=PlaneNo-1; vp_fimage;',...
	'if isempty(Message), PlaneNo=max(PlaneNo-1,1); Message=Message0; end;',...
	'set(hplane,''string'',PlaneNo); ',...
	'set(hgiserr,''string'',[''MSG:'',Message]);'];

pcbplaneup=['Message=Message0; PlaneNo=PlaneNo+1; vp_fimage;',...
	'if isempty(Message), PlaneNo=max(PlaneNo-1,1); Message=Message0; end;',...
	'set(hplane,''string'',PlaneNo); ',...
	'set(hgiserr,''string'',[''MSG:'',Message]);'];

%	'set(hgiserr,''string'',[''MSG:'',Message]);'];

uicontrol(gisAgui,'string', '<<VIEW',...
	'TooltipString','Decrease Plane No. for viewing only.',...
	'position',[106 142 50 20],'BackgroundColor',Bcolor,'callback',pcbplanedn);

uicontrol(gisAgui,'string', 'PLANE>>',...
	'TooltipString','Increment Plane for viewing only.',...
	'position',[155 142 50 20],'BackgroundColor',Bcolor,'callback',pcbplaneup);

cbplane=['PlaneNo=str2num(get(hplane,''string'')); Message=Message0;',...
	'vp_fimage;',...
	'if isempty(Message), PlaneNo=max(PlaneNo-1,1); Message=Message0; end;',...
	'set(hplane,''string'',PlaneNo); ',...
	'set(hgiserr,''string'',[''MSG:'',Message]);'];

hplane=uicontrol(gisAgui,'style','edit','string',PlaneNo,...
	'TooltipString','Key in Plane for viewing only.',...
	'position',[205 142 35 20],'BackgroundColor',Kcolor,'callback',cbplane);

%%	'if ~IdentBgrnd, set(hgiserr,''string'',''ERR: Background Not Defined''); return; end; ',...
%%
uicontrol(gisAgui,'String','PROCESS Image',...
	'TooltipString','Initiate Processing Map GIS Weights to Atlas Regions.',...
	'Position',[10 35 110 25],...
	'CallBack',[ 'if ~IdentAtlas, set(hgiserr,''string'',''ERR: ATLAS Not Defined''); return; end; ',...
	'if ~IdentGIS, set(hgiserr,''string'',''ERR: GIS Not Defined''); return; end; ',...
	'eval(cbmapgis);',...
	'vp_fimage;',...
	'if isempty(Message), PlaneNo=max(PlaneNo-1,1);',...
	'set(hplane,''string'',PlaneNo); PlaneNo0=PlaneNo; ',...
	'else set(hgiserr,''string'',[''MSG: '',Message]);',...
	' end;'] );

	
uicontrol(gisAgui,'String','QUIT',...
	'TooltipString','Quit and exit.',...
	'Position',[180 35 60 25],...
	'CallBack',['delete(gisAgui);','delete(FI);']);
%	'CallBack',['set(gisAgui,''UserData'',1); ', 'delete(gisAgui)']);

hgiserr = uicontrol(gisAgui,'string', ['MSG : ',Message],...
	'TooltipString','Image error or message field',...
	'position',[10 10 230 25],...
	'CallBack',['set(hgiserr,''string'',[''MSG: '',Message]);'],...
	'BackgroundColor',Ecolor);




