function [out1, out2, Message]=vp_VOIfun(action,in1,in2,in3,in4)
%_______________________________________________________________________
% vp_VOIfun.m  		4.7.7 Phoebe Spetsieris  Feb. 27, 2002
%			Rev. ScAnVP 5.4 Dec. 23, 2004
%			Rev. ScAnVP 6.3 Jan. 02, 2014
%
% FORMAT function [out1, out2, Message]=vp_VOIfun(action,in1,in2,in3,in4)
%
% Volume of Interest value image functions
%	For cubic and spherical regions values returned are averages
%	over all non-zero points. The voxel coordinates and the value 
%	at each voxel are noted in the command window as well at the
%	min, max range within the volume evaluated at each point.
%
% Opens and closes files,
% Reads Point coordinate files
% calls write routines and saves data
%
% action: 'readPNT', Reads a text file listing point coordinates 
%	in1=filename
%	out1=no of points, out2=x y z coordinate list
%
% action: 'PNTvalues', Extracts file point values at given points
%	in1=pntxyzmm (array of normalized coordinates)
%	in2=array of image file names.
%	in3=region type 0=point, 1=cubic, 2=spherical.
%	in4=radius in mm.
%	out1=status, out2= array of (file no.) (point no.) value 
%
% action: 'savePNTS', Saves Output Values and Input data in Text File
%  in1= array of (file no.), (point no.), value 
%  in2=array of image file names.
%  in3=pntxyzmm (array of normalized coordinates)
%  in4= Title Line of Saved Text
%  out1=status
%

global Message
global VOX ORIGIN DIM MATYPE SCALE

out1=0; out2=[];

if strcmp(action,'readPNT') 
  fp = fopen(in1,'rt');
  if fp <= 0, vp_message(['READ PNT File: fopen error']); out1=fp; return; end;
  
  dumpstr=fscanf(fp,'%s',1);
  while(~strcmp(dumpstr,'NPnts:')),dumpstr=fscanf(fp,'%s',1);
	  if isempty(dumpstr), 
  		vp_note(['Invalid File: ''NPnts'' not found'],2); fclose(fp); out1=-1;
		break;
	  end;
  end;
  if out1 < 0, return, end;
  npnts=fscanf(fp,'%d',1), 
  if isempty(npnts),
  	vp_note(['Invalid File ERROR: cannot read No. Pnts'],2); fclose(fp); out1=-1;
  return; end;
  
  out2=[]; xi=0; yi=0; zi=0;
  for i=1:npnts
	dumpnum=[];
	while isempty(dumpnum)
	 for k=1:3
	  if k==1, xi=xi+1; end;
	  if k==2, yi=yi+1; end;
	  if k==3, zi=zi+1; end;
  	  dumpstr=fscanf(fp,'%s',1);
	  if isempty(dumpstr), 
  	    vp_message(['READ PNT File: read error ' num2str(k)]); fclose(fp); out1=-1;
	  return; end;
	  dumpnum=str2num(dumpstr);
	  if k==1, xi=dumpnum; end;
	  if k==2, yi=dumpnum; end;
	  if k==3, zi=dumpnum; end;
	  out2(i,:)=[xi yi zi];
	 end
	end;
  end
  
  fclose(fp);
  out1=1; Message=['PNT Coordinate File read'];
  
elseif strcmp(action,'PNTvalues') 
	npnts=size(in1,1);
	if npnts <=0,  out1=-1;
	 vp_note(['VOIfun ERROR; Invalid Point Coordinates' ],2); return; 
	end
	nfiles=size(in2,1),
	if nfiles <=0,  out1=-1;
	 vp_note(['VOIfun ERROR; Invalid File Names' ],2); return; 
	end
	xyzmm=in1; fnames=in2,
	regtype=in3,
	if regtype ~= 0, radius=in4, end;
	if (regtype > 2 | regtype < 0), vp_message('Invalid Region Type'); return; end;

   	h=waitbar(0,['Processing ']);
   
	for nf=1:nfiles
	  xyzvox=[]; % repeat in case files have different dimensions 
	  nf, fname=deblank(fnames(nf,:)),
	  vp_hread(fname);
	  for j=1:3, if ORIGIN(j) <=0, ORIGIN(j)=1; end; end;
	  for j=1:3, xyzvox(:,j)=(xyzmm(:,j)/VOX(j) + ORIGIN(j)); end;
	  rxyzvox=round(xyzvox),
	  if in3 == 0,
	    for j=1:3,
	     if ( min(rxyzvox(:,j)) < 1 | max(rxyzvox(:,j)) > DIM(j) )  
	     vp_note(['Pt outside range for dim ',num2str(j),' file ',num2str(nf)],2),
	     out1=-1;
	     return; end;
	    end;
	  end
	  [fid,Message] = fopen(fname,'r');
	  if (fid ~= -1 )
	    xyzdata=[];
 
	    xyzdata= fread(fid,inf,MATYPE);

	    fclose(fid);
	    xyzdata = SCALE*xyzdata;
	    
	    nvoxs=DIM(1)*DIM(2)*DIM(3);
	    %length(xyzdata),
	    if nvoxs ~= length(xyzdata),
	   	vp_note(['Dimension discrepency nvoxs: ',num2str(length(xyzdata)),' file ',num2str(nf)],3),
	    end
	  else
	    vp_message(Message);
	    out1=-1;
	    return;
	  end

	  plnarea=DIM(1)*DIM(2);
	  
	  if in3 ~= 0
	    xrad=in4/VOX(1),
	    yrad=in4/VOX(2),
	    zrad=in4/VOX(3),
	  
	    for np=1:npnts
  	      waitbar((nf-1+ np/npnts)/nfiles,h,['Processing File: ',num2str(nf)]);
	      xv=xyzvox(np,1); yv=xyzvox(np,2); zv=xyzvox(np,3);
	      % check bounds
	      rnd=0.001 ; %mm
	      rndx=rnd/VOX(1); %voxx
	      rndy=rnd/VOX(2); %voxy
	      rndz=rnd/VOX(3); %voxz
	      zmin=ceil(zv-zrad-rndz); zmax=floor(zv+zrad+rndz);
	      zmin=max(1,zmin); zmax=min(zmax,DIM(3));
	      if ( (zmin <= zv+zrad) & (zv > 0) & (zv <= DIM(3)+rndz))
	      	xmin=ceil(xv-xrad-rndx); xmax=floor(xv+xrad+rndx);
	        xmin=max(1,xmin); xmax=min(xmax,DIM(1));
	      	%if ((xv >= xmin) & (xv <= xmax) & (xv > 0) & (xv <= DIM(1)))
	        if ( (xmin <= xv+xrad) & (xv > 0) & (xv <= DIM(1)+rndx))
	      	  ymin=ceil(yv-yrad-rndy); ymax=floor(yv+yrad+rndy);
	          ymin=max(1,ymin), ymax=min(ymax,DIM(2)),
	      	  %if ((yv >= ymin) & (yv <= ymax) & (yv > 0) & (yv <= DIM(2)))
	          if ( (ymin <= yv+yrad) & (yv > 0) & (yv <= DIM(2)+rndy))
		  
		     xv;yv;zv;
		     xyzvals=[]; avgval=0;
		     nonzxyzvals=[]; nonzavgval=0; % excluding zeros
		     minval=0; maxval=0; nonznvals=0; % excluding zeros
	             for z= zmin:zmax
	               for x=xmin:xmax
		        for y=ymin:ymax
	    		  nvox=(z-1)*plnarea+ (y-1)*DIM(1) + x;
	    		  nvox=uint32(nvox);
	   	          if ((nvox < 1) | (nvox > nvoxs)),
	     			vp_note(['Invalid vox ',num2str(nvox),' Point ',num2str(np)]),
			  else
			    if ( (in3==2) & ( sqrt( ((x-xv)*VOX(1)).^2 + ((y-yv)*VOX(2)).^2 + ((z-zv)*VOX(3)).^2 ) >= (in4+rnd) ) )
			    else
			
				xmm=VOX(1)*(x-ORIGIN(1)); ymm=VOX(2)*(y-ORIGIN(2)); zmm=VOX(3)*(z-ORIGIN(3)); 
	    		    	xyzvals=[xyzvals ; [x y z xmm ymm zmm xyzdata(nvox)]];
			    	avgval=avgval+xyzdata(nvox) ;
				if xyzdata(nvox) ~= 0
				  nonznvals=nonznvals+1;
	    		    	  nonzxyzvals=[nonzxyzvals ; [x y z xyzdata(nvox)]];
			    	  nonzavgval=nonzavgval+xyzdata(nvox) ;
				  if nonznvals==1, minval=xyzdata(nvox); maxval=minval;
				  else
				    if xyzdata(nvox) < minval, minval=xyzdata(nvox); end;
				    if xyzdata(nvox) > maxval, maxval=xyzdata(nvox); end;
				  end;
				end
			    end
	   	          end
		        end %for y
		       end %for x
	             end %for z
		     disp(['File ',num2str(nf),' Point ',num2str(np)]); 
		     disp(' VoxelX    VoxelY     VoxelZ     Xmm     Ymm     Zmm     Value'); 
		     xyzvals,
		     nvals=size(xyzvals,1);
		     if nvals ~= 0,
		     	avgval=avgval/nvals,
		     end
		     %nonznvals=size(nonzxyzvals,1);
		     if nonznvals ~= 0,
		     disp(['File ',num2str(nf),' Point ',num2str(np)]); 
			nonzavgval=nonzavgval/nonznvals;
			disp(['Non Zero Average for ',num2str(nonznvals),' voxels: ',num2str(nonzavgval)]);
			disp(['Non Zero (Min, Max) range: (',num2str(minval),', ',num2str(maxval),')']);
		     end
			
	    	     out2=[out2 ; [nf np nonzavgval]];
		   
	      	  else % out of range
		     vp_message(['yv = ',num2str(yv),' Out of Range ']);
		     %vp_message(['yv Out of Range ']);
	             out2=[out2 ; [nf np 0]];
	          end % if yv
	      	  else % out of range
		   vp_message(['xv = ',num2str(xv),' Out of Range ']);
		   %vp_message(['xv Out of Range ']);
	           out2=[out2 ; [nf np 0]];
	        end % if xv
	      	else % out of range
		 vp_message(['zv = ',num2str(zv),' Out of Range ']);
	         out2=[out2 ; [nf np 0]];
	      end % if zv
	    end %for np
	    
	  else % Nearest Point
	   for np=1:npnts
	    
	    % get the value of the nearest voxel
	    
	    xv=rxyzvox(np,1), yv=rxyzvox(np,2), zv=rxyzvox(np,3),
	    
	    nvox=(zv-1)*plnarea+ (yv-1)*DIM(1) + xv;
	    nvox=uint32(nvox);
	    
	    out2=[out2 ; [nf np xyzdata(nvox)]];
	  
	   end %for np
	  end
	end %for nf
        waitbar(1,h); pause(1); close(h);
	
        out1=1;
	if in3==0,
	 Message=['Nearest Point values evaluated'];
	elseif in3==1,
	 Message=['Average values within cube R=',num2str(radius),'mm. evaluated.'];
	elseif in3==2,
	 Message=['Average values within sphere R=',num2str(radius),'mm. evaluated.'];
	else
	 Message=['Invalid Type: ',num2str(in3)];
	end
	
elseif strcmp(action,'savePNTS') 
	if nargin < 2, vp_note('No Values Entered'); return; end;
	if isempty(in1), vp_note('No Values Entered'); return; end;
	len=size(in1,1);
	if nargin > 2, filenm=[vp_nm('nm',in2(1,:)),'_',num2str(len),'Pnts.txt'],
	else filenm=['VOI_',num2str(len),'Pnts.txt']; end;
	[out1, out2, Message]=vp_VOIfun('openPNT',filenm);
	if out1 <= 0, return; end;
	if nargin > 4, fprintf(out1,'%s\n',in4); end;
	if nargin > 2,
	  fprintf(out1,' --------------------------------------------------------------------------------\n')
	  fprintf(out1,' File#   Point#    Value               File Name\n\n')
	else
	  fprintf(out1,' --------------------------------------------------------\n')
	  fprintf(out1,' File#   Point#    Value   \n\n')
	end
	for i=1:len
	  if nargin > 2
	    j=round(in1(i,1));
	    fprintf(out1,'%4d %7d %13.4f       %s\n',round(in1(i,1)),round(in1(i,2)),in1(i,3),in2(j,:));
	  else
	    fprintf(out1,'%4d %7d %13.4f\n',round(in1(i,1)),round(in1(i,2)),in1(i,3));
	  end
	end
	if nargin > 2,
	  fprintf(out1,'\n');
	  fprintf(out1,'  File Names\n');
	  len=size(in2,1);
	  for i=1:len
	    fprintf(out1,'%4d  %s\n',i,in2(i,:));
	  end
	end;
	if nargin > 3,
	  fprintf(out1,'\n');
	  fprintf(out1,'  Point Coordinates (mm)\n');
	  fprintf(out1,'  No.    Xmm      Ymm      Zmm\n');
	  len=size(in3,1);
	  for i=1:len
	    fprintf(out1,'%4d %8.2f %8.2f %8.2f\n',i,in3(i,1),in3(i,2),in3(i,3));
	  end
	end;
	[o1 o2]=vp_VOIfun('close',out1);
	if o1 < 0, out1=o1, end;
  
	
elseif strcmp(action,'openPNT') 
	q=max([find(in1=='.') 0]);
	PNTfnm=[in1(1:q-1) '_VAL.txt'],
	out1 = fopen(PNTfnm,'wt');
	Message=['Txt file: ',PNTfnm];
	if out1 <=0, vp_message(['PNT Value Save File: fopen error']); return; end;
	
elseif strcmp(action,'close') 
	out1 = fclose(in1) ;
	if out1 ~= 0, vp_message(['VOIfun: fclose error']); return; end;
	
else 
  vp_note(['Invalid VOIfun Option: ',action],2); return; 
    
end
