% vp_append
% APPEND ANALYZE Format image
%_______________________________________________________________________
%
% vp_append allows the user to combine multiple ANALYZE format images.
% into one by rescaling and appending each in succession. The total number
% of axial planes is the sum of the planes of all the component images.
%_______________________________________________________________________
% vp_append 	ScAnVP	C.0	P. Spetsieris	5/25/99
%		rev. 5.2	P.S. 11/18/03

global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN
global EXPTIM DURATION MATYPE GENTIM SUBID EXPDATE
global HelpMode FMenu NameLst Message

if HelpMode, vp_help(mfilename), return ; end;

if vp_filesui(Inf,'.img','Select images to APPEND',mfilename) < 0 ,return; end;

set(FMenu,'Pointer','Watch');
m= size(NameLst,1);
dim3=0;

h=waitbar(0,'Processing APPEND ...');
waitbar(.2,h);

for i=1:m
  FName=deblank(NameLst(i,:));
  %P=strtok(FName,'.');
  P=vp_nm('dnm',FName);
  
  vp_hread([P '.hdr']);
  
  if i > 1
    if ~isequal(VOX,vox1)
	vox1,
	VOX,
  	vp_note('ERROR: Incompatible Voxel sizes');
	set(FMenu,'Pointer','Arrow');
	return;
    end
  
    if ~isequal(DIM(1:2), dim1)
	dim1,
	DIM(1:2),
  	vp_note('ERROR: Incompatible Planar Dimensions');
	set(FMenu,'Pointer','Arrow');
	return;
    end
  
    if(TYPE ~= typ1)
	typ1,
	TYPE,
  	vp_note(['ERROR: Different TYPES']);
	set(FMenu,'Pointer','Arrow');
	return;
    end
    
    if(GLMAX > glmax0),
    	glmax0=GLMAX;
    end
    
    if(GLMIN < glmin0),
    	glmin0=GLMIN;
    end
    
  else
    vox1=VOX;
    dim1=DIM(1:2);
    typ1=TYPE;
    glmax0=GLMAX;
    glmin0=GLMIN;
  end
  
  scale(i)=SCALE;
  dim3=dim3+DIM(3);

  disp(' ');
end

scale,

maxscale=max(scale);

PlaneNo=1;

FName=deblank(NameLst(1,:));
%P=strtok(FName,'.');
%P=P(1:max([findstr(P,'\') 0]));
P=vp_nm('dir',FName);

nameimg=[P 'APPEND' '.img'];
fidapp=fopen(nameimg,'w');

for i=1:m

  	waitbar((i-1)/m,h);

  	FName=deblank(NameLst(i,:));
  	%P=strtok(FName,'.');
	P=vp_nm('dnm',FName);
	
  	%[DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN EXPTIM DURATION MATYPE] =...
	 %vp_hread([P '.hdr']),
       
	vp_hread([P '.hdr']);
	name=[P '.img'];
  
	%ImageSize=DIM(1)*DIM(2);

	DATA=[];
	%DATA=zeros(DIM(1),DIM(2));
	
	fid=fopen(name,'r');
 
	%for PlaneNo=1:DIM(3)
  	 % fseek(fid,ImageSize*(PlaneNo-1),'bof');

	  %DATA	= fread(fid,[DIM(1),DIM(2)],'uchar');
	
	  DATA	= fread(fid,MATYPE);
	  if SCALE ~= maxscale
		DATA=DATA*(SCALE/maxscale);
	  end
	  %out1=fwrite(fidapp,DATA,'uchar');
	  out1=fwrite(fidapp,DATA,MATYPE);
	%end
	
	fclose(fid);

end

fclose(fidapp);
waitbar(1,h); pause(1); close(h);

SCALE=maxscale;
DIM(3)=dim3;
DESCRIP=['ScAnVP APPENDED - ' DESCRIP];


Bcolor = [.8,1,1];

progui = figure('Color',Bcolor,'Name','APPEND',...
'NumberTitle','off','Position',[100,200,350,60],...
'Units','Pixels');
	

%'vp_hwrite(name,DIM,VOX,SCALE,TYPE,OFFSET,ORIGIN,DESCRIP);',
%cbFName=['name=get(hrname,''string''),',...
%	'name=deblank(name); namehdr=[strtok(name,''.'') ''.hdr''];',...
%	'vp_hwrite(name,DIM,VOX,SCALE,TYPE,OFFSET,ORIGIN,DESCRIP,',...
%	'glmax0,glmin0,EXPTIM,DURATION,GENTIM,SUBID,EXPDATE);',...
%	'name=[strtok(name,''.'') ''.img'']; if ~strcmp(name,nameimg),',...
%	'dos([''move '' nameimg '' '' name]), end;',...
%	'set(gco,''string'',[nameimg ''   FILE SAVED'']); ',...
%	'disp(''FILE SAVED''); pause(2); delete(progui);'];
	
       
% Save default header before user name read, to keep consistent with image saved.
% Read user name. If not the default name. Warn if only .hdr or .img doesn't exist,
% since if there aren't permissions to overwrite, only the header or image will be
% overwritten and the other will be incorrect.

%cbFName=['staterr=0; namehdr0=[strtok(nameimg,''.'') ''.hdr''];',...
%	  'name=deblank(name); namehdr=[strtok(name,''.'') ''.hdr''];',...
%	  'name=[strtok(name,''.'') ''.img''];',...
%
cbFName=['staterr=0; namehdr0=[vp_nm(''dnm'',nameimg) ''.hdr''];',...
	'if (vp_hwrite(nameimg,DIM,VOX,SCALE,TYPE,OFFSET,ORIGIN,DESCRIP,',...
	'EXPTIM,DURATION,GENTIM,SUBID,EXPDATE,glmax0,glmin0) ) < 0,',...
	'vp_message(''hwrite err''); staterr=1; ',...
	'else, ',...
	  'name=get(hrname,''string''),',...
	  'name=deblank(name); namehdr=[vp_nm(''dnm'',name) ''.hdr''];',...
	  'name=[vp_nm(''dnm'',name) ''.img''];',...
	  'if ~strcmp(name,nameimg),',...
	     'if (exist(name,''file'') & ~exist(namehdr,''file'')) | ',...
	       ' (~exist(name,''file'') & exist(namehdr,''file''))  ',...
	       'vp_message([''Remove Invalid File '' name '' .hdr or .img'']);',...
	       ' staterr=3; ',...
	     'else, [s,dosmsg]=dos([''move '' nameimg '' '' name]), ',...
	       'if s ~=0, vp_message(dosmsg); staterr=2; end; ',...
	       '[s,dosmsg]=dos([''move '' namehdr0 '' '' namehdr]), ',...
	       'if s ~=0, vp_message(dosmsg); staterr=2; end; ',...
	     'end; ',...
	     'if staterr==0,  nameimg=name;  end;',...
	  'end; ',...
	'end;',...
	'if staterr==0,',...
	  'Message=[nameimg ''   FILE SAVED'']; ',...
	  'set(gco,''string'',Message); ',...
	  'set(FMenu,''Pointer'',''Arrow'');',...
	  'disp(Message);',...
	  'vp_note(''Append Files PROCESSING COMPLETE'',2);',...
	  'delete(progui);',...
	' end; '];
	
	
uicontrol(progui,'style','text','string','ENTER NAME: ',...
	'position',[10 25 225 25],'BackgroundColor',Bcolor);
	
hrname=uicontrol(progui,'style','edit','string',nameimg,...
	'position',[10 5 325 25],'BackgroundColor','w','callback',cbFName);


