% vp_colgui.m
% sets color map
%___________________________________________________________________________
%
% The user picks a color map from a button or file selection.
% The colorbar becomes the default map except for invert color
% which is applied to the selected figure to invert it"s map.
% The map is applied to the default figure images, usually 'FI',
% if it exists, otherwise, the user can pick a figure by
% clicking on 'PICK FIGURE' on the menu and then on the figure
% window. The user can also place a colorbar or create a 
% simple colorbar image to view the colors.
% A separate option is provided to change the background screen
% color of the figure.
%__________________________________________________________________________
% vp_colgui.m	ScAnVP C.0  P. Spetsieris	Jan 5, 1999
% 	        Rev. 6.2 			Oct 11, 2011	

global HelpMode hpFig GCM CM FI UFI Ecolor

if HelpMode, vp_help('vp_colgui'), return ; end;

Message0=['............................................ '];
Message=Message0;

Fcolor = [.8,.8,.9];
Bcolor = [.9,.8,.9];

if ~exist('UFI') | (exist('UFI') & UFI==0 ) 
 if ~exist('FI') | (exist('FI') & isempty(FI) ) 
	CFI=figure('Position',[370,150,5,256],...
	'Units','Pixels');
	data=[];
	for i=0:255, data(256-i)=i; end;
	data = data';
	imagesc(data,[0 255]);
	axis off;
 else CFI=FI; end;
else CFI=UFI;
end

colgui=findobj('Name','colgui');
if isempty(colgui)
	colgui = figure('Color','w','Name','colgui',...
	'Color',Fcolor,...
	'NumberTitle','off','Position',[220,50,150,245],...
	'Units','Pixels');
else
 figure(colgui);
 set(hpFig,'string',['PICK FIGURE  (', num2str(CFI), ')']);
 return;
end;
	
 
uicontrol(colgui,'string', 'Help',...
	'TooltipString',HelpMsg,...
	'BackgroundColor',Ecolor,...
	'position',[110 205 35 20],'callback','vp_help(''vp_colgui'');');

uicontrol(colgui,'string', 'EXIT',...
	'TooltipString','CANCEL',...
	'position',[10 205 35 20],'BackgroundColor',Bcolor,...
	'callback',['delete(colgui); if ~exist(''FI''), delete(CFI); end;']);

hpFig=uicontrol(colgui,'string',['PICK FIGURE  (', num2str(CFI), ')'],...
	'position',[10 180 100 20],'BackgroundColor',Bcolor,...
	'TooltipString','Click on a figure to apply a color map',...
	'callback',['waitforbuttonpress; CFI=gcf;',...
	'hpstr=[''PICK FIGURE  ('', num2str(CFI), '')''];',...
	'set(hpFig,''string'',hpstr); ']);

uicontrol(colgui,'string', 'SCREEN COLOR OPTIONS',...
	'TooltipString','Various Screen Color Options',...
	'BackgroundColor',Ecolor,...
	'position',[10 155 135 20],'callback','vp_screengui;');

barcb=	['baropt=get(gco,''Value''); ',...
	'if (baropt==2 | baropt==3), ',...
	['ch=get(CFI,''children''); len=length(ch); for i=1:len,',...
	'if strcmp(get(ch(i),''type''),''axes''), ',...
	'delefcn=get(ch(i),''DeleteFcn''); ',...
	'if ~isempty(delefcn),',... 
	'if strcmp(delefcn(1:8),''colorbar''),  ',...
	'delete(ch(i)); end; end; end; end;'],...
	'end; ',...
	'if baropt==2, ',...
	  'ch=get(CFI,''children''); len=length(ch); ',...
	  'for i=1:len, if strcmp(get(ch(i),''type''),''axes''), ',...
	  'if ~isempty(get(ch(i),''userdata'')), ',...
	  'axes(ch(i)); try colorbar(''v6'',''vert''), catch colorbar vert; end;',...
          ' end; end; end;',...
	'elseif baropt==3, ',...
	  'ch=get(CFI,''children''); len=length(ch); ',...
	  'for i=1:len, if strcmp(get(ch(i),''type''),''axes''), ',...
	  'if ~isempty(get(ch(i),''userdata'')), ',...
	  'axes(ch(i)); try colorbar(''v6'',''horiz''), catch colorbar horiz; end;',...
          ' end; end; end;',...
	'elseif baropt==4, ',...
	  'figure(CFI); vp_colorbar([],1);',...
	'elseif baropt==5, ',...
	  'figure(CFI); vp_colorbar([],2);',...
	'elseif baropt==6, ',...
	  ['CFI=figure(''Position'',[370,150,5,256],',...
	  '''Units'',''Pixels'');',...
	  'data=[];',...
	  'for i=0:255, data(256-i)=i; end;',...
	  'data = data'';',...
	  'imagesc(data,[0 255]);',...
	  'axis off;',...
	  'figure(colgui);',...
	  'set(hpFig,''string'',[''PICK FIGURE  ('', num2str(CFI), '')'']); '],...
	'else, end;'];

%uicontrol(colgui,'string','BAR',...
%	'position',[116 155 29 25],'BackgroundColor',Bcolor,...
%	'TooltipString','Show a colorbar figure',...
%	'callback',...
%	['CFI=figure(''Position'',[370,150,5,256],',...
%	'''Units'',''Pixels'');',...
%	'data=[];',...
%	'for i=0:255, data(256-i)=i; end;',...
%	'data = data'';',...
%	'imagesc(data,[0 255]);',...
%	'axis off;',...
%	'figure(colgui);',...
%	'set(hpFig,''string'',[''PICK FIGURE  ('', num2str(CFI), '')'']);',...
%	' ']);
	
uicontrol(colgui,'string', 'PICK MAP FILE',...
	'position',[10 130 80 20],'BackgroundColor',Bcolor,...
	'TooltipString','Pick the active figure color map from a file.',...
	'callback',['figure(CFI); vp_matcolor; GCM=colormap; ']);
	
uicontrol(colgui,'string', 'SAVE',...
	'position',[90 130 54 20],'BackgroundColor',Bcolor,...
	'TooltipString','Save the active figure color map in a file.',...
	'callback',['figure(CFI); CM=colormap;',...
	'name=vp_keyin(''Enter Map Name: '',''usermap'');',...
	'if ~isempty(name), w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''\col\'',name],',...
	'save(cf,''CM''); vp_note([''Saved : '',cf],3); end;' ]);

	%%'CallBack',['figure(CFI); vp_invcol ; GCM=colormap; ']);
        %%
uicontrol(colgui,'String','INVERT COLOR',...
	'Position',[10 107 90 20],...
	'TooltipString','Invert Color Bar',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); vp_invcol ; ']);

uicontrol(colgui,'Style','PopUp',...
	'String','BAR...|Vert Bar|Hori Bar|User Bar|Semi Bar|Bar figure',...
	'TooltipString',['1: Vertical Color Bar(s) ',...
	'|2: Horizontal Color Bar(s) |3: User Bar |4: User Semi Bar |5: BAR figure'],...
	'Position',[100 95 47 32],...
	'BackgroundColor',Bcolor,...
	'CallBack',barcb);
       
uicontrol(colgui,'String','GRAY',...
	'Position',[10 90 45 15],...
	'TooltipString','256 MATLAB Continuous Gray Scale',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\gy256''];',...
	'load(cf); colormap(CM); GCM=colormap; ']);

%	'CallBack',['figure(CFI); colormap(HSV); GCM=colormap; ']);
%
uicontrol(colgui,'String','JETBK',...
	'Position',[55 90 45 15],...
	'TooltipString','MATLAB JET With 0 Value Set BLACK',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\jetbk64''];',...
	'load(cf); colormap(CM); GCM=colormap; ']);

uicontrol(colgui,'String','BONE',...
	'Position',[100 90 45 15],...
	'TooltipString','MATLAB BONE Color Scale',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); colormap(BONE); GCM=colormap; ']);

uicontrol(colgui,'String','HOT',...
	'Position',[10 75 45 15],...
	'TooltipString','256 MATLAB HOT Scale',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\hot256''];',...
	'load(cf); colormap(CM); GCM=colormap; ']);


uicontrol(colgui,'String','JET',...
	'Position',[55 75 45 15],...
	'TooltipString','256 MATLAB JET Scale',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\jet256''];',...
	'load(cf); colormap(CM); GCM=colormap; ']);


uicontrol(colgui,'String','PINK',...
	'Position',[100 75 45 15],...
	'TooltipString','MATLAB PINK Color Scale',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); colormap(PINK); GCM=colormap; ']);

%uicontrol(colgui,'String','COPPER',...
%	'Position',[10 10 45 20],...
%	'BackgroundColor',Bcolor,...
%	'CallBack',['figure(CFI); colormap(COPPER); GCM=colormap; ']);

uicontrol(colgui,'String','GE',...
	'Position',[10 60 45 15],...
	'TooltipString','GE Color Scale Simulation 221 Levels',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\GE''];',...
	'load(cf); colormap(CM); GCM=colormap; ']);

uicontrol(colgui,'String','COL21',...
	'Position',[55 60 45 15],...
	'TooltipString','256 ScAnVP 21 Level Color Scale',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\col21''];',...
	'load(cf); colormap(CM); GCM=colormap; ']);

uicontrol(colgui,'String','TEK21',...
	'Position',[100 60 45 15],...
	'TooltipString','148 ScAnVP Tektronix 21 Level Color Scale',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\tekcol21''];',...
	'load(cf); colormap(CM); GCM=colormap; ']);

uicontrol(colgui,'String','GRAYHOT',...
	'Position',[10 40 67 15],...
	'TooltipString','GRAY and HOT Scale 128 Total Levels',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\grayhot''];',...
	'load(cf); colormap(CM); GCM=colormap; ']);

uicontrol(colgui,'String','GRAYCOOL',...
	'Position',[78 40 67 15],...
	'TooltipString','Two Scale GRAY and COOL 256 Total Levels',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\graycool''];',...
	'load(cf); colormap(CM); GCM=colormap; ']);
	
uicontrol(colgui,'String','GYBICOL',...
	'Position',[10 25 67 15],...
	'TooltipString','Three Scale 256, GY128 + 64Cool and 64Hot',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\graybicol''];',...
	'load(cf); colormap(CM); GCM=colormap; ']);
	
uicontrol(colgui,'String','GYBICOL10',...
	'Position',[78 25 67 15],...
	'TooltipString','Three Scale 256, GY128 + 10 Distinct Cool and Hot Levels',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\graybicol10''];',...
	'load(cf); colormap(CM); GCM=colormap; ']);
	
uicontrol(colgui,'String','GRAYJET',...
	'Position',[10 10 67 15],...
	'TooltipString','Two Scale 256 Total Color Levels',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\grayjet256''];',...
	'load(cf); colormap(CM); GCM=colormap; ']);
	
uicontrol(colgui,'String','GRAYCOLS',...
	'Position',[78 10 67 15],...
	'TooltipString','Two Scale Gray + 21 Color Levels',...
	'BackgroundColor',Bcolor,...
	'CallBack',['figure(CFI); w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\graycols256''];',...
	'load(cf); colormap(CM); GCM=colormap; ']);
