       
%function [out1]=vp_colorbar(pos,opt,datamin,datamax,threshmin,threshmax)
%___________________________________________________________
% vp_colorbar.m	ScAnVP 5.3	P.Spetsieris  April 27, 2004
%
% Draws a full (opt=1) or upper half (opt=2) colorbar given
% an option for determining its size and position and
% the data range and threshold limits.
% If pos is empty it allows the user to determine position.
% If pos=1: medium, lower right, pos=2: small far right.
% If pos is given it places bar at the given position.
% Datamin, datamax corresponds to the background and any stored
% data values up to the maximum statistical value. For opt=2,
% the lower half of the full range (datamin, datamax) corresponds
% to the background image and the upper half includes the data range.
%___________________________________________________________

function [out1]=vp_colorbar(pos,opt,datamin,datamax,threshmin,threshmax)

   global DATAMIN DATAMAX

   dispthresh=0;
   if nargin < 1
     pos=[]; opt=1; datamin=DATAMIN; datamax=DATAMAX;
     threshmin=datamin; threshmax=datamax; 
   elseif nargin < 2
     opt=1; datamin=DATAMIN; datamax=DATAMAX;
     threshmin=datamin; threshmax=datamax; 
   elseif nargin < 3
     datamin=DATAMIN; datamax=DATAMAX;
     threshmin=datamin; threshmax=datamax; 
   elseif nargin < 4
     datamax=DATAMAX;
     threshmin=datamin; threshmax=datamax; 
   elseif nargin < 5
     threshmin=datamin; threshmax=datamax; 
   elseif nargin < 6
     threshmax=datamax; 
   end
   
   if nargin > 4
     dispthresh=1;
   end

   out1=0;
   
   data=[];
   
   outdelta=datamax-datamin;
   delta=datamax-datamin;
   
   %if datop,
   % outmax=threshmax;
   %else
   % outmax=datamax;
   %end
   
   if opt==2, delta=outdelta/2;
     statmin=datamin+delta;
     if ~dispthresh, threshmin=statmin; end;
   else
     statmin=datamin,
   end
   %statmin=datamax-delta;
   dinc=delta/128;
   
   %for i=1:129, data(i)=outmax-(i-1)*dinc; end;
   for i=1:129, data(i)=datamax-(i-1)*dinc; end;
   data = data';
	
   if isempty(pos)
    a=ver('Matlab'); matver=a.Version; matver=str2num(num2str(matver)),
    if matver < 6.5,
     vp_note(['WARNING: This option may not work for this MATLAB ver. ',num2str(matver)],4);
    end
    vp_note('Define Bar Area With Mouse',2);
    figure(gcf);
    figpos=get(gcf,'position'),
    axes('position',[0 0 1 1]);
    axis off;
    pos=getrect,
    axpos=get(gca,'position'),
    axdim(1)=axpos(1)*figpos(3);
    axdim(2)=axpos(2)*figpos(4);
    axdim(3)=axpos(3)*figpos(3);
    axdim(4)=axpos(4)*figpos(4);
    axdim,
    barx=pos(1);
    bary=pos(2);
    barwidth=pos(3);
    barheight=pos(4);
   elseif pos==1,
    barx=0.75;
    bary=0.11;
    barwidth=.04;
    barheight=.30;
   elseif pos==2,
    barx=0.82;
    bary=0.015;
    barwidth=.03;
    barheight=.18;
   else
    barx=pos(1);
    bary=pos(2);
    barwidth=pos(3);
    barheight=pos(4);
   end
   
   rect=[barx, bary, barwidth, barheight],
   axes('position',rect);
   imagesc(data,[datamin datamax]);
   %imagesc(data,[datamin outmax]);
   
   axis off;
	
   %NoStr=['Max ', num2str(datamax)];
   %[t,r]=strtok(NoStr,'.');
   %if ~isempty(r), r=r(1:min(3,length(r))); NoStr=[t,r]; end;
   %if pos==1,
    % axes('position',[.80, (bary + barheight) , .20, .02]);
   %else,
    % axes('position',[.85, (bary + barheight) , .08, .006]);
   %end
   %text(0,0,NoStr,'Color',[1.0 1.0 1.0]);
   %axis off;
   
   if dispthresh
     NoStr=['ThMax ', num2str(threshmax)];
   else
     NoStr=['Max ', num2str(datamax)];
   end
   
   [t,r]=strtok(NoStr,'.');
   if ~isempty(r), r=r(1:min(3,length(r))); NoStr=[t,r]; end;
   if pos==1,
        axes('position',[.80, (bary + ((threshmax-statmin)/delta)*barheight) , .20, .02]);
   elseif pos==2,
        axes('position',[.85, (bary + ((threshmax-statmin)/delta)*barheight) , .08, .006]);
        % axes('position',[.85, (bary + (threshold/datamax)*barheight) , .08, .006]);
   else,
        axes('position',[barx+barwidth+.01, (bary + ((threshmax-statmin)/delta)*barheight) , .08, .006]);
   end
   
   %text(0,0,NoStr,'Color',[1.0 1.0 1.0]);
   text(0,0,NoStr,'Color',[1.0 1.0 1.0],'FontWeight','Bold','FontSize',16);
   axis off;
  
   if dispthresh
     NoStr=['ThMin ', num2str(threshmin)];
   else
     if opt==1
       NoStr=['Min ', num2str(datamin)];
     else
       NoStr=[num2str(statmin)];
     end
   end
   
   [t,r]=strtok(NoStr,'.');
   if ~isempty(r), r=r(1:min(3,length(r))); NoStr=[t,r]; end;
   if pos==1,
        axes('position',[.80, (bary + ((threshmin-statmin)/delta)*barheight) , .20, .02]);
   elseif pos==2,
        axes('position',[.85, (bary + ((threshmin-statmin)/delta)*barheight) , .08, .006]);
        % axes('position',[.85, (bary + (threshold/datamax)*barheight) , .08, .006]);
   else,
        axes('position',[barx+barwidth+.01, (bary + ((threshmin-statmin)/delta)*barheight) , .08, .006]);
   end
   
   %text(0,0,NoStr,'Color',[1.0 1.0 1.0]);
   text(0,0,NoStr,'Color',[1.0 1.0 1.0],'FontWeight','Bold','FontSize',16);
   axis off;
  
   %w=which('scanvp');
   %cf=[w(1:(max(findstr(w,'\'))-4)),'col\graycols'];
   %load(cf); colormap(graycols); GCM=colormap;

   drawnow;
   
