% vp_colrange.m
% Set colormap range limits and apply to handle
%
% The user can manipulate the upper and lower color
% thresholds of a colormap and apply to the active
% data figure (usually FI). The full data range is
% determined from the global DATAMIN DATAMAX values
% corresponding to the last image displayed. These
% values can be overiden by the user. The thresholding
% operation will normalize all images in the display
% to one common scale. The user must move the sliders
% to insure that the operation takes place.
% If SET Range is clicked the active DATAMIN, DATAMAX
% globals are displayed. If color bars are present, 
% they must be reset to correspond to a new range.
%
%__________________________________________________________________________
% vp_colrange.m	 C.0 	P. Spetsieris	 June 8, 1999
%	 	 Revision 5.1 by P.S. 5/22/03
%	 	 Revision 6.1 by P.S. 5/23/11


global HelpMode HelpMsg Ecolor 
global UFI ThreshMax ThreshMin Message hslider hmaxslider hminslider 
global rangegui hThreshMin hThreshMax hclaxis hims RaScl hthmax hthmin
global DATAMIN DATAMAX SCALE GLMIN GLMAX hdatamax hdatamin
global CMin CMax

if HelpMode, vp_help(mfilename), return ; end;

ThreshMin=0;
ThreshMax=100;
%hin1=gca;

if ~exist('DATAMIN'),DATAMIN=SCALE*GLMIN; end;
if ~exist('DATAMAX'),DATAMAX=SCALE*GLMAX; end;

cbscale=['if DATAMAX<=DATAMIN, vp_message(''DATAMAX<=DATAMIN''); return; end;',...
	'RaScl=100.0/(DATAMAX-DATAMIN);'];
	
eval(cbscale);	

setcaxis=['CMin=DATAMIN+ThreshMin/RaScl; CMax=DATAMIN+ThreshMax/RaScl;'];

%cbmax=['max=str2num(get(gco,''string'')), if (max-DATAMIN) ~=0, DATAMAX=max, RaScl=100/(max-DATAMIN); end;'];
%cbmin=['min=str2num(get(gco,''string'')), if (DATAMAX-min) ~=0, DATAMIN=min, RaScl=100/(DATAMAX-min); end;'];
%cbmax=['max=str2num(get(gco,''string'')), if max > DATAMIN, DATAMAX=max;',...
%' else, vp_message(''DATAMAX < DATAMIN''); end;',...
%' delete(gcbf); vp_colrange; '];
%cbmin=['min=str2num(get(gco,''string'')), if DATAMAX > min, DATAMIN=min;',...
%' else, vp_message(''DATAMIN > DATAMAX''); end;',...
%' delete(gcbf); vp_colrange; '];
cbmax=['DATAMAX=str2num(get(gco,''string'')), delete(gcbf); vp_colrange; '];
cbmin=['DATAMIN=str2num(get(gco,''string'')), delete(gcbf); vp_colrange; '];
cbdatamax=['set(hdatamax,''string'',num2str(DATAMAX))'];
cbdatamin=['set(hdatamin,''string'',num2str(DATAMIN))'];

if ~exist('UFI') 
	UFI=gcbf;
end


%FI=gcbf;
ch=get(UFI,'children');
len=length(ch);

if len==0, msg=['Valid Data Image - Not Found']; vp_message(msg); return; end;

axcb=['hims=[];',...
'for i=1:len, if strcmp(get(ch(i),''type''),''axes''),hims=[hims,ch(i)]; end; end;'];


cbreset=['resetopt=get(gco,''Value''); ',...
	'if resetopt == 2, ',...
	'delete(gcbf); vp_colrange ; end;',...
	'if resetopt > 2, ',...
	['ch=get(UFI,''children''); len=length(ch); for i=1:len,',...
	'if strcmp(get(ch(i),''type''),''axes''), ',...
	'delefcn=get(ch(i),''DeleteFcn''); ',...
	'if ~isempty(delefcn),',... 
	'if strcmp(delefcn(1:8),''colorbar''),  ',...
	'delete(ch(i)); end; end; end; end;'],...
	'end; ',...
	'if resetopt==3, ',...
	  'ch=get(UFI,''children''); len=length(ch); ',...
	  'for i=1:len, if strcmp(get(ch(i),''type''),''axes''), ',...
	  'if ~isempty(get(ch(i),''userdata'')), ',...
	  'axes(ch(i)); try colorbar(''v6'',''vert''); catch colorbar vert; end;',...
	  ' end; end; end;',...
	'elseif resetopt==4, ',...
	  'ch=get(UFI,''children''); len=length(ch); ',...
	  'for i=1:len, if strcmp(get(ch(i),''type''),''axes''), ',...
	  'if ~isempty(get(ch(i),''userdata'')), ',...
	  'axes(ch(i)); try colorbar(''v6'',''horiz''); catch colorbar horiz; end;',...
	  ' end; end; end;',...
	'else, end;'];
	

rangegui=findobj('Name','rangegui');
if ~isempty(rangegui)
	if(strcmp(get(rangegui,'Visible'),'on'))
		figure(rangegui);
		set(rangegui,'colormap',get(UFI,'colormap'));
	end
	return
end

frmcolor=[0.5 0.7 0.8];
Bcolor = [.8,1,1];

figwid=120; fighgt=300;
rangegui = figure('Color',frmcolor,'Name','rangegui',...
'NumberTitle','off','Position',[100,300,figwid,fighgt],...
'colormap',get(UFI,'colormap'),...
'Units','Pixels');

%cbnorm=['set(rangegui,''colormap'',get(UFI,''colormap''));',...
%	'ThreshMin=0; ThreshMax=100; ',...
%	'set(hThreshMin,''string'',ThreshMin);',...
%	'set(hminslider,''Value'',ThreshMin);',...
%	'set(hThreshMax,''string'',ThreshMax);',...
%	'set(hmaxslider,''Value'',ThreshMax);',...
%	'set(hslider,''Value'',(ThreshMax+ThreshMin)/2);',...
%	'set(hthmax,''String'',sprintf(''%.6f'',DATAMIN+ThreshMax/RaScl));',...
%	'set(hthmin,''String'',sprintf(''%.6f'',DATAMIN+ThreshMin/RaScl));',...
%	'figure(rangegui); axes(hclaxis); caxis([DATAMIN+ThreshMin/RaScl DATAMIN+ThreshMax/RaScl]);',...
%	'set(hthmin,''String'',sprintf(''%.6f'',DATAMIN+ThreshMin/RaScl));',...
%	'figure(UFI); eval(axcb); for i=1:length(hims); axes(hims(i)); caxis([DATAMIN+ThreshMin/RaScl DATAMIN+ThreshMax/RaScl]); end;',...
%	'set(hminslider,''Value'',ThreshMin);'];
	
uicontrol(rangegui,'string', 'Help',...
	'TooltipString',HelpMsg,...
	'BackgroundColor',Ecolor,...
	'units','normalized',...
	'position',[85/figwid 282/fighgt 29/figwid 15/fighgt],'callback','vp_help(''vp_colrange'');');
	
uicontrol(rangegui,'Style','text','string', 'MAX  ',...
	'units','normalized',...
	'position',[10/figwid 265/fighgt 25/figwid 15/fighgt],'BackgroundColor',frmcolor);
	
hdatamax=uicontrol(rangegui,'Style','edit','string', [sprintf('%.6f',DATAMAX)],...
	'TooltipString','set DATAMAX',...
	'units','normalized',...
	'position',[35/figwid 265/fighgt 82/figwid 15/fighgt],'callback',cbmax);
	
uicontrol(rangegui,'Style','text','string', '%RANGE',...
	'TooltipString','%Color Threshold Range',...
	'units','normalized',...
	'position',[10/figwid 250/fighgt 60/figwid 15/fighgt],'BackgroundColor',frmcolor);
	
uicontrol(rangegui,'Style','text','string', 'MIN  ',...
	'units','normalized',...
	'position',[10/figwid 20/fighgt 25/figwid 15/fighgt],'BackgroundColor',frmcolor);
	
hdatamin=uicontrol(rangegui,'Style','edit','string', [sprintf('%.6f',DATAMIN)],...
	'TooltipString','set DATAMIN',...
	'units','normalized',...
	'position',[35/figwid 22/fighgt 82/figwid 15/fighgt],'callback',cbmin);
	
hthmax=uicontrol(rangegui,'Style','text','string', sprintf('%.6f',DATAMAX),...
	'TooltipString','Threshold Data Maximum',...
	'units','normalized',...
	'position',[70/figwid 238/fighgt 50/figwid 15/fighgt],'BackgroundColor',frmcolor);
	
hthmin=uicontrol(rangegui,'Style','text','string', sprintf('%.6f',DATAMIN),...
	'TooltipString','Threshold Data Minimum',...
	'units','normalized',...
	'position',[70/figwid 39/fighgt 50/figwid 15/fighgt],'BackgroundColor',frmcolor);
	

cbThreshMin=['set(rangegui,''colormap'',get(UFI,''colormap''));',...
	'eval(cbscale); eval(cbdatamax); eval(cbdatamin); ',...
	'ThreshMin=min([ThreshMax-1 str2num(get(hThreshMin,''string''))]); ',...
	'if(ThreshMin < 0), ThreshMin=0; end; if(ThreshMin > ThreshMax-1); ThreshMin=ThreshMax-1; end;',...
	'set(hThreshMin,''string'',ThreshMin);',...
	'set(hminslider,''Value'',ThreshMin);',...
	'set(hslider,''Value'',(ThreshMax+ThreshMin)/2);',...
	'figure(rangegui); axes(hclaxis); eval(setcaxis); caxis([CMin CMax]);',...
	'set(hthmin,''String'',sprintf(''%.6f'',DATAMIN+ThreshMin/RaScl));',...
	'figure(UFI); eval(axcb); for i=1:length(hims); axes(hims(i)); caxis([CMin CMax]); end;',...
	'set(hminslider,''Value'',ThreshMin);'];


cbSliThreshMin=['set(rangegui,''colormap'',get(UFI,''colormap''));',...
	'eval(cbscale); eval(cbdatamax); eval(cbdatamin); ',...
	'ThreshMin=min([ThreshMax-1 ceil(get(gco,''Value''))]);, set(hThreshMin,''string'',ThreshMin);',...
	'set(hslider,''Value'',(ThreshMax+ThreshMin)/2);',...
	'figure(rangegui); axes(hclaxis); eval(setcaxis); caxis([CMin CMax]);',...
	'set(hthmin,''String'',sprintf(''%.6f'',DATAMIN+ThreshMin/RaScl));',...
	'figure(UFI); eval(axcb); for i=1:length(hims); axes(hims(i)); caxis([CMin CMax]); end; '];
		
hminslider=uicontrol(rangegui,'Style','slider',...
	'Position', [20/figwid 56/fighgt 15/figwid 90/fighgt], 'Min',0,'Max',100,...
	'units','normalized',...
	'TooltipString','Set Threshold % Range Minimum',...
	'Value',ThreshMin,'Callback',cbSliThreshMin);
	
	
cbThreshMax=['set(rangegui,''colormap'',get(UFI,''colormap''));',...
	'eval(cbscale); eval(cbdatamax); eval(cbdatamin); ',...
	'ThreshMax=max([ThreshMin+1 str2num(get(hThreshMax,''string''))]); ',...
	'if(ThreshMax < ThreshMin+1), ThreshMax=ThreshMin+1; end; if(ThreshMax > 100); ThreshMax=100; end;',...
	'set(hThreshMax,''string'',ThreshMax);',...
	'set(hmaxslider,''Value'',ThreshMax);',...
	'set(hslider,''Value'',(ThreshMax+ThreshMin)/2);',...
	'figure(rangegui); axes(hclaxis); eval(setcaxis); caxis([CMin CMax]);',...
	'set(hthmax,''String'',sprintf(''%.6f'',DATAMIN+ThreshMax/RaScl));',...
	'figure(UFI); eval(axcb); for i=1:length(hims); axes(hims(i)); caxis([CMin CMax]); end; '];

cbSliThreshMax=['set(rangegui,''colormap'',get(UFI,''colormap''));',...
	'eval(cbscale); eval(cbdatamax); eval(cbdatamin); ',...
	'ThreshMax=max([ThreshMin+1 ceil(get(gco,''Value''))]);, set(hThreshMax,''string'',ThreshMax);',...
	'set(hslider,''Value'',(ThreshMax+ThreshMin)/2);',...
	'set(hthmax,''String'',sprintf(''%.6f'',DATAMIN+ThreshMax/RaScl));',...
	'eval(axcb); figure(UFI); for i=1:length(hims); axes(hims(i)); eval(setcaxis); caxis([CMin CMax]); end;',...
	'figure(rangegui); axes(hclaxis); caxis([CMin CMax]); '];

cbSliThreshMid=['set(rangegui,''colormap'',get(UFI,''colormap''));',...
	'eval(cbscale); eval(cbdatamax); eval(cbdatamin); ',...
	'range=ThreshMax-ThreshMin;',...
	'ThreshMax=min([100 ceil(get(gco,''Value''))+range/2]);, set(hThreshMax,''string'',ThreshMax);',...
	'ThreshMin=max([0 ceil(get(gco,''Value''))-range/2]);, set(hThreshMin,''string'',ThreshMin);',...
	'set(hmaxslider,''Value'',ThreshMax); set(hminslider,''Value'',ThreshMin);',...
	'set(hthmax,''String'',sprintf(''%.6f'',DATAMIN+ThreshMax/RaScl));',...
	'set(hthmin,''String'',sprintf(''%.6f'',DATAMIN+ThreshMin/RaScl));',...
	'eval(axcb); figure(UFI); for i=1:length(hims); axes(hims(i)); eval(setcaxis); caxis([CMin CMax]); end;',...
	'figure(rangegui); axes(hclaxis); caxis([CMin CMax]); '];

hslider=uicontrol(rangegui,'Style','slider',...
	'units','normalized',...
	'Position', [ 85/figwid 57/fighgt 15/figwid 180/fighgt], 'Min',0,'Max',100,...
	'TooltipString','Set Threshold Range Center',...
	'Value',(ThreshMax+ThreshMin)/2,'Callback',cbSliThreshMid);
	
hmaxslider=uicontrol(rangegui,'Style','slider',...
	'units','normalized',...
	'Position', [ 20/figwid 146/fighgt 15/figwid 90/fighgt], 'Min',0,'Max',100,...
	'TooltipString','Set Threshold % Range Maximum',...
	'Value',ThreshMax,'Callback',cbSliThreshMax);
	
hThreshMax=uicontrol(rangegui,'style','edit','string',ThreshMax,...
	'TooltipString','Threshold % Range Maximum',...
	'units','normalized',...
	'position',[12/figwid 238/fighgt 30/figwid 15/fighgt],'BackgroundColor',Bcolor,'callback',cbThreshMax);
	
hThreshMin=uicontrol(rangegui,'style','edit','string',ThreshMin,...
	'TooltipString','Threshold % Range Minimum',...
	'units','normalized',...
	'position',[12/figwid 39/fighgt 30/figwid 15/fighgt],'BackgroundColor',Bcolor,'callback',cbThreshMin);

%hThreshMax=uicontrol(rangegui,'style','edit','string',ThreshMax,...
%	'position',[62 238 30 15],'BackgroundColor',Bcolor,'callback',cbThreshMax);
	

%herror = uicontrol(rangegui,'string',Message0,...
%	'position',[10 20 80 15],...
%	'CallBack',['set(herror,''string'',['' '',Message]);'],...
%	'BackgroundColor',Bcolor);
	
uicontrol(rangegui,'Style','PopUp',...
	'String','RESET...|Set Range|Fix Vert Bars|Fix Hori Bars|Delete Bars',...
	'TooltipString',['1:Get Global Range| 2: (Re)Draw Vertical Color Bar(s) |',...
	'3: (Re)Draw Horizontal Color Bar(s) |4: Delete Bar(s) '],...
	'units','normalized',...
	'Position',[10/figwid 8/fighgt 64/figwid 15/fighgt],...
	'CallBack',cbreset);
       
%uicontrol(rangegui,'String','RESET',...
%	'Position',[10 5 40 15],...
%	'CallBack',['delete(gcbf); vp_colrange;']);
	
uicontrol(rangegui,'String','EXIT',...
	'units','normalized',...
	'Position',[75/figwid 4/fighgt 40/figwid 15/fighgt],...
	'CallBack','delete(gcbf);');
	
%	'CallBack',['if ThreshMax > 0 & ThreshMax <=100, delete(gcbf); ',...
%	'else, Message=''Out of Bounds''; end;']);
	

%hclaxis=axes('position', [ 0.46 0.15 0.16 0.75]);
hclaxis=axes('position', [ 0.43 0.19 0.16 0.60]);

data=[];
%for i=0:255, data(256-i)=i; end;
for i=0:255, data(256-i)=DATAMIN + i*(DATAMAX-DATAMIN)/255; end;
data = data';
%imagesc(data,[0 255]);
imagesc(data,[DATAMIN DATAMAX]);
axis off;

