function vp_controls(fi,helpfile,type)
% function vp_controls(fi,helpfile,type)
% Sets ScAnVP standard control buttons on top of a figure
%_______________________________________________________________________
% The vp_controls function is usually called automatically by ScAnVP
% routines to set up utility buttons on top of figures with images. 
% Similar utilities can be invoked from the ScAnVP menu Utilities button.
% Control utilities include options for saving or printing a figure,
% element manipulations such as add text, delete, smoothing, color range, 
% colorbar voxel value with anatomical description and other options.
% A help button is set up for the helpfile input argument.
%
% Note, Not all features are operational in all versions.
%
% -Controls can be set up as three different types
% Only Type 1 is invoked in the current version 
%
% -Colorbars with white text are usually smaller and are  
% deleted individually.
%
% Type 1: Uicontrols at the top of the figure
% Type 2: Uimenu controls following matlab defaults on top of figure
% Type 3: Uicontextmenu that pops up with right button click on figure
% Type 4: Both types 1 and 3
% Type 5: Both types 2 and 4
%_______________________________________________________________________
% vp_controls.m	C.4.0 	P. Spetsieris	 July 19, 1999
% 			 		 Jan. 18, 2001
% ScAnVP Revision 6.1, MATLAB Ver. R2006b May. 23, 2011
%        Revision 6.2.1, Apr. 24, 2013

global UFI

if type==4, vp_controls(fi,helpfile,1); vp_controls(fi,helpfile,3); return; end;
if type==5, vp_controls(fi,helpfile,2); vp_controls(fi,helpfile,3); return; end;

set(fi,'ToolBar','figure');

frmcolor=[0.5 0.5 1];

helptxt=['vp_help(''' helpfile ''')'];

vertcb=['UFI=gcbf; ch=get(UFI,''children''); len=length(ch);',...
'for i=1:len, if strcmp(get(ch(i),''type''),''axes''), ',...
'if ~isempty(get(ch(i),''userdata'')),',...
'if isempty(get(ch(i),''DeleteFcn'')), ',...
'    axes(ch(i)); try, colorbar(''v6'',''vert''); catch colorbar vert; end; ',...
'end; end; end; end;'];

%Note, colorbars are saved as type axes, with a not empty delete function.
%Avoid placing a bar on the bar itself.

horicb=['UFI=gcbf; ch=get(UFI,''children''); len=length(ch);',...
'for i=1:len, if strcmp(get(ch(i),''type''),''axes''), ',...
'if ~isempty(get(ch(i),''userdata'')),',...
'if isempty(get(ch(i),''DeleteFcn'')), ',...
'    axes(ch(i)); try, colorbar(''v6'',''horiz''); catch colorbar horiz; end; ',...
'end; end; end; end;'];

barcb=	['UFI=gcbf; baropt=get(gco,''Value''); ',...
	'if baropt > 1, ',...
	['ch=get(UFI,''children''); len=length(ch); for i=1:len,',...
	'if strcmp(get(ch(i),''type''),''axes''), ',...
	'delefcn=get(ch(i),''DeleteFcn''); ',...
	'if ~isempty(delefcn),',... 
	'if strcmp(delefcn(1:8),''colorbar''),  ',...
	'delete(ch(i)); end; end; end; end;'],...
	'end; ',...
	'if baropt==2, ',...
	  'ch=get(UFI,''children''); len=length(ch); ',...
	  'for i=1:len, if strcmp(get(ch(i),''type''),''axes''), ',...
	  'if ~isempty(get(ch(i),''userdata'')), ',...
	  'axes(ch(i)); try hbar=colorbar(''v6'',''vert''); catch colorbar vert; end;',...
	  ' end; end; end;',...
	'elseif baropt==3, ',...
	  'ch=get(UFI,''children''); len=length(ch); ',...
	  'for i=1:len, if strcmp(get(ch(i),''type''),''axes''), ',...
	  'if ~isempty(get(ch(i),''userdata'')), ',...
	  'axes(ch(i)); hbar=colorbar(''vert'',''color'',''white'');',...
	  ' end; end; end;',...
	'elseif baropt==4, ',...
	  'ch=get(UFI,''children''); len=length(ch); ',...
	  'for i=1:len, if strcmp(get(ch(i),''type''),''axes''), ',...
	  'if ~isempty(get(ch(i),''userdata'')), ',...
	  'axes(ch(i)); try colorbar(''v6'',''horiz''); catch colorbar horiz; end;',...
	  ' end; end; end;',...
	'elseif baropt==5, ',...
	  'ch=get(UFI,''children''); len=length(ch); ',...
	  'for i=1:len, if strcmp(get(ch(i),''type''),''axes''), ',...
	  'if ~isempty(get(ch(i),''userdata'')), ',...
	  'axes(ch(i)); hbar=colorbar(''horiz'',''color'',''white'');',...
	  ' end; end; end;',...
	'elseif baropt==6, ',...
	  'figure(UFI); vp_colorbar([],1);',...
	'elseif baropt==7, ',...
	  'figure(UFI); vp_colorbar([],2);',...
	'else, end;'];

editcb=	['editopt=get(gco,''Value''); ',...
	'if editopt==2, ',...
	['ginput(1); if ~strcmp(get(gco,''type''),''uicontrol'') ',...
	'& ~strcmp(get(gco,''type''),''figure''), ',...
	'if (~strcmp(get(gco,''type''),''image'') & ~strcmp(get(gco,''type''),''colorbar'')),',...
	'set(gco,''selected'',''on''); plotedit(''on'');  ',...
	'else, plotedit(''off''); axis on; set(gca,''selected'',''on'');',...
	'set(gca,''ButtonDownFcn'',''selectmoveresize''),',... 
	'waitfor(gca,''position''); set(gca,''selected'',''off''); axis off; end; end;'],...
	'elseif editopt==3, ',...
	['ginput(1); if ~strcmp(get(gco,''type''),''uicontrol'') ',...
	'& ~strcmp(get(gco,''type''),''figure''), delete(gco); end;'],...
	'elseif editopt==4, ',...
	['UFI=gcbf; ch=get(gcbf,''children''); nch=length(ch); for i=1:nch,',...
	'if strcmp(get(ch(i),''type''),''axes''), ',...
	'delefcn=get(ch(i),''DeleteFcn''); ',...
	'if ~isempty(delefcn),',... 
	'if strcmp(delefcn(1:8),''colorbar''),  ',...
	'delete(ch(i)); end; end; end; end;'],...
	'elseif editopt==5, ',...
	['UFI=gcbf; ch=get(gcbf,''children''); nch=length(ch); for i=1:nch, if strcmp(get(ch(i),''type''),''uicontrol''), ',...
	'delete(ch(i)); end; end;'],...
	'end;'];

if type==3
 
 hmen=uicontextmenu;
 set(fi,'uicontextmenu',hmen);
else
 
 hmen=fi;
 
end;

if type==1,


nbuts=10;
pos=get(fi,'position');
butwid=min(55,pos(3)/nbuts);
butwid=butwid/pos(3);
buthgt=16/pos(4);
pophgt=10/pos(4);

xpos=1 - (1-nbuts*butwid)/2;
ypos=1;

uicontrol(fi,'Style','frame',...
	'units','normalized',...
	'position',[xpos-nbuts*butwid ypos-20/pos(4) nbuts*butwid 20/pos(4)],'BackgroundColor',frmcolor);
	
uicontrol(fi,'String','Help',...
	'units','normalized',...
	'Position',[xpos-butwid*1 ypos-18/pos(4) butwid buthgt],...
	'CallBack',helptxt);
	
uicontrol(fi,'Style','PopUp',...
	'String','Bar...|Vertical|Vert tx white|Horizontal|Horiz tx white|User Bar|Semi Bar',...
	'TooltipString',['1: Vertical Color Bar(s) ',...
	'|2: Vert Bar(s)- Text Labels White,... |3: Horizontal Color Bar(s)',...
	'|4: Horiz Bar(s)- Text Labels White |5: User Bar |6: User Semi Bar'],...
	'units','normalized',...
	'Position',[xpos-butwid*2 ypos-10/pos(4) butwid pophgt],...
	'ForegroundColor','k',...
	'CallBack', barcb);
	
uicontrol(fi,'String','Smooth',...
	'units','normalized',...
	'Position',[xpos-butwid*3 ypos-18/pos(4) butwid buthgt],...
	'CallBack', ['UFI=gcbf; vp_smooth']);
	
uicontrol(fi,'String','Value',...
	'units','normalized',...
	'Position',[xpos-butwid*4 ypos-18/pos(4) butwid buthgt],...
	'CallBack',['UFI=gcbf; vp_imvalue;']);
	
uicontrol(fi,'Style','PopUp',...
	'String','Range...|Full|Semi|Norm',...
	'TooltipString',['1: Modify Full Color Map Range |2: Modify Upper or Lower Range ',...
	'3: Normalize Range '],...
	'units','normalized',...
	'Position',[xpos-butwid*5 ypos-10/pos(4) butwid pophgt],...
	'ForegroundColor','k',...
	'CallBack',['hrange=gco; UFI=gcbf; RangeOpt=get(hrange,''Value''); ',...
	'if RangeOpt==2, vp_colrange;',...
	'elseif RangeOpt==3, vp_semirange;',...
	'elseif RangeOpt==4, vp_norm;',...
	'else, end;']);
	
uicontrol(fi,'String','Color',...
	'units','normalized',...
	'Position',[xpos-butwid*6 ypos-18/pos(4) butwid buthgt],...
	'CallBack',['UFI=gcbf; vp_colgui; ']);
	
uicontrol(fi,'String','Text',...
	'units','normalized',...
	'Position',[xpos-butwid*7 ypos-18/pos(4) butwid buthgt],...
	'CallBack',['UFI=gcbf; vp_imtext;']);
%	'CallBack',['txt=input(''Key : '',''s''); gtext(txt);']);
	
	
uicontrol(fi,'Style','PopUp',...
	'String','Edit...|Move Resize Etc |Delete |Del Bars |Del Controls',...
	'TooltipString','1: Move or Edit Object |2: Delete Object ',...
	'units','normalized',...
	'Position',[xpos-butwid*8 ypos-10/pos(4) butwid pophgt],...
	'ForegroundColor','k',...
	'CallBack',editcb);
	
%uicontrol(fi,'String','Delete',...
%	'Position',[xpos-butwid*8 ypos-18 butwid buthgt],...
%	'CallBack',['ginput(1); if ~strcmp(get(gco,''type''),''uicontrol'') ',...
%	'& ~strcmp(get(gco,''type''),''figure''), delete(gco); end;']);

%	OMIT SLOW
%	'elseif SaveOpt==3, frm=getframe(fi,[0 0 512 480]); im=frame2im(frm);',...
%	'ptr=get(fi,''pointer''); set(fi,''pointer'',''watch'');',...
%	'CM=colormap; nmap=floor(CM*255); ln=length(CM); dat=zeros(512,480); ',...
%	'for i=1:512, for j=1:480, truepix=[im(j,i,1) im(j,i,2) im(j,i,3)];',...
%	'for k=1:ln, if truepix==nmap(k,:), dat(i,j)=k; end; end; end; end;',...
%	'set(fi,''pointer'',ptr);',...
%	'imwrite(dat,nmap,''scanvp.pcx'',''pcx'');',

%	'if SaveOpt==2, print ''scanvp.ps'' -dpsc -noui; disp(''scanvp.ps saved'');',...
%	'elseif SaveOpt==3, print ''scanvp.eps'' -depsc -noui; disp(''scanvp.eps saved'');',...
%	'elseif SaveOpt==4, print ''scanvp.pcx'' -dpcx256 -noui; disp(''scanvp.pcx saved'');',...
%	'elseif SaveOpt==5, print ''scanvp.tiff'' -dtiff -noui; disp(''scanvp.tiff saved'');',

uicontrol(fi,'Style','PopUp',...
	'String','Save...|PS |EPS |PCX |TIFF |BMP |IMG',...
	'TooltipString',['Save 1: Postscript .ps |2: Encapsulated Postscript: .eps |',...
	' 3: PCX (8bit): .pcx | 4: TIFF .tiff | 5: BMP .bmp |',...
	' 6: Save IMG (ANALYZE) '],...
	'units','normalized',...
	'Position',[xpos-butwid*9 ypos-10/pos(4) butwid pophgt],...
	'ForegroundColor','k',...
	'CallBack',['SaveOpt=get(gco,''Value''); nm=get(gcf,''name'');',...
	'if isempty(nm), nm=''scanvp''; end;',...
	'if SaveOpt == 2, nm=[nm ''.ps''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'print(nm,''-dpsc2'',''-zbuffer'',''-noui''); vp_note([nm '' saved''],2) ; end; ',...
	'elseif SaveOpt== 3, nm=[nm ''.eps''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'print(nm,''-depsc2'',''-zbuffer'',''-noui''); vp_note([nm '' saved''],2) ; end; ',...
	'elseif SaveOpt== 4, nm=[nm ''.pcx''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'print(nm,''-dpcx256'',''-zbuffer'',''-noui'');  vp_note([nm '' saved''],2) ; end; ',...
	'elseif SaveOpt== 5, nm=[nm ''.tiff''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'print(nm,''-dtiff'',''-noui''); vp_note([nm '' saved''],2) ; end; ',...
	'elseif SaveOpt== 6, nm=[nm ''.bmp''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'print(nm,''-dbmp256'',''-noui''); vp_note([nm '' saved''],2) ; end; ',...
	'elseif SaveOpt== 7, nm=[nm ''SV.img''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'if vp_savaslice(1,nm) >= 0, vp_note([nm '' saved''],2) ; end; end; ',...
	'else, end;'] );
	
uicontrol(fi,'String','Print',...
	'units','normalized',...
	'Position',[xpos-butwid*nbuts ypos-18/pos(4) butwid buthgt],...
	'CallBack',['print -f -dwin -noui;']);
	
	
% end type 1

else



uimenu(hmen,'label','HELP',...
	'Position',8,...
	'CallBack',helptxt);
       
uimenu(hmen,'label','PRINT',...
	'Position',8,...
	'CallBack',['print -f -dwin -noui;']);
	
uimenu(hmen,'label','HzBAR',...
	'Position',8,...
	'CallBack', horicb);
	
uimenu(hmen,'label','VtBAR',...
	'Position',8,...
	'CallBack', vertcb);
       
uimenu(hmen,'label','SMOOTH',...
	'Position',8,...
	'CallBack', ['UFI=gcbf; vp_smooth']);
       
uimenu(hmen,'label','MOVE',...
	'CallBack',['ginput(1); if ~strcmp(get(gco,''type''),''uicontrol'') ',...
	'& ~strcmp(get(gco,''type''),''figure''), ',...
	'if (~strcmp(get(gco,''type''),''image'') & ~strcmp(get(gco,''type''),''colorbar'')),',...
	'set(gco,''selected'',''on''); plotedit(''on'');  ',...
	'else, plotedit(''off''); axis on; set(gca,''selected'',''on'');',...
	'set(gca,''ButtonDownFcn'',''selectmoveresize''),',... 
	'waitfor(gca,''position''); set(gca,''selected'',''off''); axis off;',...
	'end; end;']);
	
uimenu(hmen,'label','DELETE',...
	'CallBack',['ginput(1); if ~strcmp(get(gco,''type''),''uicontrol'') ',...
	'& ~strcmp(get(gco,''type''),''figure''), delete(gco); end;']);
	
uimenu(hmen,'label','VALUE',...
	'Position',8,...
	'CallBack',['UFI=gcbf; vp_imvalue']);
       
uimenu(hmen,'label','COLOR',...
	'Position',8,...
	'CallBack',['UFI=gcbf; vp_colgui']);
	
uimenu(hmen,'label','TEXT',...
	'Position',8,...
	'ForegroundColor',[1.0 1.0 1.0],...
	'CallBack',['UFI=gcbf; vp_imtext;']);
	
hrange=uimenu(hmen,'label','RANGE',...
	'Position',8,...
	'ForegroundColor','k',...
	'CallBack',[]);
	
uimenu(hrange,'label','Full',...
	'Position',1,...
	'ForegroundColor','k',...
	'CallBack','UFI=gcbf; vp_colrange;');
	
uimenu(hrange,'label','Semi',...
	'Position',2,...
	'ForegroundColor','k',...
	'CallBack','UFI=gcbf; vp_semirange;');
	
hsave=uimenu(hmen,'label','SAVE',...
	'Position',8,...
	'CallBack',[]);
	
uimenu(hsave,'label','PS',...
	'Position',1,...
	'ForegroundColor','w',...
	'CallBack',['nm=get(gcf,''name''); if isempty(nm), nm=''scanvp''; end;',...
	'nm=[nm ''.ps''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'print(nm,''-dpsc2'',''-zbuffer'',''-noui''); vp_note([nm '' saved''],3) ; end;']);
	
%	'CallBack','print ''scanvp.eps'' -depsc -noui; disp(''scanvp.eps saved'');');
uimenu(hsave,'label','EPS',...
	'Position',2,...
	'ForegroundColor','w',...
	'CallBack',['nm=get(gcf,''name''); if isempty(nm), nm=''scanvp''; end;',...
	'nm=[nm ''.eps''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'print(nm,''-depsc2'',''-zbuffer'',''-noui''); vp_note([nm '' saved''],3) ; end;']);
	
	
%	'CallBack','print ''scanvp.pcx'' -dpcx256 -noui; disp(''scanvp.pcx saved'');');
uimenu(hsave,'label','PCX',...
	'Position',3,...
	'ForegroundColor','w',...
	'CallBack',['nm=get(gcf,''name''); if isempty(nm), nm=''scanvp''; end;',...
	'nm=[nm ''.pcx''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'print(nm,''-dpcx256'',''-noui''); vp_note([nm '' saved''],3) ; end;']);
	
	
%	'CallBack','print ''scanvp.tiff'' -dtiff -noui; disp(''scanvp.tiff saved'');');
uimenu(hsave,'label','TIFF',...
	'Position',4,...
	'ForegroundColor','w',...
	'CallBack',['nm=get(gcf,''name''); if isempty(nm), nm=''scanvp''; end;',...
	'nm=[nm ''.tiff''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'print(nm,''-dtiff'',''-noui''); vp_note([nm '' saved''],3) ; end;']);
	
	
end
