% vp_convertge
% Convert GE Format image to ANALYZE
%_______________________________________________________________________
%
% vp_convertge allows the user to convert GE format (iee) images
% to ANALYZE format. Images stored as 16bit 128x128 word values in
% the .iee file obtained from the scanners data base are converted 
% to 8bit or 16bit values and negative values are zeroed in the 
% initial ANALYZE formatted image output of convertge.
%
% Orientation is radiological (RL, patient right is image left), however,
% after normalization with SPM software, the orientation will be neurological
% (LR, patient right is image right)in spm99 but is not altered in spm5.
% Image size is 128x128 assuming the images are originally square.
% If they are not, they are padded to 256x256.
%
% Multiple frames are sorted based on the internally recorded
% start time. For multiple frames, the frame no. appears in
% the output name delimited by an 'F' after the subject name.
% Thus, 'NameFNo.img'.
%
% WARNING! Maximum allowed Planes or Frames/Subject = 35.
%
% Type dos('...\scanvp\bin\convertge h') for help with additional
% conversion options available under DOS.
%_______________________________________________________________________
% vp_convertge		C.0	P. Spetsieris	11/9/98
% 			rev 5.8	P. Spetsieris	04/27/07
% 			rev 5.9	P. Spetsieris	03/26/08

global HelpMode FMenu NameLst
global POpt 

if HelpMode, vp_help(mfilename), return ; end;

% get the image's filename {FName} 
%-----------------------------------------------------------------------
%FName      = FName(FName ~= ' ')
%NameLst      = get_file(Inf,'.iee','Select GE format (iee) images',[]);

if vp_filesui(Inf,'.iee','Select GE format (.iee) images',mfilename) < 0 ,return; end;

   prompt=['Convert output data to 8Bit or 16Bit Integer? [ 8 | 16 | EXIT]'];
   POpt=vp_opt('X',prompt,'8 Bit','Convert to 8 Bit (1Byte)','16 Bit','Convert to 16Bit (2Bytes)','EXIT','');
   if (POpt=='X' | strcmp(POpt,'EXIT')), 
        set(FMenu,'Pointer','Arrow');
	vp_note('Program Exited',2); return;
   elseif ( strcmp(POpt,'8 Bit') ), 
	NoOBytes='1';
   elseif ( strcmp(POpt,'16 Bit') ), 
	NoOBytes='2';
   end

set(FMenu,'Pointer','Watch');
m= size(NameLst,1);

h=waitbar(0,'Processing IEE images ...');
for i=1:m
  FName=deblank(NameLst(i,:));
  %DosCmd = ['convertge ',FName,' < C:\PET\dat\convertge.dat']
  
  waitbar((i-.8)/m,h);
  if i==1
    DosCmd = ['convertge ',FName,' 3 ', NoOBytes, ' > ieeoutput.txt'];
  else
    DosCmd = ['convertge ',FName,' 3 ', NoOBytes, ' >> ieeoutput.txt'];
  end
  
  %DosCmd=strrep(DosCmd,'\','/')
  %dos(DosCmd) ;
  vp_dos(DosCmd) ;

disp(' ');
end

waitbar(1,h); pause(1); close(h);
set(FMenu,'Pointer','Arrow');
disp('END GE->AN');
