% Function [out1 out2 out3 out4]=vp_cropvol(action,in1,in2)
% Select a rectangular area of a planar image and crop the
% image volume at the border limits. Zoom into image display.
%
% This 'imview' option crops a three dimensional image volume
% at the border limits of a user picked planar area. The plane
% may be in any orthogonal view.
% The region is defined by holding the left button down and 
% entering the lower left and upper right diagonal points.
% The origin, coordinates and dimensions are reevaluated and the 
% zoomed-in image is displayed in the orthogonal views display.
%
% Action 'menu': Menu for Crop Volume
%
% Action 'cropvol': Crop and display new volume
%  Input
%  in1=xyzdata, in2=[planex planey planez]
%
%  Output
%    out1=status
%    out2=nxyzdata out3=newdim out4=nxyzor
%_______________________________________________________________________
% vp_cropvol    ScAnVP	5.2    P.Spetsieris	10/29/03

function [out1,out2,out3,out4]=vp_cropvol(action,in1,in2)

global HelpMode FMenu Message Ecolor PlaneX PlaneY PlaneZ
global XYZDATA DIM DATAMIN DATAMAX GCM CMin CMax RotAngle
global XYZDATA0 DIM0 VOX0 XYZOR0 Dx Dy Dz MaxPlane MaxDim
global PlaneX0 PlaneY0 PlaneZ0 IdentView
global UFI VOX XYZOR ORIGIN hmaxpln HelpMsg


if HelpMode, vp_help(mfilename), return ; end;

out1=-1;
out2=0; out3=0; out4=0;

action,
if strcmp(action,'menu')

   if isempty(XYZDATA) vp_note('No valid image data displayed',2), return, end;
   delete(findobj('Tag','cropgui'));
   delete(findobj('Tag','rotgui'));
   %INITIALIZE
   if isempty(CMin), CMin=DATAMIN; end;
   if isempty(CMax), CMax=DATAMAX; end;

   PlaneX0=PlaneX; PlaneY0=PlaneY; PlaneZ0=PlaneZ;
   XYZDATA0=XYZDATA; DIM0=DIM; VOX0=VOX; XYZOR0=XYZOR; 
   IdentView=0;
   out1=0;
   Message=['MSG:.................'];
   Bcolor=[0.8 .8 .9];

  cropgui = figure('Color',[0.8 .7 .7],'Name','Crop Volume UI','Tag','cropgui',...
  'NumberTitle','off','Position',[100,200,160,60],'UserData',0,...
  'Units','Pixels');
	
  uicontrol(cropgui,'string', 'HELP',...
	'TooltipString','Help displayed in MATLAB window',...
	'BackgroundColor',Ecolor,...
	'position',[100 35 50 20],'callback','vp_help(''vp_cropvol'');');

  pcbcrop=['in2=[PlaneX PlaneY PlaneZ];',...
    '[out1 XYZDATA DIM XYZOR]=vp_cropvol(''cropvol'',XYZDATA,in2); ',...
    'PlaneX=XYZOR(1); PlaneY=XYZOR(2); PlaneZ=XYZOR(3); ',...
    'MaxPlane=max(DIM); MaxDim=MaxPlane; set(hmaxpln,''string'',num2str(MaxPlane));',...
    'Opt=3; FI=figure(findobj(''tag'',''orthview'')); vp_imvorth ;',...
    'drawnow;'];
	
	
  uicontrol(cropgui,'string', 'CROP/ZOOM',...
	'TooltipString','CROP and ZOOM Image Volume',...
	'position',[15 35 80 20],'callback',pcbcrop);
	

  uicontrol(cropgui,'String','RESET',...
   'TooltipString','RESET original view',...
   'Position',[35 10 45 20],...
   'CallBack',['XYZDATA=XYZDATA0; DIM=DIM0; VOX=VOX0; XYZOR=XYZOR0; RotAngle=0;',...
   'PlaneX=PlaneX0; PlaneY=PlaneY0; PlaneZ=PlaneZ0; Dx=VOX(1); Dy=VOX(2); Dz=VOX(3);',...
   'MaxPlane=max(DIM); MaxDim=MaxPlane; set(hmaxpln,''string'',num2str(MaxPlane));',...
   'Opt=3; FI=figure(findobj(''tag'',''orthview'')); vp_imvorth ;',...
   'drawnow;']);

  uicontrol(cropgui,'String','QUIT',...
	'TooltipString','Quit and exit.',...
	'Position',[100 10 50 20],...
	'CallBack',['delete(findobj(''tag'',''cropgui''));',...
	'set(FMenu,''Pointer'',''Arrow'')';] );

  
elseif strcmp(action,'cropvol')
 
  xyzdata=in1; 
  dim=size(xyzdata);
  xyzor=in2;
  viewno=0;

  TxColor=[0.8 0.2 1];
	
       
  vp_note('Click On Image',-1);
  waitforbuttonpress;
  while (gcf==findobj('name','Note'))
   waitforbuttonpress;
  end
  UFI=gcf;
  %figure(UFI);
  vp_note('Define ROI with Left Button Down',-1);
  axis off;

  found=0;
  while found==0,
    rect=getrect(UFI),
    anynegs=rect > 0 ;
    if min(anynegs)==0
      vp_note('Please Reenter Diagonal Points',-1);
      axis off;
    else
      found=1;
    end
  end
  vp_note('PROCESSING',1);

  x=round(rect(1)); y=round(rect(2)); wid=round(rect(3)); hgt=round(rect(4));
  pixrect=[x y wid hgt],

  if strcmp(get(gco,'type'),'image')
  
    i1=x, i2=x+wid-1; j1=y; j2=j1+hgt-1;
 
    udata=get(gca,'UserData');
    nxyzdata=[];
    if ~isempty(udata),
  
      viewno=udata(1), plno=udata(2), vox=udata(3:5), 
      %xyzor=udata(6:8),
      if viewno==1
       %   nxyzdata(1:wid,1:hgt,:)=xyzdata(i1:i2,j1:j2,:);
        nxyzdata=xyzdata(i1:i2,j1:j2,:);
	nxyzor=[max(xyzor(1)-i1,1) max(xyzor(2)-j1,1) xyzor(3)];
    	newdim=[wid hgt dim(3)],
      elseif viewno==2,
        %nxyzdata(:,1:wid,1:hgt)=xyzdata(:,i1:i2,j1:j2);
        nxyzdata=xyzdata(:,i1:i2,j1:j2);
	nxyzor=[xyzor(1) max(xyzor(2)-i1,1) max(xyzor(3)-j1,1)];
	newdim=[dim(1) wid hgt],
      elseif viewno==3,
        %nxyzdata(1:wid,:,1:hgt)=xyzdata(i1:i2,:,j1:j2);
        nxyzdata=xyzdata(i1:i2,:,j1:j2);
	nxyzor=[max(xyzor(1)-i1,1) xyzor(2) max(xyzor(3)-j1,1)];
	newdim=[wid dim(2) hgt],
      end
    else
  	%assume axial view
        nxyzdata(1:wid,1:hgt,:)=xyzdata(i1:i2,j1:j2,:);
	nxyzor=[max(xyzor(1)-i1,1) max(xyzor(2)-j1,1) xyzor(3)];
    	newdim=[wid hgt dim(3)],
    end
  
  else
	out1=-1;
	vp_note('Not an ''image'' ',2);
	return;
  end

  out1=0; out2=nxyzdata; out3=newdim;
  out4=nxyzor;

end 
