/*
 vp_cvolfuns.c

 Various 2D and 3D array functions

 P.SPETSIERIS  2/07/02

*/

#include <stdio.h>
#include "dbh.h"  
#include "mex.h"

void mexFunction(
	int nlhs, mxArray *plhs[],
	int nrhs, const mxArray *prhs[])
{
/* Start C code */
    int out1,i,j,k,p1,p2; /* status, array indices */
    int i2,j2,k2,i3,j3,k3; /* limits */
    int sy,sx,sz;
    int buflen, ndim, no;
    char *opt;
    int cldiam; /* cluster diameter */
    int cldimi,cldimj,cldimk; /* cluster diameter */
    int cmaxi,cmaxj,cmaxk; /* cluster diameter */
    double diam, backvalue;
    int background; /* background value */
    /* double *ddim;  ** dimensions of input array */
    const int *dim_array; /* dimensions array of input array */
    int dim[3];   /* dimensions array  */
    double *pout1, *pout2, *pin ;
    double *indata ;
    double *xyzdata ;
    int savedatai,savedataj,savedatak; /* found indices */
    int cnty,cntn;
    mxArray *barfract, *barh, *input[2];
    char *barmsg;

    /* Check proper input and output. */
    if (nrhs != 4)
	mexErrMsgTxt("enter 4 inputs required");
    else if (!mxIsChar(prhs[0]))
	mexErrMsgTxt("1st Argument must be a string");
    else if (!mxIsDouble(prhs[1]))
	mexErrMsgTxt("2nd Input data array must be double");
    else if (!mxIsNumeric(prhs[2]))
	mexErrMsgTxt("3rd Input diameter must be numeric");
    else if (!mxIsNumeric(prhs[3]))
	mexErrMsgTxt("4th Input background must be numeric");
	/*
    else if (!mxIsNumeric(prhs[4]))
	mexErrMsgTxt("5th Input dimensions must be numeric");
	*/


/* Get input arguments. */

/* get option */
buflen=mxGetN(prhs[0]) + 1;
opt = (char *)mxCalloc(buflen, sizeof(char));
if(!mxGetString(prhs[0], opt, buflen)){
    mexPrintf("Option: %s\n",opt);
}
else mexErrMsgTxt("could not read option\n");

diam = mxGetScalar(prhs[2]);
mexPrintf("diam: %f\n",diam);
cldiam= diam + 0.5; /* round to nearest integer */
mexPrintf("cldiam: %d\n",cldiam);

backvalue = mxGetScalar(prhs[3]);
mexPrintf("backvalue: %f\n",backvalue);

/*
ddim = mxGetData(prhs[4]);
ndim=mxGetN(prhs[4]);
dim[2]=1;
dim[0]=dim[0]; dim[1]=ddim[1];
if (ndim > 2) dim[2]=ddim[2];
ndim=3;
mexPrintf("dimensions: %d %d %d ndim %d\n",dim[0],dim[1],dim[2],ndim);
*/
dim[2]=1;
dim_array=mxGetDimensions(prhs[1]);
ndim=mxGetNumberOfDimensions(prhs[1]);
dim[0]=dim_array[0]; dim[1]=dim_array[1];
if (ndim > 2) dim[2]=dim_array[2];
mexPrintf("dimensions: [%d,%d,%d] ndim %d\n",dim[0],dim[1],dim[2],ndim);

indata = mxGetPr(prhs[1]);
/* buflen=mxGetN(prhs[1]);*/
mexPrintf("indata num=%d : ",dim[0]*dim[1]*dim[2]);
/*
for (i=0; i<dim[0]*dim[1]; i++)
mexPrintf("%f ",indata[i]);
*/

if (ndim > 2){

if ( (cldiam > dim[0]) || (cldiam > dim[1]) ){
 mexErrMsgTxt("cluster XY dimensions too big\n");
}
if ( (ndim > 2) && (cldiam > dim[2]) ){
 mexErrMsgTxt("cluster Z dimensions too big\n");
}
/* add a voxel and another is added in the for loop */
cldiam= cldiam+1;

/* grow area by one pixel on each side */
dim[0] +=2; dim[1] +=2; dim[2] +=2;
no=dim[0]*dim[1]*dim[2];

xyzdata = (double *)mxCalloc(no, sizeof(double));

for (k=0; k<dim[2]-2; k++){
  for (i=0; i<dim[0]-2; i++) {
   for (j=0; j<dim[1]-2; j++){
       p2= (k+1)*dim[0]*dim[1] + (j+1)*dim[0] + (i+1);
       p1=k*(dim[0]-2)*(dim[1]-2) + j*(dim[0]-2)+i;
  	/*mexPrintf("%d,%d %d, %d \n ",i,j,p1,p2);*/
       xyzdata[p2]=indata[p1];
}}}

cmaxi= ((dim[0]-cldiam) > 1)? cldiam : 1 ;
cmaxj= ((dim[1]-cldiam) > 1)? cldiam : 1 ;
cmaxk= ((dim[2]-cldiam) > 1)? cldiam : 1 ;


   barmsg=mxCalloc(30,sizeof(char));
   sprintf(barmsg,"REMOVING CLUSTERS SIZE: %d",(cldiam-1));

   barfract=mxCreateDoubleMatrix(1,1,mxREAL);
   barh=mxCreateDoubleMatrix(1,1,mxREAL);


   /*
   mexCallMATLAB(1,&barh,1,&barfract,"waitbar");
   waitbar(barfract,h);
   */

   *mxGetPr(barfract)= 0;
   input[0]=barfract;
   input[1]=mxCreateString(barmsg);
   mexCallMATLAB(1,&barh,2,&input,"waitbar");



/* loop over all values of cldimi,j,k <= cldiam */
/* i, j, k limits  rows i vary Y, colums k vary X, planes vary Z */

for (cldimk=1; cldimk<cmaxk+1 ; cldimk++){
  k2= ((dim[2]-cldimk) > 1)? (dim[2]-cldimk) : 1 ;
  *mxGetPr(barfract)=(float)(cldimk-1)/cmaxk;
  input[0]=barfract;
  input[1]=barh;
  mexCallMATLAB(0,NULL,2,&input,"waitbar");

  for (cldimi=1; cldimi<cmaxi+1 ; cldimi++){
   *mxGetPr(barfract)=(cldimk -1 + (float)(cldimi-1)/cmaxi )/cmaxk;
   input[0]=barfract;
   input[1]=barh;
   mexCallMATLAB(0,NULL,2,&input,"waitbar");

   i2= ((dim[0]-cldimi) > 1)? (dim[0]-cldimi) : 1 ;

   for (cldimj=1; cldimj<cmaxj+1 ; cldimj++){
   j2= ((dim[1]-cldimj) > 1)? (dim[1]-cldimj) : 1 ;

/* DEBUG
cnty=0; cntn=0;
k2=dim[2]-cldiam; j2=dim[1] -cldiam; i2=dim[0]-cldiam;
cldimi=cldimj=cldimk=cldiam;
*/

    /*mexPrintf("i2,j2, %d,%d \n ",i2,j2);*/
   for (k=0; k<k2; k++){
   savedatak=0;

	/*mexPrintf("k: %d\n",k);*/
    for (j=0; j<j2; j++){
    savedataj=0;
     for (i=0; i < i2; i++){
      savedatai=0;
      /* find all non zero surface pixels
       (at least one coord must be on the surface of 6 sided box)
      */
      for( sy=i; sy < i+cldimi+1; sy +=cldimi){ /* check 2 y sides */
       for( sx=j; sx < j+cldimj+1; sx++){
        for( sz=k; sz < k+cldimk+1; sz++){
         p2=sz*dim[0]*dim[1] + sx*dim[0] + sy;
         /*if (xyzdata[sy,sx] != backvalue){ savedatai=1; break;}*/
    	/* mexPrintf("(%d,%d), xyzdata[%d]= %f \n ",sy,sx,p2,xyzdata[p2]);*/
         if (xyzdata[p2] != backvalue){ savedatai=1; cnty++; break;}
        }/* end for sz */
        if (savedatai==1) break ;
       }/* end for sx */
       if (savedatai==1)  break ;
      } /* end for sy */
      
      if (savedatai==0) { /* check 2 x sides */

        for( sx=j; sx < j+cldimj+1; sx +=cldimj){
         for( sy=i; sy < i+cldimi+1; sy++){
          for( sz=k; sz < k+cldimk+1; sz++){
           p2=sz*dim[0]*dim[1] + sx*dim[0] + sy;
           /*if (xyzdata[sy,sx] != backvalue){ savedatai=1; break;}*/
           if (xyzdata[p2] != backvalue){ savedatai=1; cnty++; break;}
          }/* end for sz */
          if (savedatai==1) break ;
         } /* end for sy */
         if (savedatai==1) break ;
        } /* end for sx */
        
      }  /* end for if datai */

      if (savedatai==0) { /* check 2 z sides */

        for( sz=k; sz < k+cldimk+1; sz +=cldimk){
         for( sy=i; sy < i+cldimi+1; sy++){
          for( sx=j; sx < j+cldimj+1; sx++){
           p2=sz*dim[0]*dim[1] + sx*dim[0] + sy;
           /*if (xyzdata[sy,sx] != backvalue){ savedatai=1; break;}*/
           if (xyzdata[p2] != backvalue){ savedatai=1; cnty++; break;}
          }/* end for sx */
          if (savedatai==1) break ;
         } /* end for sy */
         if (savedatai==1) break ;
        } /* end for sz */
        
      }  /* end for if datai */
     

      if (savedatai==0) {
	  cntn++;
       /* Set all internal values to backround */
        for(sy=i+1; sy< i+cldimi ; sy++){
          for(sx=j+1; sx< j+cldimj ; sx++){
            for(sz=k+1; sz< k+cldimk ; sz++){
             p2=sz*dim[0]*dim[1] + sx*dim[0] + sy;
             xyzdata[p2] = backvalue;
       		/*xyzdata[sy,sx] = backvalue;*/
            } /* end for sz */
          } /* end for sx */
        }/* end for sy */
        
        i=i+cldimi-1;
         /* jump i */
      }
      else { savedataj=1; }
     }/* end for i */
     
     if (savedataj==0){
      j=j+cldimj-1;
     }
     else { savedatak=1; }
    } /* end for j */
    if (savedatak==0){
      k=k+cldimk-1;
    }
   } /* end for k */
/*
DEBUG
	mexPrintf("y:%d,n:%d\n",cnty,cntn);
*/
   }/* end for cldimj */
  }/* end for cldimi */
  mexPrintf("Completed %5.2f%%\n ",(cldimk*100.0/cmaxk));
}/* end for cldimk */


/* strip off the outer border pixels */
 dim[0] -=2; dim[1] -=2; dim[2] -=2;
 no=dim[0]*dim[1]*dim[2];

 plhs[0] = mxCreateDoubleMatrix(1,1, mxREAL);
 pout1 = mxGetPr(plhs[0]);
 *pout1 = 0 ;

 plhs[1] = mxCreateNumericArray(ndim,dim,mxDOUBLE_CLASS,mxREAL);
 pout2= mxGetPr(plhs[1]);
 for (k=0; k<dim[2]; k++){
   for (i=0; i<dim[0]; i++) {
     for (j=0; j<dim[1]; j++){
        p1=k*dim[0]*dim[1] + j*dim[0] + i;
	p2=(k+1)*(dim[0]+2)*(dim[1]+2) + (j+1)*(dim[0]+2)+(i+1);
        pout2[p1] = xyzdata[p2];
      }
     }
 }
 mexCallMATLAB(0,NULL,1,&barh,"delete");
 /*
 mxDestroyArray(barfract);
 mxDestroyArray(barh);
 mxDestroyArray(input);
 */

} /* end ndim=3 */

else { /* ndim=2 */


/* assumes only 2 dimensions */
if ( (cldiam > dim[0]) || (cldiam > dim[1]) ){
 mexErrMsgTxt("cluster dimensions too big\n");
}
/* add a voxel and another is added in the for loop */
cldiam= cldiam+1;

/* grow area by one pixel on each side */
dim[0] +=2; dim[1] +=2;
if (ndim > 2) dim[2] += 2;
no=dim[0]*dim[1]*dim[2];

xyzdata = (double *)mxCalloc(no, sizeof(double));

for (i=0; i<dim[0]-2; i++) {
   for (j=0; j<dim[1]-2; j++){
       p2=(j+1)*dim[0] + (i+1); p1=j*(dim[0]-2)+i;
  /*mexPrintf("%d,%d %d, %d \n ",i,j,p1,p2);*/
  xyzdata[p2]=indata[p1];
}}

/* loop over all values of cldimi,j,k <= cldiam */
for (cldimi=1; cldimi<cldiam+1 ; cldimi++){
 for (cldimj=1; cldimj<cldiam+1 ; cldimj++){

/* i, j limits  rows vary Y, colums vary X */

 i2= ((dim[0]-cldimi) > 1)? (dim[0]-cldimi) : 1 ;
 j2= ((dim[1]-cldimj) > 1)? (dim[1]-cldimj) : 1 ;
  /*mexPrintf("i2,j2, %d,%d \n ",i2,j2);*/
 for (j=0; j<j2; j++){
 savedataj=0;
   for (i=0; i < i2; i++){
  /*mexPrintf("i,j,savedataj %d,%d,%d \n ",i,j,savedataj);*/
    savedatai=0;
    /* find all non zero surface pixels
     (at least one coord must be on the perimeter)
    */
    for( sy=i; sy < i+cldimi+1; sy +=cldimi){
     for( sx=j; sx < j+cldimj+1; sx++){
       p2=sx*dim[0] + sy;
       /*if (xyzdata[sy,sx] != backvalue){ savedatai=1; break;}*/
  /* mexPrintf("(%d,%d), xyzdata[%d]= %f \n ",sy,sx,p2,xyzdata[p2]);*/
       if (xyzdata[p2] != backvalue){ savedatai=1; break;}
     }
     /* end for sx */
  /* mexPrintf("sy=%d, savedatai=%d \n ",sy,savedatai); */
     if (savedatai==1) break ;
    }
     /* end for sy */
    if (savedatai==0) {

      for( sx=j; sx < j+cldimj+1; sx +=cldimj){
       for( sy=i; sy < i+cldimi+1; sy++){
         p2=sx*dim[0] + sy;
         /*if (xyzdata[sy,sx] != backvalue){ savedatai=1; break;}*/
         if (xyzdata[p2] != backvalue){ savedatai=1; break;}
       }
       /* end for sy */
       if (savedatai==1) break ;
      }/* end for sx */
       
    } /* end for if datai */

    if (savedatai==0) {
     /* Set all internal values to backround */
      for(sy=i+1; sy< i+cldimi ; sy++){
        for(sx=j+1; sx< j+cldimj ; sx++){
         p2=sx*dim[0] + sy;
         xyzdata[p2] = backvalue;
       		/*xyzdata[sy,sx] = backvalue;*/
        }
	/* end for sx */
      }
      /* end for sy */
      i=i+cldimi-1;
       /* jump i */
    }
    else savedataj=1;
   }
   /* end for i */
   if (savedataj==0){
    j=j+cldimj-1;
   }
 }
 /* end for j */
 }/* end for cldimj */
}/* end for cldimi */


/* strip off the outer border pixels */
 dim[0] -=2; dim[1] -=2;
 if (ndim > 2) dim[2] -= 2;
 no=dim[0]*dim[1]*dim[2];

 plhs[0] = mxCreateDoubleMatrix(1,1, mxREAL);
 pout1 = mxGetPr(plhs[0]);
 *pout1 = 0 ;

 plhs[1] = mxCreateNumericArray(ndim,dim,mxDOUBLE_CLASS,mxREAL);
 pout2= mxGetPr(plhs[1]);
 for (i=0; i<dim[0]; i++) {
     for (j=0; j<dim[1]; j++){
        p1= j*dim[0] + i;
	p2= (j+1)*(dim[0]+2)+(i+1);
        pout2[p1] = xyzdata[p2];
      }
 }
} /* end ndim=2 */


 /*
 for (i=0; i<dim[0]*dim[1]; i++) {
      pout2[i] = xyzdata[i];
 }
 */


return;
/**/
}



