% vp_cvtype
% Convert ANALYZE Format images of one type to another.
%_______________________________________________________________________
% User selects an data type to convert the image to.
% vp_cvtype calls vp_imcvt to perform image operations such as 8->16bit
% 16->8bit, 8->double etc. on the ANALYZE format images.
% The image is scaled and converted to real values before each operation is
% performed. If there are negative values, and an 8bit output is requested
% the negative values are set to zero. The processed images are assigned
% a suffix character 'imop'. Interactive renaming is enabled unless set to
% automatic. For integer output, if values are less than the maximum allowed
% for that type, scaling is set to one to allow rounding only if the
% "IROUND", Integer Rounding, Scale 1 option is selected.
%
% imop
%  Z=ZERONEGS
%  B=8bit
%  S=16bit
%  I=32bit
%  F=32bit Float
%  D=64 Double
%_______________________________________________________________________
% vp_cvtype	ScAnVP	C.4.4	P. Spetsieris	1/13/00
%		upgrade 5.1 by P.S.		7/22/03	
%		upgrade 5.8 by P.S.		4/09/07
%		upgrade 6.4 by P.S.		1/11/15

global HelpMode FMenu Message Ecolor Op AutoName


if HelpMode, vp_help(mfilename),  return ; end;

IdentGroup=0;
DefType=0;
out1=0;
Op='B';
OpS='Byte';
Message=['MSG:.................'];
Bcolor=[0.8 .8 .8];
AutoName=0;
IRoundScl=0;
Dummy='';

set(FMenu,'Pointer','Watch');

cvtypegui = figure('Color',[0.9 .8 .8],'Name','Image Types','Tag','cvtypegui',...
'NumberTitle','off','Position',[100,200,250,100],'UserData',0,...
'Units','Pixels');
	
uicontrol(cvtypegui,'string', 'HELP',...
	'TooltipString','Help displayed in MATLAB window',...
	'BackgroundColor',Ecolor,...
	'position',[178 75 50 20],'callback','vp_help(''vp_cvtype'');');
	
cbtypemenu = ['val=get(htypemenu,''Value''); if val==2, Op=''B''; OpS=''Byte''; ',...
	'elseif val == 3, Op=''S''; OpS=''Short'';',...
	'elseif val == 4, Op=''I''; OpS=''Int32''; ',...
	'elseif val == 5, Op=''F''; OpS=''Float''; ',...
	'elseif val == 6, Op=''D''; OpS=''Double''; ',...
	'end; if(val ~=1), DefType=1;',...
	'Message=[''Convert To Type '' OpS];',...
	'set(herr,''string'',Message); else, end; '];

htypemenu=uicontrol(cvtypegui,'Style','popup','Visible','on',...
	'position',[112 50 128 20],'BackgroundColor',Bcolor,...
	'TooltipString','Select Type to Convert To',...
	'String',...
	['Convert To Type...|Convert To 8bit|Convert To 16bit|Convert To 32bit|',...
	'Convert To Float (32bit)|Convert To Double (64bit)'],'Tag','TypeMenu',...
    	'callback',cbtypemenu);

pcbnames=['NameLst = get_file(Inf,''.img'',''Select images to Convert'',[]);',...
	  'if ~isempty(NameLst),',...
	  'IdentGroup=1; end;'];
	
uicontrol(cvtypegui,'string', 'SELECT IMAGES',...
	'TooltipString','Pick Images for Conversion',...
	'position',[10 50 100 20],'BackgroundColor',Bcolor,'callback',pcbnames);
	

uicontrol(cvtypegui,'String','PROCESS',...
	'TooltipString','Initiate Processing.',...
	'Position',[10 25 65 20],...
	'CallBack',[ 'if ~IdentGroup, set(herr,''string'',''ERR: Images Not Defined''); return; end; ',...
	'if ~DefType, set(herr,''string'',''ERR: Data Type Not Defined''); return; end; ',...
	'm=size(NameLst,1); h=waitbar(0,''Processing Image Convert Type ...'');',...
	'for i=1:m, FName=deblank(NameLst(i,:)); out1=vp_imcvt(FName,Op,2,1,AutoName,Dummy,Dummy,IRoundScl);',...
	'waitbar((i-.8)/m,h);',...
	'if out1<0, set(herr,''string'',['' '',Message]); pause(2); end;',...
	'end; waitbar(1,h); pause(1); close(h); set(FMenu,''Pointer'',''Arrow'')';] );
	
uicontrol(cvtypegui,'Style','Check','String','IROUND',...
	'TooltipString','Integer Rounding, Scale=1',...
	'Value',IRoundScl,'Position',[76 25 70 20],...
	'CallBack',[ 'IRoundScl=get(gco,''value''),']);
       
uicontrol(cvtypegui,'Style','Check','String','AUTO',...
	'TooltipString','Automate Output Naming',...
	'Value',AutoName,'Position',[150 25 50 20],...
	'CallBack',[ 'AutoName=get(gco,''value''),']);
       
uicontrol(cvtypegui,'String','QUIT',...
	'TooltipString','Quit and exit.',...
	'Position',[200 25 40 20],...
	'CallBack',['delete(cvtypegui);',...
	'set(FMenu,''Pointer'',''Arrow'')';] );

herr = uicontrol(cvtypegui,'string', [' ',Message],...
	'TooltipString','Report error or message field',...
	'position',[10 0 230 20],...
	'CallBack',['set(herr,''string'',['' '',Message]);'],...
	'BackgroundColor',Ecolor);


