% vp_defaults.m
% Set ScAn/VP  Analyze header defaults
%
% DIM     : Image Width, Height(Pixels), No of slices
% VOX     : Voxel Width, Height(mm), Interslice distance 
% SCALE   : Scale Factor (DATA multiplier
% TYPE    : Data Type  (see vp_hwrite)
% OFFSET  : Data Offset (bytes)
% ORIGIN  : Origin (Pixel x,y,z coordinates) 
% DESCRIP : File Descriptor
% GLMAX   : Global Maximum
% GLMIN   : Global Minimum
% EXPTIM  : Frame Start Time [HR:MN:SC]
% DURATION: Scan Duration (secs) dim(6)
% MATYPE  : Matlab Data Type (see vp_hread)
%___________________________________________________________________________
%
% Sets global default header values into working memory.
% The SPM names are used for variables. EXPTIM and DURATION have been
% assigned by ScAn/VP. Default values comply with SPM Normal values.
% The 'originator' field of the ANALYZE format has been changed to
% ORIGIN in the SPM version of the header.  funused1 of the ANALYZE
% format is used for SCALE.
%
% see also dbh.h (ANALYZE) vp_hwrite.m vp_hread.m and spm_type.m
%___________________________________________________________________________
% 
% Additional global variables used by get_file browser routine
% gFNames gFName gNameLst gPrevLst 
% gFileDir gPrevDirs
% gFilter gPrompt gHomeDir
% Ecolor Bcolor Fcolor 
%___________________________________________________________________________
% vp_defaults.m	C.4.4	P. Spetsieris  Dec. 27, 1999
%  Revision Ver 6.1	P. Spetsieris  Jan. 19, 2011 

global HelpMode POpt 
global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN EXPTIM DURATION
global MATYPE DATAMIN DATAMAX Message
global EXPDATE SUBID GENTIM

global gFNames gFName gNameLst gPrevLst 
global gFileDir gPrevDirs
global gFilter gPrompt gHomeDir
global Ecolor Bcolor Fcolor 

if HelpMode, vp_help(mfilename), return ; end;

%Set Defaults

DIM=[79 95 68];
VOX=[2.0 2.0 2.0];
SCALE=1.0;
TYPE=2;
OFFSET=0;
ORIGIN=[40 57 26];
DESCRIP=['ScAn/VP Default Header File' 0];
EXPTIM=['00:00:00' 0];
GLMAX=255;
GLMIN=0;
DURATION=0;
MATYPE='uchar';
DATAMIN=GLMIN;
DATAMAX=GLMAX;
SUBID=['None'];
GENTIM=['00:00:00'];
EXPDATE=['///'];


