% function [fi]=vp_fimg(fname,planeno, wno, wscale, fi)
% ScanVP window image display 
%_______________________________________________________________________
% vp_fimg allows the user to display a single slice scan in a subwindow
% of a new or previously specified figure multi-subwindow display.
% The image file, plane No., window number and scale of the window
% is specified in the input arguments. The function returns the figure
% number or a negative error code.
% code. This function is modeled on previous scanvp scripts. 
%_______________________________________________________________________
% Based on vp_fimage, vp_windows, vp_imframe ver.C.0  P. Spetsieris 1998
%
% Input:
% fname    Image file name
% planeno  Plane No. to display
% wno    Window No
% wscale   Window Scale
% fi       Figure No. 0: New Figure, Not 0: Previously defined
%-----------------------------------------------------------------------
% vp_fimg ScAnVP ver. 6.2  P.Spetsieris, Ph.D.     12/1/2011
%               Rev. 7.0 by P.S. 11/28/15

	function [fi]=vp_fimg(fname,planeno, wno, wscale, fin)

	global DATA DATAMIN DATAMAX PlaneNo FName 
	global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN DESCRIP
	global EXPTIM DURATION MATYPE Message XYZOR GENTIM SUBID EXPDATE
	global MenuWid HelpMode VAL_OFFSET DisplayOrient InputOrient


	if HelpMode, vp_help(mfilename), return ; end;

	fi=-1;
	if(isempty(fname))vp_note('Reference File Not Specified',2); return, end;

	vp_hread(fname);
 
	XYZOR=ORIGIN;

	XYZOR(1) = max(XYZOR(1), 1);
	XYZOR(2) = max(XYZOR(2), 1);
	XYZOR(3) = max(XYZOR(3), 1);

	P=fname;
	P=P(P ~=' '),
	q     = length(P);
	if P(q - 3) == '.'; P = P(1:(q - 4)); end
	fname=P;

	fnimg = [fname '.img'];
	[fid,Message] = fopen(fnimg,'r');
	if (fid ~= -1 )

	if wscale == 1 ; wndmax = 9; 
	elseif wscale == 2 ; wndmax = 4; 
	elseif wscale == 4 ; wndmax = 1; 
        else, 
	  vp_note(['Invalid Window Scale ', num2str(wscale)],2);
	return; end

	winview=1;	% Axial

	if wno > wndmax,
	vp_note(['Window No ', num2str(wno), ' Exceeds Max Window ',num2str(wndmax)],2);
	return, end;

	imagesize=DIM(1)*DIM(2)*vp_roifuns('bytes',MATYPE) ;

	DATA=zeros(DIM(1),DIM(2));
 
	if(planeno > DIM(3) | planeno <= 0),
	 Message = 'Plane Out of Bounds',
	  vp_note(['Plane No ', num2str(planeno), ' Exceeds Max ',num2str(DIM(3))],2);
		return;
	end;
  	fseek(fid,imagesize*(planeno-1),'bof');

	% Set the image frame axes

	ssize=get(0, 'ScreenSize');
	%devicewidth=512; deviceheight=512;
	devicewidth=ssize(3)/4; deviceheight=devicewidth;

	xpos0=1;
	ypos0=1;

	if (fin==0)

	  fi = figure('Color',[0 0 1]*.8,...
	  'Name',fname,...
	  'NumberTitle','off',...
	  'Position',[MenuWid+20,(ssize(4)-deviceheight)/2-ypos0,devicewidth,deviceheight],...
	  'Resize','on',...
	  'Tag','ScAnVP FRAME',...
	  'Units','Pixels',...
	  'Pointer','Cross',...
	  'Visible','on');

	else
	  fi=figure(fin);
	end

	if (fi < 1)return; end;

	set(fi,'Tag','image');
	set(fi,'Name',fname);
	

	axi04=axes('Position',[0 0 1 1],'Visible','Off') ;		% FULL WINDOW
	axi02=axes('Position',[.25 .25 .5 .5],'Visible','Off');		% 256x256 WINDOW
	axi01=axes('Position',[.375 .375 .25 .25],'Visible','Off');	% 128x128 WINDOW


	frmwid=1;
	winformat=3;

	for wndscl=1:2

	 if wndscl==2, winformat=2;  xpos0=0; ypos0=0; end;
	 xpos=xpos0;
	 ypos=ypos0;
	 %wndwid = 128*wndscl;
	 %wndhgt = 128*wndscl;
	 wndwid = devicewidth/winformat;
	 wndhgt = deviceheight/winformat;

	 axor=zeros(winformat*winformat,2);
	 for i=1:winformat
 
	  for j=1:winformat
	    wndno= (i-1)*winformat + j ;
	    [axor(wndno,1), axor(wndno,2)]=vp_axorigin(xpos,ypos,wndwid,wndhgt,devicewidth,deviceheight);
	    axi(wndno)=axes('Position',[axor(wndno,1) axor(wndno,2) wndwid/devicewidth wndhgt/deviceheight],'Visible','Off');
	    xpos = xpos + wndwid + frmwid;
	  end; % for j
  
	  xpos = xpos0;
	  ypos = ypos + wndhgt + frmwid;
	 end; % for i
 
	 if wndscl==1, axor1=axor; axi1=axi ;
	 else axor2=axor; axi2=axi ; end ; % for if wndscl

	end ; % for wndscl

	%DATA	= fread(fid,[DIM(1),DIM(2)],'uchar');
	DATA	= fread(fid,[DIM(1),DIM(2)],MATYPE);
	
	DATA = SCALE*DATA';
    if (DisplayOrient~=InputOrient)
        DATA = fliplr(DATA); end;
	
	if VAL_OFFSET ~=0, DATA=DATA+VAL_OFFSET; end; 

	DATAMAX=max(max(DATA)),
	DATAMIN=min(min(DATA)),
	
	%DATA=flipud(DATA);

	if wno==0,
		if wscale == 1, axes(axi01), 
		elseif wscale == 2, axes(axi02), 
		elseif wscale == 4, axes(axi04), end; % if wscale	
	else
		if wscale == 1, axes(axi1(wno)) ;
		else if wscale == 2, axes(axi2(wno)) ; 
		elseif wscale == 4, axes(axi04), wno=0, end; end % if wscale	
	end	
		
	%imh=image(DATA);
	%imh=imagesc(DATA,[0 GLMAX]);
	if (DATAMIN==DATAMAX),
	  if ( DATAMIN==0),
	    %vp_message(['WARNING: ZERO DATA Plane:',num2str(planeno)]);
	    %pause(2);
	    vp_note(['WARNING: ZERO DATA Plane:',num2str(planeno)],2);
	  else,
	    vp_note(['WARNING: DATAMIN = DATAMAX = ',num2str(DATAMIN),', Plane:',num2str(planeno)],2);
	  end
	  figure(fi);
	  imh=image(DATA);
	  Message=[];
	 
	else
	 figure(fi);
	 imh=imagesc(DATA,[DATAMIN DATAMAX]);
	end;
	
	%axis off image
	axis off image xy
	
	%Correct for aspect ratio
	vp_aspect(winview,VOX);
		
	set(gca,'UserData',[winview planeno VOX XYZOR]);
	
	planenoStr=num2str(planeno);
	%thdl=text(i+.5,j+1,planenoStr,'Color',[1.0 1.0 1.0]);
	thdl=text(1,DIM(2)-1,planenoStr,'Color',[1.0 1.0 1.0]);
	
	%colorbar vert ;
	drawnow;
	
	fclose(fid);
else
	Message
	vp_message(Message);
end

%   fprintf('\n\n> '); 

