% vp_fixhdr.m
% Allows user to key in modifications to Analyze header
% read in values or to create a user defined header.
%
% Variables that can be set are:
%
% DIM     : Image Width, Height(Pixels), No of slices
% VOX     : Voxel Width, Height(mm), Interslice distance 
% SCALE   : Scale Factor (DATA multiplier
% TYPE    : Data Type 
%           TYPE 1:   bits/pix = 1; 
%           TYPE 2:   bits/pix = 8;  uchar
%           TYPE 4:   bits/pix = 16; int16
%           TYPE 8:   bits/pix = 32; int32
%           TYPE 16:  bits/pix = 32; float
%           TYPE 64:  bits/pix = 64; double
% OFFSET  : Data Offset (bytes)
% ORIGIN  : Origin (Pixel x,y,z coordinates) 
% DESCRIP : File Descriptor
% GLMAX   : Global Maximum
% GLMIN   : Global Minimum
% EXPTIM  : Frame Start Time [HR:MN:SC]
% MATYPE  : Matlab Data Type
% DURATION: Scan Duration (secs) dim(6)
%___________________________________________________________________________
% vp_fixhdr.m	ScAnVP C.4.2	P. Spetsieris	Oct. 7, 1999
%		Rev. 5.2 	by P.S.		Oct. 15, 2003

global HelpMode Ecolor MATYPE Message
global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN EXPTIM DURATION
global EXPDATE GENTIM SUBID

if HelpMode, vp_help(mfilename), return ; end;

delete(findobj('Name','FIX HEADER'));

%Set Defaults
vp_defaults;

%FName=['Default.hdr' 0];
FName=['Default.hdr'];

%DIM=[79 95 68];
%VOX=[2.0 2.0 2.0];
%SCALE=1.0;
%TYPE=2;
%OFFSET=0;
%ORIGIN=[40 57 26];
%DESCRIP=['ScAn/VP Default Header File' 0];
%EXPTIM=['00:00:00' 0];
%GLMAX=255;
%GLMIN=0;
%DURATION=0;

Message=['............................'];


fixhdr = figure('Color','w','Name','FIX HEADER',...
'NumberTitle','off','Position',[100,200,285,350],...
'Units','Pixels')
	
Bcolor = [.8,.8,.9];
%Bcolor = 'w';
Kcolor = [.8,.8,1.0];

	
uicontrol(fixhdr,'string', 'Help',...
	'TooltipString','Help displayed in MATLAB window',...
	'BackgroundColor',Ecolor,...
	'position',[230 320 40 20],'callback','vp_help(''vp_fixhdr'');');
	

cbFName=['FName=get(hname,''string'');',...
  	'FName=deblank(FName);',...
  	'vp_hread(FName); ',...
	'set(hname,''string'',FName);',...
	'set(hdescrip,''string'',DESCRIP);',...
	'set(htype,''string'',num2str(TYPE));',...
	'set(hoffset,''string'',num2str(OFFSET));',...
	'set(hscale,''string'',num2str(SCALE));',...
	'set(hglmin,''string'',num2str(GLMIN));',...
	'set(hglmax,''string'',num2str(GLMAX));',...
	'if length(EXPTIM) ~=8, EXPTIM=[''00:00:00'']; end;',...
	'set(hexptim,''string'',EXPTIM);',...
	'set(hduration,''string'',num2str(DURATION));',...
	'set(hor1,''string'',num2str(ORIGIN(1)));',...
	'set(hor2,''string'',num2str(ORIGIN(2)));',...
	'set(hor3,''string'',num2str(ORIGIN(3)));',...
	'set(hdim1,''string'',num2str(DIM(1)));',...
	'set(hdim2,''string'',num2str(DIM(2)));',...
	'set(hdim3,''string'',num2str(DIM(3)));',...
	'set(hvox1,''string'',num2str(VOX(1)));',...
	'set(hvox2,''string'',num2str(VOX(2)));',...
	'set(hvox3,''string'',num2str(VOX(3)));',...
	'set(hsubid,''string'',SUBID);',...
	'set(hexpdate,''string'',EXPDATE);',...
	'set(hgentim,''string'',GENTIM);',...
	'set(herror,''string'',Message)'];
	
%	'set(herror,''string'',[''FILE '' FName '' READ'']);'];
	
cbdescrip=['DESCRIP=get(hdescrip,''string''); '];
cbtype=['TYPE=str2num(get(htype,''string'')); '];
cboffset=['OFFSET=str2num(get(hoffset,''string'')); '];
cbscale=['SCALE=str2num(get(hscale,''string'')); '];
cbglmin=['GLMIN=str2num(get(hglmin,''string'')); '];
cbglmax=['GLMAX=str2num(get(hglmax,''string'')); '];
cbexptim=['EXPTIM=get(hexptim,''string'');',...
' if length(EXPTIM) ~=8, vp_note(''Must be HR:MN:SC'',2); EXPTIM=[''00:00:00''];',...
' set(hexptim,''string'',EXPTIM); end;'];
cbduration=['DURATION=str2num(get(hduration,''string'')); '];
cbor1=['ORIGIN(1)=str2num(get(hor1,''string'')); '];
cbor2=['ORIGIN(2)=str2num(get(hor2,''string'')); '];
cbor3=['ORIGIN(3)=str2num(get(hor3,''string'')); '];

cbdim1=['DIM(1)=str2num(get(hdim1,''string'')); '];
cbdim2=['DIM(2)=str2num(get(hdim2,''string'')); '];
cbdim3=['DIM(3)=str2num(get(hdim3,''string'')); '];

cbvox1=['VOX(1)=str2num(get(hvox1,''string'')); '];
cbvox2=['VOX(2)=str2num(get(hvox2,''string'')); '];
cbvox3=['VOX(3)=str2num(get(hvox3,''string'')); '];

%%  	'P=strtok(FName,''.''),',...
%%  	'vp_hread([P ''.hdr'']); ',...
%%
uicontrol(fixhdr,'string', 'PICK FILE',...
	'position',[10 290 70 25],...
	'TooltipString','Enter File Name',...
	'callback',['FName=get_file(1,''.hdr'',''please select image'',[]); ',...
	'if ~isempty(FName),',...
  	'FName=deblank(FName);',...
  	'vp_hread([FName]); ',...
	'set(hname,''string'',FName);',...
	'set(hdescrip,''string'',DESCRIP);',...
	'set(htype,''string'',num2str(TYPE));',...
	'set(hoffset,''string'',num2str(OFFSET));',...
	'set(hscale,''string'',num2str(SCALE));',...
	'set(hglmin,''string'',num2str(GLMIN));',...
	'set(hglmax,''string'',num2str(GLMAX));',...
	'set(hexptim,''string'',EXPTIM);',...
	'set(hduration,''string'',num2str(DURATION));',...
	'set(hor1,''string'',num2str(ORIGIN(1)));',...
	'set(hor2,''string'',num2str(ORIGIN(2)));',...
	'set(hor3,''string'',num2str(ORIGIN(3)));',...
	'set(hdim1,''string'',num2str(DIM(1)));',...
	'set(hdim2,''string'',num2str(DIM(2)));',...
	'set(hdim3,''string'',num2str(DIM(3)));',...
	'set(hvox1,''string'',num2str(VOX(1)));',...
	'set(hvox2,''string'',num2str(VOX(2)));',...
	'set(hvox3,''string'',num2str(VOX(3)));',...
	'set(hsubid,''string'',SUBID);',...
	'set(hexpdate,''string'',EXPDATE);',...
	'set(hgentim,''string'',GENTIM);',...
	'set(herror,''string'',Message); end;']);
	
%	'set(herror,''string'',[''FILE '' FName '' READ'']);']);
	
hname=uicontrol(fixhdr,'style','edit','string',FName,...
	'TooltipString','Enter File Name',...
	'position',[72 290 207 25],'BackgroundColor',Kcolor,'callback',cbFName);
	
uicontrol(fixhdr,'style','text','string', 'SUBJECT ID: ',...
	'TooltipString','Subject Identification Number',...
	'position',[10 265 65 22],'BackgroundColor',Bcolor);
	
hsubid=uicontrol(fixhdr,'style','text','string',SUBID,...
	'TooltipString','Subject Identification Number',...
	'position',[75 265 67 23],'BackgroundColor',Bcolor);

uicontrol(fixhdr,'style','text','string', 'SCAN DATE: ',...
	'TooltipString','DATE OF SCAN',...
	'position',[148 265 65 22],'BackgroundColor',Bcolor);
	
hexpdate=uicontrol(fixhdr,'style','text','string',EXPDATE,...
	'TooltipString','DATE OF SCAN',...
	'position',[213 265 65 23],'BackgroundColor',Bcolor);

uicontrol(fixhdr,'style','text','string', 'CLOCK TIME: ',...
	'TooltipString','ACTUAL FRAME START TIME',...
	'position',[10 240 70 22],'BackgroundColor',Bcolor);
	
hgentim=uicontrol(fixhdr,'style','text','string',GENTIM,...
	'TooltipString','ACTUAL FRAME START TIME',...
	'position',[80 240 65 23],'BackgroundColor',Bcolor);


uicontrol(fixhdr,'style','text','string', 'DESCRIP ',...
	'TooltipString','File Descriptor',...
	'position',[10 215 55 22],'BackgroundColor',Bcolor);
	
hdescrip=uicontrol(fixhdr,'style','edit','string',DESCRIP,...
	'TooltipString','File Descriptor',...
	'position',[65 215 212 20],'BackgroundColor',Kcolor,'callback',cbdescrip);

uicontrol(fixhdr,'style','text','string', 'TYPE ',...
	'TooltipString','Image Type',...
	'position',[10 190 55 20],'BackgroundColor',Bcolor);
	
htype=uicontrol(fixhdr,'style','edit','string',num2str(TYPE),...
	'TooltipString','Image Type',...
	'position',[58 190 42 20],'BackgroundColor',Kcolor,'callback',cbtype);

uicontrol(fixhdr,'style','text','string', 'SCALE ',...
	'TooltipString','Data Multiplier',...
	'position',[110 190 55 20],'BackgroundColor',Bcolor);
	
hscale=uicontrol(fixhdr,'style','edit','string',num2str(SCALE),...
	'TooltipString','Data Multiplier',...
	'position',[165 190 100 20],'BackgroundColor',Kcolor,'callback',cbscale);

uicontrol(fixhdr,'style','text','string', 'OFFSET ',...
	'TooltipString','Data Offset (bytes)',...
	'position',[10 163 45 20],'BackgroundColor',Bcolor);
	
hoffset=uicontrol(fixhdr,'style','edit','string',num2str(OFFSET),...
	'TooltipString','Data Offset (bytes)',...
	'position',[58 163 42 20],'BackgroundColor',Kcolor,'callback',cboffset);
	
uicontrol(fixhdr,'style','text','string', 'GLMIN ',...
	'TooltipString','Global Minimum',...
	'position',[100 163 55 20],'BackgroundColor',Bcolor);
	
hglmin=uicontrol(fixhdr,'style','edit','string',num2str(GLMIN),...
	'TooltipString','Global Minimum',...
	'position',[148 163 42 20],'BackgroundColor',Kcolor,'callback',cbglmin);

uicontrol(fixhdr,'style','text','string', 'GLMAX ',...
	'TooltipString','Global Maximum',...
	'position',[190 163 55 20],'BackgroundColor',Bcolor);
	
hglmax=uicontrol(fixhdr,'style','edit','string',num2str(GLMAX),...
	'TooltipString','Global Maximum',...
	'position',[238 163 42 20],'BackgroundColor',Kcolor,'callback',cbglmax);


uicontrol(fixhdr,'style','text','string', 'START TIME',...
	'TooltipString','Relative Frame Start Time HR:MN:SC',...
	'position',[10 137 65 22],'BackgroundColor',Bcolor);
	
hexptim=uicontrol(fixhdr,'style','edit','string',EXPTIM,...
	'TooltipString','Relative Start Time HR:MN:SC',...
	'position',[77 137 65 23],'BackgroundColor',Kcolor,'callback',cbexptim);

uicontrol(fixhdr,'style','text','string', 'DURATION',...
	'TooltipString','Scan Duration (Secs)',...
	'position',[145 137 65 22],'BackgroundColor',Bcolor);
	
hduration=uicontrol(fixhdr,'style','edit','string',DURATION,...
	'TooltipString','Scan Duration (Secs)',...
	'position',[210 137 65 23],'BackgroundColor',Kcolor,'callback',cbduration);

uicontrol(fixhdr,'style','text','string', 'ORIGIN X ',...
	'TooltipString','Pixel Coordinate X of Origin',...
	'position',[10 110 55 22],'BackgroundColor',Bcolor);
	
hor1=uicontrol(fixhdr,'style','edit','string',num2str(ORIGIN(1)),...
	'TooltipString','Pixel Coordinate X of Origin',...
	'position',[65 110 35 25],'BackgroundColor',Kcolor,'callback',cbor1);

uicontrol(fixhdr,'style','text','string', 'ORIGIN Y ',...
	'TooltipString','Pixel Coordinate Y of Origin',...
	'position',[100 110 55 22],'BackgroundColor',Bcolor);
	
hor2=uicontrol(fixhdr,'style','edit','string',num2str(ORIGIN(2)),...
	'TooltipString','Pixel Coordinate Y of Origin',...
	'position',[155 110 35 25],'BackgroundColor',Kcolor,'callback',cbor2);

uicontrol(fixhdr,'style','text','string', 'ORIGIN Z ',...
	'TooltipString','Pixel Coordinate Z of Origin',...
	'position',[190 110 55 22],'BackgroundColor',Bcolor);
	
hor3=uicontrol(fixhdr,'style','edit','string',num2str(ORIGIN(3)),...
	'TooltipString','Pixel Coordinate Z of Origin',...
	'position',[245 110 35 25],'BackgroundColor',Kcolor,'callback',cbor3);
	

uicontrol(fixhdr,'style','text','string', 'DIM X ',...
	'TooltipString','Scan X DIMENSION (Pixels)',...
	'position',[10 85 55 22],'BackgroundColor',Bcolor);
	
hdim1=uicontrol(fixhdr,'style','edit','string',num2str(DIM(1)),...
	'TooltipString','Scan X DIMENSION (Pixels)',...
	'position',[65 85 35 25],'BackgroundColor',Kcolor,'callback',cbdim1);

uicontrol(fixhdr,'style','text','string', 'DIM Y ',...
	'TooltipString','Scan Y DIMENSION (Pixels)',...
	'position',[100 85 55 22],'BackgroundColor',Bcolor);
	
hdim2=uicontrol(fixhdr,'style','edit','string',num2str(DIM(2)),...
	'TooltipString','Scan Y DIMENSION (Pixels)',...
	'position',[155 85 35 25],'BackgroundColor',Kcolor,'callback',cbdim2);

uicontrol(fixhdr,'style','text','string', 'DIM Z ',...
	'TooltipString','Z DIMENSION (No of Slices)',...
	'position',[190 85 55 22],'BackgroundColor',Bcolor);
	
hdim3=uicontrol(fixhdr,'style','edit','string',num2str(DIM(3)),...
	'TooltipString','Z DIMENSION (No of Slices)',...
	'position',[245 85 35 25],'BackgroundColor',Kcolor,'callback',cbdim3);


uicontrol(fixhdr,'style','text','string', 'VOX X ',...
	'TooltipString','Voxel DX (mm)',...
	'position',[10 60 55 22],'BackgroundColor',Bcolor);
	
hvox1=uicontrol(fixhdr,'style','edit','string',num2str(VOX(1)),...
	'TooltipString','Voxel DX (mm)',...
	'position',[65 60 35 25],'BackgroundColor',Kcolor,'callback',cbvox1);

uicontrol(fixhdr,'style','text','string', 'VOX Y ',...
	'TooltipString','Voxel DY (mm)',...
	'position',[100 60 55 22],'BackgroundColor',Bcolor);
	
hvox2=uicontrol(fixhdr,'style','edit','string',num2str(VOX(2)),...
	'TooltipString','Voxel DY (mm)',...
	'position',[155 60 35 25],'BackgroundColor',Kcolor,'callback',cbvox2);

uicontrol(fixhdr,'style','text','string', 'VOX Z ',...
	'TooltipString','Voxel DZ (mm)',...
	'position',[190 60 55 22],'BackgroundColor',Bcolor);
	
hvox3=uicontrol(fixhdr,'style','edit','string',num2str(VOX(3)),...
	'TooltipString','Voxel DZ (mm)',...
	'position',[245 60 35 25],'BackgroundColor',Kcolor,'callback',cbvox3);



uicontrol(fixhdr,'String','SAVE',...
	'Position',[10 35 60 25],...
	'CallBack',['vp_hwrite(FName,DIM,VOX,SCALE,TYPE,OFFSET,ORIGIN,DESCRIP,',...
	'EXPTIM,DURATION,GENTIM,SUBID,EXPDATE,GLMAX,GLMIN);',...
	'set(herror,''string'',[''FILE '' FName(1:min(30,length(FName))) ''... SAVED'']);']);

uicontrol(fixhdr,'String','QUIT',...
	'Position',[215 35 60 25],...
	'CallBack',['delete(fixhdr);']);
	
%	'CallBack',['delete(fixhdr);','delete(FI);']);

herror = uicontrol(fixhdr,'string', ['MSG : ',Message],...
	'position',[10 10 270 25],...
	'Callback','set(gco,''string'',get(gco,''string''))',...
	'BackgroundColor',Ecolor);

