% vp_flipim
% Flip ANALYZE images on X, Y, or Z axis or to Sagittal or Coronal views
%_______________________________________________________________________
% vp_flipim allows the user to flip up<->down (Y axis) or right<->left
% (X axis) each plane of a set of ANALYZE format images or to flip the 
% plane sequence top<->down (Z axis) or to flip the view from Axial to
% Sagittal or Coronal. It also provides an option for X axis flip around
% the Origin. It assumes the original orientation is Axial.
% The results are saved in a new Analyze image with dimensions and origin
% reset. Display routines also assume initial axial orientation,
% so that mislabeling can occur if these files are used with the standard
% display routines.
%_______________________________________________________________________
% vp_flipim		C.4.6	P. Spetsieris	10/13/00
% 		Revision 6.1	P. Spetsieris	3/14/11

global HelpMode FMenu Message NameLst

if HelpMode, vp_help(mfilename), return ; end;

out1=0;
out2=0;

opstr={'Xaxis','O_Xaxis', 'Yaxis','Zaxis','Sag.','Cor.','HELP','QUIT'};
opno=menu('FLIP AXIS',opstr);
if opno==7, vp_help('vp_flipim'); return, end;
if opno==8, return, end;
opch=char(opstr(opno));
op=opch(1);

%NameLst      = get_file(Inf,'.img',['Select images to Flip '],[]);
if vp_filesui(Inf,'.img','Select images to FLIP',mfilename) < 0 ,return; end;

m= size(NameLst,1);
dim3=0;

if m <=0,
  return;
end;

set(FMenu,'Pointer','Watch');

disp('PROCESSING');
	
h=waitbar(0,'Processing FLIP images ...');
for i=1:m

 	waitbar((i-.8)/m,h);
  	FName=deblank(NameLst(i,:));
	
	[out1 out2]=vp_imflip(FName,op,2);
	
	if out1 < 0, 
	  vp_message(Message);

	  %while(findobj('Name','Message')), pause(1); end;
	  waitfor(findobj('Name','Message'));
	else
	  %while(~isempty(findobj('Tag','imflipgui'))), pause(1); end;
	end
end

waitbar(1,h); pause(1); close(h);

vp_note('FLIP PROCESSING COMPLETE',2);
set(FMenu,'Pointer','Arrow');
%disp('END vp_flipim');


