% vp_genmri
% Convert GE GENESIS MRI Format image to ANALYZE
%_______________________________________________________________________
%
% vp_genmri allows the user to convert a GE format (GENESIS-MRI) image
% to ANALYZE format.
%
% The user selects the first and last plane (.MR or .Plane#) image files.
% All intermediate slices are reconstucted into a single ANALYZE format
% image with the same name. Pixel size is 8 or 16 bits.
% The user is given the option to skip intermediate slices.
% See DOS('vpgenmri h') for further help. 
%
%_______________________________________________________________________
% vp_genmri		C.0	P. Spetsieris	July 29, 1999

global HelpMode FMenu NameLst

if HelpMode, vp_help(mfilename), return ; end;

% get the image's filename {FName} 
%-----------------------------------------------------------------------
%FName      = FName(FName ~= ' ')
%NameLst      = get_file(2,'.MR','Pick GENESIS 1st & Last Plane (.MR)',[]);

if vp_filesui(2,'*.*','Pick GENESIS 1st & Last Plane (.MR or .#)',mfilename) < 0, return; end;

m= size(NameLst,1);

bytestr=vp_keyin('Save 1 or 2 bytes/pixel   [1 | 2]','1');
if isempty(bytestr), return; end;
bytefact=min(2,max(1,round(str2num(bytestr)))),

skipstr=vp_keyin('Image Skip factor [1=all, 2=every other,...]','1');
if isempty(skipstr), return; end;
skipfact=max(1,round(str2num(skipstr))),

vp_note([num2str(bytefact),'bytes/pixel, skip fact=',num2str(skipfact)],2);

set(FMenu,'Pointer','Watch');
h=waitbar(0,'Processing IEE images ...');
for i=1:m
  FName=deblank(NameLst(i,:));
  %DosCmd = ['genmri ',FName,' < C:\PET\dat\genmri.dat']
  
  waitbar((i-.8)/m,h);
  if i==1
    DosCmd = ['vpgenmri ',FName];
  else
    DosCmd = [DosCmd,'-',FName,',',num2str(skipfact),' ',num2str(bytefact), ' > genoutput.txt'];
  end
  
disp(' ');
end

%DosCmd=strrep(DosCmd,'\','/'),
%unix(DosCmd) ;
%[s,w]=dos(DosCmd,'-echo'),

[s, w]=vp_dos(DosCmd),
set(FMenu,'Pointer','Arrow');

waitbar(1,h); pause(1); close(h);

if s < 0,
 vp_note(['Check genoutput.txt ERROR: ',w]);
else,
 vp_note('PROCESS COMPLETE. Check genoutput.txt');
end;


disp('END GENESIS->AN');


