% vp_getroiparams.m
% Interface to Get_roi_parameters.m
%
% Sets GUI interface controls for inputing text file containing ROI data,
% tracer type, initial and final frames, and plot options and calls
% Get_roi_parameters for plot processing. A text output file is saved.
% This function performs ROI based graphic analysis.
%
% Format for input text data file is:
% No FName ScanDur(Min) MidTim(Min) CaudNuL CaudNuR PutamL PutamR Par_Occ(Avg)
% (This file can be created with the GROUP ROI routine)
%
% Tracers:
%	RAC : C-11 Raclopride
%	CIT : F-18 FP-BCIT
%	DOP : F-18 FluoroDopa
%
% Plot Options:
%	Simple Plot - SOR -1 Values
%	Patlak Plot - Ki Values
%	Logan Plot  - DVR Values
%___________________________________________________________________________
% vp_getroiparams.m 4.7.7  GUI Interface   Phoebe Spetsieris  June 3, 2002
%
% Get_roi_parameters.m  MAIN Routine Written at NSUH by Yilong Ma PhD
%    				     First evaluation in March 2000
%    				     Report problems to yma@nshs.edu

global Frame0 MaxFrame TxtFName Tracer PlotOpt Message
global HelpMode Ecolor DATA XYZDATA FrameNo 
global htxtname hFrame0 hmaxfrm Message0
global FI GCM Tracer


if HelpMode, vp_help(mfilename), help Get_roi_parameters , return ; end;

TxtFName=[];
Tracer=[];
PlotOpt=[];

%Set user interface controls

bkgcolor = [.8,.9,.9];
Message0=['....'];
Message=Message0;

Frame0=1;
MaxFrame = 1 ;

GCM=colormap;

delete(findobj('Name','roiparamsgui'));

cbFrame0=['Frame0=str2num(get(hFrame0,''string''));'];
cbmaxfrm=['MaxFrame=str2num(get(hmaxfrm,''string''));'];

roiparamsgui = figure('Color',[.5,.6,.6],'Name','roiparamsgui',...
'NumberTitle','off','Position',[100,200,250,154],...
'Units','Pixels');
	
uicontrol(roiparamsgui,'string', 'Help',...
	'TooltipString','Help displayed in MATLAB window',...
	'BackgroundColor',Ecolor,...
	'position',[200 129 40 20],'callback',...
	'vp_help(''vp_getroiparams''); help Get_roi_parameters; ');

cbPTxtName=['TxtFName=get_file(1,''.txt'',''please select text file'',[]); ',...
	'if ~isempty(TxtFName),',...
	'set(htxtname,''string'',TxtFName); ',...
	'vp_dispfile(TxtFName); ',...
	'if isempty(Message), Message=Message0; end; end;',...
	];
	
uicontrol(roiparamsgui,'string', 'ROI.txt FILE',...
	'position',[10 104 75 20],'BackgroundColor',bkgcolor,...
	'ToolTipString',...
	'No FName ScanDur(Min) MidTim(Min) CaudNuL CaudNuR PutamL PutamR Par_Occ(Avg)',...
	'callback',cbPTxtName);
	
cbTxtFName=['TxtFName=get(htxtname,''string'');','Message=Message0 ;',...
	'if ~isempty(TxtFName),',...
	'vp_dispfile(TxtFName); ',...
	'if isempty(Message), Message=Message0; end; end;',...
	];
	
htxtname=uicontrol(roiparamsgui,'style','edit','string',TxtFName,...
	'ToolTipString',...
	'No FName ScanDur(Min) MidTim(Min) CaudNuL CaudNuR PutamL PutamR Par_Occ(Avg)',...
	'position',[85 104 155 20],'BackgroundColor',bkgcolor,'callback',cbTxtFName);
	
uicontrol(roiparamsgui,'string', 'Initial Frame',...
	'TooltipString','Initial Process Frame Number',...
	'position',[10 35 75 20],'BackgroundColor',bkgcolor);
	
hFrame0=uicontrol(roiparamsgui,'style','edit','string',Frame0,...
	'TooltipString','Initial Process Frame Number',...
	'position',[85 35 35 20],'BackgroundColor',bkgcolor,'callback',cbFrame0);

uicontrol(roiparamsgui,'string', 'Final Frame',...
	'TooltipString','Final Process Frame Number',...
	'position',[130 35 75 20],'BackgroundColor',bkgcolor);
hmaxfrm=uicontrol(roiparamsgui,'style','edit','string',MaxFrame,...
	'TooltipString','Final Process Frame Number',...
	'position',[205 35 35 20],'BackgroundColor',bkgcolor,'callback',cbmaxfrm);

cbTracerOpts = ['if isempty(TxtFName), vp_note(''Text File Not Defined'',2); else,',...
	' TracerOpt=get(hTracerMenu,''Value''); ',...
	' if TracerOpt== 2, ',...
	' Tracer=''RAC'';',...
	'elseif TracerOpt== 3, ',...
	' Tracer=''CIT'';',...
	'elseif TracerOpt== 4, ',...
	' Tracer=''DOP'';',...
	'elseif TracerOpt== 5, ',...
	' Tracer=''FET'';',...
	'else ; end; end;'];
	
hTracerMenu=uicontrol(roiparamsgui,'Style','PopUp','String',['Tracer Options|',...
	'RAC : C-11 Raclopride|',...
	'CIT  : F-18 FP-BCIT|',...
	'DOP : F-18 FluoroDopa|',...
	'FET  : F-18 FluoroDopa - Key Time Delay'],...
	'TooltipString',['1: C-11 Raclopride |',...
	'2: F-18 FP-BCIT |',...
	'3: F-18 FluoroDopa |',...
	'4: F-18 FluoroDopa, No Decay Cor., Key Time Delay'],...
	'Position',[10 82 210 20],...
	'CallBack', cbTracerOpts,...
	'BackgroundColor',bkgcolor);
	
	
cbPOpts = ['if isempty(TxtFName), vp_note(''Text File Not Defined'',2); else,',...
	' POpt=get(hPlotMenu,''Value''); ',...
	' if POpt== 2, PlotOpt=1;',...
	'elseif POpt== 3, PlotOpt=2; ',...
	'elseif POpt== 4, PlotOpt=3; ',...
	'else ; end; end;'];
	
hPlotMenu=uicontrol(roiparamsgui,'Style','PopUp','String',['Plot Options|',...
	'Simple Plot - SOR -1 Values|',...
	'Patlak Plot - Ki Values|',...
	'Logan Plot - DVR Values'],...
	'TooltipString',['1: Siple Plot gives Regional SOR Values. |',...
	'2: Patlak Plot gives Regional Ki Values. |',...
	'3: Logan Plot gives Regional DVR Values.'],...
	'Position',[10 60 210 20],...
	'CallBack', cbPOpts,...
	'BackgroundColor',bkgcolor);

uicontrol(roiparamsgui,'String','CANCEL',...
	'Position',[10 10 60 20],...
	'CallBack',['delete(gcbf);']);
	
uicontrol(roiparamsgui,'String','PLOT',...
	'Position',[180 10 60 20],...
	'CallBack',['if isempty(TxtFName), vp_note(''Select Text File'',2);',...
	'elseif isempty(Tracer), vp_note(''Select Tracer '',2);',...
	'elseif isempty(PlotOpt), vp_note(''Select PlotOpt '',2);',...
	'elseif Frame0==MaxFrame, vp_note(''Set Frames'',2);',...
	'else,',...
	'figs=findobj(''type'',''figure''), figno=round(max(figs))+1, figure(figno),',...
	'Get_roi_parameters(TxtFName,Tracer,PlotOpt,Frame0,MaxFrame,figno); end;']);
	

