% vp_getvoxparams.m
% Interface to imfun4.exe
%
% Sets GUI interface controls for creating Logan DVR or Patlak Ki maps.
% Provides fields for inputing .txt text file containing ROI tissue data,
% tracer type, initial and final frames, initial and final planes
% and map options and calls imfun4.exe for processing.
% An Analyze format image is created and a text output file is saved.
%
% Format for input text data file is:
% No FName ScanDur(Min) MidTim(Min) CaudNuL CaudNuR PutamL PutamR Par_Occ(Avg)
% (This file can be created using the GROUP ROI routine)
%
% Tracers:
%	RAC : C-11 Raclopride
%	DOP : F-18 FluoroDopa
%	CIT : F-18 FP_BCIT
%
% Map Options:
%	Patlak Image - Ki Values
%	Logan Image  - DVR Values
%___________________________________________________________________________
% vp_getvoxparams.m 4.7.7 Matlab Interface  Phoebe Spetsieris  June 10, 2002
%
% MAIN .exe routine based on imfun4.c	    Yilong Ma      May, 1999
%
% This task enables dynamic functionalization of PET image files.
% It creates voxel-based Logan plots and Ki maps using reference
% tissue input derived from occipital cortex or cerebellum
% in accordance with one of the menu options.
% Tracers
% 1--F-18 FDOPA,FPCIT HLife=109.7, k2=0.037(Occ. Cortex)
% 2--C-11 Raclopride  HLife=20.3, k2=0.163
% 
% Image files must be in ANALYZE format. Reference ROI data files
% should have the same base name with a '.txt' suffix and be in the
% image directory which also serves as the ouput directory.
% The name.txt file contains time and reference tissue roi data.
% Functional images are assigned an 'f' prefix.
%    				     Report problems to yma@nshs.edu
%  
% See also MATLAB command window for dos('...scanvp\bin\imfun4 help')

global Frame0 MaxFrame TxtFName Tracer PlotOpt Message
global Plane0 MaxPlane
global HelpMode Ecolor DATA XYZDATA FrameNo 
global htxtname hFrame0 hmaxfrm hPlane0 hmaxpln Message0
global FI GCM 


if HelpMode, vp_help(mfilename), vp_dos('imfun4 help'); return ; end;

TxtFName=[];
Tracer=[];
PlotOpt=[];

%Set user interface controls

bkgcolor = [.9,.9,.8];
Message0=['....'];
Message=Message0;

Frame0=1;
MaxFrame = 1 ;
Plane0=1;
MaxPlane = 1 ;
TotFrames = 1 ;

GCM=colormap;

delete(findobj('Name','voxparamsgui'));

cbFrame0=['Frame0=str2num(get(hFrame0,''string''));'];
cbmaxfrm=['MaxFrame=str2num(get(hmaxfrm,''string''));'];
cbPlane0=['Plane0=str2num(get(hPlane0,''string''));'];
cbmaxpln=['MaxPlane=str2num(get(hmaxpln,''string''));'];
cbtotfrms=['TotFrames=str2num(get(htotfrms,''string''));'];

voxparamsgui = figure('Color',[.6,.7,.6],'Name','voxparamsgui',...
'NumberTitle','off','Position',[100,200,250,200],...
'Units','Pixels');
	
uicontrol(voxparamsgui,'string', 'Help',...
	'TooltipString','Help displayed in MATLAB window',...
	'BackgroundColor',Ecolor,...
	'position',[200 174 40 20],'callback',...
	'vp_help(''vp_getvoxparams''); vp_dos(''imfun4 help''); ');

cbPTxtName=['TxtFName=get_file(1,''.txt'',''please select .txt text file'',[]); ',...
	'if ~isempty(TxtFName),',...
	'set(htxtname,''string'',TxtFName); ',...
	'vp_dispfile(TxtFName); ',...
	'if isempty(Message), Message=Message0; end; end;',...
	];
	
uicontrol(voxparamsgui,'string', 'ROI.txt FILE',...
	'position',[10 149 75 20],'BackgroundColor',bkgcolor,...
	'ToolTipString',...
	'No FName ScanDur(Min) MidTim(Min) CaudNuL CaudNuR PutamL PutamR Par_Occ(Avg)',...
	'callback',cbPTxtName);
	
cbTxtFName=['TxtFName=get(htxtname,''string'');','Message=Message0 ;',...
	'if ~isempty(TxtFName),',...
	'vp_dispfile(TxtFName); ',...
	'if isempty(Message), Message=Message0; end; end;',...
	];
	
htxtname=uicontrol(voxparamsgui,'style','edit','string',TxtFName,...
	'ToolTipString',...
	'No FName ScanDur(Min) MidTim(Min) CaudNuL CaudNuR PutamL PutamR Par_Occ(Avg)',...
	'position',[85 149 155 20],'BackgroundColor',bkgcolor,'callback',cbTxtFName);
	
uicontrol(voxparamsgui,'string', 'Initial Plane',...
	'TooltipString','Initial Process Plane Number',...
	'position',[10 125 75 20],'BackgroundColor',bkgcolor);
	
hPlane0=uicontrol(voxparamsgui,'style','edit','string',Plane0,...
	'TooltipString','Initial Process Plane Number',...
	'position',[85 125 35 20],'BackgroundColor',bkgcolor,'callback',cbPlane0);

uicontrol(voxparamsgui,'string', 'Final Plane',...
	'TooltipString','Final Process Plane Number',...
	'position',[130 125 75 20],'BackgroundColor',bkgcolor);
	
hmaxpln=uicontrol(voxparamsgui,'style','edit','string',MaxPlane,...
	'TooltipString','Final Process Plane Number',...
	'position',[205 125 35 20],'BackgroundColor',bkgcolor,'callback',cbmaxpln);
	
uicontrol(voxparamsgui,'string', 'Initial Frame',...
	'TooltipString','Initial Process Frame Number (Suggested Start Time > 20min)',...
	'position',[10 105 75 20],'BackgroundColor',bkgcolor);
	
hFrame0=uicontrol(voxparamsgui,'style','edit','string',Frame0,...
	'TooltipString','Initial Process Frame Number (Suggested Start Time > 20min)',...
	'position',[85 105 35 20],'BackgroundColor',bkgcolor,'callback',cbFrame0);

uicontrol(voxparamsgui,'string', 'Final Frame',...
	'TooltipString','Final Process Frame Number',...
	'position',[130 105 75 20],'BackgroundColor',bkgcolor);
	
hmaxfrm=uicontrol(voxparamsgui,'style','edit','string',MaxFrame,...
	'TooltipString','Final Process Frame Number',...
	'position',[205 105 35 20],'BackgroundColor',bkgcolor,'callback',cbmaxfrm);

uicontrol(voxparamsgui,'string', 'Total Frames',...
	'TooltipString','Total Number of Frames From Start',...
	'position',[130 80 75 20],'BackgroundColor',bkgcolor);
	
htotfrms=uicontrol(voxparamsgui,'style','edit','string',TotFrames,...
	'TooltipString','Total Number of Frames',...
	'position',[205 80 35 20],'BackgroundColor',bkgcolor,'callback',cbtotfrms);

cbTracerOpts = ['if isempty(TxtFName), vp_note(''Text File Not Defined'',2); else,',...
	' TracerOpt=get(hTracerMenu,''Value''); ',...
	' if TracerOpt== 2, ',...
	' Tracer=1;',...
	'elseif TracerOpt== 3, ',...
	' Tracer=1;',...
	'elseif TracerOpt== 4, ',...
	' Tracer=2;',...
	'else ; end; end;'];
	
hTracerMenu=uicontrol(voxparamsgui,'Style','PopUp','String',['Tracer Options|',...
	'DOP : F-18 FluoroDopa|',...
	'CIT : F-18 FP_BCIT|',...
	'RAC : C-11 Raclopride'],...
	'TooltipString',['1: F-18 FluoroDopa 2: F-18 FP_BCIT, 3: C-11 Raclopride '],...
	'Position',[10 35 210 20],...
	'CallBack', cbTracerOpts,...
	'BackgroundColor',bkgcolor);
	
cbPOpts = ['if isempty(TxtFName), vp_note(''Text File Not Defined'',2); else,',...
	' POpt=get(hPlotMenu,''Value''); ',...
	' if POpt== 2, PlotOpt=1;',...
	'elseif POpt== 3, PlotOpt=2; ',...
	'elseif POpt== 4, PlotOpt=3; ',...
	'else ; end; end;'];
	
hPlotMenu=uicontrol(voxparamsgui,'Style','PopUp','String',['Map Options|',...
	'Logan Image - DVR Values|',...
	'Patlak Image - Ki Values'],...
	'TooltipString',[' ',...
	'1: Logan Opt gives Regional DVR Values.|',...
	'2: Patlak Opt gives Regional Ki Values.'],...
	'Position',[10 55 210 20],...
	'CallBack', cbPOpts,...
	'BackgroundColor',bkgcolor);

uicontrol(voxparamsgui,'String','CANCEL',...
	'Position',[10 10 60 20],...
	'CallBack',['delete(gcbf);']);
	
%%	'elseif Plane0==MaxPlane, vp_note(''Set Planes'',2);',...
%%
%'[s,w]=dos(doscmd,''-echo''),',...
%%
uicontrol(voxparamsgui,'String','PROCESS',...
	'Position',[180 10 60 20],...
	'CallBack',['if isempty(TxtFName), vp_note(''Select Text File'',2);',...
	'elseif isempty(Tracer), vp_note(''Select Tracer '',2);',...
	'elseif isempty(PlotOpt), vp_note(''Select PlotOpt '',2);',...
	'elseif Frame0==MaxFrame, vp_note(''Set Frames'',2);',...
	'elseif TotFrames < MaxFrame-Frame0+1, vp_note(''Set Frames'',2);',...
	'else,',...
	'if Plane0==MaxPlane,',...
	'vp_keyin(''Process only one plane? [OK=y | CANCEL=no]'',''yes'');',...
	'if (isempty(Keyin) | strcmp(Keyin,''n'') | strcmp(Keyin,''no'')),',...
	'vp_note(''Set Planes'',2);',...
	'return, end;',...
	'end;',...
	'doscmd=[''imfun4 '',TxtFName,'' '',num2str(Plane0),'' '',',...
	'num2str(MaxPlane),'' '',num2str(Frame0),'' '',num2str(MaxFrame),',...
	''' '',num2str(TotFrames),'' '',num2str(PlotOpt),'' '',num2str(Tracer),',...
	''' > fun4output.txt''];',...
	'h=waitbar(0.5,''Processing Voxel Parameterization'');',...
	'[s,w]=vp_dos(doscmd);',...
	'waitbar(1,h); pause(1); close(h);',...
	'if s < 0,',...
	'vp_note(''PROCESS FAILED, Check MATLAB Command Window and fun4output.txt.'');',...
	'else,',...
	'vp_note(''PROCESS COMPLETE Check fun4output.txt'');',...
	'end; end;']);
	

