function out1 = vp_gismap(action,in1,in2)
%
% in1=RoiNo: Process one roi.
% in1=0: Process all rois
%
% action: abort - Kill Map
% action: save - save gis plane in file
% action: display
%	   
% in2=0; Initialize colormap CM
% in2=1; Maintain previous colormap CM
%
% Displays map of all pixels within threshold limits within region(s)
% of interest weighted by the GIS weighting factor derived by previous
% SSM analysis.
%
% Threshmode Mode must be two dimensional fixed or variable.
%
% Smoothing=0; Smoothing Off
% Smoothing=1; Type A smooth with outline reduction
% Smoothing=2; Type B smooth no outline reduction
%
% FILLType=1; Solid Filling of Threshold pixels = GisWeight
% FILLType=2; Tapering of GisWeight based on TaperFactor 0 to 100%
%_______________________________________________________________________
%  	C.4.6 Phoebe Spetsieris  June 27, 2000
%  	ScAnVP 5.2 Upgrade by PS Mar. 01, 2004
%  	ScAnVP 6.1 Upgrade by PS May. 23, 2011

global DATA WTotal PlaneNo Thresholds DATAMIN DATAMAX
global ThreshMode FixedThMin HelpMode GMIN GMAX
global LabNames LabIds GisLab GisWeight GisOri UFI 
global dim1 dim3 vox1 mtyp3 scale3 BgrndFName or1 or3 GMin3 GMax3
global dimS orS voxS
global RANGEMIN RANGEMAX RI CM FI Smoothing PreSmooth FILLType TaperFactor
global PreSmooth

	
if HelpMode, vp_help(mfilename), return ; end;
      
out1=0;
Message='................';

if ThreshMode ==2 | ThreshMode == 4,
	disp('Not valid for 3D ThreshMode')
return, end;


delete(findobj('Tag','GisMap'));


if strcmp(action,'abort') 
       h=findobj('Name','gisprogui');
       if ~isempty(h), figure(h), axis off; end;
       return;
	
elseif strcmp(action,'display') 

	% debug axis on
        h=findobj('Name','gisprogui');
        if ~isempty(h), figure(h), axis off; end;
        axis off;

  	%cm=get(findobj('Tag','image'),'Colormap');
  
	if (in2==0),
	  w=which('scanvp');
	  cf=[w(1:(max(findstr(w,'\'))-4)),'col\grayhot256'];
	  load(cf);
	  %CM(length(CM)/2,:)=CM(1+length(CM)/2,:);
	end;

	
	gismin=min(GisWeight); gismax=max(GisWeight);
	if gismin==gismax,
	  
	  if gismin==0,
	    vp_note('ERROR: ZERO GIS WEIGHTS');
	    return;
	  end
	  vp_note('WARNING: No Variation in GIS Weights',2);
	  if gismin < 0,
	    gismax=0;
	  else
	    gismin=0;
	  end
	  GisWeight(length(GisWeight)+1)=0;
	end
	
	deltagis=(gismax-gismin);
	
	RANGEMAX=gismax;
	if gismin < 0 & gismax > 0,
		deltagis=2*max(gismax,-gismin);
		RANGEMAX=deltagis/2, RANGEMIN=RANGEMAX-2*deltagis ;
		if (in2==0),
	  		cf=[w(1:(max(findstr(w,'\'))-4)),'col\graybicol'];
	  		load(cf);
		end;
	end;
	gismax,gismin,deltagis,
	RANGEMIN=RANGEMAX-2*deltagis ;

	pos=get(FI,'Position');
	sizex=pos(3); sizey=pos(4);
	%sizex=512; sizey=512;
	if in1 ~= 0
		sizex=sizex/2; sizey=sizey/2;
	end
       
      
      
  	% GIS MAP CONTROLS

	FMap = figure('Color',[0 0 1]*.8,...
	'Name','GIS MAP',...
	'NumberTitle','off',...
	'Position',[pos(1)-40,pos(2)-40,sizex,sizey],...
	'Resize','on',...
	'Colormap',CM,...
	'Toolbar','figure',...
	'UserData',[in1,Smoothing FILLType TaperFactor],...
	'Tag','GisMap',...
	'Units','Pixels',...
	'Pointer','watch',...
	'Visible','off');
	
	%'CM(length(CM)/2,:)=CM(1+length(CM)/2,:);',
	
	updcb=['in=get(gcf,''UserDATA'');',...
	 'vp_gismap(''display'',in(1),1);'];
	 
	%smoocb=['in=get(gcf,''UserDATA''); if Smoothing==0, Smoothing=1,else Smoothing=0, end;',...
	% 'vp_gismap(''display'',in(1),1);'];
	
	 %'if FILLType > 1, vp_tapergui; else, vp_gismap(''display'',in(1),1); end;'];
	tapercb=['in=get(gcf,''UserDATA''); if FILLType==2, FILLType=1; else FILLType=2; end;',...
	 'vp_gismap(''display'',in(1),1); '];
	 
   	uicontrol(FMap,'String','Clear ',...
	 'Position',[2 0 43 20],...
	'CallBack',['vp_gismap(''abort'');']);

   	uicontrol(FMap,'String','Update ',...
	'Position',[45 0 45 20],...
	 'CallBack',updcb);
       
	uicontrol(FMap,'Style','PopUp',...
	'String','Save...|Save PS|Save EPS|Save PCX|Save TIFF|Save BMP',...
	'TooltipString',['Save in ''gismap.*'' : 1: Postscript .ps |2: ',...
	'Encapsulated Postscript: .eps | 3: PCX (8bit): .pcx | 4: TIFF .tiff | 5. BMP .bmp'],...
	'Position',[90 0 50 22],...
	'ForegroundColor','k',...
	'CallBack',...
	['SaveOpt=get(gco,''Value''); ',...
	'if SaveOpt==2, print ''gismap.ps'' -dpsc2 -zbuffer -noui; disp(''gismap.ps saved'');',...
	'elseif SaveOpt==3, print ''gismap.eps'' -depsc2 -zbuffer -noui; disp(''gismap.eps saved'');',...
	'elseif SaveOpt==4, print ''gismap.pcx'' -dpcx256 -noui; disp(''gismap.pcx saved'');',...
	'elseif SaveOpt==5, print ''gismap.tiff'' -dtiff -noui; disp(''gismap.tiff saved'');',...
	'elseif SaveOpt==6, print ''gismap.bmp'' -dbmp256 -noui; disp(''gismap.bmp saved'');',...
	'else, end;'] );
       
   	uicontrol(FMap,'String','Hot ',...
	'Position',[140 0 30 20],...
	'CallBack',...
	['w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\grayhot256'']; load(cf);',...
	'delete(findobj(''tag'',''Colorbar'')); colormap(CM); try colorbar(''v6'',''vert'');',...
	'catch colorbar; end;']);
	
   	uicontrol(FMap,'String','Jet ',...
	'Position',[170 0 30 20],...
	'CallBack',...
	['w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\grayjet256'']; load(cf);',...
	'delete(findobj(''tag'',''Colorbar'')); colormap(CM); try colorbar(''v6'',''vert'');',...
	'catch colorbar; end;']);

   	uicontrol(FMap,'String','BiCol',...
	'Position',[200 0 35 20],...
	'CallBack',...
	['w=which(''scanvp'');',...
	'cf=[w(1:(max(findstr(w,''\''))-4)),''col\graybicol'']; load(cf);',...
	'delete(findobj(''tag'',''Colorbar'')); colormap(CM); try colorbar(''v6'',''vert'');',...
	'catch colorbar; end;']);

   	uicontrol(FMap,'String','Col ',...
	'Position',[235 0 30 20],...
	'CallBack',['delete(findobj(''tag'',''Colorbar'')); vp_matcolor;',...
	'colormap(CM); try colorbar(''v6'',''vert''); catch colorbar; end;']);

	uicontrol(FMap,'Style','PopUp', 'String',...
	 'Post Smoothing OFF | Smooth A (minimal outline) | Smooth B (fast) ',...
	 'ToolTipString','Smooth Algorithms with/without Roi Outline Reduction',...
	 'Position',[265 0 130 22],...
	 'Value',Smoothing+1,...
	 'CallBack',...
	 ['in=get(gcf,''UserDATA''); Smoothing=get(gco,''Value'') -1; ',...
	 'if Smoothing==2, UFI=gcbf; vp_smooth; else, vp_gismap(''display'',in(1),1); end;']);
	 
   	%uicontrol(FMap,'style','menu','String','SmoothA',...
	% 'Position',[230 0 60 20],...
	% 'ToolTipString','Smooth with Roi Outline Reduction',...
	% 'Value',Smoothing,...
	% 'CallBack',smoocb);

   	%uicontrol(FMap,'String','SmoothB',...
	% 'Position',[292 0 52 20],...
	% 'ToolTipString','Smooth without Roi Outline Reduction',...
	% 'CallBack',['UFI=gcbf; vp_smooth;']);

   	%uicontrol(FMap,'Style','Check','String','Taper',...
	% 'Position',[345 0 50 20],...
	% 'Value',(FILLType > 1),...
	% 'CallBack',tapercb);

   	uicontrol(FMap,'String','Bi-Range ',...
	 'Position',[396 0 59 20],...
	 'CallBack','RI=findobj(''tag'',''GisMap''); vp_birange;');

   	uicontrol(FMap,'String','Value ',...
	 'Position',[455 0 55 20],...
	 'CallBack','figure(findobj(''tag'',''GisMap'')); vp_imvalue;');


	lh=findobj('Tag','roi');
	nr=size(lh);
	%dw=double(zeros(size(DATA)));
	
        ngis=size(GisLab);
	if ngis(1)==1, GisLab=char(GisLab), end;
	
	%dw=double(DATA);
	%dsize=size(dw);
	
	% set Background
	bgrndSize=dim3(1)*dim3(2);
	fidbgrnd=fopen(BgrndFName,'r');
      	sz=bgrndSize*vp_roifuns('bytes',mtyp3);
	fseek(fidbgrnd,sz*( (or3(3) +(PlaneNo-or1(3))) -1),'bof');
	bgrndDATA=[];
	bgrndDATA= fread(fidbgrnd,[dim3(1),dim3(2)],mtyp3);
	
        fclose(fidbgrnd);
	
	%for i=1:dim1(1)
	%  for j=1:dim1(2)
	%	  outDATA(i,j)=bgrndDATA(i-or1(1)+or3(1), j-or1(2)+or3(2));
	%  end
	%end
	
	outDATA=imcrop(bgrndDATA,[or3(2)-or1(2)+1,or3(1)-or1(1)+1,dim1(2)-1,dim1(1)-1]);
	
	if PreSmooth > 0, outDATA=vp_interp2D(outDATA,PreSmooth); end;
	
	%dw=double(scale3*outDATA');
	dw=scale3*double(outDATA');
	
	% convert to Gis Range
	%gratio=(gismax -gismin)/(GMAX-GMIN);
	%dw= gismin + (dw-GMIN)*gratio;
	
	gratio=(deltagis-deltagis/128.0)/(GMax3-GMin3);
	%gratio=(deltagis)/(GMax3-GMin3);
	
	% map the MRI image to the negatively flipped gis range (min-delta, min-(max-min)).
	% map the MRI image to the negatively flipped gis range (min-2*delta/64, (min-2*delta/64)-deltagis)).
	
	%dw= 2*gismin -gismax + (dw-GMin3)*gratio;
	%dw= gismin -3*deltagis -deltagis + (dw-GMin3)*gratio;
	%dw= gismin -2*deltagis/64.0 -deltagis + (dw-GMin3)*gratio;
	
	%dw= gismax -2*(deltagis + deltagis/64.0) + (dw-GMin3)*gratio;
	%dw= gismax -2*deltagis + (dw-GMin3)*gratio;
	dw= RANGEMAX -2*deltagis + (dw-GMin3)*gratio;
	
	dsize=size(dw);
	
	h=waitbar(0,'Processing Gis Map ...');
	for i=(1:nr(1))
	
	    waitbar((i-1)/(2*nr(1)),h);
	    udata=get(lh(i),'UserData');
	    nroi=udata(1);
	  
     	    labid=LabIds(nroi,:);
	    [labno,ori]=strtok(labid,'LRC');
	    if isempty(ori), ori='C';
	    elseif length(ori) > 1, ori=ori(1); end;
	    
            %[labno,ret]=sscanf(labid,'%d%c',2);
	    %if ret > 1, labno, ori=char(labno(2)),
	    %else ori='C'; end;
	    
	    %ori=labid(length(labid)),
	    
	    identroi=0;
	    
	    
	    for j=1:ngis(1)
	     if strcmp(LabNames(nroi,:),GisLab(j,:))
	       %if strcmp(ori,GisOri(j)), identroi=1; jgis=j; GisLab(j,:), ori, end;
	       if strcmp(ori,GisOri(j)), identroi=1; jgis=j; end;
	     end
	    end
		
	    identroi,
	    if((in1 == 0 | in1==nroi) & identroi)
		
		x=get(lh(i),'XData');
		y=get(lh(i),'YData');
		pw=roipoly(DATA,x,y);
		
		
		%if ThreshMode==5 | Thresholds(nroi) ~= 100
		
		  datsiz=size(pw);
		  nel=datsiz(1)*datsiz(2);
		  %convert to vector
		  ve=[];
		  ve(1)=DATA(1); j=1;
		  for i=1:nel
		     if pw(i) == 1
		  	ve(j)=DATA(i) ; j=j+1;
		     end
		  end;
	
        	  tmax=max(ve);
		  %tmin=tmax*(1-(Thresholds(nroi)/100));
		  
		  if Thresholds(nroi) == 100, tmin=min(ve);
		  elseif ThreshMode==5, tmin=FixedThMin,
		  else
		   tmin=tmax -(tmax-GMIN)*(Thresholds(nroi)/100);
		  end
		  
		  gfact=0;
		  if FILLType==2 & TaperFactor > 0 & TaperFactor <=100,
		        gmax = GisWeight(jgis);
		  	taperfact=100/TaperFactor;
			dg=deltagis/taperfact;
			gmin=gmax; updn=1;
			if gmax > 0, gmin=max(gmax-dg,gismin); 
				gmin=max(gmin,0);
			elseif gmax < 0, gmax=min(gmin+dg,gismax);
			 	gmax=min(gmax,0); updn=-1;
			end;
			if tmax ~= tmin,
			 gfact=updn*(gmax-gmin)/(tmax-tmin);
			else gfact=0; end;
			
		     %dgis=(deltagis/taperfact)/(tmax-tmin) ;
		  end;
	
		  for i=1:nel
	   	   if pw(i) == 1
	   		if DATA(i) >= tmin,
			 dw(i) = GisWeight(jgis) ;
			 
			 if FILLType==2 & TaperFactor > 0 & TaperFactor <=100,
			 
			   dw(i)=dw(i)-(tmax-DATA(i))*gfact;
			 
			   %dw(i)= dw(i) + (DATA(i)-tmin)*dgis-deltagis/(taperfact*2);
			   if dw(i) < gismin, foundmin=1, dw(i)=gismin; end;
			   if dw(i) > gismax, foundmax=1, dw(i)=gismax; end;
			 end
			 
			 % Correct for colormap roundoff
			 %if(dw(i)==gismin),dw(i)=dw(i)+deltagis/64; end;
	  		end
	   	   end
		  end;
		
		%end % for if
		
		%dw=bitor(dw,pw);
	    end
	end
	
	%figure; image(dw); %keyboard;

	textx=dsize(1)/3;
	if Smoothing ==1,
	
	  disp('smooth ON');
	  
	  %dw0=imresize(dw,[sizex,sizex*(dsize(2)/dsize(1))],'bilinear');
	  
	  d1=(dw >= gismin);  
	  d2=(dw < gismin); 
	  
	  % increase background separation
	  sepfactor= 2.0*deltagis;
	  d1=(dw.*d1 + dw.*d2 - sepfactor*d2);
	  
	  dw1=imresize(d1,[sizex,sizex*(dsize(2)/dsize(1))],'nearest');
	  waitbar(.6,h);
	  
	  %filter > 3 creates more artifacts
	  avfilter=fspecial('average',3);
	  dw2=filter2(avfilter,dw1);
	  waitbar(.7,h);
	  
	  %mrimax=gismin -3*deltagis;
	  %mrimax=gismin -2*deltagis/64.0 -sepfactor;
	  %mrimax=gismax -deltagis -2*deltagis/64.0 -sepfactor;
	  
	  %mrimax=gismax -deltagis -deltagis/128.0 -sepfactor;
	  mrimax=RANGEMAX -deltagis -deltagis/128.0 -sepfactor;
	  
	  dw3=(dw2 >= gismin | dw2 <= mrimax);
	  dw4=(dw2 < gismin & dw2 > mrimax );
	  
	  dw=(dw2.*dw3 + dw1.*dw4);
	  d1=(dw >= gismin);  
	  d2=(dw < gismin); 
	  
	  %sepfactor= deltagis*(3.0-2.0/64);
	  % decrease separation
	  dw=(dw.*d1 + dw.*d2 + sepfactor*d2);
	  waitbar(.8,h);
	  
	  textx=sizex/3;
	else,
	  %disp('smooth OFF');
	end;
	
	%imaph=imagesc(dw,[gismin gismax]);
	
	%RANGEMIN=2*gismin-gismax; RANGEMAX=gismax;
	%Assume colormap has at least 64 colors;
	
	%RANGEMIN=gismin-deltagis-2*deltagis/64 ; RANGEMAX=gismax;
	%RANGEMIN=gismax-2*(deltagis + deltagis/64) ; RANGEMAX=gismax;
	%RANGEMIN=gismax-2*deltagis ; RANGEMAX=gismax;
	
	waitbar(1,h);
	close(h);
	figure(FMap);
	imaph=imagesc(dw,[RANGEMIN RANGEMAX]);
	
	axis off image xy
       
	newdim=size(dw);
	
	newrat=[newdim(2)/dim1(1), newdim(1)/dim1(2)] ;
	
	vox=[vox1(1)/newrat(1), vox1(2)/newrat(2), vox1(3)];
	or=[or1(1)*newrat(1), or1(2)*newrat(2), or1(3)];
	
	%Correct for aspect ratio
	vp_aspect(1, vox);
		
	set(gca,'UserData',[1 PlaneNo vox or]);
	
	try colorbar('v6','vert'); catch colorbar; end;
	
	PlaneNoStr=num2str(PlaneNo);
	
	if in1 ~= 0
	  thdl=text(.1,0,['Plane: ' num2str(PlaneNo) '  Roi: ' num2str(in1) '  Thresh:' num2str(Thresholds(in1)) ],'Color',[1.0 1.0 1.0]);
	else
	  thdl=text(.1,0,['Plane: ' num2str(PlaneNo)],'Color',[1.0 1.0 1.0]);
	end
	
	text(textx,0,['GIS Weight Range: min: ' num2str(gismin) ' max: ' num2str(gismax)],...
	'Color','w'),
	
        %set(FMap,'Pointer','arrow','Colormap',CM,'Position',[pos(1)-5,pos(2)-5,sizex,sizey]);
        set(FMap,'Pointer','arrow','Visible','on');
	drawnow;
	
        if Smoothing==2,
	  UFI=FMap; vp_smooth; 
	end

elseif strcmp(action,'save') 


	gismin=min(GisWeight); gismax=max(GisWeight);
	
	deltagis=(gismax-gismin);
	
	if gismin < 0 & gismax > 0,
		deltagis=2*max(gismax,-gismin);
	end;
	
	h=waitbar(0.1,['Saving Plane ' num2str(PlaneNo)]);
	
	lh=findobj('Tag','roi');
	nr=size(lh);
	
        ngis=size(GisLab);
	
	dw0=zeros([dimS(2), dimS(1)]);
	
	for i=(1:nr(1))
	    waitbar(i/nr(1),h);
	    
	    udata=get(lh(i),'UserData');
	    nroi=udata(1);
	  
     	    labid=LabIds(nroi,:);
	    [labno,ori]=strtok(labid,'LRC');
	    if isempty(ori), ori='C';
	    elseif length(ori) > 1, ori=ori(1); end;
	    
	    identroi=0;
	    
	    for j=1:ngis(1)
	     if strcmp(LabNames(nroi,:),GisLab(j,:))
	       if strcmp(ori,GisOri(j)), identroi=1; jgis=j; end;
	     end
	    end
		
	    if((in1 == 0 | in1==nroi) & identroi)
		
		  x=get(lh(i),'XData');
		  y=get(lh(i),'YData');
		  pw=roipoly(DATA,x,y);
		
		  datsiz=size(pw);
		  nel=datsiz(1)*datsiz(2);
	
		  %convert to vector
		  ve=[];
		  ve(1)=DATA(1); j=1;
		  for i=1:nel
		     if pw(i) == 1
		  	ve(j)=DATA(i) ; j=j+1;
		     end
		  end;
	
        	  tmax=max(ve);
		  
		  if Thresholds(nroi) == 100, tmin=min(ve);
		  elseif ThreshMode==5, tmin=FixedThMin,
		  else
		   tmin=tmax -(tmax-GMIN)*(Thresholds(nroi)/100);
		  end
		  
		  gfact=0;
		  if FILLType==2 & TaperFactor > 0 & TaperFactor <=100,
		  
		        gmax = GisWeight(jgis);
		  	taperfact=100/TaperFactor;
			dg=deltagis/taperfact;
			gmin=gmax; updn=1;
			if gmax > 0, gmin=max(gmax-dg,gismin); 
				gmin=max(gmin,0);
			elseif gmax < 0, gmax=min(gmin+dg,gismax);
			 	gmax=min(gmax,0); updn=-1;
			end;
			if tmax ~= tmin,
			 gfact=updn*(gmax-gmin)/(tmax-tmin);
			else gfact=0; end;
			
		  end;
	
		  for i=1:nel
	   	   if pw(i) == 1
	   		if DATA(i) >= tmin,
			 %dw(i) = GisWeight(jgis) ;
			 dw0(i) = GisWeight(jgis) ;
			 
			 
			 if FILLType==2 & gfact~= 0,
			 
			   %dw(i)=dw(i)-(tmax-DATA(i))*gfact;
			   %if dw(i) < gismin, foundmin=1, dw(i)=gismin; end;
			   %if dw(i) > gismax, foundmax=1, dw(i)=gismax; end;
			   %dw0(i)=dw(i);
			   
			   dw0(i)=dw0(i)-(tmax-DATA(i))*gfact;
			   if dw0(i) < gismin, foundmin=1, dw0(i)=gismin; end;
			   if dw0(i) > gismax, foundmax=1, dw0(i)=gismax; end;
			   
			 end
			 
	  		end
	   	   end;
		  end;
		
		
	    end
	end
	
	% save
	cw=double(dw0');
	
	%imagesc(dw0,[gismin, gismax]); keyboard;
	
	out1=fwrite(in2,cw,'double');
	if out1 <= 0, Message=lasterr(''), 
	else Message=['Plane:' num2str(PlaneNo) ', '  num2str(out1)  ' bytes written'];
	end;
	
	waitbar(1,h); close(h) ;
end	

