% function out1 = vp_globhdr(action, ghdrin) 
% vp_globhdr saves or restores the global values of an ANALYZE header in a structure
%
% action:
%  'save', formats the global values listed below in the returned structure
%  'restore', resets the global header values to the input structure ghdrin parameters 
%
% ghdrin: Input structure for action 'restore'
% out1: Returns a structure for action 'save', 0 for action 'restore', -1 for error
%
% Analyze Global Header Parameters
% DIM     - image size       [i j k [l]] (voxels)
% VOX     - voxel size       [x y z [t]] (mm [sec])
% SCALE   - scale factor
% TYPE    - datatype (integer - see spm_type)
% OFFSET  - offset (bytes)
% ORIGIN  - [i j k] of origin  (default = [0 0 0])
% DESCRIP - description string (default = 'spm compatible')
%
% Additions by PS
% EXPTIM  - Relative frame start time [HR:MN:SC]
% DURATION- scan duration (secs) dim(6)
% GENTIM  - Actual Frame Start Time
% SUBID   - Subject ID
% EXPDATE - Scan Date
% GLMAX   - global maximum
% GLMIN   - global minimum
%___________________________________________________________________________
%
% For vp_globhdr input action 'save' a structure is formated with the Analyze
% header values stored in scanvp global variables and returned in out1.
% For action 'restore', the global values are set from the input structure values.
%
% see also dbh.h (ANALYZE) vp_hread.m, vp_hwrite.m
%__________________________________________________________________________
% vp_globhdr.m    ScAnVP ver. 6.2            July 7, 2011

function out1 = vp_globhdr(action, ghdrin) 

global Message
global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP EXPTIM DURATION GENTIM SUBID EXPDATE GLMAX GLMIN


out1=0;


if nargin < 1, vp_note('Must specify action ''save'' or ''restore'' ',2); out1=-1;
elseif strcmp(action,'save')
  out1=struct('dim',DIM,'vox',VOX,'scale',SCALE,'type',TYPE,'offset',OFFSET,...
          'origin',ORIGIN,'descrip',DESCRIP,'exptim',EXPTIM,'duration',DURATION,...
          'gentim',GENTIM,'subid',SUBID,'expdate',EXPDATE,'glmax',GLMAX,'glmin',GLMIN);

elseif strcmp(action,'restore')
  DIM=ghdrin.dim; VOX=ghdrin.vox; SCALE=ghdrin.scale; TYPE=ghdrin.type; OFFSET=ghdrin.offset;
  ORIGIN=ghdrin.origin; DESCRIP=ghdrin.descrip; EXPTIM=ghdrin.exptim; DURATION=ghdrin.duration;
  GENTIM=ghdrin.gentim; SUBID=ghdrin.subid; EXPDATE=ghdrin.expdate;
  GLMAX=ghdrin.glmax; GLMIN=ghdrin.glmin;

else
 action,
 vp_note('INVALID action',2);
 out1=-1;
end
