% vp_groupmask.m
% Create a groupmask or mask image set with input mask.
%
% 1) Create Group Threshold Mask
% vp_mkTmask allows the user to select a set of ANALYZE format normalized
% images files and a lower fractional threshold to be applied to each 
% image's maximum value in the routine ssmpca.exe which creates a mask
% image based on the composite product of individual 0|1 maps of values 
% above the threshold. A default threshold of .35 is provided. 
% The interface creates a file containing a list of files the first of
% which is an input header followed by the input images required by ssmpca.exe. 
% It then runs the dos command:  'ssmpca names.lst .thresh > maskoutput.txt'
% to create the mask. The resulting mask is saved in the user directory.
%
% 2) Mask multiply images and save.
% User inputs a mask image and a set of images to be masked. 
% The data image pixel values are multiplied by the corresponding mask image
% values to create each output image. Usually, the mask contains 0/1 values
% and the masked output images will contain the original data wherever mask values
% are 1 and 0 elsewhere. A _m suffix is applied to the output names to indicate
% masked values. 
%
%
% ScAnVP 5.1     P. Spetsieris, Ph.D.    7/21/03  
%_______________________________________________________________________

global HelpMode FMenu NameLst POpt

if HelpMode, vp_help(mfilename), return ; end;

prompt=['Create a Composite (Fract. of Max) Group Mask  or  Mask Data'];
POpt='Help';
while (strcmp(POpt,'Help'))
   POpt=vp_opt('X',prompt,'CREATE MASK','Make group lower threshold (fract of Max) composite map','MASK DATA','mask group images with 0|1 mask or other input image','EXIT','','Help','');
   if(strcmp(POpt,'X')) return; end;
   if(strcmp(POpt,'EXIT')) return; end;
   if(strcmp(POpt,'Help')),
    vp_help('vp_groupmask');
    vp_note('Create a Lower Threshold Mask or Specify an existing [0|1] mask image to remove insignificant voxels');
   end
end
  
if (strcmp(POpt,'CREATE MASK'))
 vp_mkTmask;
elseif (strcmp(POpt,'MASK DATA'))
 vp_maskimgs;
end

