function [out1, nameimg, rdata]=vp_hemipro(FName, imop, saveop, flipRL)
% Right/Left Hemi mask operation on an ANALYZE Format image
%_______________________________________________________________________
%
% vp_hemipro masks out half of an image by setting to zero the other half,
% right or left of ANALYZE format images.
%
% imop
%  R = RIGHT on axial display 
%  L = LEFT on axial display 
%
% saveop=1  :  Write image without returning DATA
% saveop=2  :  Return DATA without writing image
% flipRL=1  :  Flip image R/L
% out1   :  Return status
% nameimg   :  Return Saved Hemi-Image Name
% rdata   :  Return DATA
%____________________________________________________________________
% vp_hemipro	ScAnVP	5.2	P. Spetsieris	9/18/03
%               Rev. 7.0 by P. Spetsieris  11/27/15

global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN VAL_OFFSET
global EXPTIM DURATION MATYPE Message GENTIM SUBID EXPDATE
global HelpMode

if HelpMode, vp_help(mfilename), return ; end;
out1=0;
rdata=[];
nameimg=[];

%m= size(NameLst,1);

RDATA=[];

imop,

FName=deblank(FName);
%P=strtok(FName,'.');
P=vp_nm('dnm',FName);
	
vp_hread([P '.hdr']);
	
name=[P '.img'];
  
fid=fopen(name,'r');
RDATA=[];
 
jhalf=round(DIM(1)/2);
if nargin < 3, saveop=1; end;
if nargin < 4, flipRL=0; end;
for i=1:DIM(3)
  
	DATA=[];
	
	DATA	= fread(fid,[DIM(1),DIM(2)],MATYPE);
    RDATA(:,:,i)=DATA';
	if flipRL ~= 0, RDATA(:,:,i)=fliplr(RDATA(:,:,i)); end;
    
	if strcmp(imop,'R') 
	  for j=1:jhalf
	   RDATA(:,j,i)=0;
	  end
	elseif strcmp(imop,'L') 
	  for j=jhalf+1:DIM(1)
	   RDATA(:,j,i)=0;
	  end
	else
		  Message=['ERROR: Invalid IMOP' imop];
		  disp(Message);
		  out1=-1;
		  return;
	end
	  
end %for i

fclose(fid);

MaxDim=DIM(3);

if saveop == 1,
 nameimg=[P '_' imop '.img'];
 fidop=fopen(nameimg,'w');
end


for j=1:MaxDim

      DATA=RDATA(:,:,j);
      if saveop == 2, rdata(:,:,j)=DATA; end;
             
      if saveop == 1,
        if flipRL, DATA=fliplr(DATA); end; %flip back before saving
        DATA=DATA';
        no=fwrite(fidop,DATA,MATYPE);
        if no <=0,
  		  Message=['Write ERROR no: ' num2str(no) ' pixels Plane:' num2str(j)] ;
		  disp(Message);
		  out1=-1;
		  return;
	    end
      end
	
end %for j

if saveop == 2
  rdata=SCALE*rdata;
  if VAL_OFFSET ~=0, rdata=rdata+VAL_OFFSET; end;
end
%out3=SCALE;

dim=DIM; vox=VOX; or=ORIGIN;
DESCRIP=[DESCRIP, ' -HEMIMAGE ' imop];
TYPE,MATYPE,DESCRIP,

if saveop == 2, return; end;
if saveop ==1, fclose(fidop); end;

Bcolor = [.8,1,1];

hemiprogui = figure('Color',Bcolor,'Name',[imop ' cvt'],'Tag','hemiprogui',...
'NumberTitle','off','Position',[100,200,250,60],'UserData',0,...
'Units','Pixels');
	
% Save default header before user name read, to keep consistent with image saved.
% Read user name. If not the default name. Warn if only .hdr or .img doesn't exist,
% since if there aren't permissions to overwrite, only the header or image will be
% overwritten and the other will be incorrect.

%	'nameimg=deblank(nameimg); namehdr0=[strtok(nameimg,''.'') ''.hdr''];',...
%
%	  'name=deblank(name); namehdr=[strtok(name,''.'') ''.hdr''];',...
%	  'name=[strtok(name,''.'') ''.img''];',...
%
cbFName=['staterr=0; hrname=findobj(''tag'',''namefield''); nameimg=get(hrname,''userdata''),',...
	'nameimg=deblank(nameimg); namehdr0=[vp_nm(''dnm'',nameimg) ''.hdr''];',...
	'if (vp_hwrite(nameimg,DIM,VOX,SCALE,TYPE,OFFSET,ORIGIN,DESCRIP,',...
	'EXPTIM,DURATION,GENTIM,SUBID,EXPDATE) ) < 0,',...
	'vp_message(''hwrite err''); staterr=1; ',...
	'else, ',...
	  'name=get(hrname,''string''),',...
	  'name=vp_nm(''dnm'',name); namehdr=[name ''.hdr''];',...
	  'name=[name ''.img''];',...
	  'if ~strcmp(name,nameimg),',...
	     'if (exist(name,''file'') & ~exist(namehdr,''file'')) | ',...
	       ' (~exist(name,''file'') & exist(namehdr,''file''))  ',...
	       'vp_message([''Remove Invalid File '' name '' .hdr or .img'']);',...
	       ' staterr=3; ',...
	     'else, [s,dosmsg]=dos([''move '' nameimg '' '' name]), ',...
	       'if s ~=0, vp_message(dosmsg); staterr=2; end; ',...
	       '[s,dosmsg]=dos([''move '' namehdr0 '' '' namehdr]), ',...
	       'if s ~=0, vp_message(dosmsg); staterr=2; end; ',...
	     'end; ',...
	     'if staterr==0,  nameimg=name;  end;',...
	  'end; ',...
	'end;',...
	'if staterr==0,',...
	  'set(gco,''string'',[nameimg ''   FILE SAVED'']); Message=[''FILE SAVED'']; ',...
	  'disp(Message); pause(2); set(findobj(''tag'',''hemiprogui''),''UserData'',1); ',...
	' end; '];
	
	
	
uicontrol(hemiprogui,'style','text','string','ENTER NAME: ',...
	'position',[10 25 125 25],'BackgroundColor',Bcolor);
	
hrname=uicontrol(hemiprogui,'style','edit','tag','namefield','string',nameimg,...
	'userdata',nameimg,...
	'position',[10 5 225 25],'BackgroundColor','w','callback',cbFName);


while( get(findobj('tag','hemiprogui'),'UserData')==0) ,pause(1); end;

delete( findobj('tag','hemiprogui') );
