function [DIM,VOX,SCALE,TYPE,OFFSET,ORIGIN,DESCRIP,EXPTIM,DURATION,MATYPE,GENTIM,SUBID,EXPDATE,GLMAX,GLMIN,VAL_OFFSET] = vp_hread(P,endian)
% -Version 5.9.1  (C)2008  Center for Neurosciences
% vp_hread based in part on spm_hread, reads an ANALYZE or nifti-1 header
%
% FORMAT [DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP,EXPTIM,DURATION,MATYPE,GENTIM,SUBID,EXPDATE,GLMAX,GLMIN,VAL_OFFSET] = vp_hread(P);
%
% P       - filename 	     (e.g  name.img)
% DIM     - image size       [i j k [l] [t]] (voxels) [secs]
% VOX     - voxel size       [x y z [t]] (mm [secs])
% SCALE   - scale factor
% TYPE    - datatype (integer - see spm_type)
% OFFSET  - offset (bytes)
% ORIGIN  - origin [i j k]
% DESCRIP - description string
% EXPTIM  - Relative frame start time [HR:MN:SC]
% DURATION- scan duration (secs) dim(6)
% MATYPE  - Matlab Data Type
% Message - Status Message
% GENTIM  - Actual Frame Start Time
% SUBID   - Subject ID
% EXPDATE - Scan Date
% GLMAX   - global maximum
% GLMIN   - global minimum
% VAL_OFFSET - value offset for nifti files.
% 
%___________________________________________________________________________
%
% spm_hread reads variables into working memory from an ANALYZE or nifti-1
% compatible header file.  If the header or header field does not exist global
% defaults are used. For SPM99/ANALYZE headers, ORIGIN is determined from the
% 'originator' field. funused1 of the ANALYZE format is used for SCALE.
% For SPM5/nifti-1 headers, ORIGIN is determined from the
% hdr.srow_x,_y,_z fields.
%
% see also dbh.h (ANALYZE) spm_hwrite.m, spm_type.m (spm99)
% and spm5\@nifti\*
%
%__________________________________________________________________________
% vp_hread.m	modeled in part after spm_hread 1.4 96/09/11
%		Modifications by P. Spetsieris : 
%
%		add parameters DURATION, EXPTIM,MATYPE,Message etc.. 12/6/99
%		add SUBID,GENTIM,EXPDATE.. 3/13/2000
%		Other modifications indicated by 'PS'
%		Modified to read spm5, nifti_1 neaders.  1/2/08
%		Modified to UNIX headers.  3/3/08
%		Modified to return VAL_OFFSET for nifti files or 0.  4/27/12
% endian 1: UNIX, 0: DOS
%		Modified to set nifti type global NIFTITYPE.  4/25/13
 
global Message
global DIM VOX SCALE TYPE OFFSET ORIGIN GLMAX GLMIN EXPTIM DURATION MATYPE DESCRIP
global SUBID GENTIM EXPDATE
global HDRTYPE VAL_OFFSET NIFTITYPE

VAL_OFFSET=0
NIFTITYPE=0;
if (nargin < 2) endian=0; end;
Message=[' '];
% ensure correct suffix {.hdr}
%---------------------------------------------------------------------------

FName=deblank(P);
    [sfx,P]=vp_nm('sfx',FName);
	
    if (strcmp(sfx,'hdr') | strcmp(sfx,'img'))
       P=[P '.hdr'];
    elseif (strcmp(sfx,'nii'))
	   P=[P '.nii']; NIFTITYPE=1;
    elseif (isempty(sfx) & exist([P '.hdr'],'file'))
	   P=[P '.hdr'];
    else
        vp_note([sfx ' is NOT A RECOGNIZED HEADER'],3);
        FName, P, sfx,
        DIM= -1; return;
    end;
    
% open header file
%---------------------------------------------------------------------------
P     = P(P ~= ' ');
if endian==0
  %fid   = fopen(P,'r',);
  fid   = fopen(P,'r','ieee-le');
else
  fid   = fopen(P,'r','ieee-be');
end
if (fid > 0)

% read (struct) header_key
%---------------------------------------------------------------------------
fseek(fid,0,'bof');

sizeof_hdr 	= fread(fid,1,'int32');
data_type  	= setstr(fread(fid,10,'char'))';
db_name    	= setstr(fread(fid,18,'char'))';
extents    	= fread(fid,1,'int32');
session_error   = fread(fid,1,'int16');
regular    	= setstr(fread(fid,1,'char'))';
hkey_un0    	= setstr(fread(fid,1,'char'))';

% read (struct) image_dimension
%---------------------------------------------------------------------------
fseek(fid,40,'bof');

dim    		= fread(fid,8,'int16');

% check if niftii format
%---------------------------------------------------------------------------
fseek(fid,344,'bof');
mag=deblank(char(fread(fid,4,'uint8')'));
%if (strcmp(mag,'ni1') || strcmp(mag,'n+1') ),
%
if (strcmp(mag,'ni1') | strcmp(mag,'n+1') ),
niftiformat=1, HDRTYPE='NIFTI', else niftiformat=0; HDRTYPE='ANALYZE', end;
disp(['Header TYPE: ',HDRTYPE,' :', mag]);
if strcmp(mag,'n+1') , vp_note(['CONVERT NIFTI type ',mag, ' TO ANALYZE']); end;

if ~niftiformat % ANALYZE FORMAT

fseek(fid,56,'bof');
vox_units    	= setstr(fread(fid,4,'char'))';
cal_units    	= setstr(fread(fid,8,'char'))';
unused1		= fread(fid,1,'int16');
datatype	= fread(fid,1,'int16');
bitpix		= fread(fid,1,'int16'),
dim_un0		= fread(fid,1,'int16');
pixdim		= fread(fid,8,'float');
vox_offset	= fread(fid,1,'float');
funused1	= fread(fid,1,'float');
funused2	= fread(fid,1,'float');
funused3	= fread(fid,1,'float');
cal_max		= fread(fid,1,'float');
cal_min		= fread(fid,1,'float');
compressed	= fread(fid,1,'int32');
verified	= fread(fid,1,'int32');
glmax		= fread(fid,1,'int32'),
glmin		= fread(fid,1,'int32'),

% read (struct) data_history
%---------------------------------------------------------------------------
fseek(fid,148,'bof');

descrip		= setstr(fread(fid,80,'char'))';
aux_file	= setstr(fread(fid,24,'char'))';
orient		= fread(fid,1,'char');
origin		= fread(fid,5,'int16');
generated	= setstr(fread(fid,10,'char'))';
scannum		= setstr(fread(fid,10,'char'))';
patient_id	= setstr(fread(fid,10,'char'))';
exp_date	= setstr(fread(fid,10,'char'))';
exp_time	= setstr(fread(fid,10,'char'))';

hist_un0	= setstr(fread(fid,3,'char'))';
views		= fread(fid,1,'int32');
vols_added	= fread(fid,1,'int32');
start_field	= fread(fid,1,'int32');
field_skip	= fread(fid,1,'int32');
omax		= fread(fid,1,'int32');
omin		= fread(fid,1,'int32');
smax		= fread(fid,1,'int32');
smin		= fread(fid,1,'int32');

fclose(fid);

Message=['ANALYZE FILE ' P ' READ'];
if isempty(smin)
	%error(['There is a problem with the header file ' P '.']);
	Message=['There is a problem with the header file ' P '.'];
	vp_message(Message);
	error(Message); % Exit
end


% convert to global variables
%---------------------------------------------------------------------------
DIM    	  	= dim(2:4)';
dim,
VOX       	= pixdim(2:4)';
P,
SCALE     	= funused1,
% If it's zero it will be set to 1, otherwise no change
SCALE    	= ~SCALE + SCALE;
TYPE     	= datatype;
OFFSET	  	= vox_offset;
ORIGIN    	= origin(1:3)',
DESCRIP   	= descrip(1:max(find(descrip)));
GLMAX		= glmax;
GLMIN		= glmin;
DURATION	= dim(6) ;	%PS Scan Duration (Secs)	
EXPDATE		= exp_date(1:10);	%PS Scan Date
EXPTIM		= exp_time(1:8);	%PS Relative Frame Start Time
GENTIM		= generated(1:8);	%PS Actual Frame Start Time
SUBID		= patient_id(1:10);	%PS Subject ID

else %NIFTII format %PS

fseek(fid,56,'bof');
intent_p	= fread(fid,3,'float'),
intent_code	= fread(fid,1,'int16'),
datatype	= fread(fid,1,'int16'),
bitpix		= fread(fid,1,'int16'),
slice_start	= fread(fid,1,'int16'),
pixdim		= fread(fid,8,'float'),
vox_offset	= fread(fid,1,'float'),
scl_slope	= fread(fid,1,'float'),
scl_inter	= fread(fid,1,'float'),
slice_end	= fread(fid,1,'int16'),
slice_code	= setstr(fread(fid,10,'char'))',
xyzt_units	= setstr(fread(fid,10,'char'))',
cal_max		= fread(fid,1,'float'),
cal_max		= fread(fid,1,'float'),
slice_duration	= fread(fid,1,'float'),
toffset		= fread(fid,1,'float'),
glmax		= fread(fid,1,'int32'),
glmin		= fread(fid,1,'int32'),
% read (struct) data_history
%---------------------------------------------------------------------------
fseek(fid,148,'bof');

descrip		= setstr(fread(fid,80,'char'))',

fseek(fid,228,'bof');
aux_file	= setstr(fread(fid,24,'char'))',

fseek(fid,252,'bof');
qform_code	= fread(fid,1,'int32'),
sform_code	= fread(fid,1,'int32'),

fseek(fid,256,'bof');
quatern_b	= fread(fid,1,'float'),
quatern_c	= fread(fid,1,'float'),
quatern_d	= fread(fid,1,'float'),
qoffset_x	= fread(fid,1,'float'),
qoffset_y	= fread(fid,1,'float'),
qoffset_z	= fread(fid,1,'float'),
srow_x		= fread(fid,4,'float'),
srow_y		= fread(fid,4,'float'),
srow_z		= fread(fid,4,'float'),
intent_name	= setstr(fread(fid,16,'char'))',
magic		= setstr(fread(fid,4,'char'))',

Message=['NIFTII FILE ' P ' READ'];
fclose(fid);

% convert to global variables
%---------------------------------------------------------------------------
DIM    	  	= dim(2:4)';
dim,
VOX       	= pixdim(2:4)';
P,
SCALE     	= scl_slope,
SCALE    	= ~SCALE + SCALE;
TYPE     	= datatype;
OFFSET	  	= vox_offset;
DESCRIP   	= descrip(1:max(find(descrip)));
GLMAX		= glmax;
GLMIN		= glmin;

datmat= [srow_x srow_y srow_z [0 0 0 1]']'; 
eee=[eye(4,3) [1 1 1 1]'];
datmat = datmat/eee,
datori= datmat\[ 0 0 0 1]';
origin=datori(1:3)',
ORIGIN=round(origin),

DURATION	= round(slice_duration);%PS Slice Duration 
EXPDATE		= '__/__/____'; %PS Scan Date Not Defined
EXPTIM		= '__:__:__';	%PS Relative Frame Start Time
GENTIM		= '__:__:__';	%PS Actual Frame Start Time Not Defined
SUBID		= 'xxxxxxxxxx';	%PS Subject ID

if (scl_inter ~= 0),
 VAL_OFFSET=scl_inter,
 valoffstr=sprintf('%f',VAL_OFFSET),
 vp_note(['NIFTI to ANALYZE VAL_OFFSET ',valoffstr],3);
end;

end %nifti format

GLMIN=0; GLMAX=1;
if TYPE==2
  MATYPE='uchar'; GLMAX=255;
elseif TYPE==4
  MATYPE='int16'; GLMAX=32767;
elseif TYPE==8
  MATYPE='int32'; GLMAX= 2^31 -1;
elseif TYPE==16
  MATYPE='float'; GLMAX=1;
elseif TYPE==64
  MATYPE='double'; GLMAX=1;
else %PS
  MATYPE='uchar';
  disp(['set MATYPE ?: Unknown TYPE ' num2str(TYPE)]);
  Message=['MATYPE ?: Unknown TYPE ' num2str(TYPE)];
  if ( (TYPE==512*(TYPE/512)) & (TYPE > 0)), MATYPE='UNIX',
   if ~niftiformat % ANALYZE FORMAT
     vp_note(['Error: CONVERT TYPE ',num2str(TYPE), ' UNIX -> DOS']); return; 
   else
     vp_note(['Error: CONVERT NIFTI TYPE ',num2str(TYPE), ' UNIX -> ANALYZE/DOS']); return; 
   end
  else
    vp_message(Message);
  end;
end


else
	Message=['ERROR opening header file: ', P],
	vp_message(Message);
%PS	global DIM VOX SCALE TYPE OFFSET ORIGIN GLMAX GLMIN
%PS	DESCRIP = ['defaults'];
	DIM=-1;
end
