function [out1, out2, out3]=vp_imflip(FName, imop, in3)
% Perform image flip operation on an ANALYZE Format image
%_______________________________________________________________________
%
% vp_imflip performs image operations such as planar flip up->down (Y axis),
% right->left (X axis), or top->down (Z axis) or conversion to Sagittal or
% Coronal Planar views on ANALYZE format axial images.
%
% imop
%  Y=UP->DOWN on axial view Y axis
%  X=LEFT->RIGHT on axial view X axis
%  O=LEFT->RIGHT around X Axis Origin
%  Z=TOP->DOWN reverse plane order (Z axis)
%  S=Convert to Sagittal view
%  C=Convert to Coronal view
%
% in3=1  :  Return DATA without writing image
% in3=2  :  Return DATA and write image
% out1   :  Return status
% out2   :  Return DATA
% out3   :  Return SCALE
%_______________________________________________________________________
% vp_imflip		C.4.6	P. Spetsieris	10/3/00
% 		Revision 6.1	P. Spetsieris	3/14/11

global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN
global EXPTIM DURATION MATYPE Message GENTIM SUBID EXPDATE
global HelpMode

if HelpMode, vp_help(mfilename), return ; end;

out1=0;
out2=[];
out3=0;

%m= size(NameLst,1);

RDATA=[];

imop,
	
%for i=1:m

%FName=deblank(NameLst(i,:));

FName=deblank(FName);
%P=strtok(FName,'.');
P=vp_nm('dnm',FName);
	
%glmaxdat=0;
	
vp_hread([P '.hdr']);
	
name=[P '.img'];
  
%	ImageSize=DIM(1)*DIM(2)*DIM(3);
%ImageSize=DIM(1)*DIM(2);

  
  fid=fopen(name,'r');
  RDATA=[];
 
for i=1:DIM(3)
  

	DATA=[];
	
	%DATA	= fread(fid,MATYPE);
	DATA	= fread(fid,[DIM(1),DIM(2)],MATYPE);
	  
	
	if strcmp(imop,'Y') 
	       RDATA(:,:,i)=flipud(DATA');
	elseif strcmp(imop,'X') 
	       RDATA(:,:,i)=fliplr(DATA');
	elseif strcmp(imop,'O') 
	       SDATA=zeros(DIM(1),DIM(2));
	       orx=ORIGIN(1); forx=DIM(1)-orx +1;
	       dx= forx-orx;
	       
	       if dx > 0, x1=1; x2=DIM(1)-dx; b1=x1+dx; b2=DIM(1);
	       else x1=1-dx; x2=DIM(1); b1=1; b2=DIM(1) + dx;
	       end;
	       for ix=x1:x2
		  for iy=1:DIM(2)
		  	SDATA(ix+dx,iy)=DATA(ix,iy);
		  end
	       end
	       RDATA(:,:,i)=fliplr(SDATA');
	elseif (strcmp(imop,'Z') | strcmp(imop,'S') | strcmp(imop,'C')) 
	       RDATA(:,:,i)=DATA;
		
	else
		  Message=['ERROR: Invalid IMOP' imop];
		  disp(Message);
		  out1=-1;
		  return;
	end
	  
	  %maxout=max(RDATA),
	  %minout=min(RDATA),
	  %maxout=max(max(RDATA(:,:,PlaneNo))),
	  %minout=min(min(RDATA(:,:,PlaneNo))),
	  %keyboard;
	



 % DATA=RDATA';
 %out2=[out2,DATA];

end %for i

fclose(fid);

if strcmp(imop,'S')
	MaxDim=DIM(1);
elseif strcmp(imop,'C')
	MaxDim=DIM(2);
else
	MaxDim=DIM(3);
end

if in3~=1,
 nameimg=[P imop '.img'];
 fidop=fopen(nameimg,'w');
end


for j=1:MaxDim

	if (strcmp(imop,'Y') | strcmp(imop,'X') | strcmp(imop, 'O') ) 
	       DATA=RDATA(:,:,j);
	       DATA=DATA';
	elseif strcmp(imop,'Z') 
	       DATA=RDATA(:,:,(DIM(3)-j+1));
	elseif strcmp(imop,'S') 
		DATA=zeros(DIM(2),DIM(3));
		for ix=1:DIM(2)
		  for iy=1:DIM(3)
		  	DATA(ix,iy)=RDATA(j,ix,iy);
		  end
		end
	elseif strcmp(imop,'C') 
		DATA=zeros(DIM(1),DIM(3));
		for ix=1:DIM(1)
		  for iy=1:DIM(3)
		  	DATA(ix,iy)=RDATA(ix,j,iy);
		  end
		end
	else
	end
	
       
        out2(:,:,j)=DATA';
 

      if in3~=1,
	no=fwrite(fidop,DATA,MATYPE);
	if no <=0,
  		Message=['Write ERROR no: ' num2str(no) ' pixels Plane:' num2str(j)] ;
		disp(Message);
		out1=-1;
		return;
	end
      end
	
end %for j


dim=DIM; vox=VOX; or=ORIGIN;
if strcmp(imop,'S')
    DESCRIP=[DESCRIP, ' -SAGITTAL Flip '];
    DIM(1)=dim(2); DIM(2)=dim(3); DIM(3)=dim(1);
    VOX(1)=vox(2); VOX(2)=vox(3); VOX(3)=vox(1);
    ORIGIN(1)=or(2); ORIGIN(2)=or(3); ORIGIN(3)=or(1);
    
elseif strcmp(imop,'C')
    DESCRIP=[DESCRIP, ' -CORONAL Flip '];
    DIM(2)=dim(3); DIM(3)=dim(2);
    VOX(2)=vox(3); VOX(3)=vox(2);
    ORIGIN(2)=or(3); ORIGIN(3)=or(2);
else
    DESCRIP=[DESCRIP, ' -Flip axis ' imop];
end
  
TYPE,MATYPE,DESCRIP,
	
out3=SCALE;


if in3==1, return, end;

fclose(fidop);


Bcolor = [.8,1,1];

imflipgui = figure('Color',Bcolor,'Name',[imop ' cvt'],'Tag','imflipgui',...
'NumberTitle','off','Position',[100,200,250,60],'UserData',0,...
'Units','Pixels');
	

%cbFName=['hrname=findobj(''tag'',''namefield''); name=get(hrname,''string''),',...
%	'name=deblank(name); namehdr=[strtok(name,''.'') ''.hdr''];',...
%	'vp_hwrite(name,DIM,VOX,SCALE,TYPE,OFFSET,ORIGIN,DESCRIP,',...
%	'EXPTIM,DURATION,GENTIM,SUBID,EXPDATE);',...
%	'nameimg=get(hrname,''userdata'');',...
%	'name=[strtok(name,''.'') ''.img'']; if ~strcmp(name,nameimg),',...
%	'dos([''move '' nameimg '' '' name]), end;',...
%	'set(gco,''string'',[name ''   FILE SAVED'']); Message=[''FILE SAVED'']; ',...
%	'disp(Message); set(findobj(''tag'',''imflipgui''),''UserData'',1);'];

%%	'disp(''FILE SAVED''); pause(2); delete(findobj(''tag'',''imflipgui''));'];
	
%%	'set(hroierr,''string'',[''MSG: '',Message]);'] ;


% Save default header before user name read, to keep consistent with image saved.
% Read user name. If not the default name. Warn if only .hdr or .img doesn't exist,
% since if there aren't permissions to overwrite, only the header or image will be
% overwritten and the other will be incorrect.

%	'nameimg=deblank(nameimg); namehdr0=[strtok(nameimg,''.'') ''.hdr''];',...
%	  'name=deblank(name); namehdr=[strtok(name,''.'') ''.hdr''];',...
%	  'name=[strtok(name,''.'') ''.img''];',...
%
cbFName=['staterr=0; hrname=findobj(''tag'',''namefield''); nameimg=get(hrname,''userdata''),',...
	'nameimg=vp_nm(''dnm'',nameimg); namehdr0=[nameimg ''.hdr'']; nameimg=[nameimg ''.img''];',...
	'if (vp_hwrite(nameimg,DIM,VOX,SCALE,TYPE,OFFSET,ORIGIN,DESCRIP,',...
	'EXPTIM,DURATION,GENTIM,SUBID,EXPDATE) ) < 0,',...
	'vp_message(''hwrite err''); staterr=1; ',...
	'else, ',...
	  'name=get(hrname,''string''),',...
	  'name=vp_nm(''dnm'',name); namehdr=[name ''.hdr''];',...
	  'name=[name ''.img''];',...
	  'if ~strcmp(name,nameimg),',...
	     'if (exist(name,''file'') & ~exist(namehdr,''file'')) | ',...
	       ' (~exist(name,''file'') & exist(namehdr,''file''))  ',...
	       'vp_message([''Remove Invalid File '' name '' .hdr or .img'']);',...
	       ' staterr=3; ',...
	     'else, [s,dosmsg]=dos([''move '' nameimg '' '' name]), ',...
	       'if s ~=0, vp_message(dosmsg); staterr=2; end; ',...
	       '[s,dosmsg]=dos([''move '' namehdr0 '' '' namehdr]), ',...
	       'if s ~=0, vp_message(dosmsg); staterr=2; end; ',...
	     'end; ',...
	     'if staterr==0,  nameimg=name;  end;',...
	  'end; ',...
	'end;',...
	'if staterr==0,',...
	  'set(gco,''string'',[nameimg ''   FILE SAVED'']); Message=[''FILE SAVED'']; ',...
	  'disp(Message); pause(2); set(findobj(''tag'',''imflipgui''),''UserData'',1); ',...
	' end; '];
	
	
	
uicontrol(imflipgui,'style','text','string','ENTER NAME: ',...
	'position',[10 25 125 25],'BackgroundColor',Bcolor);
	
hrname=uicontrol(imflipgui,'style','edit','tag','namefield','string',nameimg,...
	'userdata',nameimg,...
	'position',[10 5 225 25],'BackgroundColor','w','callback',cbFName);


while( get(findobj('tag','imflipgui'),'UserData')==0) ,pause(1); end;

delete( findobj('tag','imflipgui') );
%while( findobj('tag','imflipgui') )pause(1); end;
%end % for i
