% vp_imfun
% Functionalize ANALYZE Format image
%_______________________________________________________________________
% vp_imfun allows the user to functionalize an ANALYZE format image
% using BLOOD FILE INPUT data. Input images are assumed to be in ANALYZE
% format in units of KBq/cc. If images are in Bq/ml pre-multipy by
% 0.0001 to convert to KBq/cc. Nifti images can be converted to ANALYZE
% using the ScAnVP conversions utility.
%
% Raw count rates are converted in accordance with the following options:
%
% STEADY STATE METHODS
% Opt 3:    rCMRG  - (mg/100g/min)   Cerebral Metabolic Glucose Rate (FDG)
% DYNAMIC METHODS
% Opt 7a:   Patlak - (mg/100g/min)   Metabolism   (FDG)
% Opt 7b:   Patlak - (micro liters/g/min) Uptake  (FDOPA)
%
% The user picks the image(s) to be functionalized. Each must have
% a corresponding image blood file (name.blf) in which the first line
% provides the Name, Plasma Glucose Concentration and Start and End Times,
% followed by sequential lines of time and blood count data.
%
% Functionalized images are 8bit images and are assigned an 'f' prefix.
% Output is dumped in 'funoutput.txt'. Processing is performed by the
% 'imfun.exe' routine which can also be run alone in a Dos window, using
% a name or Name.lst file for batch operations.
% For further options, see dos('...scanvp\bin\imfun help').
%_______________________________________________________________________
% vp_imfun		ScAnVP C.0	P. Spetsieris	12/31/98
%               ScAnVP Rev. 5.9 4/21/08

global HelpMode NameLst POpt

if HelpMode, vp_help(mfilename), return ; end;

vp_note('Images should be in ANALYZE format in units of KBq/cc',3);

POpt=vp_opt('X','VOXEL FUNCTIONALIZATION (BLOOD FILE INPUT)','Single Scan - FDG Glucose','','Patlak - Metabolism/Uptake','','Help','');

if(strcmp(POpt,'X'))return; end;

if(strcmp(POpt,'Help')),
  vp_help('vp_imfun'); vp_imfun; 
  return;
end

if(strcmp(POpt,'Single Scan - FDG Glucose')),
  vp_imfun3; 
  return;
end

if(strcmp(POpt,'Patlak - Metabolism/Uptake')),
  vp_imfun7; 
  return;
end


