% vp_imfun3
% Functionalize ANALYZE Format image
%_______________________________________________________________________
% vp_imfun3 performs voxel functionalization of an ANALYZE format image
% in the steady-state (FDG - tracer).
%
% Raw count rates are converted in accordance with the following options:
%
% Opt 3 : rCMRG - Cerebral Metabolic Glucose Rate (mg/100 g/min)
%
% The user picks the image(s) to be functionalized. Each must have
% a corresponding image blood file (name.blf) in which the first line
% provides the Name, Plasma Glucose Concentration and Start and End Times,
% followed by sequential lines of time and blood count data.
%
% Functionalized images are 8bit images and are assigned an 'f' prefix.
% Output is dumped in 'funoutput.txt'. Processing is performed by the
% 'imfun.exe' routine (Opt=3) which can also run alone in a Dos window
% using a name or Name.lst file for batch operations.
% See also, dos('...scanvp\bin\imfun help') for further options.
%_______________________________________________________________________
% vp_imfun3	ScAnVP	C.0	P. Spetsieris	12/31/98
% 		revision 5.5	P.S.		5/10/05

global HelpMode NameLst POpt

if HelpMode, vp_help(mfilename), return ; end;

POpt=vp_opt('X','Opt 3 : rCMRG - Cerebral Metabolic Rate Glucose (m/100 g/min) (FDG)','Functionalize Images','','Help','','EXIT','');

if(strcmp(POpt,'X'))return; end;
if(strcmp(POpt,'EXIT'))return; end;

if(strcmp(POpt,'Help')),
  vp_help('vp_imfun3'); vp_imfun3; 
  return;
end

% Continue
% get the image's filename {FName} 
%-----------------------------------------------------------------------
%FName      = FName(FName ~= ' ')

%NameLst      = get_file(Inf,'.img','Select images',[]);
if vp_filesui(Inf,'.img','Select images to Functionalize',mfilename) < 0 ,return; end;

m= size(NameLst,1);


h=waitbar(0.1,'Processing Functionalization');

defdir=pwd;
for i=1:m
  FName=deblank(NameLst(i,:));
  
  waitbar((i-.8)/m,h);
  [nm,dnm,dr,nm,sfx]=vp_nm('nm',FName),
  name=[nm,'.',sfx], funoutput=[defdir,'\funoutput.txt'],
  cd(dr);
  if i==1
  	DosCmd = ['imfun ',name,' 3 > ',funoutput];
  else
  	%DosCmd = ['imfun ',FName,' 3 >> funoutput.txt'];
  	DosCmd = ['imfun ',name,' 3 >> ',funoutput];
  end
  %DosCmd=strrep(DosCmd,'\','/')
  %unix(DosCmd);
  %DosCmd,
  %[s,w]=dos(DosCmd),
  [s,w]=vp_dos(DosCmd)
  disp(' ');
  if s~=0, vp_note(w,3), end;
end

waitbar(1,h); pause(1); close(h);

cd(defdir);

if s == 0,
 vp_note('END imfun- Output names preceded by ''f''- Check Matlab Window and funoutput.txt');
else,
 vp_message('PROCESS FAILED, - Check Matlab Window and funoutput.txt');
end


