% function [out1 val xmm ymm zmm x y plno]=vp_impnt(displopt);
%
% Pick a point on a data image. Returns its
% value, normal(mm) and pixel coordinates and plane no..
% If display option is set to one it also displays a text box
% with the retrieved values.
% Coordinates correspond to Talairach Atlas values for normalized
% images in the Neurological display assuming the correct "Input"
% orientation of the image file on disk is specified on the ScAnVP menu.
%_______________________________________________________________________
% vp_imvalue.m 		C.4.4 Phoebe Spetsieris  Jan. 27, 2000
% vp_impnt.m  		C.4.7.8 Phoebe Spetsieris March 4, 2002 

function [out1,val,xmm,ymm,zmm,x,y,plno] = vp_impnt(displopt)

global HelpMode FI

if HelpMode, vp_help(mfilename), return ; end;

out1=0;
val=0; 
viewno=0;
xmm=0;
ymm=0;
zmm=0;
xpix=0;
ypix=0;
zpix=0;

if nargin < 1, displopt=0; end;

TxColor=[0.8 0.2 1];

	
%if (~exist('FI') | isempty(FI) ), 
if  isempty(FI),  
  vp_message('No Valid Display Image');
  out1=-1;
  return;
end 
      
figure(FI);
       
[x,y]=ginput(1);

if strcmp(get(gco,'type'),'image')
  cdata=get(gco,'CDATA');
  cdata=cdata';
  
  sz=size(cdata);
  mx=max(max(cdata));
  mn=min(min(cdata));
  
  x=round(x); y=round(y);
  val=cdata(x,y);
  udata=get(gca,'UserData');
  if ~isempty(udata),
  
    viewno=udata(1); plno=udata(2); vox=udata(3:5); xyzor=udata(6:8);
    if viewno==1
  	xmm=(x-xyzor(1))*vox(1); ymm=(y-xyzor(2))*vox(2);
	zmm=(plno-xyzor(3))*vox(3);
    elseif viewno==2,
  	ymm=(x-xyzor(2))*vox(2); zmm=(y-xyzor(3))*vox(3);
	xmm=(plno-xyzor(1))*vox(1);
    elseif viewno==3,
  	xmm=(x-xyzor(1))*vox(1); zmm=(y-xyzor(3))*vox(3);
	ymm=(plno-xyzor(2))*vox(2);
    end
  end
  
else
	out1=-1;
	vp_message('Not an ''image'' point');
	return;
end

if displopt > 0

  himv=findobj('Name','ImPoint');

  position=[50,100,280,70];

  if ~isempty(himv); position=get(himv,'Position'); delete(himv); end;


        himv = figure('Color','w','Name','ImPoint',...
	'NumberTitle','off','Position',position,...
	'Units','Pixels','Visible','on');
	
	axis off;

	%uicontrol(himv,'String','RETURN',...
	%'Position',[160 10 55 20],...
	%'CallBack',[' ; ',...
	%'delete(findobj(''Name'',''ImPoint''));'] );

	
	coord=[' (',num2str(x) ', ' num2str(y),')'];
	if viewno == 1, view ='Axial XY,  ';
	elseif viewno==2, view = 'Sagittal YZ,  ';
	elseif viewno==3, view = 'Coronal XZ,  ';
	else view= 'Not Defined,   ';
	end
	
        textstr=['View: ', view, 'pix',coord];
	text(0.0,.6, textstr,...
	'FontName','Times','FontSize',10,...
	'VerticalAlignment','Middle',...
	'HorizontalAlignment','Left',...
	'Color',TxColor);

	if viewno~=0,
	
	  %textstr=['PlaneNo :   ',num2str(plno), '  ', coord ];
	  textstr=['PlaneNo :   ',num2str(plno)];
	  text(0.0,.8, textstr,...
	  'FontName','Times','FontSize',10,...
	  'VerticalAlignment','Middle',...
	  'HorizontalAlignment','Left',...
	  'Color',TxColor);
	
	  textstr=['x= ',num2str(xmm),', y= ',...
		num2str(ymm),', z= ',num2str(zmm), '  (mm)'];
	  text(0.0,.40, textstr,...
	  'FontName','Times','FontSize',10,...
	  'VerticalAlignment','Middle',...
	  'HorizontalAlignment','Left',...
	  'Color',TxColor);
	end
	
	
	textstr=['Value: ',num2str(val), ',   Min,Max(', num2str(mn),...
	', ',num2str(mx),')'];

	
	text(0.0,.20, textstr,...
	'FontName','Times','FontSize',10,...
	'VerticalAlignment','Middle',...
	'HorizontalAlignment','Left',...
	'Color',TxColor);
	
end % if displopt
       
	








