function [out1]= vp_imsave(fname,xyzdata,mode);
% function [out1]= vp_imsave(fname,xyzdata,mode);
% Write an Analyze format image using input data and global parameters
%
% fname   - File name 	     (e.g 'name.img')
% xyzdata - image data	     DXxDYxDZ (volume)
% mode    - 0 (interrogate name), 1 (save specified name)
%         - 2 save specified name but don't note 'SAVED'
%
% GLOBAL PARAMETERS
% VOX     - voxel size       [x y z] (mm)
% SCALE   - scale factor
% TYPE    - datatype (integer - see help vp_fixhdr)
% OFFSET  - offset (bytes)
% ORIGIN  - [i j k] of origin )
% DESCRIP - description string
% Additions by PS
% EXPTIM  - Relative frame start time [HR:MN:SC]
% DURATION- scan duration (secs) dim(6)
% GENTIM  - Actual Frame Start Time
% SUBID   - Subject ID
% EXPDATE - Scan Date
% GLMAX   - global maximum (Calculated in vp_hwrite)
% GLMIN   - global minimum (Calculated in vp_hwrite)
% MATYPE  - Matlab Data Type
% 
%___________________________________________________________________________
% out1   :  Return value
%_______________________________________________________________________
% vp_imsave		ScAnVP 5.2   P. Spetsieris	10/23/03
%	 		Revision 6.2   P. Spetsieris	11/16/11

global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN
global EXPTIM DURATION MATYPE GENTIM SUBID EXPDATE
global HelpMode Message

if HelpMode, vp_help(mfilename), return ; end;

out1=0;

dim=size(xyzdata);
if length(dim) ~=3,
  vp_note(['ERROR: XYZ Data should by 3 dimensional.']);
  out1=-1;
  return;
end;
DIM=dim; %set global

m= size(fname,1);
if m > 1,
  vp_note(['ERROR: Enter only one file.']);
  out1=-1;
  return;
end;

fname=deblank(fname);
P=fname(1:length(fname)-4);
  
% hwrite routine figures out GlMAX GLMIN from type
% out1 = vp_hwrite(P,dim,vox,scale,type,offset,origin,descrip,EXPTIM,DURATION,GENTIM,SUBID,EXPDATE);
% if out1 < 0 ,
%   vp_note(['ERROR: Writing Header.']);
%   return;
% end;

disp(' ');

%WRITE IMAGE
inam=[P '.img'],
fidop=fopen(inam,'w');

if max(max(max(xyzdata))) == 0,
  vp_note(['WARNING: 0 maximum']);
  waitfor(findobj('Name','Note'));
end

if TYPE==2
	datype='uchar';
elseif TYPE==4
	datype='int16';
elseif TYPE==8
	datype='int32';
elseif TYPE==16
	datype='float';
elseif TYPE==64
	datype='double';
else
	  vp_note(['ERROR: Invalid TYPE' num2str(TYPE)]);
	  out1=-1;
	  return;
end
	
no=fwrite(fidop,xyzdata,datype);
if no <=0,
  	vp_note(['Write ERROR no: ' num2str(no) ' pixels']) ;
	out1=-1;
	return;
end
	
fclose(fidop);

Bcolor = [.8,1,1];


% Read user name. If not the default name. Warn if only .hdr or .img doesn't exist,
% since if there aren't permissions to overwrite, only the header or image will be
% overwritten and the other will be incorrect.
       
%P=fname(1:length(fname)-4);
cbfname=['staterr=0; hsvname=findobj(''tag'',''savename''); inam=get(hsvname,''userdata''),',...
	'inam=deblank(inam); namehdr0=[inam(1:length(inam)-4) ''.hdr''];',...
	'if (vp_hwrite(inam,DIM,VOX,SCALE,TYPE,OFFSET,ORIGIN,DESCRIP,',...
	'EXPTIM,DURATION,GENTIM,SUBID,EXPDATE) ) < 0,',...
	'vp_message(''hwrite err''); staterr=1; ',...
	'else, ',...
	  'name=get(hsvname,''string''),',...
	  'name=deblank(name); namehdr=[name(1:length(name)-4) ''.hdr''];',...
	  'name=[name(1:length(name)-4) ''.img''];',...
	  'if ~strcmp(name,inam),',...
	     'if (exist(name,''file'') & ~exist(namehdr,''file'')) | ',...
	       ' (~exist(name,''file'') & exist(namehdr,''file''))  ',...
	       'vp_message([''Remove Invalid File '' name '' .hdr or .img'']);',...
	       ' staterr=3; ',...
	     'else, [s,dosmsg]=dos([''move '' inam '' '' name]), ',...
	       'if s ~=0, vp_message(dosmsg); staterr=2; end; ',...
	       '[s,dosmsg]=dos([''move '' namehdr0 '' '' namehdr]), ',...
	       'if s ~=0, vp_message(dosmsg); staterr=2; end; ',...
	     'end; ',...
	     'if staterr==0,  inam=name;  end;',...
	  'end; ',...
	'end;',...
	'if staterr==0,',...
	  'vp_note([''FILE SAVED''],1); ',...
	  'delete(findobj(''tag'',''namegui'')); ',...
	' end; '];
	
if nargin > 2,
 if mode>= 1,
	staterr=0; inam=deblank(inam);
	if (vp_hwrite(inam,DIM,VOX,SCALE,TYPE,OFFSET,ORIGIN,DESCRIP,...
	   EXPTIM,DURATION,GENTIM,SUBID,EXPDATE) ) < 0,
	   vp_message('hwrite err'); staterr=1; end; 
	if staterr==0, if mode ==1,
	  vp_note(['FILE ',inam,' SAVED'],1); end; end;
 return; end;
end

namegui = figure('Color',Bcolor,'Name','Image Save','Tag','namegui',...
'NumberTitle','off','Position',[100,200,320,60],...
'Units','Pixels');
	
       
uicontrol(namegui,'style','text','string','ENTER NAME: ',...
	'position',[10 25 125 25],'BackgroundColor',Bcolor);
	
hsvname=uicontrol(namegui,'style','edit','tag','savename','string',inam,...
	'userdata',inam,...
	'position',[10 5 300 25],'BackgroundColor','w','callback',cbfname);


waitfor(findobj('tag','namegui'));
