% vp_imui.m
% Sets variables and user interface controls for sectional display.
% Sets Window Format, Initial and Final Planes, View and Slice Parameters. 
% Assumes the Image FName is set elsewhere.
%__________________________________________________________________________
% vp_imz.m	C.0	P. Spetsieris  April 1, 1999
% 		Rev. 6.2.1 by P.S. April 27, 2013
%       Rev. 7.0   by P.S. Oct. 7, 2015

global WinView  WinFormat Plane0 MaxPlane MaxDim Opt FName Time Message
global NumLabels PhyLabels FI GCM

%bkgcolor = [.8,.8,1];
bkgcolor = [.8,.9,1];
Opt=1;
Time=0;
Message0=['....'];
Message=Message0;

WinView=1;
WinFormat=4 ;
SliceDelta=5 ; %default
Plane0=1;
MaxPlane = 1 ;

NumLabels=1;
PhyLabels=1; 
       
delete(findobj('Name','imviewgui'));

imviewgui = figure('Color',[.6,.6,1],'Name','imviewgui',...
'NumberTitle','off','Position',[100,200,250,235],...
'Units','Pixels');
	

cbview=['WinView=str2num(get(hview,''string''));'];
cbformat=['WinFormat=str2num(get(hform,''string''));'];
cbplane0=['Plane0=str2num(get(hplane0,''string''));'];
cbmaxpln=['MaxPlane=str2num(get(hmaxpln,''string''));'];
cbdelta=['SliceDelta=str2num(get(hdelta,''string''));'];


uicontrol(imviewgui,'string', 'VIEW  1=AXI',...
	'TooltipString','Axial View',...
	'position',[10 150 72 20],'callback',...
	['WinView=1; set(hview,''string'',''1'');',...
	'MaxPlane=DIM(3); MaxDim=DIM(3); set(hmaxpln,''string'',num2str(DIM(3)));']);
	
uicontrol(imviewgui,'string', '2=SAG',...
	'TooltipString','Sagittal View',...
	'position',[82 150 44 20],'callback',...
	['WinView=2; set(hview,''string'',''2'');',...
	'MaxPlane=DIM(1); MaxDim=DIM(1); set(hmaxpln,''string'',num2str(DIM(1)));']);
	
uicontrol(imviewgui,'string', '3=COR',...
	'TooltipString','Coronal View',...
	'position',[126 150 44 20],'callback',...
	['WinView=3; set(hview,''string'',''3'');',...
	'MaxPlane=DIM(2); MaxDim=DIM(2); set(hmaxpln,''string'',num2str(DIM(2)));']);

%uicontrol(imviewgui,'String','ROT',...
% 	'ToolTipString',['Rotate around axis parallel to Z through Pt.'],...
%	'Callback', 'vp_rotvol',...
%	'Position',[170 150 28 20]);
	
hview=uicontrol(imviewgui,'style','edit','string',num2str(WinView),...
	'TooltipString','Enter View Parameter',...
	'position',[200 150 30 20],'BackgroundColor',bkgcolor,'callback',cbview);

	
uicontrol(imviewgui,'string', 'FORMAT  1',...
	'TooltipString','Display Format 1=Single or Tile',...
	'position',[10 125 72 20],'callback',['WinFormat=1; set(hform,''string'',''1'');']);
	
uicontrol(imviewgui,'string', '2=2x2',...
	'TooltipString','2x2 Display',...
	'position',[82 125 45 20],'callback',['WinFormat=2; set(hform,''string'',''2'');']);
	
uicontrol(imviewgui,'string', '3=3x3',...
	'TooltipString','3x3 Display',...
	'position',[127 125 44 20],'callback',['WinFormat=3; set(hform,''string'',''3'');']);
	
uicontrol(imviewgui,'string', '4',...
	'TooltipString','4x4 Display',...
	'position',[10 105 23 20],'callback',['WinFormat=4; set(hform,''string'',''4'');']);
	
uicontrol(imviewgui,'string', '5',...
	'TooltipString','5x5 Display',...
	'position',[33 105 23 20],'callback',['WinFormat=5; set(hform,''string'',''5'');']);
	
uicontrol(imviewgui,'string', '6',...
	'TooltipString','6x6 Display',...
	'position',[56 105 23 20],'callback',['WinFormat=6; set(hform,''string'',''6'');']);
	
uicontrol(imviewgui,'string', '7',...
	'TooltipString','7x7 Display',...
	'position',[79 105 23 20],'callback',['WinFormat=7; set(hform,''string'',''7'');']);
	
uicontrol(imviewgui,'string', '8',...
	'TooltipString','8x8 Display',...
	'position',[102 105 23 20],'callback',['WinFormat=8; set(hform,''string'',''8'');']);
	
uicontrol(imviewgui,'string', '9',...
	'TooltipString','9x9 Display',...
	'position',[125 105 23 20],'callback',['WinFormat=9; set(hform,''string'',''9'');']);
	
uicontrol(imviewgui,'string', '10',...
	'TooltipString','10x10 Display',...
	'position',[148 105 23 20],'callback',['WinFormat=10; set(hform,''string'',''10'');']);
	
	
hform=uicontrol(imviewgui,'style','edit','string',WinFormat,...
	'TooltipString','Enter Display Format',...
	'position',[200 120 30 20],'BackgroundColor',bkgcolor,'callback',cbformat);
	
       
hdelta=uicontrol(imviewgui,'style','edit','string',SliceDelta,...
	'TooltipString','Enter number of slices to skip',...
	'position',[200 80 30 20],'BackgroundColor',bkgcolor,'callback',cbdelta);

uicontrol(imviewgui,'string', 'SLICE SKIP 1',...
	'TooltipString','Disply Consecutive Slices',...
	'position',[10 80 71 20],'callback',['SliceDelta=1; set(hdelta,''string'',''1'');']);
	
uicontrol(imviewgui,'string', '2',...
	'TooltipString','Skip 2 slices',...
	'position',[81 80 18 20],'callback',['SliceDelta=2; set(hdelta,''string'',''2'');']);
	
uicontrol(imviewgui,'string', '3',...
	'TooltipString','Skip 3 slices',...
	'position',[99 80 18 20],'callback',['SliceDelta=3; set(hdelta,''string'',''3'');']);
	
uicontrol(imviewgui,'string', '4',...
	'TooltipString','Skip 4 slices',...
	'position',[117 80 18 20],'callback',['SliceDelta=4; set(hdelta,''string'',''4'');']);
	
uicontrol(imviewgui,'string', '5',...
	'TooltipString','Skip 5 slices',...
	'position',[135 80 18 20],'callback',['SliceDelta=5; set(hdelta,''string'',''5'');']);
	
uicontrol(imviewgui,'string', '6',...
	'TooltipString','Skip 6 slices',...
	'position',[153 80 18 20],'callback',['SliceDelta=6; set(hdelta,''string'',''6'');']);
	
uicontrol(imviewgui,'Style','Check','String','Num. Labels',...
	'TooltipString','Label Slices Numerically',...
	'Value',NumLabels,'Position',[10 60 100 15],...
	'CallBack',[ 'if ~NumLabels, NumLabels=1; else NumLabels=0, end;']);
	
uicontrol(imviewgui,'Style','Check','String','XYZmm Labels',...
	'TooltipString','Show Slice Position in mm.',...
	'Value',PhyLabels,'Position',[120 60 100 15],...
	'CallBack',[ 'if ~PhyLabels, PhyLabels=1; else PhyLabels=0, end;']);
	
uicontrol(imviewgui,'string', 'Initial Plane',...
	'TooltipString','Initial Display Slice Number',...
	'position',[10 35 75 20],'BackgroundColor',bkgcolor);
hplane0=uicontrol(imviewgui,'style','edit','string',Plane0,...
	'TooltipString','Initial Display Slice Number',...
	'position',[85 35 35 20],'BackgroundColor',bkgcolor,'callback',cbplane0);

uicontrol(imviewgui,'string', 'Final Plane',...
	'TooltipString','Final Display Slice Number',...
	'position',[130 35 75 20],'BackgroundColor',bkgcolor);
hmaxpln=uicontrol(imviewgui,'style','edit','string',MaxPlane,...
	'TooltipString','Final Display Slice Number',...
	'position',[205 35 35 20],'BackgroundColor',bkgcolor,'callback',cbmaxpln);

uicontrol(imviewgui,'String','CANCEL',...
	'Position',[10 10 60 25],...
	'CallBack',['set(gcbf,''UserData'',-1); delete(gcbf);']);
	
