% vp_imutil.m
% Image Controls, Print and Save utilities
%___________________________________________________________________________
% These options can be applied to images displayed by IMVIEW
% or other ScAnVp routines and provide options for displaying
% other types of images.
% The user can pick a figure, by clicking on 'PICK FIGURE' and
% then clicking on the figure window, otherwise the option is 
% applied to a default figure if it exists, usually 'FI'.
%
% Print:        Print Image
% Smooth:       Smooth image by Bilinear Interpolation
% Invert Screen ON|OFF: Will invert the background screen and text color
%               on any new figures created when printed or saved as files.
% Value:        Read Pixel Value On Valid Data Image
% Text:         Place Text On Image
% Color:        Set Color Map on Active Image Figure
% Full Range:   Modify Full Color Map Range
% Semi RAnge:   Modify Upper or Lower Range
% Normal Range: Normalize All Images in Display Figure to Single Data Range
% LinePlot:     Display a 2D Plot of the values of a Hor. or Vert. Line Seg.
% SurfPlot:     Display a 3D Plot of the values of a Rectangular Image Area
% Bars:         Display vertical or horizontal color bar
% EDIT:         Move, or deltete object, colorbar or controls	
% Movie:        Show a previously created movie
% Marker:       Places geometric markers (rect, circ, ell) at X, Y, Z point.
% Save or View image files type
% 	postscript (*.ps, Save only)  
% 	encapsulated postscript (*.eps, Save only) 
% 	8bit PCX (*.pcx) 
% 	24bit TIFF (*.tiff)
% 	GIF (*.gif)
% 	bitmap (*.bmp)
% 	ANALYZE (*.img) (save single slice as .img file)
%__________________________________________________________________________
% vp_imutil.m	ScAnVP C.4.6  P. Spetsieris	Jan 16, 2001
%		ScAnVP Rev. 5.9	 P. Spetsieris	Feb. 4, 2008
%		ScAnVP Rev. 6.1	 P. Spetsieris	May.24, 2011
%		ScAnVP Rev. 6.3	 P. Spetsieris	Jan.10, 2014
%		ScAnVP Rev. 7.0	 P. Spetsieris	Jan.10, 2016
global HelpMode hufig UFI FI HelpMsg Ecolor

if HelpMode, vp_help(mfilename), return ; end;

Message0=['............................................ '];
Message=Message0;

Fcolor = [.8,.8,.8];
Bcolor = [.9,.8,.9];
if ~exist('UFI') | isempty(UFI)| UFI==0, if exist('FI') & ~isempty(FI),
 UFI=FI; else vp_note('WARNING NO IMAGE: DISPLAY IMAGE, PICK FIGURE # For Most Options ',3); UFI=0; end; end;

utilgui=findobj('Name','utilgui');

if ~isempty(utilgui)
 figure(utilgui);
 set(hufig,'string',['Pick Figure  (', num2str(UFI), ')']);
 return;
else
	utilgui = figure('Color','w','Name','utilgui',...
	'Color',Fcolor,...
	'NumberTitle','off','Position',[100,50,130,250],...
	'Units','Pixels');
end;
	
if UFI==utilgui, UFI=1; 
 vp_message('Warning: Figure Not Valid'); 
end;
       
checkcb=['if ~exist(''UFI'') | UFI<1 | isempty(UFI);,',...
	' vp_note(''WARNING: Figure Not defined'',3); return;  ',...
	' end;'];
 
nmcb=['if ~exist(''UFI'') | UFI<1 | isempty(UFI);,',...
	' vp_message(''Figure Not defined''); nm=[]; ',...
	' else, figure(UFI); nm=''scanvp''; nm=get(UFI,''name''); ',...
	' if isempty(nm), nm=''scanvp''; end; end;'];
 
barcb=	['eval(checkcb); baropt=get(gco,''Value''); ',...
	'if baropt > 1, ',...
	['ch=get(UFI,''children''); len=length(ch); for i=1:len,',...
	'if strcmp(get(ch(i),''type''),''axes''), ',...
	'delefcn=get(ch(i),''DeleteFcn''); ',...
	'if ~isempty(delefcn),',... 
	'if strcmp(delefcn(1:8),''colorbar''),  ',...
	'delete(ch(i)); end; end; end; end;'],...
	'end; ',...
	'if baropt==2, ',...
	  'ch=get(UFI,''children''); len=length(ch); ',...
	  'for i=1:len, if strcmp(get(ch(i),''type''),''axes''), ',...
	  'if ~isempty(get(ch(i),''userdata'')), ',...
	  'axes(ch(i)); try colorbar(''v6'',''vert''); catch colorbar vert; end;',...
	  ' end; end; end;',...
	'elseif baropt==3, ',...
	  'ch=get(UFI,''children''); len=length(ch); ',...
	  'for i=1:len, if strcmp(get(ch(i),''type''),''axes''), ',...
	  'if ~isempty(get(ch(i),''userdata'')), ',...
	  'axes(ch(i)); try colorbar(''v6'',''horiz''); catch colorbar horiz; end;',...
	  ' end; end; end;',...
	'else, end;'];

editcb=	['eval(checkcb); editopt=get(gco,''Value''); figure(UFI); ',...
	'if editopt==2, ',...
	['ginput(1); if ~strcmp(get(gco,''type''),''uicontrol'') ',...
	'& ~strcmp(get(gco,''type''),''figure''), ',...
	'if (~strcmp(get(gco,''type''),''image'') & ~strcmp(get(gco,''type''),''colorbar'')),',...
	'set(gco,''selected'',''on''); plotedit(''on'');  ',...
	'else, plotedit(''off''); axis on; set(gca,''selected'',''on'');',...
	'set(gca,''ButtonDownFcn'',''selectmoveresize''),',... 
	'waitfor(gca,''position''); set(gca,''selected'',''off''); axis off; end; end;'],...
	'elseif editopt==3, ',...
	['ginput(1); if ~strcmp(get(gco,''type''),''uicontrol'') ',...
	'& ~strcmp(get(gco,''type''),''figure''), delete(gco); end;'],...
	'elseif editopt==4, ',...
	['ch=get(UFI,''children''); nch=length(ch); for i=1:nch,',...
	'if strcmp(get(ch(i),''type''),''axes''), ',...
	'delefcn=get(ch(i),''DeleteFcn''); ',...
	'if ~isempty(delefcn),',... 
	'if strcmp(delefcn(1:8),''colorbar''),  ',...
	'delete(ch(i)); end; end; end; end;'],...
	'elseif editopt==5, ',...
	['ch=get(UFI,''children''); nch=length(ch); for i=1:nch, if strcmp(get(ch(i),''type''),''uicontrol''), ',...
	'delete(ch(i)); end; end;'],...
	'end;'];



uicontrol(utilgui,'string', 'Help',...
	'TooltipString',HelpMsg,...
	'BackgroundColor',Ecolor,...
	'position',[80 225 29 20],'callback','vp_help(''vp_imutil'');');

hufig=uicontrol(utilgui,'string',['PICK FIGURE  (', num2str(UFI), ')'],...
	'position',[10 195 105 25],'BackgroundColor',Bcolor,...
	'TooltipString','Click on Image to select Active Figure. ',...
	'callback',['vp_note(''Click on Image'',2); ',...
	'waitforbuttonpress; UFI=gcf;',...
	'hpstr=[''PICK FIGURE  ('', num2str(UFI), '')''];',...
	'set(hufig,''string'',hpstr); vp_note([''Active Figure '',num2str(UFI)],2); ']);
	

uicontrol(utilgui,'String','PRINT',...
	'TooltipString','Print image',...
	'Position',[10 170 55 015],...
	'CallBack',['eval(checkcb); figure(UFI);',...
	'print -f -dwin -noui;'],...
	'BackgroundColor',Bcolor,...
	'ForegroundColor',Tcolor);

uicontrol(utilgui,'String','SMOOTH',...
	'TooltipString','Smooth image by bilinear interpolation',...
	'Position',[65 170 55 015],...
	'CallBack','eval(checkcb); vp_smooth',...
	'BackgroundColor',Bcolor,...
	'ForegroundColor',Tcolor);

uicontrol(utilgui,'String','Invert Screen ON',...
	'TooltipString','Invert screen and text color on new figure hardcopy output',...
	'Position',[10 155 88 015],...
	'CallBack','set(0,''DefaultFigureInvertHardCopy'',''on'')',...
	'BackgroundColor',Bcolor,...
	'ForegroundColor',Tcolor);

uicontrol(utilgui,'String','OFF',...
	'TooltipString','Retain screen and text color on new figure hardcopy output',...
	'Position',[98 155 22 015],...
	'CallBack','set(0,''DefaultFigureInvertHardCopy'',''off'')',...
	'BackgroundColor',Bcolor,...
	'ForegroundColor',Tcolor);

uicontrol(utilgui,'String','VALUE',...
	'TooltipString','Read Pixel Value On Valid Data Image',...
	'Position',[10 130 55 015],...
	'CallBack','eval(checkcb); vp_imvalue',...
	'BackgroundColor',Bcolor,...
	'ForegroundColor',Tcolor);

uicontrol(utilgui,'String','TEXT',...
	'TooltipString','Place Text On Image',...
	'Position',[65 130 55 015],...
	'CallBack','eval(checkcb); vp_imtext',...
	'BackgroundColor',Bcolor,...
	'ForegroundColor',Tcolor);

uicontrol(utilgui,'Style','PopUp',...
	'String','EDIT...|Move |Delete |Del. Bars |Del. Controls ',...
	'TooltipString','1: Move Object |2: Delete Object ',...
	'Position',[10 100 65 015],...
	'ForegroundColor',Tcolor,...
	'BackgroundColor',Bcolor,...
	'CallBack',editcb);
	
       
uicontrol(utilgui,'String','COLOR',...
	'TooltipString','Set Color Map on Active Image Figure',...
	'Position',[10 115 50 015],...
	'CallBack','eval(checkcb); vp_colgui',...
	'BackgroundColor',Bcolor,...
	'ForegroundColor',Tcolor);


cbrange = ['eval(checkcb); RangeOpt=get(gco,''Value'');',...
	'if RangeOpt==2, vp_colrange;',...
	'elseif RangeOpt==3, vp_semirange;',...
	'elseif RangeOpt==4, vp_norm;',...
	'else, end;'];
	
uicontrol(utilgui,'Style','PopUp',...
	'String','RANGE...|FULL|SEMI|NORM',...
	'TooltipString',['1: Modify Full Color Map Range |',...
	'2: Modify Upper or Lower Range |3: Normalize '],...
	'Position',[60 117 62 015],...
	'ForegroundColor',Tcolor,...
	'BackgroundColor',Bcolor,...
	'CallBack',cbrange);
	
uicontrol(utilgui,'Style','PopUp',...
	'String','BARS...|Vert Bar|Hori Bar',...
	'TooltipString','1: Draw Vertical Color Bar(s) |2: Draw Horizontal Color Bar(s) ',...
	'Position',[73 100 49 015],...
	'ForegroundColor',Tcolor,...
	'BackgroundColor',Bcolor,...
	'CallBack',barcb);
       

uicontrol(utilgui,'Style','PopUp','String',...
	['Save File Type...|Save PS |Save EPS |Save PCX |Save TIFF |Save GIF |Save BMP |Save IMG'],...
	'TooltipString',['',...
	'Save PS | ',...
	'Save EPS | ',...
	'Save 8bit PCX | ',...
	'Save 24bit TIFF | ',...
	'Save 8bit GIF | ',...
	'Save BMP | ',...
	'Save IMG (ANALYZE) '],...
	'Position',[10 70 112 25],...
	'ForegroundColor',Tcolor,...
	'BackgroundColor',Bcolor,...
	'Interruptible','on',...
	'CallBack',['UtilOpt=get(gco,''Value''); eval(nmcb); out1=0; lasterr('''');',...
	'if UtilOpt == 2, if ~isempty(nm), nm=[nm ''.ps''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'print(gcf, nm,''-dpsc2'',''-zbuffer'',''-noui''); vp_note([nm '' saved''],2); end; end; ',...
	'elseif UtilOpt== 3, if ~isempty(nm), nm=[nm ''.eps''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'print(gcf, nm,''-depsc2'',''-zbuffer'',''-noui''); vp_note([nm '' saved''],2); end; end; ',...
	'elseif UtilOpt== 4, if ~isempty(nm), nm=[nm ''.pcx''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'print(gcf, nm,''-dpcx256'',''-zbuffer'',''-noui''); vp_note([nm '' saved''],2); end; end; ',...
	'elseif UtilOpt== 5, if ~isempty(nm), nm=[nm ''.tiff''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'print(gcf,nm,''-dtiff'',''-noui''); vp_note([nm '' saved''],2); end; end;',...
	'elseif UtilOpt== 6, if ~isempty(nm), nm=[nm ''.gif''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'print(gcf, nm,''-dgif'',''-noui''); vp_note([nm '' saved''],2); end; end; ',...
	'elseif UtilOpt== 7, if ~isempty(nm), nm=[nm ''.bmp''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'print(gcf, nm,''-dbmp256'',''-noui''); vp_note([nm '' saved''],2); end; end; ',...
	'elseif UtilOpt== 8, if ~isempty(nm), nm=[nm ''SV.img''];',...
	'vp_keyin(''File Name'',nm); if ~isempty(Keyin), nm=Keyin;',...
	'out1=vp_savaslice(1,nm); if out1 >= 0, vp_note([nm '' saved''],2);',...
	'else, vp_note([''err='' num2str(out1)]); end; end; end; ',...
	'else, end;'] );
	
              
uicontrol(utilgui,'Style','PopUp','String',...
	['Display File Type...| View PCX|',...
	' View TIFF| View GIF| View BMP | View IMG '],...
	'TooltipString',['',...
	'View PCX | View TIFF | View GIF | View BMP | ',...
	'View IMG '],...
	'Position',[10 45 112 25],...
	'ForegroundColor',Tcolor,...
	'BackgroundColor',Bcolor,...
	'Interruptible','on',...
	'CallBack',...
	['UtilOpt=get(gco,''Value''); ',...
	'if UtilOpt == 2 ,',...
	'[dat,map]=imread(get_file(1,''.pcx''),''pcx'');',...
	'figure; imagesc(dat,[0 255]); axis off; colormap(map); ',...
	'elseif UtilOpt== 3, [dat,map]=imread(get_file(1,''.tiff''),''tiff'');',...
	'figure; image(dat); axis off; ',...
	'elseif UtilOpt== 4, [dat,map]=imread(get_file(1,''.gif''),''gif'');',...
	'figure; image(dat); axis off; ',...
	'elseif UtilOpt== 5, nm=get_file(1,''.bmp''); [dat,map]=imread(nm,''bmp'');',...
	'figure(''name'',nm); imagesc(dat,[0 255]); axis off; colormap(map); ',...
	'elseif UtilOpt== 6, vp_imview; ',...
	'end;']);
	
	
uicontrol(utilgui,'string','LinePLOT',...
	'Position',[10 31 55 012],...
	'BackgroundColor',Ecolor,...
	'CallBack','eval(checkcb); vp_lineplot');
       
uicontrol(utilgui,'string','SurfPLOT',...
	'Position',[10 18 55 013],...
	'BackgroundColor',Ecolor,...
	'CallBack','eval(checkcb); vp_surfplot');
       
	%'CallBack','eval(checkcb); vp_xyzmarker');
	%
uicontrol(utilgui,'string','xyzMarker',...
	'Position',[65 18 55 013],...
    'TooltipString','Draw a geometric marker at X,Y,Z mm on the display',...
	'BackgroundColor',Ecolor,...
	'CallBack','vp_xyzmarker');
       
uicontrol(utilgui,'string','MOVIE',...
	'Position',[10 5 55 013],...
	'BackgroundColor',Ecolor,...
	'CallBack','vp_movie');
       
uicontrol(utilgui,'string','NORM',...
	'Position',[65 30 55 015],...
	'TooltipString','Normalize display to set min, max',...
	'BackgroundColor',Ecolor,...
	'CallBack','vp_norm');
       
uicontrol(utilgui,'string', 'EXIT',...
	'position',[80 0 29 17],'BackgroundColor',Bcolor,...
	'callback',['delete(utilgui); ']);
	
	
	
