% vp_imviewpro
% multi window image display processing 
%_______________________________________________________________________
% vp_imviewpro is a routine that displays consecutive sectional slices 
% from an ANALYZE format image or image set in various multi-figure 
% multi-subwindow display formats. Orthogonal views and dynamic sequences
% can be specified in the 'vp_imview' calling routine.
% Note, X, Y, Z coordinates represent mm distance from the origin.
% These values correspond to Talairach coordinates only if the file
% is normalized and in the Neurological Orientation. If it is normalized
% in the Radiological orientation it can be flipped along the X axis
% prior to display, otherwise X=-X is the corresponding Talairach coordinate.
%_______________________________________________________________________
% vp_imviewpro	 ScAnVP	C.0		P. Spetsieris	4/30/98
%		 Rev. 5.2 by P.S. 11/10/03, 5.9 04/03/08
%		 Rev. 6.2 by P.S. 04/24/12, 6.2.1 04/24/12, 6.2.2 08/14/13
%		 Rev. 7.0 by P.S. 10/07/15

global Message PlaneNo FName WinView WinFormat MaxPlane Plane0 Opt Time MaxDim
global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN DESCRIP
global EXPTIM DURATION MATYPE DATAMIN DATAMAX GENTIM SUBID EXPDATE
global GCM SliceDelta XYZDATA XYZOR NumLabels PhyLabels 
global Keyin BkgColor VAL_OFFSET DisplayOrient InputOrient

%FName      = get_file(1,'.img','please select image',[]);

Message=[];

if Opt == 1

vp_hread(FName);
 
P=deblank(FName);
q     = length(P);
if P(q - 3) == '.'; P = P(1:(q - 4)); end
FName=P;

delete(findobj('Tag','rotviewgui'));

if(Time==1)

  WinView=1;
  WinFormat=4 ;
  Plane0 = 1;
  MaxPlane = DIM(3) ;
  MaxDim=DIM(3);
  
else
  if WinView==1
  	if DIM(3) < MaxDim, MaxPlane=DIM(3);
  	else MaxPlane=min(MaxPlane,DIM(3)); end;
  elseif WinView==2
  	if DIM(1) < MaxDim, MaxPlane=DIM(1);
  	else MaxPlane=min(MaxPlane,DIM(1)); end;
  elseif WinView==3
  	if DIM(2) < MaxDim, MaxPlane=DIM(2);
  	else MaxPlane=min(MaxPlane,DIM(2)); end;
  end
  
  if Plane0 > MaxPlane, Plane0=1; end;
 
end

vp_imvorth;

return;


elseif Opt==2

if isempty(PlaneNo)
	PlaneNo0= [];
else
	PlaneNo0= PlaneNo;
end

PlaneNo = 1; 

FWID=WinFormat*DIM(1);
FHGT=WinFormat*DIM(2);
xmax = DIM(1)/FWID ;
ymax = DIM(2)/FHGT ;
ImageSize=DIM(1)*DIM(2);
WMax=WinFormat*WinFormat;
MaxDim = DIM(3);

DATA=zeros(DIM(1),DIM(2));

	if WinView == 2
		MaxDim= DIM(1);
		DATA=zeros(DIM(2),DIM(3));
		FWID=WinFormat*DIM(2);
		FHGT=WinFormat*DIM(3);
		xmax = DIM(2)/FWID ;
		ymax = DIM(3)/FHGT ;
	elseif WinView == 3
		MaxDim= DIM(2);
		DATA=zeros(DIM(1),DIM(3));
		FWID=WinFormat*DIM(1);
		FHGT=WinFormat*DIM(3);
		xmax = DIM(1)/FWID ;
		ymax = DIM(3)/FHGT ;
	end

  
  PlaneNo=Plane0 ;
  txti=5;
  txtj= 10 - 3*WinFormat ;
 
  while PlaneNo <= min(MaxPlane,MaxDim) ,

	WNo = 1;

	FI = figure('Color',BkgColor,'Name',FName,...
	'Position',[100,10,512,512],...
	'Units','Pixels');
	
	while WNo <= WMax ,
	if(PlaneNo > MaxDim), break; end;
	if(PlaneNo > MaxPlane), break; end;
	
	if WinView == 1
		DATA=XYZDATA(:,:,PlaneNo);
		DATA = DATA';
	elseif WinView == 2
		DATA=zeros(DIM(2),DIM(3));
		for ix=1:DIM(2)
		  for iy=1:DIM(3)
		  	DATA(ix,iy)=XYZDATA(PlaneNo,ix,iy);
		  end
		end
	elseif WinView == 3
		DATA=zeros(DIM(1),DIM(3));
		for ix=1:DIM(1)
		  for iy=1:DIM(3)
		  	DATA(ix,iy)=XYZDATA(ix,PlaneNo,iy);
		  end
		end
	end

   	if PlaneNo >= Plane0,
		Ax(PlaneNo-Plane0+1)=subplot(WinFormat,WinFormat,WNo);
		if WinView ~= 1
			DATA=DATA';
		end
		
		imh=imagesc(DATA,[DATAMIN DATAMAX]);

		axis off image xy
 		colormap(GCM);
		vp_aspect(WinView,VOX);
		
		if NumLabels,
		  PlaneNoStr=num2str(PlaneNo);
		  thdl=text(txti-2,txtj+8,PlaneNoStr,'Color',[0.9 0.9 0.8],...
	  	    'FontName','Times','FontSize',7);
		end
		
		%Display Coordinate
		if PhyLabels,
		  if WinView == 1
		    ZCoord=(PlaneNo-XYZOR(3))*Dz;
		    titlestr=num2str((PlaneNo-XYZOR(3))*Dz);
		    text(txti+10,txtj-8,['z=',titlestr],...
	  	    'FontName','Times','FontSize',11,...
		    'Color',[1.0 1.0 1.0]);
		  elseif WinView == 2
		    XCoord=(PlaneNo-XYZOR(1))*Dx ;
		    titlestr=num2str((PlaneNo-XYZOR(1))*Dx);
		    text(txti+10,txtj-8,['x=',titlestr],...
	  	    'FontName','Times','FontSize',11,...
		    'Color',[1.0 1.0 1.0]);
		  elseif WinView == 3
		    YCoord=(PlaneNo-XYZOR(2))*Dy;
		    titlestr=num2str((PlaneNo-XYZOR(2))*Dy);
		    text(txti+10,txtj-8,['y=',titlestr],...
	  	    'FontName','Times','FontSize',11,...
		    'Color',[1.0 1.0 1.0]);
		  end
		end
		
		set(Ax(PlaneNo-Plane0+1),'UserData',[WinView PlaneNo VOX XYZOR]);
		
		drawnow;
		WNo = WNo + 1;
   	end % if PlaneNo
	PlaneNo = PlaneNo + SliceDelta ;
	
	end % While WNo
	
	vp_controls(gcf,mfilename,1);
	
   end % while
   
   PlaneNo=PlaneNo0;	% Restore Original value;
   fprintf('\n\n> '); 


elseif Opt==3

  NoImgs=size(DyFNames,1),
  
  if isempty(PlaneNo)
	PlaneNo0= [];
  else
	PlaneNo0= PlaneNo;
  end

  WNo=1;
  for ImNo=1:NoImgs,
    P=vp_nm('dnm',DyFNames(ImNo,:));
    FName=P,
    q  = length(P);
    TName=['...',P((q-min(6,q):q))];
    TName=strrep(TName,'_','\_');

    [out1 XYZDATA DATAMIN DATAMAX]=...
      vp_volfuns('xyzdata',DyFNames(ImNo,:),(DisplayOrient~=InputOrient));

    XYZOR=ORIGIN;
    XYZOR(1) = max(XYZOR(1), 1);
    XYZOR(2) = max(XYZOR(2), 1);
    XYZOR(3) = max(XYZOR(3), 1);
    Dx=VOX(1); Dy=VOX(2); Dz=VOX(3);

    if ImNo==1
      FWID=WinFormat*DIM(1);
      FHGT=WinFormat*DIM(2);
      ImageSize=DIM(1)*DIM(2);
      MaxDim = DIM(3);
      WMax=WinFormat*WinFormat;
      PlaneOri=ORIGIN(3);

      if WinView == 2
	MaxDim= DIM(1);
	DATA=zeros(DIM(2),DIM(3));
	FWID=WinFormat*DIM(2);
	FHGT=WinFormat*DIM(3);
        PlaneOri=ORIGIN(1);
      elseif WinView == 3
	MaxDim= DIM(2);
	DATA=zeros(DIM(1),DIM(3));
	FWID=WinFormat*DIM(1);
	FHGT=WinFormat*DIM(3);
        PlaneOri=ORIGIN(2);
      end

      PlaneNo=-1;
      while (PlaneNo < 1)
      	prompt=['Which Plane No.? [1-',num2str(MaxDim),'| q]'];
      
      	vp_keyin(prompt,num2str(PlaneOri));

      	if (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
      	return, end;
  
      	PlaneNo=str2num(Keyin);
	if ( (PlaneNo < 1) | (PlaneNo > MaxDim)),
         MaxDiM,
	 vp_note('Plane No Out of Range',3); PlaneNo=-1; end;
      end % while
	
      dim1=DIM;
    end %if ImNo
    
    if ~isequal(DIM, dim1), vp_note('WARNING: INCOMPATIBLE DIMENSIONS',3); end;
  
    DATA=zeros(DIM(1),DIM(2));
    txti=5;
    txtj= 10 - 3*WinFormat ;
    if PlaneNo > MaxDim ,
     vp_message(['PlaneNo ',num2str(PlaneNo),' exceeds MaxDim ',num2str(MaxDim)]); 
     PlaneNo=PlaneNo0;	% Restore Original value;
     return;
    end
    if ( (ImNo <= NoImgs) & ((WNo > WMax) | (ImNo==1)) ) ,
	WNo = 1;
	FI = figure('Color',BkgColor,'Name',[FName,'... ',num2str(ImNo),' of ',num2str(NoImgs)],...
	'Position',[100,10,512,512],...
	'Units','Pixels');
    end % if ImNo
	
    if(ImNo > NoImgs), break; end;
	
	if WinView == 1
		DATA=XYZDATA(:,:,PlaneNo);
		DATA = DATA';
	elseif WinView == 2
		DATA=zeros(DIM(2),DIM(3));
		for ix=1:DIM(2)
		  for iy=1:DIM(3)
		  	DATA(ix,iy)=XYZDATA(PlaneNo,ix,iy);
		  end
		end
	elseif WinView == 3
		DATA=zeros(DIM(1),DIM(3));
		for ix=1:DIM(1)
		  for iy=1:DIM(3)
		  	DATA(ix,iy)=XYZDATA(ix,PlaneNo,iy);
		  end
		end
	end

	Ax(ImNo)=subplot(WinFormat,WinFormat,WNo);
	if WinView ~= 1
		%DATA=rot90(DATA);
		DATA=DATA';
	end
	imh=imagesc(DATA,[DATAMIN DATAMAX]);
	axis off image xy
 	colormap(GCM);
	vp_aspect(WinView,VOX);
		
	if NumLabels,
	  ImNoStr=num2str(ImNo);
	  thdl=text(txti-2,txtj+8,ImNoStr,'Color',[0.9 0.9 0.8],...
  	    'FontName','Times','FontSize',7);
	end
		
	%Display Coordinate
	if PhyLabels,
	  if WinView == 1
	    ZCoord=(PlaneNo-XYZOR(3))*Dz;
	    titlestr=num2str((PlaneNo-XYZOR(3))*Dz);
	    titlestr=['z=',titlestr];
	    text(txti+10,txtj-8,TName,...
  	    'FontName','Times','FontSize',8,...
	    'Color',[1.0 1.0 1.0]);
	  elseif WinView == 2
	    XCoord=(PlaneNo-XYZOR(1))*Dx ;
	    titlestr=num2str((PlaneNo-XYZOR(1))*Dx);
	    titlestr=['x=',titlestr];
	    text(txti+10,txtj-8,TName,...
  	    'FontName','Times','FontSize',8,...
	    'Color',[1.0 1.0 1.0]);
	  elseif WinView == 3
	    YCoord=(PlaneNo-XYZOR(2))*Dy;
	    titlestr=num2str((PlaneNo-XYZOR(2))*Dy);
	    titlestr=['y=',titlestr];
	    text(txti+10,txtj-8,TName,...
  	    'FontName','Times','FontSize',8,...
	    'Color',[1.0 1.0 1.0]);
	  end
	end
	
	set(Ax(ImNo),'UserData',[WinView PlaneNo VOX XYZOR]);
		
        if ((WNo==WMax) | (ImNo==NoImgs)),
	  titlestr=['Plane No: ',num2str(PlaneNo),', ',titlestr];
 	  uicontrol(gcf,'style','text','string',titlestr,'position',[0 0 100 15]);
     	  vp_controls(gcf,mfilename,1);
        end
	
	drawnow;
	WNo = WNo + 1;
	
   end % for
   
   PlaneNo=PlaneNo0;	% Restore Original value;
   fprintf('\n\n> '); 

end %if Opt


