% vp_imvorth
% orthogonal views image display 
%_______________________________________________________________________
% vp_imvorth is a routine that displays three orthogonal slices through
% a point in an ANALYZE format image in three sectional views.
% Note, X, Y, Z coordinates represent mm distance from the origin.
% These values correspond to Talairach (or MNI) coordinates only if the file
% is normalized and displayed in the Neurological Orientation. If it is 
% stored in the Radiological orientation it is flipped along the X axis
% prior to display so that X=X is the corresponding Talairach coordinate.
%
% The "view point" is initally set to the origin defined in the header but
% can be modified by the user. If the origin is [0 0 0], the point
% is initially set to the midpoint. The user can then set the view
% point as the new origin. The data volume can also be rotated around
% any orthogonal axis through the view point that is active when the 
% rotate command is called. To rotate through a different point a new
% view point must be selected and the command must be reinitiated.
% The volume and voxel dimensions are redefined to form a cubic
% volume using the largest original dimension and centered at
% the view point which becomes the new origin unless reset.
% Volumes can be cropped by defining rectangular borders in any view.
% The new origin and volume data can be saved as a new image file.
%_______________________________________________________________________
% vp_imvorth		C.0		P. Spetsieris	4/6/99
%           Revision ScAnVP 5.1	 7/11/03, 5.2 11/13/03
%           Revision ScAnVP 6.1	 6/3/11, 6.2 4/24/12, 6.2.1 4/27/13
%           Revision ScAnVP 7.0  10/28/15

global Message PlaneNo FName MaxPlane Plane0 Opt Time MaxDim
global PlaneX PlaneY PlaneZ XYZDATA XYZOR FI
global DIM VOX SCALE TYPE OFFSET ORIGIN GLMIN GLMAX MATYPE GCM
global DATAMAX DATAMIN NumLabels PhyLabels
global XCoord YCoord ZCoord PntValue hVAL
global XYZDATA0 DIM0 VOX0 XYZOR0 Dx Dy Dz RotAngle
global PlaneX0 PlaneY0 PlaneZ0 DESCRIP
global BkgColor VAL_OFFSET InputOrient DisplayOrient
global ActiveOps

Message=[];

wformat=2;

if Opt ~= 3

delete(findobj('Tag','orthview'));

FNimg = [FName '.img'];

%flipim= InputOrient~=DisplayOrient;
[out1 XYZDATA DATAMIN DATAMAX]=vp_volfuns('xyzdata',FNimg,(InputOrient~=DisplayOrient));
DATAMAX, DATAMIN,

if isempty(PlaneNo)
	PlaneNo0= [];
else
	PlaneNo0= PlaneNo;
end

PlaneNo = 1; 


FWID=wformat*DIM(1);
FHGT=wformat*DIM(2);
xmax = DIM(1)/FWID ;
ymax = DIM(2)/FHGT ;
ImageSize=DIM(1)*DIM(2);
WMax=wformat*wformat;
MaxDim = DIM(3);

 
DATA=[];
%%XYZDATA=[];
DATA=zeros(DIM(1),DIM(2));

figwid=512; fighgt=480;
FI = figure('Color',BkgColor,...
	'Position',[350,10,figwid,fighgt],...
	'Name',FName,...
	'Tag','orthview',...
	'Pointer','cross',...
	'Units','Pixels');
	
%  set(gcf,'Pointer','crosshair');
%  set(gcf,'ButtonDownFcn','vp_imvalue');
	
XYZOR=ORIGIN;

XYZOR(1) = max(XYZOR(1), 1);
XYZOR(2) = max(XYZOR(2), 1);
XYZOR(3) = max(XYZOR(3), 1);

Dx=VOX(1);
Dy=VOX(2);
Dz=VOX(3);

PlaneZ=XYZOR(3);
PlaneX=XYZOR(1);
PlaneY=XYZOR(2);

if prod([PlaneX PlaneY PlaneZ])==1,
 PlaneX=round(DIM(1)/2); PlaneY=round(DIM(2)/2); PlaneZ=round(DIM(3)/2);
end

%%DATAMAX=SCALE*(max(max(max(XYZDATA)))),
%%DATAMIN=SCALE*(min(min(min(XYZDATA)))),
%%XYZDATA=SCALE*XYZDATA;

XYZDATA0=XYZDATA; DIM0=DIM; VOX0=VOX; XYZOR0=XYZOR;

end %for Opt not 3

PlaneZ = max(PlaneZ, 1);
PlaneY = max(PlaneY, 1);
PlaneX = max(PlaneX, 1);

PlaneZ = min(PlaneZ, DIM(3));
PlaneY = min(PlaneY, DIM(2));
PlaneX = min(PlaneX, DIM(1));

for ViewNo=1:3

  PlaneNo=PlaneZ ;
  
  WNo = 3 ;
  %WNo = ViewNo ;
  
  
  if ViewNo ~= 1
	if ViewNo == 2
		MaxDim= DIM(1);
		FWID=wformat*DIM(2);
		FHGT=wformat*DIM(3);
		xmax = DIM(2)/FWID ;
		ymax = DIM(3)/FHGT ;
		PlaneNo=PlaneX ;
		WNo = 2 ;
	elseif ViewNo == 3
		MaxDim= DIM(2);
		FWID=wformat*DIM(1);
		FHGT=wformat*DIM(3);
		xmax = DIM(1)/FWID ;
		ymax = DIM(3)/FHGT ;
		PlaneNo=PlaneY ;
		WNo = 1 ;
	end
  end

  txti=5;
  %txtj=-5 ;
  txtj= 10 - 3*wformat ;
  %txtj=15;
  %txtj=8 ;

	if ViewNo == 1
	
		DATA=zeros(DIM(1),DIM(2));
		DATA	= XYZDATA(:,:,PlaneNo);
		DATA = DATA';
		
	elseif ViewNo == 2
		DATA=zeros(DIM(2),DIM(3));
		for ix=1:DIM(2)
		  for iy=1:DIM(3)
		  	DATA(ix,iy)=XYZDATA(PlaneNo,ix,iy);
		  end
		end
	elseif ViewNo == 3
		DATA=zeros(DIM(1),DIM(3));
		for ix=1:DIM(1)
		  for iy=1:DIM(3)
		  	DATA(ix,iy)=XYZDATA(ix,PlaneNo,iy);
		  end
		end
	end

%subDATA = DATA
		AOx(WNo)=subplot(wformat,wformat,WNo);
		if ViewNo ~= 1
			%DATA=rot90(DATA);
			DATA=DATA';
		end
		%DATA=flipud(DATA);
		%imh=imagesc(DATA,[0 255]);
		if (DATAMAX == DATAMIN )
			vp_message(['ERR: DATA MAX = MIN = ',num2str(DATAMAX)]);
			return;
		end

		imh=imagesc(DATA,[DATAMIN DATAMAX]);
		
 		axis image xy off;
		
		% Correct Aspect ratio
		vp_aspect(ViewNo,VOX);
		
		if NumLabels,
		  PlaneNoStr=num2str(PlaneNo);
		  text(txti,txtj,PlaneNoStr,'Color',[0.9 0.9 0.8],...
	  	    'FontName','Times','FontSize',8);
		end
		
		
		if ViewNo == 1
		  ZCoord=(PlaneNo-XYZOR(3))*Dz;
		  titlestr=[];
		  if PhyLabels,
		    titlestr=['Z=', num2str((PlaneNo-XYZOR(3))*Dz), 'mm'];
		  end
		  text(txti+10,txtj-10,['AXIAL    ',titlestr],...
	  	  'FontName','Times','FontSize',11,...
		  'Color',[1.0 1.0 1.0]);
		   PntValue=DATA(PlaneY,PlaneX);
	           line([PlaneX-4 PlaneX+4], [PlaneY PlaneY]); line([PlaneX PlaneX], [PlaneY-4 PlaneY+4]);
		  
		elseif ViewNo == 2
		  XCoord=(PlaneNo-XYZOR(1))*Dx ;
		  titlestr=[];
		  if PhyLabels,
		    titlestr=['X=', num2str((PlaneNo-XYZOR(1))*Dx), 'mm'];
		  end
		  text(txti+10,txtj-10,['SAGITTAL    ',titlestr],...
	  	  'FontName','Times','FontSize',11,...
		  'Color',[1.0 1.0 1.0]);
	           line([PlaneY-4 PlaneY+4], [PlaneZ PlaneZ]); line([PlaneY PlaneY], [PlaneZ-4 PlaneZ+4]);
		   
		elseif ViewNo == 3
		  YCoord=(PlaneNo-XYZOR(2))*Dy;
		  titlestr=[];
		  if PhyLabels,
		    titlestr=['Y=', num2str((PlaneNo-XYZOR(2))*Dy), 'mm'];
		  end
		  %titlestr=num2str((PlaneNo-XYZOR(2))*Dy);
		  text(txti+10,txtj-10,['CORONAL    ',titlestr],...
	  	  'FontName','Times','FontSize',11,...
		  'Color',[1.0 1.0 1.0]);
	           line([PlaneX-4 PlaneX+4], [PlaneZ PlaneZ]); line([PlaneX PlaneX], [PlaneZ-4 PlaneZ+4]);
		   
		 end
		
		set(AOx(WNo),'UserData',[ViewNo PlaneNo VOX XYZOR]);
	 	
		set(findobj('tag','orthview'),'name',FName);
		
		drawnow;
end %for
   
   cbreset=['PlaneZ=round((ZCoord/Dz) + XYZOR(3));',...
	'PlaneX=round((XCoord/Dx) + XYZOR(1)); PlaneY=round((YCoord/Dy) +XYZOR(2)) ;',...
	'Opt=3; FI=figure(findobj(''tag'',''orthview'')); vp_imvorth ;'];
	
   cbcopyfig=['eval(cbreset); fsav=FI;',...
        'fnew=figure; FI=fnew; ActiveOps=0; vp_imvorth ; colormap(GCM);',...
	' set(FI,''color'',[0 0 0]); FI=fsav; ActiveOps=1; '];
	
   cbsetorigin=['XYZOR(1)=PlaneX; XYZOR(2)=PlaneY; XYZOR(3)=PlaneZ;',...
	'Opt=3; FI=figure(findobj(''tag'',''orthview'')); vp_imvorth ;'];
	
   cbxreset=['XCoord=str2num(get(gco,''string''));', cbreset];
   cbXFlip=['vp_note(''Assuming Neurological display (Check Input), X=X ',...
            'Talairach (/ MNI) for Talairach (/ MNI) normalized images.'');'];
   cbyreset=['YCoord=str2num(get(gco,''string''));', cbreset];
   cbzreset=['ZCoord=str2num(get(gco,''string''));', cbreset];
   
   cbxyzreset=['delete(findobj(''type'',''line'')); ',...
   '[out1 XCoord YCoord ZCoord]=vp_xyzcoord(gcf);', cbreset];
   
   cbsave=['TYPE=64; SCALE=1; ORIGIN=XYZOR; DESCRIP=[DESCRIP '' ScAnVP Edited'']; ',...
   	  ' vp_imsave([FName ''_'' num2str(RotAngle) ''.img''],XYZDATA); '];
       
   cbsetblack=['col=[0 0 0]; set(gcf,''color'',col);'];
	

   if ActiveOps,

     uicontrol(FI,'String','X mm',...
	'ToolTipString',['X coordinate in mm. from Origin'],...
	'Units','normalized',...
	'Position',[300/figwid 160/fighgt 35/figwid 20/fighgt]);

%	'CallBack','XCoord=str2num(get(gco,''string'')); ');

     uicontrol(FI,'style','edit','string',num2str(XCoord),...
	'ToolTipString',['X coordinate in mm. from Origin'],...
	'Units','normalized',...
	'Position',[335/figwid 160/fighgt 50/figwid 20/fighgt],...
	'CallBack', cbxreset );
	
     uicontrol(FI,'String','Note Orient.',...
	'ToolTipString',['For normalized Neurological Display, X values ',...
        'correspond to Talairach coordinates. See Help.'],...
	'Units','normalized',...
	'ForegroundColor',[0.7, 0, 0.7],...
	'Position',[390/figwid 158/fighgt 87/figwid 20/fighgt],...
	'CallBack', cbXFlip );
	
     uicontrol(FI,'String','Y mm',...
	'ToolTipString',['Y coordinate in mm. from Origin'],...
	'Units','normalized',...
	'Position',[300/figwid 135/fighgt 35/figwid 20/fighgt]);

%	'CallBack','YCoord=str2num(get(gco,''string'')); ');
     uicontrol(FI,'style','edit','string',num2str(YCoord),...
	'ToolTipString',['Y coordinate in mm. from Origin'],...
	'Units','normalized',...
	'Position',[335/figwid 135/fighgt 50/figwid 20/fighgt],...
	'CallBack', cbyreset );

     uicontrol(FI,'String','Z mm',...
	'ToolTipString',['Z coordinate in mm. from Origin'],...
	'Units','normalized',...
	'Position',[300/figwid 110/fighgt 35/figwid 20/fighgt]);

     uicontrol(FI,'style','edit','string',num2str(ZCoord),...
	'ToolTipString',['Z coordinate in mm. from Origin'],...
	'Units','normalized',...
	'Position',[335/figwid 110/fighgt 50/figwid 20/fighgt],...
	'CallBack', cbzreset );

     uicontrol(FI,'String','VIEW Pt.',...
	'ToolTipString',['View Sections through Point X,Y,Z mm. from origin.'],...
	'Units','normalized',...
	'Position',[300/figwid 185/fighgt 58/figwid 20/fighgt],...
	'CallBack',cbxyzreset);
	
     uicontrol(FI,'String','Off',...
	'ToolTipString',['Erase Cross'],...
	'Units','normalized',...
	'Position',[358/figwid 185/fighgt 27/figwid 20/fighgt],...
	'CallBack',['delete(findobj(''type'',''line''))']);
	
     uicontrol(FI,'Style','text','String',['Vox: (', num2str(PlaneX),'  ',num2str(PlaneY),'  ',num2str(PlaneZ),')'],...
	'Units','normalized',...
	'Position',[300/figwid 78/fighgt 90/figwid 20/fighgt],...
	'ToolTipString',['Voxel Coordinates of X,Y,Z'],...
	'ForegroundColor',[1.0 1.0 1.0],...
	'BackgroundColor',BkgColor);
	
     hVAL=uicontrol(FI,'String',['Val: ',num2str(PntValue)],...
	'ToolTipString',['Value at X,Y,Z  mm. from origin.'],...
	'Units','normalized',...
	'Position',[390/figwid 110/fighgt 87/figwid 20/fighgt]);



     cbviewopts = ['if isempty(XYZDATA), vp_note(''Volume Not Defined'',2); else,',...
	' ImOpt=get(hviewmenu,''Value''); ',...
	' if ImOpt== 2, ',...
	'vp_rotvol; ',...
	'elseif ImOpt== 3, ',...
	'UFI=FI; vp_cropvol(''menu'');',...
	'else ; end; end;'];


     hviewmenu=uicontrol(FI,'Style','PopUp','String',['ROT/CROP...|',...
	'Rotate(X,Y,Z)|',...
	'Crop & Zoom'],...
	'TooltipString',['1: Rotate Volume Around Z axis Through Point |',...
	'2: Crop Volume'],...
	'Units','normalized',...
	'Position',[300/figwid 55/fighgt 87/figwid 20/fighgt],...
	'CallBack', cbviewopts);
	
	
     uicontrol(FI,'String','BLACK BKGRND',...
	'ToolTipString',['Set The Window Background BLACK.'],...
	'Units','normalized',...
	'Position',[300/figwid 30/fighgt 87/figwid 20/fighgt],...
	'CallBack', cbsetblack );

     uicontrol(FI,'String','SET ORIGIN',...
	'ToolTipString',['Set View Point As New Origin.'],...
	'Units','normalized',...
	'Position',[390/figwid 80/fighgt 87/figwid 20/fighgt],...
	'CallBack', cbsetorigin );

     uicontrol(FI,'String',['SAVE ORI/VOL'],...
	'ToolTipString',['Save New Header & Data Volume'],...
	'Units','normalized',...
	'Callback', cbsave,...
	'Position',[390/figwid 55/fighgt 87/figwid 20/fighgt]);
	
     uicontrol(FI,'String',['COPY FIGURE'],...
	'ToolTipString',['Generate a fixed copy of this figure.'],...
	'Units','normalized',...
	'Callback', cbcopyfig,...
	'Position',[390/figwid 30/fighgt 87/figwid 20/fighgt]);
	

     vp_controls(FI,mfilename,1);

   end; %if ActiveOps

   PlaneNo=PlaneNo0;	% Restore Original value;
   fprintf('\n\n> '); 
   

