% vp_imzorth
% orthogonal views statistical/background image display 
%_______________________________________________________________________
% vp_imzorth is a routine that displays three orthogonal slices through
% a point in a statistical/background ANALYZE format image in three 
% sectional views. The "view point" (initially the origin or midpoint
% if the origin is [0 0 0]) can be modified.
% The upper half of the values are assigned to data and the lower half
% to the background (MRI).
%
% Note, X, Y, Z coordinates represent mm distance from the origin.
% These values correspond to Talairach (or MNI) coordinates only if the file
% is normalized and displayed in the Neurological Orientation. If it is 
% stored in the Radiological orientation it is flipped along the X axis
% prior to display so that X=X is the corresponding Talairach (or MNI)
% coordinate.
%_______________________________________________________________________
% vp_imzorth		C.0		P. Spetsieris	4/6/99
%		Revision ScAnVP 5.1			7/11/03
%		Revision ScAnVP 6.2, 6.2.1		4/27/12, 4/29/13
%       Revision ScAnVP 7.0  10/28/15

global Message PlaneNo FName MaxPlane Plane0 Opt Time MaxDim
global PlaneX PlaneY PlaneZ XYZDATA XYZOR MinThresh MaxThresh FI
global DIM VOX SCALE TYPE OFFSET ORIGIN GLMIN GLMAX MATYPE GCM CM
global DATAMAX DATAMIN NumLabels PhyLabels DatOp
global BACKMAX FOREMIN
global XCoord YCoord ZCoord PntValue hVAL
global BkgColor VAL_OFFSET ImputOrient DisplayOrient

Message=[];

wformat=2;

if Opt ~= 3

delete(findobj('Tag','orthview'));

FNimg = [FName '.img'];

[out1 XYZDATA DATAMIN DATAMAX]=vp_volfuns('xyzdata',FNimg,(InputOrient~=DisplayOrient));
DATAMAX, DATAMIN,

%%[fid,Message] = fopen(FNimg,'r');
%%if (fid == -1 )
%%	vp_message(Message);
%%	return;
%%end

if isempty(PlaneNo)
	PlaneNo0= [];
else
	PlaneNo0= PlaneNo;
end

PlaneNo = 1; 

FWID=wformat*DIM(1);
FHGT=wformat*DIM(2);
xmax = DIM(1)/FWID ;
ymax = DIM(2)/FHGT ;
ImageSize=DIM(1)*DIM(2);
WMax=wformat*wformat;
MaxDim = DIM(3);

%BkgColor=[.2 .4 .6]; % Set elsewhere
 
DATA=[];
%%XYZDATA=[];
DATA=zeros(DIM(1),DIM(2));

%fseek(fid,0,'bof');


%%XYZDATA=zeros(DIM(1),DIM(2),DIM(3));
%%for PlaneNo = 1:DIM(3) ,
%%	XYZDATA(:,:,PlaneNo) = fread(fid,[DIM(1),DIM(2)],MATYPE);
%%end %for
%%fclose(fid);

figwid=512; fighgt=480;
FI = figure('Color',BkgColor,...
	'Position',[350,10,figwid,fighgt],...
	'Name',FName,...
	'Tag','orthview',...
	'Pointer','cross',...
	'Units','Pixels');
	
XYZOR=ORIGIN;

XYZOR(1) = max(XYZOR(1), 1);
XYZOR(2) = max(XYZOR(2), 1);
XYZOR(3) = max(XYZOR(3), 1);

Dx=VOX(1);
Dy=VOX(2);
Dz=VOX(3);

PlaneZ=XYZOR(3);
PlaneX=XYZOR(1);
PlaneY=XYZOR(2);

if prod([PlaneX PlaneY PlaneZ])==1,
  PlaneX=round(DIM(1)/2); PlaneY=round(DIM(2)/2); PlaneZ=round(DIM(3)/2);
end
 
%correct for data mid range
% Not needed if maintain previous DATAMAX,DATAMIN

%datamax=max(max(max(XYZDATA))),
%datamin=min(min(min(XYZDATA))),
%midvalue=(datamin+datamax)/2,
%if midvalue < BACKMAX,
 %%shift background to lower values
 %shift=2*(BACKMAX-midvalue),
 %dataf=(XYZDATA > BACKMAX);
 %datab=(XYZDATA <= BACKMAX);
 %XYZDATA=(XYZDATA.*dataf+ XYZDATA.*datab -shift*datab);
 %save in file
 %BACKMAX=BACKMAX-shift; 
 %[fid,Message] = fopen(FNimg,'w');
 %if (fid == -1 )
%	vp_message(Message);
%	return;
% end
% out1=fwrite(fid,XYZDATA,MATYPE);
% fclose(fid);
%end

BACKMAX,

%DATAMAX=SCALE*(max(max(max(XYZDATA)))),
%DATAMIN=SCALE*(min(min(min(XYZDATA)))),

%%XYZDATA=SCALE*XYZDATA;
%%if VAL_OFFSET ~=0, XYZDATA=XYZDATAi + VAL_OFFSET; end; 
%%DATAMAX=(max(max(max(XYZDATA)))),
%%DATAMIN=(min(min(min(XYZDATA)))),

end %for Opt not 3

PlaneZ = max(PlaneZ, 1);
PlaneY = max(PlaneY, 1);
PlaneX = max(PlaneX, 1);

PlaneZ = min(PlaneZ, DIM(3));
PlaneY = min(PlaneY, DIM(2));
PlaneX = min(PlaneX, DIM(1));

for ViewNo=1:3

  PlaneNo=PlaneZ ;
  
  WNo = 3 ;
  %WNo = ViewNo ;
  
  
  if ViewNo ~= 1
	if ViewNo == 2
		MaxDim= DIM(1);
		FWID=wformat*DIM(2);
		FHGT=wformat*DIM(3);
		xmax = DIM(2)/FWID ;
		ymax = DIM(3)/FHGT ;
		PlaneNo=PlaneX ;
		WNo = 2 ;
	elseif ViewNo == 3
		MaxDim= DIM(2);
		FWID=wformat*DIM(1);
		FHGT=wformat*DIM(3);
		xmax = DIM(1)/FWID ;
		ymax = DIM(3)/FHGT ;
		PlaneNo=PlaneY ;
		WNo = 1 ;
	end
  end

  txti=5;
  %txtj=-5 ;
  txtj= 10 - 3*wformat ;
  %txtj=15;
  %txtj=8 ;

	if ViewNo == 1
	
		DATA=zeros(DIM(1),DIM(2));
		DATA	= XYZDATA(:,:,PlaneNo);
		DATA = DATA';
		
		
	elseif ViewNo == 2
		DATA=zeros(DIM(2),DIM(3));
		for ix=1:DIM(2)
		  for iy=1:DIM(3)
		  	DATA(ix,iy)=XYZDATA(PlaneNo,ix,iy);
		  end
		end
	elseif ViewNo == 3
		DATA=zeros(DIM(1),DIM(3));
		for ix=1:DIM(1)
		  for iy=1:DIM(3)
		  	DATA(ix,iy)=XYZDATA(ix,PlaneNo,iy);
		  end
		end
	end

%subDATA = DATA
		AOx(WNo)=subplot(wformat,wformat,WNo);
		
		if ViewNo ~= 1
			%DATA=rot90(DATA);
			DATA=DATA';
		end
		%DATA=flipud(DATA);
		%DATA=DATA*SCALE;
		%imh=imagesc(DATA,[0 SCALE*255]);
		%imh=imagesc(DATA,[DATAMIN MaxThresh]);
		if (DATAMAX == DATAMIN )
			vp_message(['ERR: DATA MAX = MIN = ',num2str(DATAMAX)]);
			return;
		end

		imh=imagesc(DATA,[DATAMIN DATAMAX]);
 		axis image xy off;
		
		%Correct for aspect ratio
		vp_aspect(ViewNo,VOX);
		
		if NumLabels,
		  PlaneNoStr=num2str(PlaneNo);
		  text(txti,txtj,PlaneNoStr,'Color',[0.9 0.9 0.8],...
	  	    'FontName','Times','FontSize',8);
		end
		
		if ViewNo == 1
		  ZCoord=(PlaneNo-XYZOR(3))*Dz;
		  titlestr=[];
		  if PhyLabels,
		    titlestr=['Z=', num2str((PlaneNo-XYZOR(3))*Dz), 'mm'];
		  end
		  text(txti+10,txtj-10,['AXIAL    ',titlestr],...
	  	  'FontName','Times','FontSize',11,...
		  'Color',[1.0 1.0 1.0]);
		  PntValue=DATA(PlaneY,PlaneX);
	          line([PlaneX-4 PlaneX+4], [PlaneY PlaneY]); line([PlaneX PlaneX], [PlaneY-4 PlaneY+4]);
		  
		elseif ViewNo == 2
		  XCoord=(PlaneNo-XYZOR(1))*Dx ;
		  titlestr=[];
		  if PhyLabels,
		    titlestr=['X=', num2str((PlaneNo-XYZOR(1))*Dx), 'mm'];
		  end
		  text(txti+10,txtj-10,['SAGITTAL    ',titlestr],...
	  	  'FontName','Times','FontSize',11,...
		  'Color',[1.0 1.0 1.0]);
	           line([PlaneY-4 PlaneY+4], [PlaneZ PlaneZ]); line([PlaneY PlaneY], [PlaneZ-4 PlaneZ+4]);
		   
		elseif ViewNo == 3
		  YCoord=(PlaneNo-XYZOR(2))*Dy;
		  titlestr=[];
		  if PhyLabels,
		    titlestr=['Y=', num2str((PlaneNo-XYZOR(2))*Dy), 'mm'];
		  end
		  %titlestr=num2str((PlaneNo-XYZOR(2))*Dy);
		  text(txti+10,txtj-10,['CORONAL    ',titlestr],...
	  	  'FontName','Times','FontSize',11,...
		  'Color',[1.0 1.0 1.0]);
	           line([PlaneX-4 PlaneX+4], [PlaneZ PlaneZ]); line([PlaneX PlaneX], [PlaneZ-4 PlaneZ+4]);
		   
		end
		
		set(AOx(WNo),'UserData',[ViewNo PlaneNo VOX XYZOR]);
		drawnow;
end %for

   cbreset=['PlaneZ=round((ZCoord/Dz) + XYZOR(3));',...
	'PlaneX=round((XCoord/Dx) + XYZOR(1)); PlaneY=round((YCoord/Dy) +XYZOR(2)) ;',...
	'Opt=3; FI=figure(findobj(''tag'',''orthview'')); vp_imzorth ;'];
   
   cbxreset=['XCoord=str2num(get(gco,''string''));', cbreset];
   cbyreset=['YCoord=str2num(get(gco,''string''));', cbreset];
   cbzreset=['ZCoord=str2num(get(gco,''string''));', cbreset];
   cbXFlip=['vp_note(''Assuming Neurological display (Check Input), X=X ',...
            'Talairach (/ MNI) for Talairach (/ MNI) normalized images.'');'];     
   %cbxyzreset=['[out1 XCoord YCoord ZCoord]=vp_xyzcoord;', cbreset];
   cbxyzreset=['delete(findobj(''type'',''line'')); ',...
   '[out1 XCoord YCoord ZCoord]=vp_xyzcoord(gcf);', cbreset];
	
   uicontrol(FI,'String','X mm',...
	'ToolTipString',['X coordinate in mm. from Origin'],...
	'units','normalized',...
	'Position',[265/figwid 160/fighgt 35/figwid 20/fighgt]);

%	'CallBack','XCoord=str2num(get(gco,''string'')); ');
   uicontrol(FI,'style','edit','string',num2str(XCoord),...
	'ToolTipString',['X coordinate in mm. from Origin'],...
	'units','normalized',...
	'Position',[300/figwid 160/fighgt 50/figwid 20/fighgt],...
	'CallBack', cbxreset );
	
   uicontrol(FI,'String','Y mm',...
	'ToolTipString',['Y coordinate in mm. from Origin'],...
	'units','normalized',...
	'Position',[265/figwid 135/fighgt 35/figwid 20/fighgt]);

%	'CallBack','YCoord=str2num(get(gco,''string'')); ');
   uicontrol(FI,'style','edit','string',num2str(YCoord),...
	'ToolTipString',['Y coordinate in mm. from Origin'],...
	'units','normalized',...
	'Position',[300/figwid 135/fighgt 50/figwid 20/fighgt],...
	'CallBack', cbyreset );

   uicontrol(FI,'String','Z mm',...
	'ToolTipString',['Z coordinate in mm. from Origin'],...
	'units','normalized',...
	'Position',[265/figwid 110/fighgt 35/figwid 20/fighgt]);

   uicontrol(FI,'style','edit','string',num2str(ZCoord),...
	'ToolTipString',['Z coordinate in mm. from Origin'],...
	'units','normalized',...
	'Position',[300/figwid 110/fighgt 50/figwid 20/fighgt],...
	'CallBack', cbzreset );

%	'CallBack',['PlaneZ=round((ZCoord/Dz) + XYZOR(3));',...
%	'PlaneX=round((XCoord/Dx) + XYZOR(1)); PlaneY=round((YCoord/Dy) +XYZOR(2)) ;',...
%	'Opt=3; FI=figure(findobj(''tag'',''orthview'')); vp_imzorth ;']);

   uicontrol(FI,'String','VIEW Pt.',...
	'ToolTipString',['View Sections through Point X,Y,Z mm. from origin.'],...
	'units','normalized',...
	'Position',[265/figwid 185/fighgt 58/figwid 20/fighgt],...
	'CallBack',cbxyzreset);
	
   uicontrol(FI,'String','Off',...
	'ToolTipString',['Erase Cross'],...
	'units','normalized',...
	'Position',[323/figwid 185/fighgt 27/figwid 20/fighgt],...
	'CallBack',['delete(findobj(''type'',''line''))']);
	
   uicontrol(FI,'Style','text','String',['Vox: (', num2str(PlaneX),'  ',num2str(PlaneY),'  ',num2str(PlaneZ),')'],...
	'units','normalized',...
	'Position',[262/figwid 78/fighgt 90/figwid 20/fighgt],...
	'ToolTipString',['Voxel Coordinates of X,Y,Z'],...
	'ForegroundColor',[1.0 1.0 1.0],...
	'BackgroundColor',BkgColor);
	
   hVAL=uicontrol(FI,'String',['Val: ',num2str(PntValue)],...
	'ToolTipString',['Value at X,Y,Z  mm. from origin.'],...
	'units','normalized',...
	'Position',[265/figwid 55/fighgt 87/figwid 20/fighgt]);

   uicontrol(FI,'String','Note Orient.',...
	'ToolTipString',['For normalized Neurological Display, X values ',...
        'correspond to Talairach coordinates. See Help.'],...
	'Units','normalized',...
	'ForegroundColor',[0.7, 0, 0.7],...
	'Position',[265/figwid 22/fighgt 87/figwid 20/fighgt],...
	'CallBack', cbXFlip );
	
    vp_controls(FI,mfilename,1);
    

   PlaneNo=PlaneNo0;	% Restore Original value;
   fprintf('\n\n> '); 


   vp_statbar(1,DATAMIN,DATAMAX,MinThresh,MaxThresh);
   	
   %w=which('scanvp');
   %cf=[w(1:(max(findstr(w,'\'))-4)),'col\grayhot'];
   %load(cf); GCM=CM;
   
   %%cf=[w(1:(max(findstr(w,'\'))-4)),'col\graycols'];
   %%load(cf); colormap(graycols); GCM=colormap;

   GCM=get(findobj('name','Statistical Map'),'colormap');
   
   colormap(GCM);
   
   drawnow;
   
