% vp_interp.m
% Allows user to change the size of an Analyze image by specifying
% new voxel or new file dimensions and using linear or nearest 
% neighbor interpolation.
% The change can be applied to multiple files. The new dimensions
% and changed Origin coordinates and file dimensions are saved
% in the header. The images are assigned an 'I' prefix.
%
% Variables that can be specified are either:
%
% DIM     : Image Width, Height(Pixels), No of slices
%
% or
%
% VOX     : Voxel Width, Height(mm), Interslice distance 
%___________________________________________________________________________
% vp_interp.m	C.4.2	P. Spetsieris  Oct. 7, 1999

global HelpMode Ecolor MATYPE Message
global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN EXPTIM DURATION
global EXPDATE GENTIM SUBID IntMethod

if HelpMode, vp_help(mfilename), return ; end;

delete(findobj('Name','INTERP'));

% DIM     : Image Width, Height(Pixels), No of slices
% VOX     : Voxel Width, Height(mm), Interslice distance 
% SCALE   : Scale Factor (DATA multiplier
% TYPE    : Data Type  (see vp_hwrite)
% OFFSET  : Data Offset (bytes)
% ORIGIN  : Origin (Pixel x,y,z coordinates) 
% DESCRIP : File Descriptor
% GLMAX   : Global Maximum
% GLMIN   : Global Minimum
% EXPTIM  : Frame Start Time [HR:MN:SC]
% MATYPE  : Matlab Data Type
% DURATION: Scan Duration (secs) dim(6)
%Set Defaults
vp_defaults;

ORIGIN=[max(ORIGIN(1),1) max(ORIGIN(2),1) max(ORIGIN(3),1)];

ORIG2=ORIGIN;
DIM2=DIM;
VOX2=VOX;

%FName=['Default.hdr' 0];
FName=['Default.hdr'];

%DIM=[79 95 68];
%VOX=[2.0 2.0 2.0];
%SCALE=1.0;
%TYPE=2;
%OFFSET=0;
%ORIGIN=[40 57 26];
%DESCRIP=['ScAn/VP Default Header File' 0];
%EXPTIM=['00:00:00' 0];
%GLMAX=255;
%GLMIN=0;
%DURATION=0;

Message=['Specify File'];
IdentFile=0;
IntMethod='linear';

interp = figure('Color','w','Name','INTERP3',...
'NumberTitle','off','Position',[100,200,280,290],...
'Units','Pixels');
	
Bcolor = [.8,.8,.9];
B2color = [.8,.95,.8];
%Bcolor = 'w';
Kcolor = [.8,.8,1.0];
K2color = [1.0,.80,.80];

%	'set(hoffset,''string'',num2str(OFFSET));',...
%	'set(hglmin,''string'',num2str(GLMIN));',...
%	'set(hglmax,''string'',num2str(GLMAX));',...
%	'set(hexptim,''string'',EXPTIM);',...
%	'set(hduration,''string'',num2str(DURATION));',...
%	'set(hdescrip,''string'',DESCRIP);',...
%	'set(htype,''string'',num2str(TYPE));',...
%	'set(hscale,''string'',num2str(SCALE));',...
%	'set(hsubid,''string'',SUBID);',...
%	'set(hexpdate,''string'',EXPDATE);',...

%  	'P=strtok(FName,''.'');',...
%
cbFName=['FName=get(hname,''string'');',...
  	'FName=deblank(FName);',...
  	'P=vp_nm(''dnm'',FName);',...
  	'vp_hread([P ''.hdr'']); ',...
	'ORIGIN=[max(ORIGIN(1),1) max(ORIGIN(2),1) max(ORIGIN(3),1)];',...
	'DIM2=DIM; VOX2=VOX; ORIG2=ORIGIN; ',...
	'DIM1=DIM; VOX1=VOX; ORIG1=ORIGIN; ',...
	'set(hname,''string'',FName);',...
	'set(hor1,''string'',num2str(ORIGIN(1)));',...
	'set(hor2,''string'',num2str(ORIGIN(2)));',...
	'set(hor3,''string'',num2str(ORIGIN(3)));',...
	'set(hdim1,''string'',num2str(DIM(1)));',...
	'set(hdim2,''string'',num2str(DIM(2)));',...
	'set(hdim3,''string'',num2str(DIM(3)));',...
	'set(hvox1,''string'',num2str(VOX(1)));',...
	'set(hvox2,''string'',num2str(VOX(2)));',...
	'set(hvox3,''string'',num2str(VOX(3)));',...
	'set(hor21,''string'',num2str(ORIGIN(1)));',...
	'set(hor22,''string'',num2str(ORIGIN(2)));',...
	'set(hor23,''string'',num2str(ORIGIN(3)));',...
	'set(hdim21,''string'',num2str(DIM(1)));',...
	'set(hdim22,''string'',num2str(DIM(2)));',...
	'set(hdim23,''string'',num2str(DIM(3)));',...
	'set(hvox21,''string'',num2str(VOX(1)));',...
	'set(hvox22,''string'',num2str(VOX(2)));',...
	'set(hvox23,''string'',num2str(VOX(3)));',...
	'IdentFile=1;',...
	'set(herror,''string'',[''FILE '' FName '' READ'']);'];
	
%cboffset=['OFFSET=str2num(get(hoffset,''string'')); '];

cbdim1=['DIM2(1)=str2num(get(hdim21,''string''));',...
	 'VOX2(1)= (DIM(1)*VOX(1))/DIM2(1); set(hvox21,''string'',num2str(VOX2(1)));',...
	 'ORIG2(1)=round(((ORIGIN(1)-1)*VOX(1))/VOX2(1)+1);ORIG2(1)=max(ORIG2(1),1);',...
	 'ORIG2(1)=min(ORIG2(1),DIM2(1)); set(hor21,''string'',num2str(ORIG2(1)));' ];
cbdim2=['DIM2(2)=str2num(get(hdim22,''string''));',...
	 'VOX2(2)= (DIM(2)*VOX(2))/DIM2(2); set(hvox22,''string'',num2str(VOX2(2)));',...
	 'ORIG2(2)=round(((ORIGIN(2)-1)*VOX(2))/VOX2(2)+1);ORIG2(2)=max(ORIG2(2),1);',...
	 'ORIG2(2)=min(ORIG2(2),DIM2(2)); set(hor22,''string'',num2str(ORIG2(2)));' ];
cbdim3=['DIM2(3)=str2num(get(hdim23,''string''));',...
	'VOX2(3)= (DIM(3)*VOX(3))/DIM2(3); set(hvox23,''string'',num2str(VOX2(3)));',...
	 'ORIG2(3)=round(((ORIGIN(3)-1)*VOX(3))/VOX2(3)+1);ORIG2(3)=max(ORIG2(3),1);',...
	 'ORIG2(3)=min(ORIG2(3),DIM2(3)); set(hor23,''string'',num2str(ORIG2(3)));' ];

cbvox1=['VOX2(1)=str2num(get(hvox21,''string''));',...
 'DIM2(1)= (DIM(1)*VOX(1))/VOX2(1); set(hdim21,''string'',num2str(DIM2(1)));',...
	 'ORIG2(1)=round(((ORIGIN(1)-1)*VOX(1))/VOX2(1)+1);ORIG2(1)=max(ORIG2(1),1);',...
	 'ORIG2(1)=min(ORIG2(1),DIM2(1)); set(hor21,''string'',num2str(ORIG2(1)));' ];
cbvox2=['VOX2(2)=str2num(get(hvox22,''string''));',...
 'DIM2(2)= (DIM(2)*VOX(2))/VOX2(2); set(hdim22,''string'',num2str(DIM2(2)));',... 
	 'ORIG2(2)=round(((ORIGIN(2)-1)*VOX(2))/VOX2(2)+1);ORIG2(2)=max(ORIG2(2),1);',...
	 'ORIG2(2)=min(ORIG2(2),DIM2(2)); set(hor22,''string'',num2str(ORIG2(2)));' ];
cbvox3=['VOX2(3)=str2num(get(hvox23,''string''));',...
 'DIM2(3)= (DIM(3)*VOX(3))/VOX2(3); set(hdim23,''string'',num2str(DIM2(3)));',... 
	 'ORIG2(3)=round(((ORIGIN(3)-1)*VOX(3))/VOX2(3)+1);ORIG2(3)=max(ORIG2(3),1);',...
	 'ORIG2(3)=min(ORIG2(3),DIM2(3)); set(hor23,''string'',num2str(ORIG2(3)));' ];


%  	'P=strtok(FName,''.'');',...
%
uicontrol(interp,'string', 'PICK FILE',...
	'position',[10 260 70 25],...
	'TooltipString','Enter File Name',...
	'callback',['FName=get_file(1,''.hdr'',''please select image'',[]); ',...
	'if ~isempty(FName),',...
  	'FName=deblank(FName);',...
  	'P=vp_nm(''dnm'',FName);',...
  	'vp_hread([P ''.hdr'']); ',...
	'ORIGIN=[max(ORIGIN(1),1) max(ORIGIN(2),1) max(ORIGIN(3),1)];',...
	'DIM1=DIM; VOX1=VOX; ORIG1=ORIGIN; ',...
	'DIM2=DIM; VOX2=VOX; ORIG2=ORIGIN; ',...
	'set(hname,''string'',FName);',...
	'set(hor1,''string'',num2str(ORIGIN(1)));',...
	'set(hor2,''string'',num2str(ORIGIN(2)));',...
	'set(hor3,''string'',num2str(ORIGIN(3)));',...
	'set(hdim1,''string'',num2str(DIM(1)));',...
	'set(hdim2,''string'',num2str(DIM(2)));',...
	'set(hdim3,''string'',num2str(DIM(3)));',...
	'set(hvox1,''string'',num2str(VOX(1)));',...
	'set(hvox2,''string'',num2str(VOX(2)));',...
	'set(hvox3,''string'',num2str(VOX(3)));',...
	'set(hor21,''string'',num2str(ORIGIN(1)));',...
	'set(hor22,''string'',num2str(ORIGIN(2)));',...
	'set(hor23,''string'',num2str(ORIGIN(3)));',...
	'set(hdim21,''string'',num2str(DIM(1)));',...
	'set(hdim22,''string'',num2str(DIM(2)));',...
	'set(hdim23,''string'',num2str(DIM(3)));',...
	'set(hvox21,''string'',num2str(VOX(1)));',...
	'set(hvox22,''string'',num2str(VOX(2)));',...
	'set(hvox23,''string'',num2str(VOX(3)));',...
	'IdentFile=1;',...
	'set(herror,''string'',[''FILE '' FName '' READ'']); end;']);
	
hname=uicontrol(interp,'style','edit','string',FName,...
	'TooltipString','Enter File Name',...
	'position',[72 260 207 25],'BackgroundColor',Kcolor,'callback',cbFName);
	

%		'elseif mopt==3, IntMethod=''cubic'',',...
% OMIT hung system	'elseif mopt==4, IntMethod=''spline'', end;'];

cbmethod = ['mopt=get(hmethod,''Value''); if mopt==1, IntMethod=''linear'',',...
		'elseif mopt==2, IntMethod=''nearest'', end;'];
	
hmethod=uicontrol(interp,'Style','popup','Visible','on','String',...
	'Linear Interpolation|Nearest Neighbor ',...
	'Tag','MethodMenu',...
	'TooltipString',['Linear Interpolation, Nearest Neighbor, '],...
	'BackgroundColor',Bcolor,...
    	'Position',[10 230 150 25],'callback',cbmethod);
	
uicontrol(interp,'String','HELP',...
	'TooltipString','Help displayed in MATLAB window',...
	'Position',[215 235 60 25],...
	'BackgroundColor',Ecolor,...
	'CallBack',['vp_help(''vp_interp'');']);

uicontrol(interp,'style','text','string', 'ORIGIN X ',...
	'TooltipString','Pixel Coordinate X of Origin',...
	'position',[10 210 55 15],'BackgroundColor',Bcolor);
	
hor1=uicontrol(interp,'style','text','string',num2str(ORIGIN(1)),...
	'TooltipString','Pixel Coordinate X of Origin',...
	'position',[65 210 35 15],'BackgroundColor',Bcolor);

uicontrol(interp,'style','text','string', 'ORIGIN Y ',...
	'TooltipString','Pixel Coordinate Y of Origin',...
	'position',[100 210 55 15],'BackgroundColor',Bcolor);
	
hor2=uicontrol(interp,'style','text','string',num2str(ORIGIN(2)),...
	'TooltipString','Pixel Coordinate Y of Origin',...
	'position',[155 210 35 15],'BackgroundColor',Bcolor);

uicontrol(interp,'style','text','string', 'ORIGIN Z ',...
	'TooltipString','Pixel Coordinate Z of Origin',...
	'position',[190 210 55 15],'BackgroundColor',Bcolor);
	
hor3=uicontrol(interp,'style','text','string',num2str(ORIGIN(3)),...
	'TooltipString','Pixel Coordinate Z of Origin',...
	'position',[245 210 35 15],'BackgroundColor',Bcolor);
	
uicontrol(interp,'style','text','string', 'DIM X ',...
	'TooltipString','Scan X DIMENSION (Pixels)',...
	'position',[10 195 55 15],'BackgroundColor',Bcolor);
	
hdim1=uicontrol(interp,'style','text','string',num2str(DIM(1)),...
	'TooltipString','Scan X DIMENSION (Pixels)',...
	'position',[65 195 35 15],'BackgroundColor',Bcolor);

uicontrol(interp,'style','text','string', 'DIM Y ',...
	'TooltipString','Scan Y DIMENSION (Pixels)',...
	'position',[100 195 55 15],'BackgroundColor',Bcolor);
	
hdim2=uicontrol(interp,'style','text','string',num2str(DIM(2)),...
	'TooltipString','Scan Y DIMENSION (Pixels)',...
	'position',[155 195 35 15],'BackgroundColor',Bcolor);

uicontrol(interp,'style','text','string', 'DIM Z ',...
	'TooltipString','Z DIMENSION (No of Slices)',...
	'position',[190 195 55 15],'BackgroundColor',Bcolor);
	
hdim3=uicontrol(interp,'style','text','string',num2str(DIM(3)),...
	'TooltipString','Z DIMENSION (No of Slices)',...
	'position',[245 195 35 15],'BackgroundColor',Bcolor);

uicontrol(interp,'style','text','string', 'VOX X ',...
	'TooltipString','Voxel DX (mm)',...
	'position',[10 180 55 15],'BackgroundColor',Bcolor);
	
hvox1=uicontrol(interp,'style','text','string',num2str(VOX(1)),...
	'TooltipString','Voxel DX (mm)',...
	'position',[65 180 35 15],'BackgroundColor',Bcolor);

uicontrol(interp,'style','text','string', 'VOX Y ',...
	'TooltipString','Voxel DY (mm)',...
	'position',[100 180 55 15],'BackgroundColor',Bcolor);
	
hvox2=uicontrol(interp,'style','text','string',num2str(VOX(2)),...
	'TooltipString','Voxel DY (mm)',...
	'position',[155 180 35 15],'BackgroundColor',Bcolor);

uicontrol(interp,'style','text','string', 'VOX Z ',...
	'TooltipString','Voxel DZ (mm)',...
	'position',[190 180 55 15],'BackgroundColor',Bcolor);
	
hvox3=uicontrol(interp,'style','text','string',num2str(VOX(3)),...
	'TooltipString','Voxel DZ (mm)',...
	'position',[245 180 35 15],'BackgroundColor',Bcolor);
	
uicontrol(interp,'style','text','string', 'KEY IN NEW DIMENSIONS FOR DIM OR VOX : ',...
	'TooltipString','New Dimensions for 3D Interpolation',...
	'position',[10 140 150 25],'BackgroundColor',K2color);
	
uicontrol(interp,'style','text','string', 'ORIGIN X ',...
	'TooltipString','Pixel Coordinate X of Origin',...
	'position',[10 110 55 22],'BackgroundColor',B2color);
	
hor21=uicontrol(interp,'style','text','string',num2str(ORIG2(1)),...
	'TooltipString','Pixel Coordinate X of Origin',...
	'position',[65 110 35 22],'BackgroundColor',B2color);

uicontrol(interp,'style','text','string', 'ORIGIN Y ',...
	'TooltipString','Pixel Coordinate Y of Origin',...
	'position',[100 110 55 22],'BackgroundColor',B2color);
	
hor22=uicontrol(interp,'style','text','string',num2str(ORIG2(2)),...
	'TooltipString','Pixel Coordinate Y of Origin',...
	'position',[155 110 35 22],'BackgroundColor',B2color);

uicontrol(interp,'style','text','string', 'ORIGIN Z ',...
	'TooltipString','Pixel Coordinate Z of Origin',...
	'position',[190 110 55 22],'BackgroundColor',B2color);
	
hor23=uicontrol(interp,'style','text','string',num2str(ORIG2(3)),...
	'TooltipString','Pixel Coordinate Z of Origin',...
	'position',[245 110 35 22],'BackgroundColor',B2color);
	
uicontrol(interp,'style','text','string', 'DIM X ',...
	'TooltipString','Scan X DIMENSION (Pixels)',...
	'position',[10 85 55 22],'BackgroundColor',B2color);
	
hdim21=uicontrol(interp,'style','edit','string',num2str(DIM2(1)),...
	'TooltipString','Scan X DIMENSION (Pixels)',...
	'position',[65 85 35 25],'BackgroundColor',K2color,'callback',cbdim1);

uicontrol(interp,'style','text','string', 'DIM Y ',...
	'TooltipString','Scan Y DIMENSION (Pixels)',...
	'position',[100 85 55 22],'BackgroundColor',B2color);
	
hdim22=uicontrol(interp,'style','edit','string',num2str(DIM2(2)),...
	'TooltipString','Scan Y DIMENSION (Pixels)',...
	'position',[155 85 35 25],'BackgroundColor',K2color,'callback',cbdim2);

uicontrol(interp,'style','text','string', 'DIM Z ',...
	'TooltipString','Z DIMENSION (No of Slices)',...
	'position',[190 85 55 22],'BackgroundColor',B2color);
	
hdim23=uicontrol(interp,'style','edit','string',num2str(DIM2(3)),...
	'TooltipString','Z DIMENSION (No of Slices)',...
	'position',[245 85 35 25],'BackgroundColor',K2color,'callback',cbdim3);

uicontrol(interp,'style','text','string', 'VOX X ',...
	'TooltipString','Voxel DX (mm)',...
	'position',[10 60 55 22],'BackgroundColor',B2color);
	
hvox21=uicontrol(interp,'style','edit','string',num2str(VOX2(1)),...
	'TooltipString','Voxel DX (mm)',...
	'position',[65 60 35 25],'BackgroundColor',K2color,'callback',cbvox1);

uicontrol(interp,'style','text','string', 'VOX Y ',...
	'TooltipString','Voxel DY (mm)',...
	'position',[100 60 55 22],'BackgroundColor',B2color);
	
hvox22=uicontrol(interp,'style','edit','string',num2str(VOX2(2)),...
	'TooltipString','Voxel DY (mm)',...
	'position',[155 60 35 25],'BackgroundColor',K2color,'callback',cbvox2);

uicontrol(interp,'style','text','string', 'VOX Z ',...
	'TooltipString','Voxel DZ (mm)',...
	'position',[190 60 55 22],'BackgroundColor',B2color);
	
hvox23=uicontrol(interp,'style','edit','string',num2str(VOX2(3)),...
	'TooltipString','Voxel DZ (mm)',...
	'position',[245 60 35 25],'BackgroundColor',K2color,'callback',cbvox3);


uicontrol(interp,'String','PROCESS',...
	'Position',[10 35 60 25],...
	'CallBack',['if ~IdentFile, set(herror,''string'',''ERR: File Not Specified''); return; end; ',...
	'set(herror,''string'',[''PROCESSING FILE '' FName(1:min(30,length(FName))) ]);',...
	'set(interp,''Pointer'',''watch''); drawnow; disp(''PROCESSING '');',...
	'FName, DIM1, VOX1, ORIG1, DIM2, VOX2, ORIG2,',...
	'[out1]=vp_interpro(FName,DIM2,VOX2,ORIG2,2);',...
	'set(interp,''Pointer'',''arrow''); drawnow; disp('' '');',...
	'if out1<0, set(herror,''string'',[''PROCESSING ERROR'']);, else,',...
	'set(herror,''string'',[''PROCESSING COMPLETE'']); end;']);

uicontrol(interp,'String','RE-BATCH',...
	'Position',[90 35 100 25],...
	'TooltipString','REPEAT for a batch of files',...
	'CallBack',['vp_interbatch;']);
	
uicontrol(interp,'String','QUIT',...
	'Position',[215 35 60 25],...
	'CallBack',['delete(interp);']);
	
%	'CallBack',['delete(interp);','delete(FI);']);

herror = uicontrol(interp,'string', ['MSG : ',Message],...
	'position',[10 10 270 25],...
	'Callback','set(gco,''string'',get(gco,''string''))',...
	'BackgroundColor',Ecolor);

