function [out1, out2]=vp_interpro(FName, dim2, vox2,orig2,in3)
% Perform image interpolation on an ANALYZE Format image
%_______________________________________________________________________
%
% vp_interpro performs linear or nearest neighbor interpolation
% in the X, Y, or Z dimension of an ANALYZE Format image.
% Specifications are determined by the input parameters for dimensions
% and voxel sizes. The data is saved in a new file and the specified
% origin and dimensions are recorded in the new header.
% The new default name is given an 's' prefix for resampling.
%
% in3=1  :  Return DATA without writing image
% in3=2  :  Return DATA and write image
% out1   :  Return status
% out2   :  Return DATA
%_______________________________________________________________________
% vp_interpro		C.4.6	P. Spetsieris	11/2/00
%                       ScAnVP rev.5.3 by P.S	03/30/04

global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN
global EXPTIM DURATION MATYPE Message GENTIM SUBID EXPDATE
global HelpMode IntMethod

if HelpMode, vp_help(mfilename), return ; end;

out1=0;
out2=[];

RDATA=[];

FName=deblank(FName);
%P=strtok(FName,'.');
P=vp_nm('dnm',FName);
	
name=[P '.img'];
  
fid=fopen(name,'r');
RDATA=[];
 
h=waitbar(0.1,['Processing image 3D ',IntMethod,' interpolation ...']);
for i=1:DIM(3)
	
        %DATA=[];
	%DATA= fread(fid,[DIM(1),DIM(2)],MATYPE);
	%RDATA(:,:,i)= DATA';
	  
	RDATA(:,:,i)= fread(fid,[DIM(1),DIM(2)],MATYPE);
	
 %maxout=max(RDATA),
 %minout=min(RDATA),
 %maxout=max(max(RDATA(:,:,PlaneNo))),
 %minout=min(min(RDATA(:,:,PlaneNo))),

end %for i

waitbar(.25,h);

fclose(fid);

if in3~=1,
	len=length(P);
	mx=max([findstr(P,'\') 0]);
	dir=P(1:mx);
	nm=P(mx+1:len);
	nameimg=[dir 'I' nm '.img'];
	%nameimg=[dir 's' nm '.img'];
 	%nameimg=[P 'I.img'],
 	fidop=fopen(nameimg,'w');
end

%Replicate edge values

data1=RDATA;

data1(:,(DIM(2)+1),:)=data1(:,DIM(2),:);
data1((DIM(1)+1),:,:)=data1(DIM(1),:,:);
data1(:,:,(DIM(3)+1))=data1(:,:,DIM(3));

[x,y,z]=meshgrid(0:VOX(2):DIM(2)*VOX(2),...
	0:VOX(1):DIM(1)*VOX(1),0:VOX(3):DIM(3)*VOX(3));
[x2,y2,z2]=meshgrid(0:vox2(2):(dim2(2)-1)*vox2(2),...
	0:vox2(1):(dim2(1)-1)*vox2(1),0:vox2(3):(dim2(3)-1)*vox2(3));

waitbar(.3,h);
data2=interp3(x,y,z,data1,x2,y2,z2,IntMethod);
waitbar(.9,h);

if in3~=1,
	no=fwrite(fidop,data2,MATYPE);
	if no <=0,
  		Message=['Write ERROR no: ' num2str(no) ' pixels'] ;
		set(hroierr,'string',['MSG: ',Message]);
		disp(Message);
		out1=-1;
		return;
	end
end
      
out2=data2;

    DESCRIP=[DESCRIP, '-',IntMethod,' Interpolated'];
    DIM=dim2;
    VOX=vox2;
    ORIGIN=orig2;
    
if in3==1, return, end;

fclose(fidop);
waitbar(1,h); pause(1); close(h);


Bcolor = [.8,1,1];

interprogui = figure('Color',Bcolor,'Name','Interpro','Tag','interprogui',...
'NumberTitle','off','Position',[100,200,250,60],'UserData',0,...
'Units','Pixels');
	

%	'if exist(name,''file''), vp_message(''Err: File exists''), else, ',

%cbFName=['hrname=findobj(''tag'',''namefield''); name=get(hrname,''string''),',...
%	'name=deblank(name);',...
%	'vp_hwrite(name,DIM,VOX,SCALE,TYPE,OFFSET,ORIGIN,DESCRIP,',...
%	'EXPTIM,DURATION,GENTIM,SUBID,EXPDATE);',...
%	'names=get(hrname,''userdata''); nameimg=char(names(1)); name0=char(names(2));',...
%	'name=[strtok(name,''.'') ''.img''];',...
%	'if strcmp(name,name0), vp_note(''Invalid Name=ORIGINAL'');',...
%	'else, if ~strcmp(name,nameimg) ',...
%	' dos([''move '' nameimg '' '' name]), end;',...
%	' namehdr=[strtok(name,''.'') ''.hdr''];',...
%	' vp_hwrite(name,DIM,VOX,SCALE,TYPE,OFFSET,ORIGIN,DESCRIP,',...
%	' EXPTIM,DURATION,GENTIM,SUBID,EXPDATE);',...
%	' set(gco,''string'',[name ''   FILE SAVED'']); Message=[''FILE SAVED'']; ',...
%	' disp(Message); set(findobj(''tag'',''interprogui''),''UserData'',1);',...
%	'end; '];
	

% Save default header before user name read, to keep consistent with image saved.
% Read user name. If not the default name. Warn if only .hdr or .img doesn't exist,
% since if there aren't permissions to overwrite, only the header or image will be
% overwritten and the other will be incorrect.

%	'nameimg=deblank(nameimg); namehdr0=[strtok(nameimg,''.'') ''.hdr''];',...
%	  'name=deblank(name); namehdr=[strtok(name,''.'') ''.hdr''];',...
%	  'name=[strtok(name,''.'') ''.img''];',...
%
cbFName=['staterr=0; hrname=findobj(''tag'',''namefield''); ',...
	'names=get(hrname,''userdata''); nameimg=char(names(1)); name0=char(names(2));',...
	'nameimg=vp_nm(''dnm'',nameimg); namehdr0=[nameimg ''.hdr'']; nameimg=[nameimg ''.img''];',...
	'if (vp_hwrite(nameimg,DIM,VOX,SCALE,TYPE,OFFSET,ORIGIN,DESCRIP,',...
	'EXPTIM,DURATION,GENTIM,SUBID,EXPDATE) ) < 0,',...
	'vp_message(''hwrite err''); staterr=1; ',...
	'else, ',...
	  'name=get(hrname,''string''),',...
	  'name=vp_nm(''dnm'',name); namehdr=[name ''.hdr'']; name=[name ''.img''];',...
	  'if ~strcmp(name,nameimg),',...
	   'if strcmp(name,name0), vp_note(''Invalid Name=ORIGINAL''); staterr=4; ',...
	   'elseif ~strcmp(name,nameimg) ',...
	     'if (exist(name,''file'') & ~exist(namehdr,''file'')) | ',...
	       ' (~exist(name,''file'') & exist(namehdr,''file''))  ',...
	       'vp_message([''Remove Invalid File '' name '' .hdr or .img'']);',...
	       ' staterr=3; ',...
	     'else, [s,dosmsg]=dos([''move '' nameimg '' '' name]), ',...
	       'if s ~=0, vp_message(dosmsg); staterr=2; end; ',...
	       '[s,dosmsg]=dos([''move '' namehdr0 '' '' namehdr]), ',...
	       'if s ~=0, vp_message(dosmsg); staterr=2; end; ',...
	     'end; ',...
	   'end;',...
	  'end; ',...
	  'if staterr==0,  nameimg=name;  end;',...
	'end;',...
	'if staterr==0,',...
	  'set(gco,''string'',[nameimg ''   FILE SAVED'']); Message=[''FILE SAVED'']; ',...
	  'disp(Message); pause(2); set(findobj(''tag'',''interprogui''),''UserData'',1); ',...
	' end; '];
	
	
uicontrol(interprogui,'style','text','string','ENTER NAME: ',...
	'position',[10 25 125 25],'BackgroundColor',Bcolor);
	
hrname=uicontrol(interprogui,'style','edit','tag','namefield','string',nameimg,...
	'userdata',{nameimg,name},...
	'position',[10 5 225 25],'BackgroundColor','w','callback',cbFName);


%while( get(findobj('tag','interprogui'),'UserData')==0) ,pause(1); end;
waitfor( findobj('tag','interprogui'),'UserData');

delete( findobj('tag','interprogui') );

return;
