% vp_marker
% Place marker on ANALYZE Format images
%_______________________________________________________________________
% vp_marker allows the user to place a 5x5 square pixel marker on 
% every slice of an ANALYZE format image at a pre-fixed x,y disk file
% position. The color is that of the maximum file value.
% Marked image files are saved on disk and prefixed with an 'X'.
% The main purpose is to track flipping of Left to Right in testing
% image processing operations. Check the position of the marker before
% and after processing. For Neurologicaly oriented files the marker
% is placed on the anatomical right. For Radiological files the marker is
% on the left. This is visible if the orientation is specified for "Input"
% on the ScAnVP menu but the correct orientation must be known by the user.
%_______________________________________________________________________
% vp_marker		C.4.2	P. Spetsieris	11/23/99
%	 		Revision 6.1 4/28/11

global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN DESCRIP
global EXPTIM DURATION MATYPE Message GENTIM SUBID EXPDATE
global HelpMode FMenu NameLst

%global bytegui hrname nameimg

if HelpMode, vp_help(mfilename), return ; end;

%NameLst      = get_file(Inf,'.img','Select images to place marker',[]);
if vp_filesui(Inf,'.img','Select images to MARK',mfilename) < 0 ,return; end;


m= size(NameLst,1);
dim3=0;

if m <1,
  vp_note('ERROR: Enter at least one file.',3);
  return;
end;


set(FMenu,'Pointer','Watch');
h=waitbar(0.1,'Processing image Markers ...');
for i=1:m

  	FName=deblank(NameLst(i,:));
  	%P=strtok(FName,'.');
	P=vp_nm('dnm',FName);
	
	vp_hread([P '.hdr']);
	
    posx=DIM(1)*.60; posy=DIM(2)*.66;
	mdim=.05*(DIM(1) + DIM(2))/2;
	mdim=max(1,round(mdim)),
	posx=max(1,round(posx)),
	posy=max(1,round(posy)),
    
    %sx=num2str(40); sy=num2str(60);
    sx=num2str(posx); sy=num2str(posy);
    sxmm=num2str((posx-ORIGIN(1))*VOX(1)); symm=num2str((posy-ORIGIN(2))*VOX(2));
	vp_note(['Placing Markers at (' sx ',' sy ')pix = (' sxmm ',' symm ')mm'], 1);
	waitbar((i-.8)/m,h);
    	
	name=[P '.img'];
  
	ImageSize=DIM(1)*DIM(2);

	fid=fopen(name,'r');
 
	SDATA=[];
	SDATA=zeros(DIM(1),DIM(2),DIM(3));

	glmaxdat=0;
	
	for PlaneNo=1:DIM(3)
		SDATA(:,:,PlaneNo) = fread(fid,[DIM(1),DIM(2)],MATYPE);
	end
	
	glmaxdat=max(max(max(SDATA))),
	
	fclose(fid);
	
	%SCALE=glmaxdat/255;
	%TYPE=2;
	
	len=length(P);
	mx=max([findstr(P,'\') 0]);
	%dir=P(1:max([findstr(P,'\') 0]));
	dir=P(1:mx);
	
	nm=P(mx+1:len);
	
	nameimg=[dir 'X' nm '.img'];
	fidconv=fopen(nameimg,'w');

	for PlaneNo=1:DIM(3)
	  DATA=[];
	  DATA=zeros(DIM(1),DIM(2));
	  
	  %DATA=SDATA(:,:,PlaneNo)/SCALE;
	  DATA=SDATA(:,:,PlaneNo);
	  
	  %Place mdim X mdim marker
	  for i=1:mdim, for j=1:mdim
	  
	  %DATA(i+40,j+60)=255; end; end;
	  DATA(i+posx,j+posy)=glmaxdat; end; end;
	  
	  %out1=fwrite(fidconv,DATA,'uchar');
	  out1=fwrite(fidconv,DATA,MATYPE);
	end
	
	fclose(fidconv);
	
	DESCRIP=[DESCRIP,'- MARKED IMAGE'];
	
	vp_hwrite(nameimg,DIM,VOX,SCALE,TYPE,OFFSET,ORIGIN,DESCRIP,...
	EXPTIM,DURATION,GENTIM,SUBID,EXPDATE,GLMAX,GLMIN);
	
	vp_note(['FILE ' nameimg ' SAVED'],1);
	
	
end
waitbar(1,h); pause(1); close(h);

set(FMenu,'Pointer','Arrow');
vp_note('Marker PROCESSING COMPLETE',3);

