% vp_mask.m
% Create Analyze Volume Mask using Rois
%___________________________________________________________________________
% vp_mask uses regions of interest defined on a reference image
% to create an output image of zeros and ones across planes.
% All pixels within each region are given a value of one and all
% others zero. The output is saved as an 8bit Analyze image which
% can be used by statistical routines. To create a mask using
% thresholded regions use 'GIS/ROI Map/Mask'.
% The mask image is saved in the orientation of the "Input" image
% setting on the main ScAnVP menu. An option is provided to check
% the setting.
%__________________________________________________________________________
% vp_mask.m	ScAnVP Ver. C.0	P. Spetsieris   Jan. 12, 1998
%                  Rev. 7.0 P. Spetsieris   Jan. 19, 2016

global HelpMode Ecolor FI Display Orient InputOrient FMenu

if HelpMode, vp_help(mfilename), return ; end;

vp_imframe;

FName=[];
WndNo=0;
WndScl=4;
PlaneNo=1;
Thresh=100;
Message0=['............................................ '];
Message=Message0;

maskref = figure('Color','w','Name','MASKref',...
'NumberTitle','off','Position',[100,200,300,100],...
'Units','Pixels');
	
Bcolor = [.8,.8,1];

cbFName=['FName=get(hname,''string''); ',...
	'vp_fimage; set(FI,''tag'',''mask''); ',...
	'if (isempty(Message) | strcmp(Message,''Maximum Plane Reached'')), ',...
	'vp_gmask, delete(maskref);',...
	'else set(herror,''string'',[''Error: '',Message]);',...
	' end; '] ;
	
cbPName=['FName=get_file(1,''.img'',''please select image'',[]); ',...
	'if ~isempty(FName),',...
	'set(hname,''string'',FName); ',...
	'vp_fimage; set(FI,''tag'',''mask''); ',...
	'if (isempty(Message) | strcmp(Message,''Maximum Plane Reached'')), ',...
	'vp_gmask, delete(maskref);',...
	'else set(herror,''string'',[''Error: '',Message]);',...
	' end; end; '] ;
	
uicontrol(maskref,'string', 'PICK REF.',...
	'position',[10 35 60 25],'BackgroundColor',Bcolor,...
	'callback',cbPName);
	
hname=uicontrol(maskref,'style','edit','string',FName,...
	'position',[72 35 225 25],'BackgroundColor',Bcolor,'callback',cbFName);

pcbSetOrient = [' ',...
 'if (InputOrient==1)',...
  '  vp_note([''Set for Radiologically (RL) oriented Disk Input files. RESET on main scanvp menu.''], 4);',...
 'else',...
 '  vp_note([''Set for Neurologically (LR) oriented Disk Input files. RESET on main scanvp menu.''], 4);',...
  'end; figure(FMenu);'];

uicontrol(maskref,'string', 'Check Input File Orientation',...
	'TooltipString',['Set Common Radiological (Right is Left) or Neurological (Right is Right)',...
    ' Disk Input File Orientation on Main Menu.'],...
	'position',[72 65 160 20],...
	'BackgroundColor',Bcolor,'callback',pcbSetOrient);

uicontrol(maskref,'String','HELP',...
	'Position',[10 65 60 25],...
	'CallBack',['vp_help(''vp_mask'')']);

uicontrol(maskref,'String','QUIT',...
	'Position',[235 65 60 25],...
	'CallBack',['delete(maskref);','delete(FI);']);
%	'CallBack',['set(maskref,''UserData'',1); ', 'delete(maskref)']);

herror = uicontrol(maskref,'string', ['MSG : ',Message],...
	'position',[10 10 285 25],...
	'CallBack',['set(herror,''string'',[''MSG: '',Message]);'],...
	'BackgroundColor',Ecolor);

