% vp_maskimgs.m
% Mask images and save.
%
% User inputs a mask image and a set of images to be masked. 
% The data image pixel values are multiplied by the corresponding mask image
% values to create each output image. Usually, the mask contains 0/1 values
% and the masked output images will contain the original data wherever mask values
% are 1 and 0 elsewhere. A _m suffix is applied to the output names to indicate
% masked values. 
%
% ScAnVP 5.1    P. Spetsieris    7/18/03
% revision 5.5  P.S.   6/2/05


global HelpMode FMenu NameLst POpt
global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN
global EXPTIM DURATION MATYPE GENTIM SUBID EXPDATE

if HelpMode, vp_help(mfilename), return ; end;

maskname=[]; masking=0;

maskname=get_file(1,'*mask*.img','Select Mask');
if isempty(maskname), return; end;
%mask=spm_read_vols(spm_vol(maskname));
%dim=size(mask);
%mask=reshape(mask,prod(dim),1);
[out1 mask]=vp_volfuns('volvect',maskname);
if (out1 < 0) vp_message('ERROR reading mask');
return, end;
  
%PS get the image filenames {FName} 
prompt=['Select Group Image Data set'];
if vp_filesui(Inf,'*.img',prompt,mfilename) < 0 ,return; end;
disp(prompt);
%-----------------------------------------------------------------------
set(FMenu,'Pointer','Watch');
sub= size(NameLst,1);

h=waitbar(0,'Processing images ...');

for i=1:sub
  msg=['reading image ' NameLst(i,:)];
  disp(msg);
  waitbar((i-.8)/sub,h,['Reading image ',num2str(i)]);
  %indata(:,:,:,i)=spm_read_vols(spm_vol(NameLst(i,:)));
  [out1, imgvect(:,i)]=vp_volfuns('volvect',NameLst(i,:));
  if (out1 < 0) vp_message('ERROR reading image'); return, end;
end

% dim=size(indata)
% imgvect=reshape(indata,prod(dim(1:3)),sub);
% reshape 3 dimensional images to one-dimensional vectors

waitbar(1,h); pause(1); close(h);
  
masking=1;
h=waitbar(0,'Masking images ...');
for k=1:sub
     msg=['Masking Image ',num2str(k)];
     waitbar((i-.8)/sub,h,msg);
     imgvect(:,k)=imgvect(:,k).*mask;
end
waitbar(1,h); pause(1); close(h);

disp(' ');

dim=DIM;

%for i=1:length(NameLst(:,1))
%    a=spm_vol(NameLst(i,:));
%    %save_imfile=NameLst(i,1:findstr(NameLst(i,:),'.img')-1); 
%    %a.fname=[save_imfile  '_m.img'];
%    dnm=[pwd,'\',vp_nm('nm',NameLst(i,:))];
%    a.fname=[dnm,'_m.img']; 
%    a.descrip=[a.descrip ' masked image '];
%    a.dim=[dim(1:3) 16];
%    spm_write_vol(a,reshape(imgvect(:,i),dim(1:3)));
%    vp_note(['writing masked image ' int2str(i) ' to ' a.fname],2)
%end

for i=1:length(NameLst(:,1))
   
   vp_hread(NameLst(i,:));
   DESCRIP=[DESCRIP,' - Masked Image'];
   imgdata=reshape(imgvect(:,i),DIM(1:3))/SCALE;
   dname=[pwd,'\',vp_nm('nm',NameLst(i,:)),'_m.img'];
   
   out1=vp_imsave(dname,imgdata, 1), 
   if (out1 < 0),
      set(FMenu,'Pointer','Arrow');
      return;
   end;
    
   vp_note(['writing masked image ' int2str(i) ' to ' dname],1)
end

vp_note(['Program Ended'],2)
set(FMenu,'Pointer','Arrow');
