% vp_mkTmask.m
% User interface to invoke 'vp_ssmpca' routine to make a group threshold mask.
%_______________________________________________________________________
% vp_mkTmask allows the user to select a set of ANALYZE format normalized
% images files and a lower fractional threshold to be applied to each 
% image's maximum value in the routine 'vp_ssmpca' which creates a mask
% image based on the composite product of individual 0|1 maps of values 
% above the threshold. A default threshold of .35 is provided. 
% The interface creates a text file containing a list of names the first
% of which is an input header file followed by the required input images. 
% It then runs the MATLAB function:  'vp_ssmpca(names.lst, .thresh, output.txt')
% to create the mask. The resulting mask is saved in the user directory.
%_______________________________________________________________________
% vp_mkTmask.m	5.1	P. Spetsieris	07/10/2003 - Calls Dos executable
% revision	6.2	P. Spetsieris	02/06/2012 - Calls Matlab function
%_______________________________________________________________________
% The original DOS mkTmask.c routine was based on a program written by
% John Darrell Van Horn, B.A., Ph.D., 1996, NIH, Bethesda, MD
% and revised October 1998 by Marc Mentis, M.D., NSUH.
%
% The current routine is an option of the MATLAB based vp_ssmpca function
% that can be invoked by scanvp image processing group mask creation options.
%

global HelpMode NameLst POpt FMenu FName MaskOpt Keyin

if HelpMode, vp_help(mfilename), return ; end;

% get the image filenames
%-----------------------------------------------------------------------

%NameLst      = get_file(Inf,'.img','Select images',[]);

if vp_filesui(Inf,'.img','Select images to make mask',mfilename) < 0 ,return; end;

m= size(NameLst,1);

prompt=['Select Threshold [Default = .35| Other [0-.99]| X=EXIT]'];
POpt=vp_opt('X',prompt,'Default','.35','Other','Key Lower Threshold [0-.99]','EXIT','','HELP','');

if POpt=='X', 
  vp_note('Program Exited',2); return;
elseif(strcmp(POpt,'EXIT'))return;
elseif(strcmp(POpt,'HELP')),
  vp_help('vp_mktmask'); return; 
elseif strcmp(POpt,'Default'),
	thresh=.35
elseif strcmp(POpt,'Other'),
	thresh = -1;
	while (thresh <0 | thresh > .99)
 	  vp_keyin('Lower Threshold [0-.99| q]','.35');
	  if (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
 	  return, else thresh=str2num(Keyin); end;
	  if (thresh >=0 & thresh <=.99 )
	    %nm=findstr(Keyin,'.');
	    %if(size(Keyin,2) < nm+2)Keyin(1,nm+2)='0'; end;
	    %MaskOpt = ['T',Keyin(1,nm+1),Keyin(1,nm+2)],
	    Message = ['Threshold: ',Keyin];
	    vp_message(Message); 
	  else
	    Message = ['Invalid Threshold: ',Keyin];
	    vp_message(Message); 
	  end
	end
end;

h=waitbar(0.2,'Processing Make Threshold Mask');
set(FMenu,'Pointer','Watch');

for i=1:m
  FName=deblank(NameLst(i,:));
  len=size(FName,2);
  
  if i==1
	%FNameLst=[FName(1:(len-4)),'lst.txt'],

	studyname = vp_nm('nm',FName(1,:));
	vp_keyin('[Assign Output Mask Study Name | q]',studyname);
	if (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
	  Message=['Create Mask Task Exited '];
	  vp_message(Message);
	return, else studyname=Keyin; end;

	Message=['Mask Study Name: ', studyname];
	vp_message(Message);

	FNameLst=[pwd,'\', studyname,'lst.txt'],
	fid= fopen(FNameLst,'w');

	if (fid == -1)
	  Message=['Error opening ' P '. Check that you have write permission.'];
	  vp_message(Message);
	  error(Message);
	  return; %PS
	end
	fprintf(fid,'%s\r\n',[FName(1:(len-4)),'.hdr']);
  end
  fprintf(fid,'%s\r\n',[FName(1:(len-4)),'.img']);
end

fclose(fid);

waitbar(.4,h);
thstr=num2str(thresh);
if(thstr=='0'), thstr='0.00'; end;
thstr=thstr(findstr(thstr,'.'):size(thstr,2));
 
%DosCmd = ['ssmpca ',FNameLst,' ',thstr,' > maskoutput.txt'];
%[ret,w]=vp_dos(DosCmd);

OutFile=[pwd,'\maskoutput', studyname,'.txt'],
ret=vp_ssmpca(FNameLst, thstr, OutFile);
disp(' ');

waitbar(1,h); pause(1); close(h);

if (ret >=0 ),
  vp_note(['END make mask - Check Matlab Window and ', OutFile]);
else,
   %vp_note('mkTMask error, - Check Matlab Window and maskoutput.txt');
   vp_note(['mkTMask error, - Check Matlab Window and ', OutFile]);
end;

set(FMenu,'Pointer','Arrow');


