% FORMAT function vp_movie(nameop);
% ScAnVP movie player.
%
% This routine loads previously created movie frames
% and allows the user to control Play parameters.
% Buttons are provided to control speed, number
% number of loops and direction.
% The movie name can be the first argument or the
% user can pick a .mat file containing an M array
% of Matlab frames. To create a movie use 
% getframe to grab sequential frames and save
% an array M of such frames in a .mat file.
%
% Warning: A large amount of memory is required and
%	   movies should not be played on computers
%	   with less than 16 color displays.
%
% P. Spetsieris ScAnVP 4.7.8	Mar. 21, 2002
% parts based on MATLAB demo movie player xpmovie. 

function vp_movie(nameop);

global HelpMode POpt
if HelpMode, vp_help(mfilename), return ; end;

if nargin<1,
    nameop='noname';
    POpt=vp_opt('X','','Movie Player','','Help',''),

    if(strcmp(POpt,'X'))return; end;
    if(strcmp(POpt,'Help')),
      vp_help('vp_movie'); vp_movie; 
    return; end;
end;

if strcmp(nameop,'help'),

    vp_help(mfilename);

elseif strcmp(nameop,'load'),
    figNumber=gcf;
    hList=get(gcf,'Userdata');
    txth=hList(1);
    loadh=hList(2);
    playh=hList(3);
    loopsh=hList(4);
    drctnh=hList(5);
    hhelp=hList(6);
    closeh=hList(7);
    movieAxh=hList(8);
    statusAxh=hList(9);
    speedh=hList(10);
    
    set([loadh playh hhelp closeh],'Enable','off');
    
    % ====== load the movie here
    set(figNumber,'Pointer','watch');
    
    movieName=get(txth,'UserData'),
    %PSif (strcmp(movieName,'noname') | drctn==0)
    if strcmp(movieName,'noname') 
     movieName=get_file(1,'*.mat','Select Movie');
     drctn='  -->';
    end
    if exist(movieName)
      set(txth,'String', ...
        ['Status: Now loading movie "' movieName '"']);
      axes(movieAxh);
    
      s=load(movieName);
      set(movieAxh,'Userdata',s.M);
    
      set(txth,'String', ...
        ['Status: Ready to play movie "' movieName '"']);
	
      set(figNumber,'Pointer','arrow');
      % ====== End of loading the movie

      set([loadh playh hhelp closeh],'Enable','on');
      set(txth,'UserData',movieName);
    else
      set(txth,'String', ...
        ['Status: Invalid Movie File ', movieName]);
    end %if exist


elseif strcmp(nameop,'play'),
    figNumber=gcf;
    hList=get(gcf,'Userdata');
    txth=hList(1);
    loadh=hList(2);
    playh=hList(3);
    loopsh=hList(4);
    drctnh=hList(5);
    hhelp=hList(6);
    closeh=hList(7);
    movieAxh=hList(8);
    speedh=hList(10);
    
    set([loadh playh hhelp closeh],'Enable','off');
    
    set(figNumber,'Pointer','watch');
    movieName=get(txth,'UserData');
    set(txth,'String',['Status: Now playing movie "' movieName '"']);

    % ====== Play the movie here
    % Get movie data
    M=get(movieAxh,'Userdata');
    axes(movieAxh); 
    numRepsListVal=get(loopsh,'Value');
    speedListVal=get(speedh,'Value');
    numRepsList=get(loopsh,'String');
    speedList=get(speedh,'String');
    numReps=eval(numRepsList(numRepsListVal,:));
    speed=eval(speedList(speedListVal,:));

    % Get playback drctn help
    drctnListVal=get(drctnh,'Value');
    drctnList=get(drctnh,'String');
    drctn=deblank(drctnList(drctnListVal,:));

    % The movie can be played at variable speed.
    % The recomended value is 12 frames per sec.
    
    if strcmp(drctn,' -->'),
        movie(M,numReps,speed);
    elseif strcmp(drctn,' <--'),
        movie(fliplr(M),numReps,speed);
    elseif strcmp(drctn,' <-->'),
        movie(M,-numReps,speed);
    end;
    % ====== End of playing movie

    set(txth,'String',['Status: Ready to play movie "' movieName '"']);
    set(figNumber,'Pointer','arrow');

    set([loadh playh hhelp closeh],'Enable','on');

else

    % New movie
    
    movieName=nameop;
    
    delete(findobj('Name','ScAnVP movie'));
    
    figNumber=figure( ...
        'Visible','off', ...
        'NumberTitle','off', ...
        'Name','ScAnVP movie');

%PS        'Position',[0.12 0.35 0.50 0.60]);

    movieAxh=axes( ...
        'Units','normalized', ...
        'Visible','off', ...
        'XTick',[],'YTick',[], ...
        'Position',[0.05 0.15 0.70 0.50]);

    % UserData for the status axis will tell how much of the movie is actually complete
    statusAxh=axes( ...
        'Units','normalized', ...
        'Position',[0.05 0.15 0.65 0.05], ...
        'Box','on', ...
        'UserData',0, ...
        'Visible','off', ...
        'XTick',[],'YTick',[], ...
        'XLim',[0 1],'YLim',[0 1]);

    %===================================
    % Set up the Comment Window
    top=0.10;
    left=0.05;
    right=0.80;
    bottom=0.05;
    labelHt=0.05;
    spacing=0.005;
    % First, the Comment Window frame
    frmBorder=0.02;
    frmPos=[left-frmBorder bottom-frmBorder ...
        (right-left)+2*frmBorder (top-bottom)+2*frmBorder];
    uicontrol( ...
        'Style','frame', ...
        'Units','normalized', ...
        'Position',frmPos, ...
        'BackgroundColor',[0.6 0.7 0.8]);
    % Then the text label
    labelPos=[left top-labelHt (right-left) labelHt];
    txth=uicontrol( ...
        'Style','text', ...
        'Units','normalized', ...
        'HorizontalAlignment','left', ...
        'Position',labelPos, ...
        'BackgroundColor',[0.5 0.5 0.5], ...
        'ForegroundColor',[1 1 1], ...
        'String',['Status: Ready to load movie "' movieName '"'], ...
        'UserData',movieName);

    %====================================
    % parameters for all buttons
    labelColor=[0.8 0.8 0.8];
    top=0.95;
    bottom=0.05;
    yInitLabelPos=0.90;
    left=0.85;
    labelWid=0.10;
    labelHt=0.04;
    btnWid=0.10;
    %btnHt=0.05;
    btnHt=0.05;
    % Spacing between the label and the button for the same command
    btnOffset=0.001;
    % Spacing between the button and the next command's label
    spacing=0.04;

    %====================================
    % The CONSOLE frame
    frmBorder=0.02;
    yPos=0.05-frmBorder;
    frmPos=[left-frmBorder yPos btnWid+2*frmBorder 0.9+2*frmBorder];
    h=uicontrol( ...
        'Style','frame', ...
        'Units','normalized', ...
        'Position',frmPos, ...
        'BackgroundColor',[0.6 0.8 0.7]);
    
    %====================================
    % The MOVIES button
    labelStr='MOVIES';
    %'vp_movie';
    callbackStr= ['movieName=',...
     'get_file(1,''*.mat'',''Select Movie''); vp_movie(movieName);'];
    
    %btnNumber=1;
    %yLabelPos=top-(btnNumber-1)*(btnHt+labelHt+spacing);
    %btnPos=[left yLabelPos-2*btnHt btnWid 2*btnHt];
    
    % Generic button parameters
    hpick=uicontrol( ...
        'Style','pushbutton', ...
        'Units','normalized', ...
        'Position',[left bottom+2*btnHt+spacing btnWid 2*btnHt], ...
        'String',labelStr, ...
        'Callback',callbackStr);

    %====================================
    % The PLAY MOVIE button
    btnNumber=2;
    yLabelPos=top-(btnNumber-1)*(btnHt+labelHt+spacing);
    labelStr='PLAY';
    callbackStr='vp_movie play';
    
    % Generic button parameters
    btnPos=[left yLabelPos-2*btnHt btnWid 2*btnHt];
    hplay=uicontrol( ...
        'Style','pushbutton', ...
        'Units','normalized', ...
        'Position',btnPos, ...
        'String',labelStr, ...
        'Enable','off', ...
        'Callback',callbackStr);
    % The next line is a workaround for a Windows bug...
    set(hplay,'Enable','off');
    %====================================
    % The LOOPS command popup button
    btnNumber=3;
    yLabelPos=top-(btnNumber-1)*(btnHt+labelHt+spacing);
    labelStr=' Loops';
    labelList=' 1| 2| 5| 10| 25| 50';
    
    % Generic label parameters
    labelPos=[left yLabelPos-labelHt labelWid labelHt];
    uicontrol( ...
        'Style','text', ...
        'Units','normalized', ...
        'Position',labelPos, ...
        'BackgroundColor',labelColor, ...
        'HorizontalAlignment','left', ...
        'String',labelStr);

    % Generic popup button parameters
    btnPos=[left yLabelPos-labelHt-btnHt-btnOffset btnWid btnHt];
    hloops=uicontrol( ...
        'Style','popup', ...
        'Units','normalized', ...
        'Position',btnPos, ...
        'String',labelList);

    %====================================
    % The SPEED command popup button
    btnNumber=5;
    yLabelPos=top-(btnNumber-1)*(btnHt+labelHt+spacing);
    labelStr=' Speed';
    labelList=' 12| 6| 3| 1| 24| 48';
    
    % Generic label parameters
    labelPos=[left yLabelPos-labelHt labelWid labelHt];
    uicontrol( ...
        'Style','text', ...
        'Units','normalized', ...
        'Position',labelPos, ...
        'BackgroundColor',labelColor, ...
        'HorizontalAlignment','left', ...
        'String',labelStr);

    % Generic popup button parameters
    btnPos=[left yLabelPos-labelHt-btnHt-btnOffset btnWid btnHt];
    hspeed=uicontrol( ...
        'Style','popup', ...
        'Units','normalized', ...
        'Position',btnPos, ...
        'String',labelList);

    %====================================
    % The PLAYBACK DIRECTION command popup button
    btnNumber=4;
    yLabelPos=top-(btnNumber-1)*(btnHt+labelHt+spacing);
    labelStr=' Direction';
    labelList=' -->| <--| <-->';
    
    % Generic label parameters
    labelPos=[left yLabelPos-labelHt labelWid labelHt];
    uicontrol( ...
        'Style','text', ...
        'Units','normalized', ...
        'Position',labelPos, ...
        'BackgroundColor',labelColor, ...
        'HorizontalAlignment','left', ...
        'String',labelStr);

    % Generic popup button parameters
    btnPos=[left yLabelPos-labelHt-btnHt-btnOffset btnWid btnHt];
    hdrctn=uicontrol( ...
        'Style','popup', ...
        'Units','normalized', ...
        'Position',btnPos, ...
        'String',labelList);

    %====================================
    %   'Position',[left bottom+2*btnHt+spacing btnWid 2*btnHt]
    hhelp=uicontrol( ...
        'Style','pushbutton', ...
        'Units','normalized', ...
        'Position',[left top-2*btnHt btnWid 2*btnHt], ...
        'String','HELP', ...
        'Callback','vp_movie help');

    % The close button.
    closeh=uicontrol( ...
        'Style','pushbutton', ...
        'Units','normalized', ...
        'Position',[left bottom btnWid 2*btnHt], ...
        'String','EXIT', ...
        'Callback','close(gcf)');

    % ====== Warn for PC with 16 color screen
    % On PCs with less than 16 colors movies will break.
    if get(0,'ScreenDepth')<=4,
        computerType=computer;
        if strcmp(computerType(1:2),'PC'),
            warnStr='Sorry, MATLAB requires more than 16 colors for movies.';
	    vp_message(warnStr);
	    delete(findobj('name','ScAnVP movie'));
        end
    end

    % Uncover the figure
    hList=[txth hpick hplay hloops hdrctn ...
        hhelp closeh movieAxh statusAxh hspeed];
    set(figNumber,'Visible','on', ...
        'UserData',hList);

    vp_movie('load');
end;    % if strcmp(nameop, ...


