% vp_multi_imageop.m
% Calculate the resultant output image for images operated sequentialy.
%__________________________________________________________________________
%
% In this routine, the user selects an Analyze format image file set.
% Only non-zero voxels of a user selected mask image file are included.
% If masking is set off, all non-zero voxels will be evaluated.
% If the global normalization option is enabled, each voxel value is
% divided by the subject's mean non-zero value.
% For vector normalization, voxel values are divided by the square
% root of the sum of the voxel values squared.
% Only one type of normalization is permitted.
% The user inputs a scaling factor for each normalized image.
% The multiple image operation result of the corresponding scaled,
% globally normalized image voxel values is evaluated to create an
% ouput image for the set of images. The output value is set to zero
% if the mask value is zero.
% Output values can be Z-scored ((Value - mean) / STD).
% The display reflects the first input image and the output image
% after processing.
% Multi image operations include the following:
% ADD: Add corresponding image voxel values
% AVG: Average corresponding image voxel values
% SUB: Subtract corresponding image voxel values from the previous result.
% DIV: Divide corresponding image voxel values into the previous result.
% MLT: Multiply corresponding image voxel values.
% EXS: Exclude voxels that have the same sign as first in any following image
%__________________________________________________________________________
% vp_multi_imageop.m	ScAnVP ver. 5.6 	P. Spetsieris	October 27, 2005
% 			rev ver. 5.8 	P.S.	Sept. 10, 2006

global FI FNames FName pimageopgui PlaneNo0 PlaneNo hplane
global Cn NameLst OutImg 
global hSetname hmname hSecondname
global GMax1 GMin1 GMax3 GMin3 ProTime
global SetFNames 
global HelpMode Ecolor pimageopgui
global MaskOn OutOp DatOp MskOp GNop VecNop PImOp

if HelpMode, vp_help(mfilename), return ; end;

pimageopgui=findobj('Name','Multi Image Operations');
if ~isempty(pimageopgui)
	if(strcmp(get(pimageopgui,'Visible'),'on'))
		figure(pimageopgui);
	end
	return
end

vp_imframe;

FName=[];
NameLst=[];
maskFName=' ';
SetFNames=[];
pimageopNames=[];
OutImg=[];  
PImOp=[];

WndNo=0;
WndScl=4;
PlaneNo=1;
Message0=['... '];
Message=Message0;
DefSet=0;
DefMask=0;
num1=0; % Number of Files
Cn=ones(1,3);
num2=size(Cn,2); % Number of Scaling Factors
GMin1=0;
GMax1=0;
ProTime=0;
OutOp=1;
MskOp=1;
DatOp=1;
GNop=0; % global normalization ON=1; OFF=0;
AutoName=1; % automatic naming ON=1; OFF=0;
VecNop=0; % Vector Normalization ON=1; OFF=0;
AutoName=0; % automatic naming ON=1; OFF=0;
ZScoring=0; % Z-Score output image, ON=1; OFF=0;

Bcolor = [.8,.8,.8];
Kcolor = [.8,1,1];
Fcolor = [.72,.82,.78];

MaskOn=1;

pimageopgui = figure('Color',Fcolor,'Name','Multi Image Operations',...
'NumberTitle','off','Position',[100,200,350,250],...
'Units','Pixels');
	
	
uicontrol(pimageopgui,'string', 'HELP',...
	'position',[265 222 60 20],'BackgroundColor',Ecolor,...
	'callback',['vp_help(''vp_multi_imageop'')']);
	
cbtextn= ['text(0,103,''Cn'',''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''right'');'] ;


cbtexto= ['delete(findobj(''tag'',''poptext'')); ',...
	'text(0,166,[''OP =                    ''],''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''tag'',''poptext'',''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''Left'');'] ;

cbtextadd= ['text(0,166,[''OP=(C1*gI1 + C2*gI2  + ... Cn*gIn)''],''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''tag'',''poptext'',''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''Left'');'] ;

cbtextsub= ['text(0,166,[''OP=(C1*gI1 - C2*gI2 - ... Cn*gIn)''],''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''tag'',''poptext'',''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''Left'');'] ;

cbtextavg= ['text(0,166,[''OP=(C1*gI1 + C2*gI2 + ... + Cn*gIn)/n''],''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''tag'',''poptext'',''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''Left'');'] ;

cbtextdiv= ['text(0,166,[''OP = C1*gI1/C2*gI2/.../Cn*gIn''],''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''tag'',''poptext'',''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''Left'');'] ;

cbtextmlt= ['text(0,166,[''OP=(C1*gI1 .* C2*gI2 ... .* Cn*gIn)''],''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''tag'',''poptext'',''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''Left'');'] ;


eval(cbtextn);
eval(cbtexto);

axis off;

%cbSetname=['SetFNames(1,:)=get(hSetname,''string''); Message=Message0;',...
%	'FName=SetFNames(1,:); vp_fimage;',...
%	'if isempty(Message), DefSet=1; PlaneNo=max(PlaneNo-1,1); Message=[''Set :  '',FName]; end;',...
%	'if strcmp(Message,''Maximum Plane Reached''), DefSet=1; vp_note(Message,3); ',...
%	'end;'];

pcbSet=[' SetFNames=get_file(Inf,''*.img'',''SELECT IMAGE SET'',[]); ',...
	'if isempty(SetFNames), return; end; num1=size(SetFNames,1);',...
	'Cn=ones(1,num1); num2=num1; set(hCn,''string'',num2str(Cn));',...
	'if ~isempty(SetFNames), FName=SetFNames(1,:); vp_fimage; set(hSetname,''string'',FName);',...
	'if isempty(Message), DefSet=1; PlaneNo=max(PlaneNo-1,1); Message=[''Set :  '',FName]; end;',...
	'if strcmp(Message,''Maximum Plane Reached''), vp_note(Message,3); DefSet=1; end;',...
	'end;'];
	
uicontrol(pimageopgui,'string', 'SELECT FILE SET',...
	'TooltipString','Pick Image file Set.',...
	'position',[10 153 125 25],'BackgroundColor',Bcolor,'callback',pcbSet);
	
%hSetname=uicontrol(pimageopgui,'style','edit','string',SetFNames,...
%	'TooltipString','Enter Image Set file names.',...
%	'position',[85 163 230 20],'BackgroundColor',Kcolor,'callback',cbSetname);


cbmaskname=['maskFName=get(hmname,''string''); Message=Message0;',...
	'if isempty(maskFName), DefMask=0; ',...
	'else, FName=maskFName; vp_fimage;',...
	'figure(pimageopgui); eval(cbtextn);  axis off;',...
	'if isempty(Message), DefMask=1; PlaneNo=max(PlaneNo-1,1); Message=[''MASK : '',FName]; end;',...
	'if strcmp(Message,''Maximum Plane Reached''), DefMask=1; end;',...
	'vp_note(Message,2); end;'];
	
cbmaskoff=['if MaskOn, MaskOn=0; maskFName=[]; set(hmoff,''string'',''SET MASK''); ',...
	'set(hmfile,''Visible'',''off''); set(hmname,''Visible'',''off'');',...
	'else, MaskOn=1; set(hmfile,''Visible'',''on''); set(hmname,''Visible'',''on'');',...
	'set(hmoff,''string'',''SET MASK OFF''); end;']; 
	
%cbOutMenu = ['OutOp=get(houtmenu,''Value'');';];
	
pcbmask=['maskFName=get_file(1,''.img'',''Please Select Mask File'',[]); ',...
	'if isempty(maskFName), DefMask=0; set(hmname,''string'',maskFName);',...
	'else, FName=maskFName; vp_fimage; set(hmname,''string'',FName);',...
	'figure(pimageopgui); eval(cbtextn); axis off;',...
	'if isempty(Message), DefMask=1; PlaneNo=max(PlaneNo-1,1); Message=[''MASK : '',FName]; end;',...
	'if strcmp(Message,''Maximum Plane Reached''), DefMask=1; vp_note(Message,3); end;',...
	'end;'];
	
hmoff=uicontrol(pimageopgui,'string', 'SET MASK OFF',...
	'TooltipString','Set Mask On/Off',...
	'position',[10 80 90 20],'BackgroundColor',Bcolor,...
	'callback',cbmaskoff);
	
hmfile=uicontrol(pimageopgui,'string', 'MASK FILE',...
	'TooltipString','Pick Mask Image file.',...
	'position',[10 58 75 20],'BackgroundColor',Bcolor,...
	'callback',pcbmask);
	
hmname=uicontrol(pimageopgui,'style','edit','string',maskFName,...
	'TooltipString','Enter Mask Image file name.',...
	'position',[85 58 240 20],'BackgroundColor',Kcolor,'callback',cbmaskname);

	
%cbMskMenu = ['MskOp=get(hmskmenu,''Value'');';];
%hmskmenu=uicontrol(pimageopgui,'Style','popup','Visible','on','String',...
%	'Inclusive Mask|Exclusive Mask','Tag','MskMenu',...
%	'value',MskOp,...
%	'TooltipString',['Inclusive: All non-zero pixels of the mask, ',...
%	'Exclusive: Only zero pixels of the mask'],...
    %	'Position',[105 220 100 20],'callback',cbMskMenu);


%cbC2=['C2=str2num(get(hC2,''string'')); if strcmp(PImOp,''EXC''), C2=1; set(hC2,''string'',''1''); end;  '];
cbCn=['Cn=str2num(get(hCn,''string'')); num2=size(Cn,2); '];


hCn=uicontrol(pimageopgui,'style','edit','string',' ',...
	'TooltipString','SET Scaling Factors n1 n2 ... nn',...
	'position',[52 120 115 20],'BackgroundColor',Kcolor,'callback',cbCn);

cbGNon=['  GNop=1; vp_note([''Global Normalization Option ON. Each Image Divided by its Mean.''],2);'];
	
cbGNoff=[' GNop=0; vp_note([''Global Normalization Option OFF''],2); '];
	

hGNon=uicontrol(pimageopgui,'String','Global Input Normalization','Style','Checkbox',...
	'FontWeight','Normal',...
	'TooltipString','ON/OFF Switch-  (ON: Global Normalization, Divide each image by its non-zero voxel mean )',...
	'Units','pixel',...
	'Position',[185 150 150 019],...
	'value',GNop,...
	'CallBack',[ 'GNop=get(gco,''value'');',...
	' if strcmp(PImOp,''EXC''), GNop=0; ',...
	' set(gco,''value'',GNop); end; ',...
	' if (GNop==1), set(hVNon,''value'',0); VecNop=0; end;'],...
	'BackgroundColor',Bcolor,...
	'ForegroundColor',Tcolor);
	
hVNon=uicontrol(pimageopgui,'String','Vector Input Normalization','Style','Checkbox',...
	'FontWeight','Normal',...
	'TooltipString','ON/OFF Switch-  (ON: Vector Normalization, Divide each image by the sqrt. of the sum of its elements squared )',...
	'Units','pixel',...
	'Position',[185 130 150 019],...
	'value',VecNop,...
	'CallBack',[ 'VecNop=get(gco,''value'');',...
	' if strcmp(PImOp,''EXC''), VecNop=0; ',...
	' set(gco,''value'',VecNop); end; ',...
	' if (VecNop==1), set(hGNon,''value'',0); GNop=0; end;'],...
	'BackgroundColor',Bcolor,...
	'ForegroundColor',Tcolor);
	
uicontrol(pimageopgui,'Style','Check','String','Z-Score Output Image',...
	'TooltipString','Z-Score the ouput GIS image',...
	'Value',ZScoring,'Position',[185 110 150 19],...
	'BackgroundColor',Bcolor,...
	'CallBack',[ 'ZScoring=get(gco,''value''),']);
	

uicontrol(pimageopgui,'Style','Check','String','AUTO Naming',...
	'TooltipString','Automate Output Naming',...
	'Value',AutoName,'Position',[185 90 150 19],...
	'BackgroundColor',Bcolor,...
	'CallBack',[ 'AutoName=get(gco,''value''),']);
	
       
	
%	'elseif val==7, PImOp=''EXC''; ',...
%	'GNop=0; C1=1; C2=1; ',...
%	'set(hGNon,''value'',GNop); ',...
%	'set(hC1,''string'',1); ',...
%	'set(hC2,''string'',1); ',...
%	'eval(cbtexto); ',...
%	'eval(cbtextexc);',...

cbPOpsMenu = ['val=get(hpopsmenu,''Value''),',...
	'if val == 1, PImOp=''''; ',...
	'eval(cbtexto); ',...
	'elseif val==2, PImOp=''ADD''; ',...
	'eval(cbtexto); ',...
	'eval(cbtextadd);',...
	'elseif val==3, PImOp=''AVG''; ',...
	'eval(cbtexto); ',...
	'eval(cbtextavg);',...
	'elseif val==4, PImOp=''SUB''; ',...
	'eval(cbtexto); ',...
	'eval(cbtextsub);',...
	'elseif val==5, PImOp=''DIV''; ',...
	'eval(cbtexto); ',...
	'eval(cbtextdiv);',...
	'elseif val==6, PImOp=''MLT''; ',...
	'eval(cbtexto); ',...
	'eval(cbtextmlt);',...
	'elseif val==7, PImOp=''EXS''; ',...
	'eval(cbtexto); ',...
	'eval(cbtextsub);',...
	'else, PImOp=''''; ',...
	'eval(cbtexto);',...
	'end; '];

hpopsmenu=uicontrol(pimageopgui,'Style','popup','Visible','on',...
	'position',[10 210 210 20],'BackgroundColor',Bcolor,...
	'TooltipString','Select Operation',...
	'String',...
	['SELECT MULTI IMAGE OPERATION...|ADD |AVERAGE |SUBTRACT |DIVIDE |',...
	'MULTIPLY |EXCLUDE SAME SIGN ...'],...
	'Tag','POpsMenu',...
    	'callback',cbPOpsMenu);



pcbplane=['Message=Message0; PlaneNo=PlaneNo+1; vp_fimage;',...
	'if isempty(Message), PlaneNo=max(PlaneNo-1,1); Message=Message0; end;',...
	'set(hplane,''string'',PlaneNo); ',...
	'if strcmp(Message,''Maximum Plane Reached''), vp_note(Message,3); ',...
	'end; '];
	
uicontrol(pimageopgui,'string', 'VIEW PLANE +',...
	'TooltipString','Display only',...
	'position',[95 20 90 20],'BackgroundColor',Bcolor,'callback',pcbplane);


cbplane=['PlaneNo=str2num(get(hplane,''string'')); Message=Message0;',...
	'vp_fimage;',...
	'if isempty(Message), PlaneNo=max(PlaneNo-1,1); Message=Message0; end;',...
	'set(hplane,''string'',PlaneNo); ',...
	'if strcmp(Message,''Maximum Plane Reached''), vp_note(Message,3); ',...
	'end; '];

hplane=uicontrol(pimageopgui,'style','edit','string',PlaneNo,...
	'TooltipString','Display only',...
	'position',[185 20 60 20],'BackgroundColor',Kcolor,'callback',cbplane);

uicontrol(pimageopgui,'String','PROCESS',...
	'TooltipString','Create Masked multi Operated Image',...
	'Position',[10 20 60 25],...
	'CallBack',[ 'if ~DefSet, vp_note([''ERR: File Set Not Defined''],4); return; end; ',...
	'if ~DefMask & MaskOn, vp_note([''ERR: Mask Not Defined''],4); return; end; ',...
	'if (isempty(maskFName) & MaskOn), vp_note([''Mask Not Defined''],4); return; end; ',...
	'if isempty(SetFNames), vp_note([''File Set Not Defined''],4); return; end; ',...
	'if isempty(PImOp), vp_note([''Processing Operation Not Defined''],4); return; end; ',...
	'if num1==0, vp_note([''Images Set 1 Not Defined''],4); return; end; ',...
	'if num1 < 2, vp_note([''Must Specify More Than One File''],4); return; end; ',...
	'if num1 ~= num2, vp_note([''Image Set and Number of Scaling Factors Differ''],4); return; end; ',...
	'if prod(Cn) == 0, vp_note([''Error: Some Factor Cn = 0''],4); return; end; ',...
	'set(findobj(''Name'',''Multi Image Operations''),''Pointer'',''watch'');',...
	'if(ProTime==0), ProTime=1; else,',...
	'figure(findobj(''name'',''Multi Image Operations'')); ProTime=ProTime+1; end;',...
	'OutImg=[];',...
	'eval(cbpimageoppro);',...
	' '] );
	
	

cbpimageoppro = [' ',...
	'pimageopNames=char(SetFNames); dim3=0;',... 
	'if num1 > 2',...
        'vp_note([PImOp,'' of '',num2str(num1),'':  Files  '', pimageopNames(1,:), '', '',pimageopNames(2,:),'',...  ''], 3);',...
	'else,',...
        'vp_note([PImOp,'' of '',num2str(num1),'':  Files  '', pimageopNames(1,:), '' and '',pimageopNames(2,:)], 3);',...
	'end;',...
	'[out1, out2]=vp_mimpro(pimageopNames,PImOp,2,Cn,0,AutoName,(GNop+2*VecNop+3*ZScoring),maskFName);',...
	'if out1 < 0,',... 
	'disp([''vp_multi_imageop ABORTED '']);',...
	'set(FMenu,''Pointer'',''Arrow'');',...
	'return; end;',...
	'if AutoName, FName=out2; else FName = OutImg; end;',...
	'if ~isempty(FName), vp_fimage; ',...
	'    if isempty(Message), PlaneNo=max(PlaneNo-1,1); end; end;',...
        'vp_note([num2str(num1),'' IMAGE '',PImOp,'' PROCESSING COMPLETE '']);',...
	'set(FMenu,''Pointer'',''Arrow''); ',...
	'set(findobj(''Name'',''Multi Image Operations''),''Pointer'',''arrow''); ',...
	' '];
	
	
uicontrol(pimageopgui,'String','QUIT',...
	'Position',[265 20 60 25],...
	'CallBack',['delete(pimageopgui);','delete(FI);','set(FMenu,''Pointer'', ''Arrow'');']);
	
eval(cbmaskoff);
	


