% ScAnVP (Scan Analysis and Visualization Processor) Ver. 7.0 - (C) 2016
% Center for Neurosciences, Feinstein Institute for Medical Research,
%		
%
%				NAMING CONVENTIONS
%
% The following naming conventions are used as defaults by the ScAnVp
% routines. In some cases the user is allowed to overide the default name.
%
% IMAGE CONVERSION (ANALYZE format Name.img, Name.hdr)
%
%  SUFFIX
%  Z=ZERONEGS  (e.g. Name.img --> NameZ.img)
%  MA=Multiply by scalar	
%  DA=Divide by scalar	
%  AA=Add scalar	
%  SA=Subtract scalar	
%  T=Set values lower than threshold to 0.
%  X=Exclusive Range, Set values in range [T1,T2] to 0.
%  K=Create 0|1 Mask setting values in range [T1,T2] to 0.
%  B=Converted to 8bit (Byte)
%  S=Converted to 16bit (Short)
%  I=Converted to 32bit (Integer)
%  F=Converted to 32bit Float
%  D=Converted to 64 Double
%  X,Y,Z,S,C Flipped Axis or Sagittal, Coronal
%  RL=Radiological Orientation (Right is Left)
%  LR=Neurological Orientation (Right is Right)
%
% PREFIX
%  L=Natural Logarithm
%  s=Smoothed using kxlxm Box filter convolution.
%  g=global normalization dividing by image threshold values mean.
%  v=vector normalization dividing by sqare root of sum of sq. values.
%  z=z-score image. Val --> (Val-Mean)/STD of Non-zero values.
%
%
% OTHER PROCESS OUTPUT FILES 
%  SUFFIX
%  _m.img       = Masked image
%  _VAL.txt     = 3D VOI Volume of Interest Values
%  ...maskT.img = SSM Thresholded Group Image Mask
%  ...EX.img    = Extracted Slices Image
%
%  statmapA = Thresholded/Masked StatMap Routine Output
%  statmapB = PET/MRI Thresholded/Masked StatMap Routine Output
%
%  PREFIX
%  X=Marker added
%  I=Interpolated Image
%  mask....img = ROI derived Image mask
%
% ROI OUTPUT FILES - Original template creation and Group ROI processing
% ..........................................................................
%
% TEMPLATE ROI     (Name = Template or first subject name)
% Name.Pln.roi     = Template "Name", region definition file for plane "Pln".
% GROUP ROI
% name_SUM.txt     = GROUP SUMMARY PLANAR report mean values and threshold
%                    pixels for each region type and subject.
% name_SUM_c.txt   = GROUP SUMMARY COMPOSITE report mean values for each
%                    region type for coposite group.
% name_SUMn_c.txt  = GROUP SUMMARY COMPOSITE including no. threshold pixels.
% name_SUM3D_c.txt = 3D data GROUP SUMMARY COMPOSITE report.
% subject_SAS.txt  = subject region means and threshold pixels for each plane
%
%
% PCA OUTPUT FILES - Principal Component Analysis
%                    Label: AUTOTPR = Needed for Auto TPR
% ............................................................................
%
% ROI PCA - Region of Interest PCA Analysis
% 'Name' is the study name or Group ROI SUM file name.
%
% Name_gis.txt          (Lists all gis's)
% Name_lmean.txt        (log mean file).............................. AUTOTPR
% Name_srp.txt          (Lists all subject residual profile values)
% Name_ssfRScores.txt   (Lists all subject's reference scores for all gis)
% Name_ssfZScores.txt   (Lists all subject's Z scores for all gis)
% Name_gis1.txt, Name_gis2.txt,...   (Single gis regional weights)... AUTOTPR
% Name_RScores1.txt, Name_RScores2.txt,...(All subject's reference scores
%                       for single gis 1,2,...)...................... AUTOTPR
% Name_ZScores1.txt,_ZScores2.txt,(All subject Z scores for single gis 1,2,...)
%
% TPR SCORES - Topographic Profile Rating
% Name_tprScores    (All new subject scores for a single gis)
% Name_tprZScores   (All new subject Z scores for a single gis)
% For the RECALIBRATION option naming is similar to PCA output: Name_RScores1,...
% 
% ROI OPCA - Orthogonal Principal Component Analysis 
% Naming is similar to ROI PCA where a _O_ is appended after the study Name
% Name_O_gis.txt    (Lists all gis's resulting from OPCA)
% Name_O_RScores1.txt,_O_RScores2.txt,...(All subject's reference scores for
%                      single gis 1,2,...)
% Name_O_ZScores1.txt,_O_ZScores2.txt,...(All subject's Z scores for single
%                      single gis 1,2,...)
% ............................................................................
%
% VOXEL PCA - Voxel Based Principal Component Analysis
%
% 'Name' is the user assigned study name, default is 1st subject's name. 
%
% Name_lnmean.img   Group mean log deviations image ..................AUTOTPR
% Name_mean.img     Group mean deviations image
% Namemask35.img    Group mask derived using 35% threshold............AUTOTPR
% Name_gis001.img,_gis002.img,...(Single gis images of voxel weights).AUTOTPR 
% Name_lsrp001.img,_lsrp002.img, (Single subject log srp voxel values) 
% Name_VScores.txt  (Lists all subject's reference scores for all gis )
% Name_VZScores.txt (Lists all subject's Z scores for all gis)
% Name_VScores1.txt,_VScores2.txt,..(All subject reference scores for single
%                    gis 1,2,...).....................................AUTOTPR
% Name_VZScores1.txt,_VZScores2.txt,(All subject Z scores for single gis 1,2,...)
%
% VOXEL TPR - Voxel Based Topographic Profile Rating
% (A,B,C,D Interactive TPR method, S for Automated)
% Name_S1_VtprScore.txt (Single Subject Score)
% MULTI-SUBJECT
% SNo_VtprScores.txt  (All new subject scores, No=number of new subjects)
% SNo_VtprZScores.txt (All new subject Z scores, No=number of new subjects)
% For the RECALIBRATION option naming is similar to PCA output: Name_VScores1,...
%
%
% VOXEL OPCA - Voxel Orthogonal PCA
% Naming is similar to VOX PCA where a _O?_ is appended after the study Name
% The character ? refers to the method used [A,B,C or D].
% Name_O?_gis001.img    (gis 1 resulting from OPCA, similar for 2,...)
% Name_O?_VScores.txt  (Lists all subject's reference scores for all gis)
% Name_O?_VZScores.txt  (Lists all subject's Z scores for all gis)
% Name_O?_VScores1.txt,_O_VScores2.txt,...(All subject reference scores for 
%                       single gis 1,2,...)
% Name_O?_VZScores1.txt,_O?_VZScores2.txt, (All subject Z scores for single
%                       gis 1,2,...)
%_______________________________________________________________________
% vp_naming.m  7.0             Phoebe Spetsieris, Ph.D.   Sep. 28, 2015


vp_help('vp_naming');
