% vp_norm.m
% Normalize images in display to a single data (DATAMIN,DATAMAX) color range.
%
% The user keys in an upper and lower data range. If NORMALIZE is clicked,
% the globals DATAMIN, DATAMAX are set to the new values and all images in
% the active data figure (usually FI) are redrawn to match the new scale.
% If called from the utilities GUI, PICK FIGURE may have to be set properly.
% The operation can be repeated for new images while the control is active.
% If SET Range is clicked the active DATAMIN, DATAMAX globals are displayed
% and the user must click NORMALIZE to insure that images are rescaled. 
% Color bars, if present, are not redrawn automatically and must be reset
% to correspond to the new range. (Note, the data is not modified).
%__________________________________________________________________________
% vp_norm.m	C.4.7 	P. Spetsieris	 September 14, 2001
%		Revision 5.1 by P.S. 5/22/03
%		Revision 6.1 by P.S. 5/23/11


global HelpMode HelpMsg Ecolor 
global DATAMIN DATAMAX SCALE GLMIN GLMAX UFI Message
global hnormmin hnormmax normgui

if HelpMode, vp_help(mfilename), return ; end;


if ~exist('UFI') 
	UFI=gcbf;
end

ch=get(UFI,'children');
len=length(ch);
if len==0, msg=['Valid Data Image - Not Found']; vp_message(msg); return; end;

axcb=['ch=get(UFI,''children''); len=length(ch); hims=[];',...
'for i=1:len, if strcmp(get(ch(i),''type''),''axes''),hims=[hims,ch(i)]; end; end;'];


eval(axcb);
len=length(hims);
if len==0, msg=['Data Image - Not Found']; vp_message(msg); return; end;

if ~exist('DATAMIN'),DATAMIN=SCALE*GLMIN; end;
if ~exist('DATAMAX'),DATAMAX=SCALE*GLMAX; end;

cbmax=[];
cbmin=[];

Position=[155,300,120,100];

normgui=findobj('Name','normgui');
if ~isempty(normgui)
	Position=get(normgui,'Position');
	delete(normgui);
end

frmcolor=[0.5 0.7 0.8];
Bcolor = [.8,1,1];

normgui = figure('Color',frmcolor,'Name','normgui',...
'NumberTitle','off','Position',[Position(1) Position(2) 120 100],...
'colormap',get(UFI,'colormap'),...
'Units','Pixels');


uicontrol(normgui,'string', 'Help',...
	'TooltipString',HelpMsg,...
	'BackgroundColor',Ecolor,...
	'position',[85 80 29 18],'callback','vp_help(''vp_norm'');');

resetcb=['resetopt=get(gco,''Value''); ',...
	'if resetopt == 2, ',...
	'delete(gcbf); vp_norm; end;',...
	'if resetopt > 2, ',...
	['ch=get(UFI,''children''); len=length(ch); for i=1:len,',...
	'if strcmp(get(ch(i),''type''),''axes''), ',...
	'delefcn=get(ch(i),''DeleteFcn''); ',...
	'if ~isempty(delefcn),',... 
	'if strcmp(delefcn(1:8),''colorbar''),  ',...
	'delete(ch(i)); end; end; end; end;'],...
	'end; ',...
	'if resetopt==3, ',...
	  'ch=get(UFI,''children''); len=length(ch); ',...
	  'for i=1:len, if strcmp(get(ch(i),''type''),''axes''), ',...
	  'if ~isempty(get(ch(i),''userdata'')), ',...
	  'axes(ch(i)); try colorbar(''v6'',''vert''), catch colorbar vert; end;',...
	  'end; end; end;',...
	'elseif resetopt==4, ',...
	  'ch=get(UFI,''children''); len=length(ch); ',...
	  'for i=1:len, if strcmp(get(ch(i),''type''),''axes''), ',...
	  'if ~isempty(get(ch(i),''userdata'')), ',...
	  'axes(ch(i)); try colorbar(''v6'',''horiz''), catch colorbar horiz; end;',...
	  'end; end; end;',...
	'else, end;'];
	

cbnorm=['set(normgui,''colormap'',get(UFI,''colormap''));',...
	'DATAMIN=str2num(get(hnormmin,''string'')); DATAMAX=str2num(get(hnormmax,''string''));',...
	'if DATAMAX<=DATAMIN, vp_message(''Error: DATAMAX <= DATAMIN ''), return; end; ',...
	'figure(UFI); eval(axcb);',...
	'for i=1:length(hims); axes(hims(i)); caxis([DATAMIN DATAMAX]); end; '];
	
uicontrol(normgui,'Style','text','string', 'MAX  ',...
	'position',[10 60 25 15],'BackgroundColor',frmcolor);
	
hnormmax=uicontrol(normgui,'Style','edit','string', [sprintf('%.6f',DATAMAX)],...
	'position',[35 60 82 15],'callback',cbmax);
	
uicontrol(normgui,'Style','text','string', 'MIN  ',...
	'position',[10 40 25 15],'BackgroundColor',frmcolor);
	
hnormmin=uicontrol(normgui,'Style','edit','string', [sprintf('%.6f',DATAMIN)],...
	'position',[35 42 82 15],'callback',cbmin);
	
uicontrol(normgui,'string', 'NORMALIZE','callback',cbnorm,...
	'TooltipString','Normalize display',...
	'position',[10 24 105 15]);
	
%uicontrol(normgui,'String','RESET',...
%	'Position',[10 5 40 15],...
%	'CallBack',['delete(gcbf); vp_norm;']);
	
uicontrol(normgui,'Style','PopUp',...
	'String','RESET...|Set Range|Fix Vert Bars|Fix Hori Bars|Delete Bars',...
	'TooltipString',['1:Get Global Range| 2: (Re)Draw Vertical Color Bar(s) |',...
	'3: (Re)Draw Horizontal Color Bar(s) |4: Delete Bar(s) '],...
	'Position',[10 8 64 15],...
	'CallBack',resetcb);
       
uicontrol(normgui,'String','EXIT',...
	'Position',[75 4 40 15],...
	'CallBack','delete(gcbf);');
	
