function [out1, out2]=vp_num3str(in1)
%_______________________________________________________________________
% vp_num3str.m  	ScAnVP ver 6.2 Phoebe Spetsieris  Apr. 2, 2012
%
% Converts number to string or string to number.
% Input number:
%  Pads sequence no. strings to avoid alphanumeric sort errors.
%  Converts a number from 0 to 999 to a 3 digit string by pre-padding
%  with '0's if necessary. If the number is not in this range
%  It is simply converted to a string and returned.
% Input string:
%  Tests characters of the string beginning with the last and
%  ending at the first non-numeric character. The numeric
%  characters are converted into a single number and returned.  
%  The remaining characters are returned in out2.
%
% FORMAT function [out1]=vp_num3str(in1)


out1='000';
out2='';

% Test if input is character or string
if ~ischar(in1)

% Pad in1 sequence no string to avoid alphanumeric sort errors

  kseqno=num2str(in1); noschrs=length(kseqno);
  if noschrs == 1, kseqno=['00',kseqno];
  elseif noschrs==2, kseqno=['0',kseqno];
  end;

  out1=kseqno;

else %string

  nm=in1;
  ln=length(nm);

  ngisno=0;
  lend=ln;

  for i=1:ln
   
    nch=ln-i+1;
    ngisch=nm(nch);
    ngisnx=str2num(ngisch);
    if and(~isempty(ngisnx), isreal(ngisnx))  
       ngisno = ngisno + ngisnx * (10^(i-1));
       lend=lend-1;
    else
      lend=nch;
      break;
    end
  end %for

  out1=ngisno; 

  if lend~=0
    out2=nm(1:lend);
  else
    out2= '';
  end

end
