% vp_pair_imageop.m
% Calculate the corresponding pair operated image for two sets of images.
%__________________________________________________________________________
%
% In this routine, the user selects two Analyze format image file sets.
% The second set should include the same number of images as the first
% or it can include only one image to pair each image in the 1st set.
% Only non-zero voxels of a user selected mask image file are included.
% If masking is set off, all non-zero voxels will be evaluated.
% If the global normalization option is enabled, each voxel value is
% divided by the subject's mean non-zero value.
% The user inputs a scaling factor for each set of normalized images.
% The paired image operation result of the corresponding scaled,
% globally normalized image voxel values is evaluated to create an
% ouput image for each pair of images. The output value is set to zero
% if the mask value is zero. 
% The display reflects the current pair being processed.
% Image Pair operations include the following:
% ADD: Add corresponding image voxel values
% AVG: Average corresponding image voxel values
% SUB: Subtract corresponding image voxel values
% DIV: Divide corresponding image voxel values
% MLT: Multiply corresponding image voxel values
% EXC: Output voxels of image 1 excluding the non-zero voxels
%      that are common to both images withing a given 3D range.
%      3D Precision (Voxel Proximity, 1,2,..) is defined by C1
%      Voxels from each image must lie within a 3D prism of
%      radius = precision -1 to be considered common.
%
%__________________________________________________________________________
% vp_pair_imageop.m	ScAnVP ver. 5.6 	P. Spetsieris	October 21, 2005
%                       Revision. 5.7    	P. Spetsieris	June 6, 2006
%                       Rev. 6.1		P. Spetsieris	Jan. 24, 2010

global FI FNames FName pimageopgui PlaneNo0 PlaneNo hplane
global C1 C2 NameLst OutImg 
global hFirstname hmname hSecondname
global GMax1 GMin1 GMax3 GMin3 ProTime
global FirstFNames SecondFNames
global HelpMode Ecolor pimageopgui
global MaskOn OutOp DatOp MskOp GNop PImOp

if HelpMode, vp_help(mfilename), return ; end;

pimageopgui=findobj('Name','Paired Image Operations');
if ~isempty(pimageopgui)
	if(strcmp(get(pimageopgui,'Visible'),'on'))
		figure(pimageopgui);
	end
	return
end

vp_imframe;

FName=[];
NameLst=[];
maskFName=' ';
FirstFNames=[];
SecondFNames=[];
pimageopNames=[];
OutImg=[];  
PImOp=[];

WndNo=0;
WndScl=4;
PlaneNo=1;
Message0=['... '];
Message=Message0;
DefFirstSet=0;
DefSecondSet=0;
DefMask=0;
C1=1;
C2=1;
GMin1=0;
GMax1=0;
ProTime=0;
OutOp=1;
MskOp=1;
DatOp=1;
GNop=0; % global normalization ON=1; OFF=0;
AutoName=1; % automatic naming ON=1; OFF=0;

Bcolor = [.8,.8,.8];
Kcolor = [.8,1,1];
Fcolor = [.75,.72,.78];

MaskOn=1;

pimageopgui = figure('Color',Fcolor,'Name','Paired Image Operations',...
'NumberTitle','off','Position',[100,200,325,275],...
'Units','Pixels');
	
	
uicontrol(pimageopgui,'string', 'HELP',...
	'position',[255 252 60 20],'BackgroundColor',Ecolor,...
	'callback',['vp_help(''vp_pair_imageop'')']);
	
cbtext2= ['text(20,103,''C1'',''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''FontName'',''Times'',''FontSize'',9,''HorizontalAlignment'',''center'');'] ;

cbtext1= ['text(20,88,''C2'',''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''FontName'',''Times'',''FontSize'',9,''HorizontalAlignment'',''center'');'] ;



cbtexto= ['delete(findobj(''tag'',''poptext'')); ',...
	'text(0,176,[''OP =                    ''],''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''tag'',''poptext'',''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''Left'');'] ;

cbtextadd= ['text(0,176,[''OP=(C1*gImage1 + C2*gImage2)''],''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''tag'',''poptext'',''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''Left'');'] ;

cbtextsub= ['text(0,176,[''OP=(C1*gImage1 - C2*gImage2)''],''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''tag'',''poptext'',''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''Left'');'] ;

cbtextavg= ['text(0,176,[''OP=(C1*gImage1 + C2*gImage2)/2''],''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''tag'',''poptext'',''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''Left'');'] ;

cbtextdiv= ['text(0,176,[''OP = C1*gImage1/C2*gImage2''],''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''tag'',''poptext'',''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''Left'');'] ;

cbtextmlt= ['text(0,176,[''OP=(C1*gImage1  .*  C2*gImage2)''],''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''tag'',''poptext'',''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''Left'');'] ;

cbtextexc= ['text(0,176,[''OP=(Image1 EXCLUDE Image2)''],''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''tag'',''poptext'',''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''Left'');'] ;

eval(cbtext1);
eval(cbtext2);
eval(cbtexto);

axis off;

cbFirstname=['FirstFNames(1,:)=get(hFirstname,''string''); Message=Message0;',...
	'FName=FirstFNames(1,:); vp_fimage;',...
	'if isempty(Message), DefFirstSet=1; PlaneNo=max(PlaneNo-1,1); Message=[''First :  '',FName]; end;',...
	'if strcmp(Message,''Maximum Plane Reached''), DefFirstSet=1; vp_note(Message,3); ',...
	'end;'];

pcbFirst=[' FirstFNames=get_file(Inf,''*.img'',''SELECT FIRST IMAGE SET'',[]); ',...
	'if isempty(FirstFNames), return; end; num1=size(FirstFNames,1);',...
	'if ~isempty(FirstFNames), FName=FirstFNames(1,:); vp_fimage; set(hFirstname,''string'',FName);',...
	'if isempty(Message), DefFirstSet=1; PlaneNo=max(PlaneNo-1,1); Message=[''First :  '',FName]; end;',...
	'if strcmp(Message,''Maximum Plane Reached''), vp_note(Message,3); DefFirstSet=1; end;',...
	'end;'];
	
uicontrol(pimageopgui,'string', 'FILE SET 1',...
	'TooltipString','Pick FIRST Image file Set.',...
	'position',[10 163 75 20],'BackgroundColor',Bcolor,'callback',pcbFirst);
	
hFirstname=uicontrol(pimageopgui,'style','edit','string',FirstFNames,...
	'TooltipString','Enter FIRST SET Image file name.',...
	'position',[85 163 230 20],'BackgroundColor',Kcolor,'callback',cbFirstname);


cbmaskname=['maskFName=get(hmname,''string''); Message=Message0;',...
	'if isempty(maskFName), DefMask=0; ',...
	'else, FName=maskFName; vp_fimage;',...
	'figure(pimageopgui); eval(cbtext1); eval(cbtext2); axis off;',...
	'if isempty(Message), DefMask=1; PlaneNo=max(PlaneNo-1,1); Message=[''MASK : '',FName]; end;',...
	'if strcmp(Message,''Maximum Plane Reached''), DefMask=1; end;',...
	'vp_note(Message,2); end;'];
	
cbmaskoff=['if MaskOn, MaskOn=0; maskFName=[]; set(hmoff,''string'',''SET MASK ON''); ',...
	'set(hmfile,''Visible'',''off''); set(hmname,''Visible'',''off'');',...
	'else, MaskOn=1; set(hmfile,''Visible'',''on''); set(hmname,''Visible'',''on'');',...
	'set(hmoff,''string'',''SET MASK OFF''); end;']; 
	
%cbOutMenu = ['OutOp=get(houtmenu,''Value'');';];
	
pcbmask=['maskFName=get_file(1,''.img'',''Please Select Mask File'',[]); ',...
	'if isempty(maskFName), DefMask=0; set(hmname,''string'',maskFName);',...
	'else, FName=maskFName; vp_fimage; set(hmname,''string'',FName);',...
	'figure(pimageopgui); eval(cbtext1); eval(cbtext2); axis off;',...
	'if isempty(Message), DefMask=1; PlaneNo=max(PlaneNo-1,1); Message=[''MASK : '',FName]; end;',...
	'if strcmp(Message,''Maximum Plane Reached''), DefMask=1; vp_note(Message,3); end;',...
	'end;'];
	
hmoff=uicontrol(pimageopgui,'string', 'SET MASK OFF',...
	'TooltipString','Set Mask On/Off',...
	'position',[10 80 90 20],'BackgroundColor',Bcolor,...
	'callback',cbmaskoff);
	
hmfile=uicontrol(pimageopgui,'string', 'MASK FILE',...
	'TooltipString','Pick Mask Image file.',...
	'position',[10 58 75 20],'BackgroundColor',Bcolor,...
	'callback',pcbmask);
	
hmname=uicontrol(pimageopgui,'style','edit','string',maskFName,...
	'TooltipString','Enter Mask Image file name.',...
	'position',[85 58 230 20],'BackgroundColor',Kcolor,'callback',cbmaskname);

	
%cbMskMenu = ['MskOp=get(hmskmenu,''Value'');';];
%hmskmenu=uicontrol(pimageopgui,'Style','popup','Visible','on','String',...
%	'Inclusive Mask|Exclusive Mask','Tag','MskMenu',...
%	'value',MskOp,...
%	'TooltipString',['Inclusive: All non-zero pixels of the mask, ',...
%	'Exclusive: Only zero pixels of the mask'],...
    %	'Position',[105 220 100 20],'callback',cbMskMenu);

cbSecondname=['SecondFNames(1,:)=get(hSecondname,''string''); Message=Message0;',...
	'FName=SecondFNames(1,:); vp_fimage;',...
	'if isempty(Message), DefSecondSet=1; PlaneNo=max(PlaneNo-1,1); Message=[''Second :  '',FName]; end;',...
	'if strcmp(Message,''Maximum Plane Reached''), vp_note(Message,3); DefSecondSet=1;',...
	'end;'];

pcbSecond=[' SecondFNames=get_file(Inf,''*.img'',''SELECT SECOND IMAGE SET'',[]); ',...
	'if isempty(SecondFNames), return; end; num2=size(SecondFNames,1);',...
	'if ~isempty(SecondFNames), FName=SecondFNames(1,:); vp_fimage; set(hSecondname,''string'',FName);',...
	'if isempty(Message), DefSecondSet=1; PlaneNo=max(PlaneNo-1,1); Message=[''Second :  '',FName]; end;',...
	'if strcmp(Message,''Maximum Plane Reached''), DefSecondSet=1; vp_note(Message,3); end;',...
	'end;'];
	
uicontrol(pimageopgui,'string', 'FILE SET 2',...
	'TooltipString','Pick Image files for SECOND SET.',...
	'position',[10 142 75 20],'BackgroundColor',Bcolor,'callback',pcbSecond);
	
hSecondname=uicontrol(pimageopgui,'style','edit','string',SecondFNames,...
	'TooltipString','Enter Background Image file name.',...
	'position',[85 142 230 20],'BackgroundColor',Kcolor,'callback',cbSecondname);


cbC2=['C2=str2num(get(hC2,''string'')); if strcmp(PImOp,''EXC''), C2=1; set(hC2,''string'',''1''); end;  '];
cbC1=['C1=str2num(get(hC1,''string'')); if strcmp(PImOp,''EXC''), C1=round(abs(C1)); set(hC1,''string'',num2str(C1));',...
      'vp_note([''EXCLUDE VOXELS PROXIMITY '',num2str(C1)],3); ; end;  '];
%cbC1=['C1=str2num(get(hC1,''string'')); '];

hC2=uicontrol(pimageopgui,'style','edit','string',num2str(C2),...
	'TooltipString','SECOND SET Scaling Factor, NAP for EXClude Function',...
	'position',[90 109 60 14],'BackgroundColor',Kcolor,'callback',cbC2);

hC1=uicontrol(pimageopgui,'style','edit','string',num2str(C1),...
	'TooltipString','FIRST SET Scaling Factor OR 3D VOXEL Precision For EXClude Function',...
	'position',[90 124 60 14],'BackgroundColor',Kcolor,'callback',cbC1);

cbGNon=['  GNop=1; vp_note([''Global Normalization Option ON. Each Image Divided by its Mean.''],2);'];
	
cbGNoff=[' GNop=0; vp_note([''Global Normalization Option OFF''],2); '];
	

%	'CallBack',['if GNop==0, ',...
%	'eval(cbGNon);',...
%	'else ',...
%	'eval(cbGNoff);',...
%	' end; '],...

hGNon=uicontrol(pimageopgui,'String','Global Normalization','Style','Checkbox',...
	'FontWeight','Normal',...
	'TooltipString','ON/OFF Switch-  (ON: Global Normalization, Divide each image by its non-zero voxel mean )',...
	'Units','pixel',...
	'Position',[175 120 140 019],...
	'value',GNop,...
	'CallBack',[ 'GNop=get(gco,''value''),',...
	'if strcmp(PImOp,''EXC''), GNop=0; ',...
	'set(gco,''value'',GNop); ',...
	' end; '],...
	'BackgroundColor',Bcolor,...
	'ForegroundColor',Tcolor);
	

uicontrol(pimageopgui,'Style','Check','String','AUTO Naming',...
	'TooltipString','Automate Output Naming',...
	'Value',AutoName,'Position',[175 100 140 19],...
	'BackgroundColor',Bcolor,...
	'CallBack',[ 'AutoName=get(gco,''value''),']);
	
	

cbPOpsMenu = ['val=get(hpopsmenu,''Value''),',...
	'if val == 1, PImOp=''''; ',...
	'eval(cbtexto); ',...
	'elseif val==2, PImOp=''ADD''; ',...
	'eval(cbtexto); ',...
	'eval(cbtextadd);',...
	'elseif val==3, PImOp=''AVG''; ',...
	'eval(cbtexto); ',...
	'eval(cbtextavg);',...
	'elseif val==4, PImOp=''SUB''; ',...
	'eval(cbtexto); ',...
	'eval(cbtextsub);',...
	'elseif val==5, PImOp=''DIV''; ',...
	'eval(cbtexto); ',...
	'eval(cbtextdiv);',...
	'elseif val==6, PImOp=''MLT''; ',...
	'eval(cbtexto); ',...
	'eval(cbtextmlt);',...
	'elseif val==7, PImOp=''EXC''; ',...
	'GNop=0; C1=1; C2=1; ',...
	'set(hGNon,''value'',GNop); ',...
	'set(hC1,''string'',1); ',...
	'set(hC2,''string'',1); ',...
	'eval(cbtexto); ',...
	'eval(cbtextexc);',...
	'else, PImOp=''''; ',...
	'eval(cbtexto);',...
	'end; '];

hpopsmenu=uicontrol(pimageopgui,'Style','popup','Visible','on',...
	'position',[10 220 160 20],'BackgroundColor',Bcolor,...
	'TooltipString','Select Operation',...
	'String',...
	['IMAGE PAIR OPERATIONS...|ADD |AVERAGE |SUBTRACT |DIVIDE |',...
	'MULTIPLY |EXCLUDE COMMON VOXELS ...'],...
	'Tag','POpsMenu',...
    	'callback',cbPOpsMenu);



%houtmenu=uicontrol(pimageopgui,'Style','popup','Visible','on','String',...
%	'INCLUSIVE RANGE|EXCLUSIVE RANGE','Tag','OutMenu',...
%	'value',DatOp,...
%	'TooltipString',['Inclusive: All pixels within threshold range except ThMin, ',...
%	'Exclusive: Only pixels outside threshold range'],...
%	'Position',[90 82 150 25],'callback',cbOutMenu);
	
pcbplane=['Message=Message0; PlaneNo=PlaneNo+1; vp_fimage;',...
	'if isempty(Message), PlaneNo=max(PlaneNo-1,1); Message=Message0; end;',...
	'set(hplane,''string'',PlaneNo); ',...
	'if strcmp(Message,''Maximum Plane Reached''), vp_note(Message,3); ',...
	'end; '];
	
uicontrol(pimageopgui,'string', 'VIEW PLANE +',...
	'TooltipString','Display only',...
	'position',[85 20 90 20],'BackgroundColor',Bcolor,'callback',pcbplane);


cbplane=['PlaneNo=str2num(get(hplane,''string'')); Message=Message0;',...
	'vp_fimage;',...
	'if isempty(Message), PlaneNo=max(PlaneNo-1,1); Message=Message0; end;',...
	'set(hplane,''string'',PlaneNo); ',...
	'if strcmp(Message,''Maximum Plane Reached''), vp_note(Message,3); ',...
	'end; '];

hplane=uicontrol(pimageopgui,'style','edit','string',PlaneNo,...
	'TooltipString','Display only',...
	'position',[175 20 60 20],'BackgroundColor',Kcolor,'callback',cbplane);

uicontrol(pimageopgui,'String','PROCESS',...
	'TooltipString','Create Masked Pair Operated Image',...
	'Position',[10 20 60 25],...
	'CallBack',[ 'if ~DefFirstSet, vp_note([''ERR: FIRST SET File Not Defined''],4); return; end; ',...
	'if ~DefMask & MaskOn, vp_note([''ERR: Mask Not Defined''],4); return; end; ',...
	'if ~DefSecondSet, vp_note([''ERR: FILE SET 2 Not Defined''],4); return; end; ',...
	'if (isempty(maskFName) & MaskOn), vp_note([''Mask Not Defined''],4); return; end; ',...
	'if isempty(FirstFNames), vp_note([''FIRST SET Files Not Defined''],4); return; end; ',...
	'if isempty(PImOp), vp_note([''Processing Operation Not Defined''],4); return; end; ',...
	'if num1==0, vp_note([''Images Set 1 Not Defined''],4); return; end; ',...
	'if num2==0, vp_note([''Images Set 2 Not Defined''],4); return; end; ',...
	'if ((num1 ~= num2) & (num2 ~=1)), vp_note([''Image Set Sizes Differ''],4); return; end; ',...
	'if ((num2==1) & (num1>1)), vp_note([''CONSTANT 2nd Image''], 3);  num2=num1; eval(cbequateim2); end; ',...
	'if C1 == 0, vp_note([''Error: Factor C1 = 0''],4); return; end; ',...
	'if C2 == 0, vp_note([''Error: Factor C2 = 0''],4); return; end; ',...
	'if isempty(SecondFNames), vp_note([''SECOND SET Files Not Defined''],4); return; end; ',...
	'set(findobj(''Name'',''Paired Image Operations''),''Pointer'',''watch'');',...
	'if(ProTime==0), ProTime=1; else,',...
	'figure(findobj(''name'',''Paired Image Operations'')); ProTime=ProTime+1; end;',...
	'OutImg=[];',...
	'eval(cbpimageoppro);',...
	' '] );
	
cbequateim2 = ['for im2=2:num1, SecondFNames(im2,:)=SecondFNames(1,:); end;'] ;	

cbpimageoppro = ['for i=1:num2, ',...
	'pimageopNames=char(char(FirstFNames(i,:)),char(SecondFNames(i,:))); dim3=0;',... 
        'vp_note([PImOp,'' PAIR '',num2str(i),'' of '',num2str(num1),'':  Files  '', pimageopNames(1,:), '' AND  '', pimageopNames(2,:)], 3);',...
	'[out1, out2]=vp_mimpro(pimageopNames,PImOp,2,[C1 C2],0,AutoName,GNop,maskFName);',...
	'if out1 < 0,',... 
	'disp([''vp_pair_imageop ABORTED '']);',...
	'set(FMenu,''Pointer'',''Arrow'');',...
	'return; end;',...
	'if AutoName, FName=out2; else FName = OutImg; end;',...
	'if ~isempty(FName), vp_fimage; ',...
	'    if isempty(Message), PlaneNo=max(PlaneNo-1,1); end; end;',...
        'if i==num2, vp_note([num2str(num1),'' SUBJECT PAIRS: '',PImOp,'' PROCESSING COMPLETE '']);',...
	'set(FMenu,''Pointer'',''Arrow''); ',...
	'delete(findobj(''Name'',''Paired Image Operations'')); end;',...
	'end;'];
	
	%%
	%%'set(findobj(''Name'',''Paired Image Operations''),''Pointer'',''arrow'');',...
	%%
	
uicontrol(pimageopgui,'String','QUIT',...
	'Position',[255 20 60 25],...
	'CallBack',['delete(pimageopgui);','delete(FI);','set(FMenu,''Pointer'', ''Arrow'');']);
	
	

eval(cbmaskoff);
