% vp_ratiomap.m
% Calculate corresponding image ratio maps for two sets of images.
%__________________________________________________________________________
%
% In this routine, the user selects two Analyze format image file
% sets containing, e.g. statistical results from two separate processes.
% Only non-zero voxels of a user selected mask image file are included.
% If masking is set off, all non-zero voxels will be evaluated.
% If the global normalization option is enabled, each voxel value is
% divided by the subject's mean non-zero value.
% The user inputs a scaling factor for each set of normalized images.
% The ratio of the corresponding scaled, globally normalized image voxel
% values is evaluated to create an ouput ratio map image for each pair
% of images. The output value is set to zero if the mask value is zero 
% or if either the numerator or denominator is zero.
% The display reflects the current pair being processed.
%__________________________________________________________________________
% vp_ratiomap.m	ScAnVP ver. 5.6 	P. Spetsieris	October 11, 2005

global FI FNames FName ratiomapgui PlaneNo0 PlaneNo hplane
global C1 C2 NameLst OutImg 
global hnumername hmname hdenomname
global GMax1 GMin1 GMax3 GMin3 ProTime
global NumerFNames DenomFNames
global HelpMode Ecolor ratiomapgui
global MaskOn OutOp DatOp MskOp GNop

if HelpMode, vp_help(mfilename), return ; end;

ratiomapgui=findobj('Name','Ratio Map');
if ~isempty(ratiomapgui)
	if(strcmp(get(ratiomapgui,'Visible'),'on'))
		figure(ratiomapgui);
	end
	return
end

vp_imframe;

FName=[];
NameLst=[];
maskFName=' ';
NumerFNames=[];
DenomFNames=[];
RatioNames=[];
OutImg=[];

WndNo=0;
WndScl=4;
PlaneNo=1;
Message0=['............................................ '];
Message=Message0;
DefNumerator=0;
DefDenom=0;
DefMask=0;
C1=1;
C2=1;
GMin1=0;
GMax1=0;
ProTime=0;
OutOp=1;
MskOp=1;
DatOp=1;
GNop=1; % global normalization ON=1; OFF=0;
AutoName=1; % automatic naming ON=1; OFF=0;

Bcolor = [.8,.8,.8];
Kcolor = [.8,1,1];
Fcolor = [.7,.8,.8];

MaskOn=1;

ratiomapgui = figure('Color',Fcolor,'Name','Ratio Map',...
'NumberTitle','off','Position',[100,200,325,275],...
'Units','Pixels');
	
	
uicontrol(ratiomapgui,'string', 'HELP',...
	'position',[255 252 60 20],'BackgroundColor',Ecolor,...
	'callback',['vp_help(''vp_ratiomap'')']);
	
cbtext2= ['text(20,103,''C1'',''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''FontName'',''Times'',''FontSize'',9,''HorizontalAlignment'',''center'');'] ;

cbtext1= ['text(20,88,''C2'',''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''FontName'',''Times'',''FontSize'',9,''HorizontalAlignment'',''center'');'] ;

cbtext= ['text(0,66,[''Ratio = C1*gImage1/C2*gImage2''],''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''Left'');'] ;

eval(cbtext1);
eval(cbtext2);
eval(cbtext);

axis off;

cbnumername=['NumerFNames(1,:)=get(hnumername,''string''); Message=Message0;',...
	'FName=NumerFNames(1,:); vp_fimage;',...
	'if isempty(Message), DefNumerator=1; PlaneNo=max(PlaneNo-1,1); Message=[''NUMER :  '',FName]; end;',...
	'if strcmp(Message,''Maximum Plane Reached''), DefNumerator=1; vp_note(Message,3); ',...
	'end;'];

pcbnumer=[' NumerFNames=get_file(Inf,''*.img'',''SELECT NUMERATOR IMAGE SET'',[]); ',...
	'if isempty(NumerFNames), return; end; num1=size(NumerFNames,1);',...
	'if ~isempty(NumerFNames), FName=NumerFNames(1,:); vp_fimage; set(hnumername,''string'',FName);',...
	'if isempty(Message), DefNumerator=1; PlaneNo=max(PlaneNo-1,1); Message=[''NUMER :  '',FName]; end;',...
	'if strcmp(Message,''Maximum Plane Reached''), vp_note(Message,3); DefNumerator=1; end;',...
	'end;'];
	
uicontrol(ratiomapgui,'string', 'FILE SET 1',...
	'TooltipString','Pick Numerator Image file Set.',...
	'position',[10 163 75 20],'BackgroundColor',Bcolor,'callback',pcbnumer);
	
hnumername=uicontrol(ratiomapgui,'style','edit','string',NumerFNames,...
	'TooltipString','Enter Numerator Image file name.',...
	'position',[85 163 230 20],'BackgroundColor',Kcolor,'callback',cbnumername);


cbmaskname=['maskFName=get(hmname,''string''); Message=Message0;',...
	'if isempty(maskFName), DefMask=0; ',...
	'else, FName=maskFName; vp_fimage;',...
	'figure(ratiomapgui); eval(cbtext1); eval(cbtext2); axis off;',...
	'if isempty(Message), DefMask=1; PlaneNo=max(PlaneNo-1,1); Message=[''MASK : '',FName]; end;',...
	'if strcmp(Message,''Maximum Plane Reached''), DefMask=1; end;',...
	'vp_note(Message,2); end;'];
	
cbmaskoff=['if MaskOn, MaskOn=0; maskFName=[]; set(hmoff,''string'',''SET MASK ON''); ',...
	'set(hmfile,''Visible'',''off''); set(hmname,''Visible'',''off'');',...
	'else, MaskOn=1; set(hmfile,''Visible'',''on''); set(hmname,''Visible'',''on'');',...
	'set(hmoff,''string'',''SET MASK OFF''); end;']; 
	
%cbOutMenu = ['OutOp=get(houtmenu,''Value'');';];
	
pcbmask=['maskFName=get_file(1,''.img'',''Please Select Mask File'',[]); ',...
	'if isempty(maskFName), DefMask=0; set(hmname,''string'',maskFName);',...
	'else, FName=maskFName; vp_fimage; set(hmname,''string'',FName);',...
	'figure(ratiomapgui); eval(cbtext1); eval(cbtext2); axis off;',...
	'if isempty(Message), DefMask=1; PlaneNo=max(PlaneNo-1,1); Message=[''MASK : '',FName]; end;',...
	'if strcmp(Message,''Maximum Plane Reached''), DefMask=1; vp_note(Message,3); end;',...
	'end;'];
	
hmoff=uicontrol(ratiomapgui,'string', 'SET MASK OFF',...
	'TooltipString','Set Mask On/Off',...
	'position',[10 220 90 20],'BackgroundColor',Bcolor,...
	'callback',cbmaskoff);
	
hmfile=uicontrol(ratiomapgui,'string', 'MASK FILE',...
	'TooltipString','Pick Mask Image file.',...
	'position',[10 198 75 20],'BackgroundColor',Bcolor,...
	'callback',pcbmask);
	
hmname=uicontrol(ratiomapgui,'style','edit','string',maskFName,...
	'TooltipString','Enter Mask Image file name.',...
	'position',[85 198 230 20],'BackgroundColor',Kcolor,'callback',cbmaskname);

	
%cbMskMenu = ['MskOp=get(hmskmenu,''Value'');';];
%hmskmenu=uicontrol(ratiomapgui,'Style','popup','Visible','on','String',...
%	'Inclusive Mask|Exclusive Mask','Tag','MskMenu',...
%	'value',MskOp,...
%	'TooltipString',['Inclusive: All non-zero pixels of the mask, ',...
%	'Exclusive: Only zero pixels of the mask'],...
    %	'Position',[105 220 100 20],'callback',cbMskMenu);

cbdenomname=['DenomFNames(1,:)=get(hdenomname,''string''); Message=Message0;',...
	'FName=DenomFNames(1,:); vp_fimage;',...
	'if isempty(Message), DefDenom=1; PlaneNo=max(PlaneNo-1,1); Message=[''DENOM :  '',FName]; end;',...
	'if strcmp(Message,''Maximum Plane Reached''), vp_note(Message,3); DefDenom=1;',...
	'end;'];

pcbdenom=[' DenomFNames=get_file(Inf,''*.img'',''SELECT DENOMINATOR IMAGE SET'',[]); ',...
	'if isempty(DenomFNames), return; end; num2=size(DenomFNames,1);',...
	'if ~isempty(DenomFNames), FName=DenomFNames(1,:); vp_fimage; set(hdenomname,''string'',FName);',...
	'if isempty(Message), DefDenom=1; PlaneNo=max(PlaneNo-1,1); Message=[''DENOM :  '',FName]; end;',...
	'if strcmp(Message,''Maximum Plane Reached''), DefDenom=1; vp_note(Message,3); end;',...
	'end;'];
	
uicontrol(ratiomapgui,'string', 'FILE SET 2',...
	'TooltipString','Pick Image file set for denominators.',...
	'position',[10 142 75 20],'BackgroundColor',Bcolor,'callback',pcbdenom);
	
hdenomname=uicontrol(ratiomapgui,'style','edit','string',DenomFNames,...
	'TooltipString','Enter Background Image file name.',...
	'position',[85 142 230 20],'BackgroundColor',Kcolor,'callback',cbdenomname);


cbC2=['C2=str2num(get(hC2,''string'')); '];

cbC1=['C1=str2num(get(hC1,''string'')); '];

hC2=uicontrol(ratiomapgui,'style','edit','string',num2str(C2),...
	'TooltipString','Denominator Scaling Factor 2',...
	'position',[90 109 60 14],'BackgroundColor',Kcolor,'callback',cbC2);

hC1=uicontrol(ratiomapgui,'style','edit','string',num2str(C1),...
	'TooltipString','Numerator Scaling Factor 1',...
	'position',[90 124 60 14],'BackgroundColor',Kcolor,'callback',cbC1);

cbGNon=['  GNop=1; vp_note([''Global Normalization Option ON. Each Image Divided by its Mean.''],2);'];
	
cbGNoff=[' GNop=0; vp_note([''Global Normalization Option OFF''],2); '];
	

hGNon=uicontrol(ratiomapgui,'String','Global Normalization','Style','Checkbox',...
	'FontWeight','Normal',...
	'TooltipString','ON/OFF Switch-  (ON: Global Normalization, Divide each image by its non-zero voxel mean )',...
	'Units','pixel',...
	'Position',[170 110 140 019],...
	'value',GNop,...
	'CallBack',['if GNop==0, ',...
	'eval(cbGNon);',...
	'else ',...
	'eval(cbGNoff);',...
	' end; '],...
	'BackgroundColor',Bcolor,...
	'ForegroundColor',Tcolor);
	
	
uicontrol(ratiomapgui,'Style','Check','String','AUTO Naming',...
	'TooltipString','Automate Output Naming',...
	'Value',AutoName,'Position',[14 45 100 15],...
	'CallBack',[ 'AutoName=get(gco,''value''),']);


%houtmenu=uicontrol(ratiomapgui,'Style','popup','Visible','on','String',...
%	'INCLUSIVE RANGE|EXCLUSIVE RANGE','Tag','OutMenu',...
%	'value',DatOp,...
%	'TooltipString',['Inclusive: All pixels within threshold range except ThMin, ',...
%	'Exclusive: Only pixels outside threshold range'],...
%	'Position',[90 82 150 25],'callback',cbOutMenu);
	
pcbplane=['Message=Message0; PlaneNo=PlaneNo+1; vp_fimage;',...
	'if isempty(Message), PlaneNo=max(PlaneNo-1,1); Message=Message0; end;',...
	'set(hplane,''string'',PlaneNo); ',...
	'if strcmp(Message,''Maximum Plane Reached''), vp_note(Message,3); ',...
	'end; '];
	
uicontrol(ratiomapgui,'string', 'VIEW PLANE +',...
	'TooltipString','Display only',...
	'position',[165 52 90 20],'BackgroundColor',Bcolor,'callback',pcbplane);


cbplane=['PlaneNo=str2num(get(hplane,''string'')); Message=Message0;',...
	'vp_fimage;',...
	'if isempty(Message), PlaneNo=max(PlaneNo-1,1); Message=Message0; end;',...
	'set(hplane,''string'',PlaneNo); ',...
	'if strcmp(Message,''Maximum Plane Reached''), vp_note(Message,3); ',...
	'end; '];

hplane=uicontrol(ratiomapgui,'style','edit','string',PlaneNo,...
	'TooltipString','Display only',...
	'position',[255 52 60 20],'BackgroundColor',Kcolor,'callback',cbplane);

uicontrol(ratiomapgui,'String','PROCESS',...
	'TooltipString','Create Masked Ratio Maps',...
	'Position',[10 20 60 25],...
	'CallBack',[ 'if ~DefNumerator, vp_note([''ERR: Numerator File Not Defined''],4); return; end; ',...
	'if ~DefMask & MaskOn, vp_note([''ERR: Mask Not Defined''],4); return; end; ',...
	'if ~DefDenom, vp_note([''ERR: FILE SET 2 Not Defined''],4); return; end; ',...
	'if (isempty(maskFName) & MaskOn), vp_note([''Mask Not Defined''],4); return; end; ',...
	'if isempty(NumerFNames), vp_note([''Numerator Files Not Defined''],4); return; end; ',...
	'if num1==0, vp_note([''Images Set 1 Not Defined''],4); return; end; ',...
	'if num2==0, vp_note([''Images Set 2 Not Defined''],4); return; end; ',...
	'if num1 ~= num2, vp_note([''Image Set Sizes Differ''],4); return; end; ',...
	'if C1 == 0, vp_note([''Error: Factor C1 = 0''],4); return; end; ',...
	'if C2 == 0, vp_note([''Error: Factor C2 = 0''],4); return; end; ',...
	'if isempty(DenomFNames), vp_note([''Denominator Files Not Defined''],4); return; end; ',...
	'set(findobj(''Name'',''Ratio Map''),''Pointer'',''watch'');',...
	'if(ProTime==0), ProTime=1; else,',...
	'figure(findobj(''name'',''Ratio Map'')); ProTime=ProTime+1; end;',...
	'OutImg=[];',...
	'eval(cbratiopro);',...
	' '] );
	
	
cbtext= ['text(0,66,[''Ratio = C1*gImage1/C2*gImage2''],''Units'',''pixels'',''Fontweight'',''bold'',',...
	'''FontName'',''Times'',''FontSize'',12,''HorizontalAlignment'',''Left'');'] ;



cbratiopro = ['for i=1:num2, ',...
	'RatioNames=char(char(NumerFNames(i,:)),char(DenomFNames(i,:))); dim3=0;',... 
        'vp_note([''PROCESSING '',num2str(i),'' of '',num2str(num1),'' PAIRS :    RATIO of '', RatioNames(1,:), '' DIVIDED BY  '', RatioNames(2,:)], 3);',...
	'[out1,out2]=vp_mimpro(RatioNames,''DIV'',2,[C1 C2],0,AutoName,GNop,maskFName);',...
	'if out1 < 0,',... 
	'disp([''vp_ratiomap ABORTED '']);',...
	'set(FMenu,''Pointer'',''Arrow'');',...
	'return; end;',...
	'if AutoName, FName=out2, else FName=OutImg; end;',...
	'if ~isempty(FName), vp_fimage; ',...
	'    if isempty(Message), PlaneNo=max(PlaneNo-1,1); end; end;',...
        'if i==num2, vp_note([num2str(num1),'' SUBJECT PAIRS:  RATIO PROCESSING COMPLETE '']);',...
	'set(FMenu,''Pointer'',''Arrow''); ',...
	'set(findobj(''Name'',''Ratio Map''),''Pointer'',''arrow''); end;',...
	'end;'];
	
	
uicontrol(ratiomapgui,'String','QUIT',...
	'Position',[255 20 60 25],...
	'CallBack',['delete(ratiomapgui);','delete(FI);','set(FMenu,''Pointer'', ''Arrow'');']);
	


