% function [file_list, roi_list, roi_array] = vp_read_grprpt(infile)
% Read ROI matrix, file & region names from scanvp group roi output file
%
% This routine reads a  GROUP-ROI COMPOSITE SUMMARY 2D or 3D report
% and returns a list of file names, regions of interest and a data matrix.
% Reports can have title lines that do not begin with 1. The first subject
% data must begin with 1 name ... data. Following subjects can have other
% number id's. 
%
% read_rpt (main)             Yilong Ma, Ph.D.            4/24/2003
% vp_read_grprpt (revision)   ScAnVP 5.1                  5/08/2003
% vp_read_grprpt (revision)   ScAnVP 5.8                  3/20/2007
% vp_read_grprpt (revision)   ScAnVP 6.4                  1/12/2015
%_______________________________________________________________________
function [file_list, roi_list, roi_array] = vp_read_grprpt(infile)

file_list=''; roi_list=''; roi_array=[];
fd=fopen(infile,'rt');
disp(['Reading report: ',infile]);
j = 0; % determine the number of subject files
	%PS Skip any title lines.
	lnskip=0; c='0';
	while c~='1',
	  if lnskip > 20, fclose(fd);
	   vp_message('Data must begin with 1 ...');
	   return;
	  end
	  line = fgets(fd); [c,d]=sscanf(line,'%s',1);
	  if isempty(c), c='0'; lnskip=lnskip+1,
	  elseif c ~= '1', lnskip=lnskip+1;
	  end;
	end;
        while 1
           line = fgets(fd);
	   line = deblank(line); %PS
           j = j+1;
           a = length(line); 
           %PS if a == 2, break, end
           if a == 0, break, end %PS
           if ~ischar(line), %PS
	     vp_message('Error: EOF reached ');
	     fclose(fd); return;
	   end;
        end
        num_sub = j,
             
 % determine the number of regions
 frewind(fd);
 j = 0; 
 kgmax=0; gmfound=0; %Check if Global Max is listed

 	for i=1:lnskip
          line = fgets(fd); % PS dump title lines
	end;

	%PS SKIP intermediate notes and search for first line of KEY
	s=0; lnskip2=0; 
  	while(s==0),line=fgets(fd); lnskip2=lnskip2+1;
           	if ~ischar(line), %PS
			out1=-1;
	     		vp_message('Error: EOF reached ');
	     		fclose(fd); return;
	   	end;
		s=max([findstr(line,'Sequence No.') 0]);
	end

        while 1
           line = fgets(fd),
	   kgmax=max([(findstr(line,'Global Max')~=0) 0]);
           if kgmax==1, gmfound=1; end;
           j = j+1;
           if ~ischar(line), break, end;
        end

	num_keys= 4+gmfound,
        %%num_roi = j-4, %DEBUG
        num_roi = j-num_keys,
          
% read ROI matrix    
frewind(fd);
for i=1:lnskip
   line = fgets(fd); % PS dump title lines
end;
for i = 1:num_sub,
   %%[A, B] = fscanf(fd,'%s',4); %DEBUG
   [A, B] = fscanf(fd,'%s',num_keys);

   for j = 1:num_roi,
      [C, D] = fscanf(fd,'%s',1);
      roi_array(i,j) = str2num(C);
   end
end

% read subject list
frewind(fd);
for i=1:lnskip
   line = fgets(fd); % PS dump title lines
end;
for i = 1:num_sub,
   %%for j = 1:num_roi+4 %DEBUG
   for j = 1:num_roi+ num_keys
      E = fscanf(fd,'%s',1);
      if j == 2 sub_list{i} = E; end
   end
end
file_list = sub_list';

% read roi list
%%skiplns=lnskip2 - num_sub + 4 ; %Flags and Key

skiplns=lnskip2 - num_sub + num_keys ; %Flags and Key

for i=1:skiplns
   line = fgets(fd); % PS dump lines
end;
for i = 1:num_roi
   % PS skip number and get remaining line part 
   fscanf(fd,'%s%c',2); aa = fgetl(fd);
   % PS replace tabs
   aa=strrep(aa,'	',' ');
   roi_list{i}=deblank(aa); 
   %ch=' ';
   %lch=aa(length(aa)); nlch=aa(length(aa)-1);
   %if ((lch=='L' | lch=='R') & (nlch == 9) | nlch ==' '),ch=lch; aa(length(aa))=' ';end;
   %roi_list{i} = [deblank(aa),' ',ch]; %PS replace tab with ' '
end
roi_list = roi_list';

fclose(fd);
%if old_data D = fscanf(fd,'%f',[8 j-2])';


