function [out1, Message]=vp_readatlas(atlasnm,planeno)
%
% Read atlas template image plane for number of rois and
% get their labels from corresponding label file.
% In the initial run the label file and Atlas volume is read.
% In the roi BRAIN ATLAS image, regions are pre-defined on
% each plane using a fixed coded index value for each voxel
% within a given region type.
% The names of the regions are listed numerically in a separate text
% file with the name AtlasNameLabs.txt that must accompany the atlas.
% Following an initial text line defining the file, each region is 
% listed in numerical order as num name or num name_L or num name_R.
%
%_______________________________________________________________________
% function vp_readatlas.m   ScAnVP ver 5.8  P. Spetsieris Jan. 29, 2007
%		       rev. ScAnVP 7.0	P.S.  11/11/15
% 	

global LabIds LabNames PlaneNo
global Message RoiNo FI
global NonStdLabs NonStdNo NonStdLabStr
global DIM ORIGIN VOX TemplDIM TemplORIGIN TemplVOX Fitting Flipping
global ALabNames ALabNos AVolXYZ LabAIds Keyin 
global DisplayOrient InputOrient

   out1=0;
   Message=['.........................'];

   figure(FI); 
 
   if nargin < 2, planeno=0, end;
 
   if isempty(ALabNames)

     ALabNos=[];
     [atnm,atdnm]=vp_nm('nm',atlasnm);

     labfile=[atdnm,'Labs.txt'],

     vp_dispfile(labfile); delete(gcf);
  
     fp = fopen(labfile,'rt');
     if fp <= 0, Message=['READ LABEL FILE: fopen error'],
     out1=-2;
     return; end;

     dumpstr=fscanf(fp,'%s',1), %Skip First String
   
     %while(~strcmp(dumpstr,'1') | isempty(dumpstr))
     
     while(isempty(str2num(dumpstr)) | isempty(dumpstr))
   	if isempty(dumpstr), out1=-2;
	  Message=['ROI 1 not found']; return, end;
   	dumpstr=fscanf(fp,'%s',1),
     end;

     nregs=-1; regnos=0;

     if planeno ~= 0
       vp_keyin(['Enter Region Nos. Ni,Nj and/or Ranges Nk:Nm',...
  	  ' [Ni,Nj,Nk:Nm| q] (SEE Command Window List)'],'ALL');
       if strcmp(Keyin,'ALL'); nregs = -1; 
       elseif (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')), out1=-3; Message=['ROUTINE ABORTED']; return;
       else
		skey=Keyin,
		ind=findstr(skey,','),
 		lk=length(skey),
		li=length(ind),
		nkey=li+1;
		n2=-1;
		regnos=0; nregs=0;
		for k=1:nkey
		  n1=n2+ 2,
		  if (k < nkey), n2=ind(k) -1,
	 	  else, n2=lk; end;
		  sk=skey(n1:n2),
		  ink=findstr(sk,':');
		  if isempty (ink) % assume one value
			nr=str2num(sk),
			nregs=nregs+1; regnos(nregs)=nr;
			
		  else  % assume range
			t1=str2num(sk(1:ink(1)-1)),
			lsk=length(sk),
			sk(ink(1)+1),
			sk(lsk),
			t2=str2num(sk((ink(1)+1):lsk)),
			t11=min(t1,t2); t22=max(t1,t2);
		        for nr=t11:t22
			  nregs=nregs+1; regnos(nregs)=nr;
			end;
		  end;
		end;
       end;
     end;

     i=0;  
     
     nregs, regnos,
     no=str2num(dumpstr), alabname=fscanf(fp,'%s',1),    
     if ((nregs == -1) | ( (nregs > 0) & (max(regnos==no) > 0) ) ) 
      i=i+1;
      ALabNos(1)=str2num(dumpstr); 
      ALabNames=alabname;
     end;
     while(~isempty(dumpstr)),
   	no=fscanf(fp,'%d',1);
	if isempty(no), break; end;
 	dumpstr=fscanf(fp,'%s',1);    %file roi label
        if ((nregs == -1) | ( (nregs > 0) & (max(regnos==no) > 0) ) ) 
	 i=i+1;
   	 ALabNos(i)= no;
	 if ~isempty(dumpstr)
	   alabname=dumpstr,
           if i==1,
      	     ALabNames=alabname;
	   else
	     ALabNames=strvcat(ALabNames,alabname);
	   end % if 1
	 end % if isempty
	end % if nregs
     end;
     
     fclose(fp);
     [out1 AVolXYZ]=vp_volfuns('xyzdata',atlasnm, (InputOrient ~= DisplayOrient));
     if out1 <= 0, Message=['ATLAS Image File: fopen error'],
     out1=-2; return; end;
   end % ALabNames



   if planeno==0, return; end;

   if ~exist('ALabNames'), vp_note('ALabNames not defined', 3), out1=-2, return; end;
   if ~exist('ALabNos'), vp_note('ALabNos not defined', 3), out1=-2, return; end;
   if ~exist('AVolXYZ'), vp_note('AVolXYZ not defined', 3), out1=-2, return; end;

   natlasrois=size(ALabNames,1);
   natlaslabels=size(ALabNos,2); 
   if (natlasrois ~= natlaslabels),
      Message=['No Labels: ',num2str(natlaslabels),' No Rois',num2str(natlasrois)' Mismatch'];
   out1=-2; return; end;

   nrs=0;

   axyplane=[];
   axyplane=AVolXYZ(:,:,planeno);
   alabids=[];
   
   for i=1:natlasrois

    %if ~isempty(find(axyplane == i))
    if ~isempty(find(axyplane == ALabNos(i)))
        nrs=nrs+1;
	alabids(nrs)=ALabNos(i);
        if nrs > 1
	 alabnames = strvcat(alabnames,ALabNames(i,:));
	else
	 alabnames = ALabNames(i,:);
	end
    end;
    
   end;
   

   %alabids, alabnames,
   if isempty(nrs)| nrs<=0 , Message=['No Regions Found in Plane ',num2str(planeno)]; nrs;
     out1=0;
   return; end;
  
   %DIM, ORIGIN, VOX, Fitting,
   
   for i= 1:nrs
       
     RoiNo=RoiNo+1;
     labname=deblank(alabnames(i,:));
     len=length(labname);
     if strcmp((labname(len-1:len)),'_L')
     	 ori='L';
     elseif strcmp((labname(len-1:len)),'_R')
     	 ori='R';
     else
         ori=' ';
     end;
     
     if strcmp(ori,' ')
      LabNames(RoiNo,:)=[labname blanks(40-len)];
     else
      LabNames(RoiNo,:)=[labname(1:len-2) blanks(42-len)];
     end
     
     nid=NonStdNo+1;
     for j=1:NonStdNo-100
		if strcmp(LabNames(RoiNo,:),NonStdLabs(j,:))
		   nid=j+100;
		end
     end
     if nid==NonStdNo+1,
		NonStdNo=nid;
		NonStdLabs=str2mat(NonStdLabs,LabNames(RoiNo,:));
     end
     labid=[num2str(nid),ori];
     LabIds(RoiNo,:)=[labid blanks(4-length(labid))];
     LabAIds(RoiNo)=alabids(i);
	
   end
   
   
   if out1 ~= 0, Message=['READ ATLAS: error ',num2str(out1)], return; end;
   
   if out1 == 0,
   	Message=['ATLAS READ '];
   end
   
   
  % set(hroimenu,'Visible','on','Enable','on','Value',1);
