% function out1=vp_remclust(callfname,opt,ndim,fopt,fil1,fil2);
%
% Remove all clusters less than the size of a square region from
% a plane or cubic region for a volume image.
% Note, that clusters that are removed in 2D may not be removed
% in 3D because they exceed size limits in the third dimension.
%
% ndim: 1 or 2 dimensions
%
% opt=1:
% This option assumes an image with a background value of 0.
% It removes all clusters of a size keyed in by the user. 
% The dimensions of the cluster are assumed to be the same
% in each dimension. For 2 dimensions, the user must point
% to a displayed image. For three dimensions, the active
% displayed image (FName, XYZDATA) is assumed for input unless
% fopt is 2. 
% Colors are mapped to the original scale.
%
% opt=2
% Same as above but it assumes a composite image where the background
% values are the lower half of the full range. A background image
% must be selected for replacing the removed pixels.
%
%   fopt=2 (3D option only) Process file name fil1 for input.
%
%   fopt=3 (2D & 3D) Process XYZDATA with background file name fil1.
%
%   fopt=4 (3D only) Process composite file fil1 with background fil2.
%   fopt=5 (3D only) Process statistics fil1 with background fil2.
%		   keeping displayed range DATAMIN DATAMAX
%
%   For 3D options(ndim=3,opt=2), both stat and composite files are created
%				but only the composite file is displayed
%
%   callfname: function to call when completing option 2
%_______________________________________________________________________
% vp_remclust.m ScAnVp	C.4.7.6 Phoebe Spetsieris  Dec. 26, 2001
%          ScAnVP ver. 6.1 by P.S. May 24, 2011
%          ScAnVP ver. 7.0 by P.S. Jan. 12, 2016

function [out1] = vp_remclust(callfname,opt,ndim,fopt,fil1,fil2)

global HelpMode FI UFI hclust GCM Keyin 
global VOX ORIGIN DIM HelpMsg PlaneNo WinView 
global bgrndFNAME FName DATAMIN DATAMAX DATA XYZDATA
global Time hrname Opt nameimgA DisplayOrient InputOrient

if HelpMode, vp_help(mfilename), return ; end;

if nargin > 3, 
 
 if fopt==5, % save original composite
  dataminB=DATAMIN; datamaxB=DATAMAX;
 end;
 if (fopt==2 | fopt >=4),
   FName=fil1,
   if ~isempty(FName),
    FName=deblank(FName);
    %P=strtok(FName,'.');
    P=vp_nm('dnm',FName);
    [dim vox scale type offset or descrip tim dur mtyp gentim subid expdate glmax glmin] = vp_hread([P '.hdr']);
    FName=[P '.img'];
    [out1 XYZDATA DATAMIN DATAMAX]=vp_volfuns('xyzdata',FName,(DisplayOrient~=InputOrient));
    if out1 < 0, 
  	vp_message('ERROR: extracting File');
	return;
    end
    
  else, return, end;
 end;
 if fopt==3,
   bgrndFNAME=fil1,
 elseif fopt>=4,
   bgrndFNAME=fil2,
 end;
else
 fopt=0;
end;

if nargin < 6, fil2='0'; end;
if nargin < 5, fil1='0'; end;
 

out1=0; 
viewno=0;

TxColor=[0.8 0.2 1];
	
if fopt==0,
  if opt== 1,
   %vp_note('NOTE! Assumes Background 0 ',1);
   if ndim==2
    vp_keyin('Displayed image has 0 Background? [OK=y | CANCEL=no]','yes');
   else
    vp_keyin('Last Displayed image has 0 Background? [OK=y | CANCEL=no]','yes');
   end
   if (isempty(Keyin) | strcmp(Keyin,'n') | strcmp(Keyin,'no')),
     %vp_note('Select Semi option.',1);
   return, end
  elseif opt==2,
   if ndim==2
     vp_keyin('Displayed image is composite PET/MRI? [OK=y | CANCEL=no]','yes');
   else
     vp_keyin('Last Displayed image is composite PET/MRI? [OK=y | CANCEL=no]','yes');
   end
   if (isempty(Keyin) | strcmp(Keyin,'n') | strcmp(Keyin,'no')),
     %vp_note('Do not Select Semi option.',2);
   return, end
  end
end
 
vp_keyin('Key in diameter(mm)  [#|q]','');
if (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
return, end;
widmm=str2num(Keyin) ; % cluster mm width
 
% for 2 dimensions should point to plane to get correct view, etc.
% keyin is not enough for 2D

if ndim==2
   vp_note(['PICK IMAGE with Left Button']);
   %vp_note(['PICK IMAGE with Left Button'],2);
   waitforbuttonpress; UFI=gcf;
   delete(findobj('Name','Note'));
% UFI=FI;
% if  ~ishandle(UFI),  
%   vp_note(['INVALID IMAGE - PICK FIGURE with Left Button'],2);
%  waitforbuttonpress; UFI=gcf;
% end 
      
 figure(UFI);
 GCM=get(UFI,'colormap');
	
end

if opt==2,

  %vp_note('NOTE! Assumes data in upper half range & variable background',2);
  if (fopt < 3),
    bgrndFNAME=get_file(1,'.img','please select background image',[]); 
  end % if fopt
  if ~isempty(bgrndFNAME),
    vox=VOX; dim=DIM; xyzor=ORIGIN;
    fname2=deblank(bgrndFNAME),
    %P=strtok(fname2,'.');
    P=vp_nm('dnm',fname2);
    [dim2 vox2 scale2 type2 offset2 or2 descrip2 tim2 dur2 mtyp2 gentim2 subid2 expdate2 glmax2 glmin2] = vp_hread([P '.hdr']);
    bgrndFNAME=[P '.img'],
    [out1 bxyzdata bmin bmax]=vp_volfuns('xyzdata',bgrndFNAME,(DisplayOrient~=InputOrient));
    
    %backdat=xyzdata(PlaneNo); % assumes axial plane
    if out1 < 0, 
  	vp_message('ERROR: extracting Background');
	return;
    end
    
    % restore original globals
    %fname1=deblank(fname1);
    %P=strtok(fname1,'.');
    %vp_hread([P '.hdr']);
    %FName=[P '.img'],
  else, return, end;
end

if ndim==3
 %vp_keyin('Key in diameter(mm)  [no]','');
 %if (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
 %return, end;
 %widmm=str2num(Keyin) ; % cluster mm width
 
 wid=widmm/VOX(1);
 wid=round(wid); widmm=wid*VOX(1); hgtmm=wid*VOX(2); 
 if wid <=0, vp_message('ERROR: wid <=0'); return;
 else
 textstr=['VOX= [', num2str(widmm),',',num2str(hgtmm),',',num2str(wid*VOX(3)), '](mm)'];
 textstr=[textstr,' =  [',num2str(wid),',',num2str(wid),',',num2str(wid),'](Pix)'];
 vp_message(textstr);
 end;
 out2=XYZDATA;
 clim=[DATAMIN DATAMAX],
 
else, % 2D Option
% For 2D planar images the dimensions of a square are
% selected by the user using the mouse. In this case the
% region size is defined by holding the right button down and 
% entering the lower left and upper right diagonal points.
% If a rectangular region is defined using the left button, 
% the largest dimension will be used.

 %%vp_note('Define Sample Square ROI with Right Button Down',1);

 %%found=0;
 %%while found==0,
   %%rect=getrect(UFI),
   %%anynegs=rect > 0 ;
   %%if min(anynegs)==0
     %%vp_note('Please Reenter Diagonal Points',2);
   %%else
     %%found=1;
   %%end
 %%end

 %%x=round(rect(1)); y=round(rect(2)); wid=round(rect(3)); hgt=round(rect(4));

 % make sure square
  %%wid=max(wid,hgt);
  %%hgt=wid;
  %%squarerect=[x y wid hgt],

  if ~strcmp(get(gco,'type'),'image')
	out1=-1;
	vp_message('Not an ''image'' ');
	return;
  else
    %%hrect=rectangle('position',squarerect);
    cdata=get(gco,'CDATA');
    haxis=get(gco,'parent');
    clim=get(haxis,'clim');
  
    cdata=cdata';
  
    sz=size(cdata),
    udata=get(gca,'UserData');
    if isempty(udata),
      if opt==1
  	if isempty(VOX), VOX=[2 2 2]; end;
  	if isempty(PlaneNo), PlaneNo=1; end;
  	if isempty(WinView), viewno=1; else viewno=WinView; end;
  	if isempty(ORIGIN), ORIGIN=[1 1 1]; end;
      elseif opt==2;
  	if isempty(vox), VOX=vox2; else VOX=vox; end;
  	if isempty(xyzor), ORIGIN=or2; else ORIGIN=xyzor; end;
  	if isempty(PlaneNo),
 	   vp_keyin('PlaneNo? [no.| q]','1');
	   if (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
 	   return, end;
	   PlaneNo=str2num(Keyin);
	end;
  	if isempty(WinView), viewno=1; else viewno=WinView; end;
      end
      plno=PlaneNo; vox=VOX; xyzor=ORIGIN;
  
    else
      viewno=udata(1); plno=udata(2); vox=udata(3:5); xyzor=udata(6:8);
    end
    if opt==2
      if ~isequal(vox, vox2) | ~isequal(dim, dim2), 
  	vp_message('ERROR: Incompatible Voxel size or Dimensions for Background');
	vox, vox2, dim, dim2,
	return;
      end
    end
    if viewno==1
    	xmm=0; ymm=0;
  	%%xmm=(x-xyzor(1))*vox(1); ymm=(y-xyzor(2))*vox(2);
	zmm=(plno-xyzor(3))*vox(3);
	%%widmm=vox(1)*wid; hgtmm=vox(2)*hgt;
	wid=widmm/vox(1);
 	wid=round(wid); hgt=wid; widmm=wid*vox(1); hgtmm=hgt*vox(2); 
    elseif viewno==2,
    	zmm=0; ymm=0;
  	%%ymm=(x-xyzor(2))*vox(2); zmm=(y-xyzor(3))*vox(3);
	xmm=(plno-xyzor(1))*vox(1);
	%%widmm=vox(2)*wid; hgtmm=vox(3)*hgt;
	wid=widmm/vox(2);
 	wid=round(wid); hgt=wid; widmm=wid*vox(2); hgtmm=hgt*vox(3); 
    elseif viewno==3,
    	xmm=0; zmm=0;
  	%%xmm=(x-xyzor(1))*vox(1); zmm=(y-xyzor(3))*vox(3);
	ymm=(plno-xyzor(2))*vox(2);
	%%widmm=vox(1)*wid; hgtmm=vox(3)*hgt;
	%%wid=widmm/vox(1); hgt=hgtmm/vox(3);
	wid=widmm/vox(1);
 	wid=round(wid); hgt=wid; widmm=wid*vox(1); hgtmm=hgt*vox(3); 
    end
    if wid <=0, vp_message('ERROR: Pixel wid <=0'); return; end;
  
    out2=cdata';
  end % if image

end % for 2D Point to area

if opt==2

 % get forground data
 if fopt == 5,
   clim,
   datamin=dataminB, datamax=datamaxB,
   midvalue=(datamin+datamax)/2,
   %if (midvalue ~= clim(1)),
   %	vp_message('WARNING Data Minimum differs');
   %elseif (datamax ~= clim(2))
   %	vp_message('WARNING Data Maximum differs');
   %end
 else
   datamin=clim(1); datamax=clim(2);
   midvalue=(datamin+datamax)/2;
   dataf=(out2 >= midvalue);
   out2= out2.*dataf;
 end
 
 % get background data
 if ndim ==2,
   [out1 backdat]=vp_volfuns('getplane',bxyzdata,plno,viewno,dim);
   if out1 < 0, vp_message('Error retrieving background'); return; end;
 end % ndim=2
 if bmax - bmin > 0,
  mratio = (midvalue -datamin)*(1- 1/128)/(bmax-bmin);
  if ndim== 2
    backdat= datamin + backdat*mratio;
  else
    backdat= datamin + bxyzdata*mratio;
  end
 else
   out1=-1;
   vp_message(['Error: Background Limits:  (', num2str(bmin),',', num2str(bmax),')']);
   return;
 end;
end;

vp_note(['Deleting ' num2str(ndim) 'D Clusters <= ',num2str(wid),'Voxels (=',num2str(widmm),'mm.)'],2);


if ndim==2,
 hclust=figure('name','removeclusters');
 h=waitbar(.05,['Removing clusters size ',num2str(wid),' voxels.']);
end

%for i=1:wid
%[out1,out2]=vp_volfuns('remclusters2',out2,i,0);
%[out1,out2]=vp_cvolfuns('remclusters2',out2,i,0,size(out2));
%[out1,out2]=vp_cvolfuns('remclusters2',out2,i,0);
%if out1 < 0, vp_message(['error for width :', num2str(i)]); return; break; end
%waitbar(i/wid,h);
%end

[out1,out2]=vp_cvolfuns('remclusters',out2,wid,0);
if out1 < 0, vp_message(['error for width :', num2str(wid)]); return; end

if ndim==2,
 waitbar(1,h); close(h);

 figure(hclust);
end

if opt==2
 % Merge with background data
 size(out2), size(backdat),
 dataA=out2;
 [out1 out2]=vp_volfuns('mergedata',out2,backdat,1);
 if out1 < 0, vp_message('Error merging background'); return; end;
 
 	 % dim=size(out2);
	 % for i=1:dim(1), for j=1:dim(2),
	 % if out2(i,j) == 0, out2(i,j)=backdat(i,j); end;
	 %end; end;
end

if ndim==2
  imagesc(out2,clim); axis off image xy ;
  vp_aspect(viewno,vox);
  set(gca,'UserData',udata);
  set(gcf,'Tag','image');
  vp_controls(gcf,mfilename,1);

  colormap(GCM); try colorbar('v6', 'vert'); catch colorbar; end;
  
  himv=findobj('Name','clustdelui');

  position=[200,200,450,100];

  if ~isempty(himv); position=get(himv,'Position'); delete(himv); end;


        himv = figure('Color','w','Name','clustdelui',...
	'NumberTitle','off','Position',position,...
	'Units','Pixels','Visible','on');
	
	axis off;
	
	uicontrol(himv,'String','HELP',...
	'Position',[360 position(4)-18 55 18],...
	'TooltipString',HelpMsg,...
	'callback','vp_help(''vp_remclust'');');

	uicontrol(himv,'String','REPROCESS',...
	 'Position',[60 10 70 20],...
	 'Userdata',struct('vals',[opt,ndim,fopt],'str',{{callfname,fil1,fil2}}),...
	 'TooltipString','Del. clusters',...
	 'CallBack',['ud=get(gco,''userdata''); cf=ud.str(1); opt=ud.vals(1);',...
	 ' ndim=ud.vals(2); fopt=ud.vals(3); fil1=char(ud.str(2));',...
	 ' fil2=char(ud.str(3));',...
	 ' vp_remclust(cf,opt,ndim,fopt,fil1,fil2);']);
	
	 
	uicontrol(himv,'String','RETURN',...
	'Position',[360 10 55 20],...
	'CallBack',[' ; ',...
	'delete(findobj(''Name'',''clustdelui''));'] );

	
	%coord=[' (',num2str(x) ', ' num2str(y),')'];
	
	%coord=[' (',num2str(x) ',' num2str(y),', ' ',...
	% ' num2str(round(wid)) ',' num2str(round(hgt)),')'];
	
	%%coord=[' (',num2str(x) ',' num2str(y),', ' num2str(wid) ',' num2str(hgt),')'];
	coord=[' (',num2str(wid) ',' num2str(hgt),')'];

	if viewno == 1, view ='Axial XY  ';
	elseif viewno==2, view = 'Sagittal YZ  ';
	elseif viewno==3, view = 'Coronal XZ  ';
	else view= 'Not Defined,   ';
	end
	
        %textstr=['View: ', view, 'ROI x,y,wid,hgt ',coord,' (pix)'];
        %%textstr=['View: ', view, 'CLUSTER wid,hgt ',coord,' pix'];
        textstr=['View: ', view];
	text(0.0,.96, textstr,...
	'FontName','Times','FontSize',10,...
	'VerticalAlignment','Middle',...
	'HorizontalAlignment','Left',...
	'Color',TxColor);

	if viewno~=0,
	
	  textstr=['PlaneNo :  ',num2str(plno)];
	  textstr=[textstr,',', '  X= ',num2str(xmm),'mm, Y= ',...
		num2str(ymm),'mm, Z= ',num2str(zmm), 'mm'];
	  %%textstr=['PlaneNo :   ',num2str(plno),',  Z= ',num2str(zmm),'mm'];
	  text(0.0,.78, textstr,...
	  'FontName','Times','FontSize',10,...
	  'VerticalAlignment','Middle',...
	  'HorizontalAlignment','Left',...
	  'Color',TxColor);
	
	  %%textstr=['X= ',num2str(xmm),'mm, Y= ',...
	  %%	num2str(ymm),'mm, Z= ',num2str(zmm), 'mm,',...
	  %%	' WID= ', num2str(widmm),'mm, HGT= ',num2str(hgtmm), '(mm)'];
	  textstr=['CLUSTER wid,hgt ',coord,' pix',',  (', num2str(widmm),',',num2str(hgtmm), ') mm'];
	  text(0.0,.60, textstr,...
	  'FontName','Times','FontSize',10,...
	  'VerticalAlignment','Middle',...
	  'HorizontalAlignment','Left',...
	  'Color',TxColor);
	end
	
	
	textstr=['Removed Clusters less than (', num2str(widmm),...
	'mm.)'];

	text(0.0,.40, textstr,...
	'FontName','Times','FontSize',10,...
	'VerticalAlignment','Middle',...
	'HorizontalAlignment','Left',...
	'Color',TxColor);
	
	%delete(hrect);

  else % ndim=3
	textstr=['Removed Clusters less than (', num2str(widmm),...
	'mm.) SAVING FILE ...'];
	vp_message(textstr);
	
	%XYZDATA=out2;

	%P=strtok(FName,'.');
	%P=P(1:max([findstr(P,'\') 0]));
    	P=vp_nm('dir',FName);
	
	for i=1:opt
	  if i==1,
	   nameimg=[P 'clustmapA' '.img'];
	   nameimgA=nameimg;
	  else
	   nameimg=[P 'clustmapB' '.img'];
	  end
	  fidresult=fopen(nameimg,'w');
	
      % Mark with DATAMAX value on the first pixel to avoid color shift
	  if (fopt==5 & ndim==3 & i==2), DATAMAX=datamaxB; DATAMIN=dataminB; end;
	  if (i==2 & ndim==3), out2(1,1,1)=DATAMAX; end;
	
	  if (i==1 & opt==2)
        if (DisplayOrient~=InputOrient) % Flip Back 
          dataA_X=[];
          for pln=1:DIM(3)
              dataAX=fliplr(dataA(:,:,pln)'); dataA_X(:,:,pln)=dataAX';
          end;
          out1=fwrite(fidresult,dataA_X,'double');
        else
          out1=fwrite(fidresult,dataA,'double');
        end;
      else
        if (DisplayOrient~=InputOrient) % Flip Back 
           out2_X=[];
           for pln=1:DIM(3)
               out2X=fliplr(out2(:,:,pln)'); out2_X(:,:,pln)=out2X';
           end; 
           out1=fwrite(fidresult,out2_X,'double');
        else
          out1=fwrite(fidresult,out2,'double');
        end;          
	  	
	  end
	
	  fclose(fidresult);
	  if i==1
          [dim vox scale type offset or descrip tim dur mtyp gentim subid expdate glmax glmin] = vp_hread(FName);
	    outscale=1; outype=64; %double
	    descripA=['ScAnVP cluster mapA, deleted clusters < ', num2str(wid) '(pix), ' descrip],...
	    descripB=['ScAnVP cluster mapB, deleted clusters < ', num2str(wid) '(pix), ' descrip],...
	    descrip=descripA;
	  else
	    descrip=descripB;
	  end
	  if (vp_hwrite(nameimg,dim,vox,outscale,outype,offset,or,...
	    ['ScAnVP cluster map, deleted clusters < ', num2str(wid) '(pix), ' descrip],...
	    tim,dur,gentim,subid,expdate)) < 0,
	    vp_message('hwrite clustmap err'); 
	  else, 
	    if i==1
	      vp_message(['Cluster file: ', nameimg,' saved']); 
	    else
	      vp_message(['Cluster files: ', nameimg,' & clustmapA saved']); 
	    end
	  end
	end % for i
	
	% Update Orthogonal Display Only
	FName=nameimg;
	if (fopt==5), DATAMAX=datamaxB; DATAMIN=dataminB; end;
	set(hrname,'string',FName);
	XYZDATA=out2;
	Opt=1; Time=Time+1;
	eval(callfname);
	
end % ndim=3


