% ScAnVP (Scan Analysis and Visualization Processor) Ver. 7.0w - (C) 2016
% Center for Neurosciences, Feinstein Institute for Medical Research,
% Northwell Health (formerly, North Shore-LIJ Health System) 
%
%                                  REVISIONS
%
% Noteworthy revisions are listed here.
%
%   REVISION 7.0w Released Feb. 1, 2016 (Incorporates Rev. 6.4 to Sep. 2015)
%
%     HELP NOTES A concise overview of the basic operation of scanvp for new
%        users was added and documentation of old revisions was removed.
%
%     SSM-PCA A general overview of SSM-PCA was added in Help and in the
%        Documentation directory covering description of the algorithm,
%        historical development, type of images that can be processed, etc.
%
%     DISPLAY A major change was made in the way that the display handles
%        the left/right orientation of images. A switch is provided on
%        the main menu to select the orientation of the input images on
%        disk. Radiological images (Left is anatomical Right) are
%        flipped automatically to Neurological (Right is anatomical right)
%        orientation for display only. Thus, display is always Neurological
%        assuming input orientation is correctly specified. Routines that
%        require correctly oriented coordinates from the display were
%        equipped with an option to check the setting on the main menu.
%        These include: VOI values, ROI template and GROUP replay, IMAGE VIEW, 
%        Hemi-Image R/L, Statistical Mapping, Assymetry, Transparency, etc.
%      
%     ATLAS Two Atlas images were provided one with 68 planes (LR) and one
%        with 69 planes (RL) to accommodate normalized files in routines
%        that require matched dimensions and orientation. 
%
%     GROUP ROI Several corrections and additions were made including the
%        relabeling of a misnamed L/R region.
%
%     ROUTINES that were rarely used or no longer needed were removed.
%        These included the alternate spm99 based browser, the image tile
%        routine, postscript file display, etc... Some new routines such as
%        Atlas GIS ROI mapping were added separately or were imbedded
%        in existing routines such as the evaluation of the L/R Assymetry
%        Index in Image Processing, evaluation of the Jackard Similarity
%        Index and histogram display in the image (GIS)correlation routine,
%        added global value and standard deviation to the image mean output
%        program and standard deviation to the output of the ATLAS Group
%        ROI SUMn file. Improvements such as added help and documentation
%        were added throughout.
%
%   REVISION 6.3w Released Feb. 18, 2014
%
%     CORRECTIONS Several corrections were made to remove bugs in secondary
%        programs such as transparent display and multi-image view and to  
%        improve over-all function in various utilities and routines.
%
%     TPR  Improved options include easier access to reference PCs that are
%        not stored in the standard default directory, optional specification
%        of controls and provision of scatterplots following recalibration.
%
%     REPEATED TPR  This routine was made widely interactive and generalized to
%        allow for unlimited multiple trials, paired measures as well a independent,
%        variable sized prospective group evaluation, options for either direct,
%        mean normalized or Z-score output that can be in reference to either baseline
%        or derivation group scores.
%
%     BROWSER  A new option in the default browser to re-sort alphabetically a 
%        composite file selection list as well as prominent warning regarding the 
%        automatic internal alphabetic re-ordering of selected files were provided.
%
%     VOI The volume of interest(VOI) routine was modified to exclude 0
%        values from regional volume averaging and provide the min, max
%        value range as well as x y z coordinates in mm units.
%
%     MARKER New XYZ Marker utility placed geometric markers at selected image points.
%
%
%   REVISION 6.2.1w Released Apr. 29, 2013
%        Several minor modifications were made in routines to 
%        remove bugs and improve documentation and processing.
%        Notable Changes:
%        1) Multiplacation and Division of Integer Type images will only modify SCALE
%           and will not convert Type to Float.
%        2) A flag is provided to check for .nii Nifti types and advise users.
%        3) A new option in Conversion of Nifti to Analyze format will allow the user
%           to convert from Radiological to Neurological orientation at the same time. 
%        4) Documentation regarding XYZ Talairach coordinates and Neurological
%           vs. Radiological Orientation is noted in several modules.
%        
%   REVISION 6.2w
%
%   CURRENT DIR 12/29/2012. On QUIT or RESTART, ScAnVP saves the last
%        current directory in a .mat file in the scanvp\work directory and
%        retrieves it on initial scanvp entry or restart. It creates a scanvp\work\
%        directory if none exists. The user need not perform work in this directory.
%
%   GIS CORRELATION 11/21/2012
%       For thresholds above 0, an OR operation rather than the previous AND is
%       performed to include voxels that are above the threshold in at least 
%       one image of an image set. Pairs within multiple sets of images are 
%       evaluated separately with regard to processed voxel space.
%
%   MRI ANATOMICAL IMAGES 11/13/2012
%        Separate MRI background images were provided for spm5 dimensioned 
%        (Radiological) and LR (Neurological) orientation images. LR indicates
%        that left is viewed as left, etc. These were renamed to reflect if
%        they are spm99 or spm5 normalized images.
%
%   NIFTI IMAGES. 11/12/12 Programs do not require input images to be converted 
%         to Analyze format. However output images are saved in ANALYZE format.
%
%   ROC CHARACTERISTICS 10/31/2012: Reads score files (subjects vs. scores) 
%        and outputs several plots including bar and scatter plots and ROC 
%        AUC and accuracy vs. score cutoff plots. Prints text file of sensitivity
%        vs. specificity values and evaluates sensitivity for user keyed specificity.
%
%   GRAY MATTER MASKS 9/2012: A new symmetric gray matter mask is provided
%        as default (PETmask.img) for the ssm routines to replace the 35% of max 
%        lower threshold default. The user can replace the default masks 
%        with their own or use one of the masks provided. 
%        Defaults PETmask5.img and PETmask99.img are included to allow for
%        processing of spm99 or spm5 normalized images. These can correspond
%        to symmetric masks(also included) derived from a set of 72 healthy subjects
%        using a corresponding lower threshold 38% or 40% of subject maxima.
%        Individual 0/1 masks are multiplied and the final mask is right-left symmetrized.
%        
%   NEW ROUTINES FOR REPEATED MEASURES 2/2012
%        vp_ssm_autovoxrepeat: Voxel based SSM Automatic Topographic Profile Rating (TPR)
%        of SSM subject scores for a repeated set of tasks or states using
%        a pre-defined GIS. Calls new function vp_scatterpairsplot to plot repeated
%        measures scatter plots and derive paired t-test p values.
%
%   NEW ROUTINES FOR SSM-PCA 1/2012
%       vp_ssmpca:  This is a function that fully implements the Scaled Sub-Profile Model
%       (SSM-PCA) analysis of voxel-based image data using MATLAB code replacing 
%       the previous 'dos' .exe c-source code routine. PCs are sign-flipped if disease
%       subject scores are lower than control scores. Improvements include
%       optimized memory handling, a default mask, srp files and GIS files > 16
%       are not output unless requested. 
%
%   MEMORY USE: Many of the existing SSM MATLAB routines were optimized for
%       memory usage.
%    
%   LINEAR GIS ADDITION and %VAF Calculation  12/6/2011
%       Added an automatic %vaf calculator for logistic and linear regression
%       determined coefficients. The combined value is saved in the score 
%       output and on the gui interface. 
%       The %vaf calculator also works independently for user specified constants. 
%
%   TPR SCATTERPLOT 9/22/11
%       Added ability in the Score File Display option to create a scatter plot
%       of scores in TPRScore files and allow specification of control subjects
%       for the evaluation of p values.
%
%   IMAGE PROCESSING Sl/Gp options 9/20/11
%       Several routines required a mask and a threshold (default .35).
%       The threshold default was set to 0 and both the mask and threshold
%       were allowed to be overridden by pressing CANCEL when prompted.
%       Options affected included global mean normalization and evaluation
%       masking and fractional thresholding, z-score and vector image normalization.
%       The mean value output file was upgraded to output number of threshold voxels.
%
%   SCANVP HELP 7/12/2011
%       A Special Topics option was added in the main menu to allow reading of
%       non MATLAB documentation and text files, e.g. 'word' (.doc), etc. .
%
%   ANALYZE HEADER STRUCTURE 7/7/11
%       A routine to save Analyze header global values in a structure and
%	    restore when needed was added to facilitate programming.
%       
%   IMAGE LABELLING  7/7/11
%       The image voxel point value utility was expanded to additionally display 
%       an anatomical label for any point pointed to by the viewer based on the 
%       scanvp\templates\BRAIN_ATLAS default coded image. 
%
%   GIS CORRELATION PLOT  7/5/11
%       Feature added to create a scatter plot of the voxel correlation of two
%       sets of image values. 
%
%   COLORBAR 6/2011
%       The JET Colorbar was replaced with one that has black as the lowest color
%       in the default display and replaced HSV on the color gui menu. Modification
%       was also made to the GE colormap to add yellow to the upper map same as JET.
%
%   REVISION 6.1 
%
%   INTERPOLATION 5/1/11
%       Added option to allow batch processing of image files.
%
%   NEW GET_FILE BROWSER 4/26/2011
%       Provided a new get_file.m browser that is totally independent of
%       spm. Lists of files from different directories are added in separate
%       operations. User can review the list before completing selection to
%       avoid possible alphabetical reordering when order is important. 
%
%   EXCLUSIVE MASK 4/4/2011
%       Corrected exclusive range other than 0,0 set 0 values to 1.
%
%   IMAGE PROCESSING 3/2011
%       Added a SHIFT option to allow shifting of image data in any
%       direction while the origin coordinates remain the same. 
%
%   MASK IMAGE PROCESSING 11/11/2010
%       Any non-real NaN voxel values are set to 0 on output.
%
%   TPR OPTION FOR NO GROUP MEAN REFERENCE FILE  11/18/2010
%       This new option for interactive TPR allows the users to generate
%       TPR scores for subjects in the absence of any (log) data mean deviations
%       reference file. Data is centered with respect to the subject (log) data 
%       mean (row centered) and not with respect to the group mean 
%       (not column centered). Thus SRP is not evaluated. Absolute
%       score values should differ only by a constant (the group dependent 
%       mean score or GMP score) from scores generated using a group mean file.
% 
%   LOGISTIC GIS ADDITION and SSF FILE OUTPUT  3/3/2010
%       For the linear combination of GISs routine, the user is given
%       the option to determine the GIS component coefficients either
%       by logistic or linear regression. Outputs SSF Score Files.
%
%   ORTHOGONAL IMAGE DISPLAY 2/3/2010
%       The orthogonal view routine (vp_imvorth) was modified to allow copies
%       of the active display to be saved in independent figure windows.
%
%   BLACK BACKGROUND IMAGE DISPLAY 2/3/2010
%       Another option sets the window background to black.
%
%   PAIRED IMAGE PROCESSING  1/24/2010
%       The second image in each pair can be the same image entered once.
%
%   IMAGE PROCESSING MULTIPLE SCALEFACTORS  1/24/2010
%       Options requiring multiple scalefactors can have factors read from a file.
%
%   ROI TEMPLATE 1/13/2010
%       The 'fit' parameter default was set to OFF to avoid problems with
%       improperly set origins in the template and image files.
%
%   GIS CORRELATION 11/17/09
%       Added Routine to test the correlation of GIS or other images based on
%       the correlation of their corresponding image vector voxels. Both the raw
%       image and the common non-zero voxel (Pierson's rho & R (rho squared)) 
%       values are calculated.
%
%   PATCH OF PET SCANNER IEE IMAGES FOR RE-IMPORT TO DATABASE: 6/2/09
%       Option 4 was added to convertge.exe (DOS) to allow .iee GE database image
%       files that give a "colormap" error to have the colormap fields removed.
%       Output is an .iee image that can be imported on UNIX using IEIMPORT.
%
%   REVISIONS 5.9.w 4/25/2008
%		
%   FDG GLUCOSE FUNCTIONALIZATION 5.9 4/21/08
%       The FDG Glucose functionalization routine can now also work with ANALYZE
%       image data values greater than 8bit (TYPE > 2).
%
%   DOCUMENTATION 5.9 4/10/09
%       A separate documentation directory was provided for non-runtime 
%       text and word access including instructional guidance for SSM.
%
%   SCREEN OUTPUT 5.9 4/3/08
%       Options are provided to set the active and default figure screen 
%       background color, and to allow inversion of background and text
%       colors on hardcopy and file output for any subsequently created
%       figures.
%
%   ANAHDR routines 5.9 4/1/08
%       The ANAHDR routine will now flag UNIX and NIFTI header files.
%
%   BUILT IN PATH for ScAnVP\bin\DOS routines 5.9 4/1/08
%       The system path need not be set for ScAnVP\bin\DOS executable routines.
%	
%   SPM WRITE ROUTINES 5.9 3/24/08
%       Old spm99 image write routines that were incompatible with spm5 were replaced 
%       replaced with scanvp routines.
%
%   IMAGE PROCESSING  5.9  3/14/08
%       Modifications were made to improve resolution on some conversion options.
% 
%   DISPLAY UTILITIES: 5.9 2/4/08
%       An Option was added to allow the default hardcopy invert screen and
%       text colors ON/(OFF) property to be set by the user rather than by startup.
%
%   SSM VOX/PCA: 5.8.5 3/5/08
%       The SSM VOX PCA routine now flags out NIFTI and UNIX format files.
%
%   SPM NIFTI TO SCANVP READ/CONVERT 5.8.5 3/5/08
%       Nifti UNIX format to DOS conversion and addition of a Value OFFSET (intercept)  
%       can now be automatically handled by the NIFTI -> ANALYZE conversion routine.
%       The NIFTI-> ANA routine can convert nift1 .nii type images and will
%       prompt the user to convert to ANALYZE format necessary for display and SSM. 
%
%   SPM NIFTI TO SCANVP READ/CONVERT 5.8.3 1/14/08
%       Modifications were made to allow scanvp MATLAB routines to display and process
%       spm5 image files (with the correct ORIGIN) properly without previous conversion.
%       Any output is converted to ANALYZE. For scanvp DOS routines (notably, VOXEL PCA),
%       a previous conversion to ANALYZE is needed and a 'convert' NIF-> ANA option
%       is provided. If images are in UNIX format they must be converted to DOS format
%       and the ORIGIN (pre-noted in SPM) can be patched using the FIX ORIGINS routine.
%
%
%   REVISIONS 5.8.2.w 7/19/07 
%
%   SSM VOX/ROI PCA/TPR: 5.8.2.w 5/17/07 - 7/10/07
%		A new VOX PCA GUI interface was provided for selecting options.
%		Specification of Control subjects was made optional for all
%		VOX and ROI based SSM options. Empty reference directories
%       were provided for saving network files.
%
%   STATISTICAL MAP: 5.8.2.w 5/6/07
%		For INCLUSIVE mapping all values within and including the threshold
%		limits are included except a lower threshold value 0. 
%		For EXCLUSIVE mapping all values within and including the 
%		threshold limits are excluded.
%
%   CONVERSION OF PET SCANNER IEE IMAGE TO ANALYZE: 5.8.2.w 5/3/07
%		An Option is provided to save data as 16bit integer
%		or convert to 8bit as in previous versions.
%
%   LINEAR GIS ADDITION: 5.8.2.w 4/19/07
%		For the linear combination of GISs routine, the input
%		coefficients and GIS vectors can be normalized on
%		input (default) and the GIS output can be Z-scored or vector
%		normalized (the sum of the square values equals 1).
%
%   GROUP ROI ATLAS IMAGE TEMPLATES: 5.8.2.w 2/07, 4/09/07
%		Group roi templates can be predefined on a ROI BRAIN ATLAS
%		image where each region is identified by a fixed coded value 
%		for each voxel within a given region type and orientation.
%		The region index value and label name must be listed numerically
%		in a separate text file with the name AtlasNameLabs.txt.
%		Following an initial text line defining the file, each region is
%		listed in numerical order as num name or num name_L or num name_R.
%		After selecting the group images and ATLAS image, AUTO mode
%		processing can be performed using Fixed 3D and 2D as well as
%		lower limit thresholds. Limit planes are user specified.
%		Interactive mode and variable thresholding and .roi type TEMPLATE
%		output are not operational for the ATLAS option.
%		Regions can be selected by keying in their numbers separated by commas
%		or by a colon for a range of regions. Only those regions will be output.
% 
%   SINGLE-SUBJECT TPR 5.8.2.w 11/27/06
%		The scatterplots of scores produced by the routine also display
%		p-values for the hypothesis of equal means of subjects versus
%		reference normals. For multiple subjects an F-test for equal 
%		variance is performed followed by a ttest corresponding to equal
%		or unequal variance (using MATLAB ttest2 or added function tutest2). 
%		For single subjects the result of the MATLAB ttest was used but
%		this may not be appropriate. 
%
%   IMAGE PROCESSING 5.8.2.w 
%		5/08/07
%		A new option was added to allow the creation of INCLUSIVE MASKS using
%		specified values and value ranges. (can extract regions from ATLAS image)
%		4/27/07
%		Images are converted to 32bit float for most operations that manipulate 
%		values. 
%		4/27/07
%		Vector and Z-score normalization options for images were added. 
%		4/09/07
%		An Option was added to allow zero-value padding of images in any
%		X Y or Z direction.
%
%   REVISIONS 5.8.w 04/03/07
%		Publicly distributed version.
%
%   IMAGE PROCESSING 5.8.w 
%		3/22/07
%		Options were added to allow arithmetic operations such as addition,
%		subtraction, multiplication and division of images using the same 
%		or different constants for each image.
%		3/13/07
%		An Option was added to allow rectangular CROPPING of images.
%		9/10/06
%		A multi-image processing EXCLUSIVE SIGN option was added to allow 
%		voxel values to be set to zero on the first image if they have the 
%		same sign as corresponding voxels on a subsequent image in the set.
%
%
%   REVISIONS 5.7.w 11/22/06
%		Publicly distributed version.
%		Minor improvements were made including a display of the
%		p-value for the test hypothesis of equal means in pca scores and
%		TPR analysis assuming equal variance and a 0.05 confidence level.
%
%   REVISIONS 5.7
%
%   REFERENCE IMAGES   5.7 7/24/06
%		Several pet images (rgray.img, rcsf.img, rwhite.img) borrowed 
%		from spm and brainmask.img derived from rgray.img have been added
%		for reference under scanvp\pet and scanvp\mask.
%
%   GROUP ROI PROCESSING   5.7 7/22/06
%		New options allow masking and global normalization to be performed
%		on images that are processed by the group roi routine.
%		The output Summary reports indicate the mask name and if global
%		normalization was performed as well as template names.
%
%   IMAGE PROCESSING 5.7
%		7/18/06
%		An option was added to allow masking of images as a SINGLE/GROUP op.
%
%		5/31/06
%		The global normalization routine under SINGLE/GROUP operations
%		will now ask for a user-selected mask to apply on each image
%		before optional thresholding followed by division by the subject
%		mean. The means can be printed out as a separate option.
%
%		2/7/06
%		An option was added to the SINGLE/GROUP operations set to printout the
%		global means of a set of optionally masked and thresholded images.
%
%   SSM ORTHOGONAL VOX PCA    5.7 5/26/06
%		SSM Voxel Orthogonal PCA No-mask option has been removed. 
%
%   SSM SCATTER PLOTS	5.7 5/21/06
%		ZScores for VOXEL PCA, automated TPR and AUTO Diagnosis 
%		routines are now plotted in both scatter plot form as well as 
%		bar graphs and display the mean and std of the reference data.
%		
%
%   SSM ORTHOGONAL VOX TPR    5.7 3/16/06
%		SSM Topographic Profile Rating on Orthogonal Data 
%		This application of SSM is used to remove the covariance
%		attributed to a given previously derived GIS from a group
%		of one or more subject images and evaluate the TPR scores
%		due to another GIS on the reduced orthogonal image data.
%		Both the SRP due to the first GIS and the Orthogonal SRP
%		for each subject are saved. 
%
%   SSM AUTO VOX TPR    5.7 12/29/05
%		The memory utilization of automated TPR voxel routine has been
%		optimized so that it can now handle any number of subjects
%		since each is processed separately.
%
%   SSM Score Files   5.7 12/23/05
%		The display SSF score program now allows you to save a Reference
%		Score file for a selected GIS from a set of SSF score plots.
%
%   REVISIONS 5.6
%
%   SCANVP - 5.6 11/22/05
%		A revised main menu interface has been provided.
%		A pet directory with one normal pet image is included.
%		A 39 ROI template has been added.
%		
%   SSM - VOXEL BASED MEMORY OPTIMIZATION SSM 5.6 11/21/05
%		VOXEL based SSM TPR and Orthogonal PCA routines were
%		optimized to make better use of memory resources.
%
%   SSM - LINEAR COMBINATION OF VOXEL GIS COMPONENTS 5.6 11/10/05 
%		A separate utility was provided for GIS linear combinations of
%		multiple components with default vector normalization of input
%		GIS components and ZScore conversion of the output GIS.
%
%   IMAGE PROCESSING 5.6 11/10/05
%		Image processing applications were divided into separate
%		categories involving SINGLE, MULTIple, PAIR image and
%		supplementary operations.
%		Pair-wise operations were enabled for dual image sets of 
%		corresponding images for various functions such as averaging,
%		division, multiplication and exclusion of common voxels and an
%		interface was provided with options for global normalization,
%		scaling and auto-naming. Operations are applied to corresponding
%		voxels. For MULTI image operations, a single output image is 
%		created. Additional options are provided for vector normalization
%		of the input component images and for ZScore conversion of output.
%
%   STATISTICAL RATIO MAP 5.6 10/11/05
%		Statistical results from two separate processes can be displayed
%		as a ratio of values with options for scaling, masking and
%		global normalization. Equivalent results can be obtained using
%		the paired division option under Image Processing.
%
%   SSM - VOXEL BASED SUBTRACTION SSM 5.6 9/27/05
%		A new option was provided to enable SSM analysis of differences of 
%		two sets of corresponding images representing separate states for
%		the same subjects.
%
%
%   REVISIONS 5.5 
%
%
%   SSM INTERFACE 5.5 7/08/05
%		A new interface has been provided for many of the SSM routines
%		with clarification of available options and improved Help.
%
%   MASKING     5.5 6/7/05
%		Masking of images corrected to save the same data type as the original.
%
%   SSM AUTO TPR RECALIBRATION  5.5 for VOX 5/25/05 and ROI 7/21/05
%		An automated TPR RECALIBRATION procedure was added. This procedure
%		automatically sets up a new group GIS network directory and
%		reference files for a preexisting GIS that is evaluated for a new
%		group or environment. The new reference network files which include
%		the GIS, scores, mean and mask files can subsequently be used for 
%		automated single subject TPR in the new environment. 
%
%   IMAGE READ OPTIMIZATION 5.5  5/25/05
%		The scanvp volume read function was optimized allowing faster
%		response for various image display and processing functions.
%
%   FUNCTIONALIZATION 5.5  5/10/05
%		The MATLAB interface for single scan FDG glucose was modified
%		to allow processing of files deeply nested in multiple directories.
%
%   REVISIONS 5.4
%
%   HELP ROUTINES 5.4 2/10/05
%		A list of naming conventions for output files has been provided. 
%
%   GUI INTERFACE 5.4 11/12/04
%		Improvements include an initial prompt to set the Curent Directory.
%		A new SSM GUI interface was designed to help clarify SSM options.
%
%   IMAGE PROCESSING
%		Global mean normalization 5.4 12/2/04
%		An option was provided for perfoming subject global normalization.
%		Image values are divided by the subject's mean thresholdeded value.
%		The lower threshold is determined as a fraction of the subject's max.
%
%	  	Smoothing 5.4 9/13/04
%		A new Option allows the user to smooth an image using a user specified
%		box convolution kernel. The output file is assigned an 's' prefix.
%
%   SSM                 5.4 2/4/05
%		Improvements were made to the user interface, to memory handling
%		and in the presentation of bar graphs of the output scores.
%		For TPR a graph of combined new and reference subject scores 
%		is displayed on exit with Z scores offset from control values.
%		Control and new subject's are specified separately and are
%		indicated on output.
%		User friendly recalibration procedures are provided.
%		See additional details below.
%
%   SSM NETWORKS        5.4 3/3/05
%		Network reference files are provided for AUTO-TPR scoring of
%		subjects for conditions such as PDRP and HDRP.
%
%
%   SSM AUTO VOX TPR    5.4 1/26/05
%		The automatic option has been implemented for voxel based analysis
%		and operates in a way similar to the ROI version.
%		Files that must be included in the named STUDY network
%		subdirectory for hypothetical disease/condition 'COND' are:
%
%			EXAMPLE
%		        scanvp\network\COND\VOX\STUDY  (VOXEL TPR REFERENCE FILES)
%
%		        lnmean file:	STUDY_lnmean.img, STUDY_lnmean.hdr
%		        GIS file:	STUDY_gis001.img, STUDY_gis001.hdr
%		        REF Score file:	STUDY_VScores1.txt
%
%   SSM ROI TPR    5.4 1/06/05
%		The automatic roi tpr option, requires the presence of a mean
%		text file and reference scores for each reference gis.
%		The interactive version provides an option for recalibration
%		of group scores from a group summary report, if reference files
%		are not available. 
%
%   SSM VOXEL PCA 5.4 12/09/04
%		Modifications were made to allow for log transformation to be
%		an option. Output files can be assigned a study name and results
%		are saved in the MATLAB current directory. The control subjects
%		are now selected separately and their number id is posted in the
%		ouput scores file. Bar graphs of scores for each gis can be
%		displayed on exit.  
%
%   SSM AUTO ROI TPR    5.4 9/21/04
%		The automatic option has been further simplified by using standard
%		names and requiring log transformation which in now an option only
%		in interactive mode. Automatic naming of network subfiles is similar
%		to that shown in the following example corresponding to PCA output.
%		To allow automatic access to results using AUTO TPR, the resulting
%		files should be placed in a directory corresponding to the named
%		condition (COND in the example) as a subfile under scanvp\networks.
%		The pre-assigned gis id (1 in the example) is a text string that
%		can be edited by the user. A summary report (STUDY_SUM(3D)_c.txt,
%		can be provided but it can only generate Z scores in interactive mode.
%
%				EXAMPLE (INCLUDED ROI TPR REFERENCE FILES)
%		                scanvp\networks\COND\ROI\STUDY
%
%				lmean file:	STUDY_lmean.txt
%				GIS file:	STUDY_gis2.txt
%				REF Score file:	STUDY_RScores2.txt
%
%   SSM Score Files   5.4 9/16/04
%		ROI score files are designated as ...RScores.txt or ...ZScores.txt to 
%		differentiate between Reference and Z Scores. Reference score files
%		have a REF designation in the title line. For Voxel based analysis
%		the reference files are named ...VScores.txt and ...VZScores.txt.
%		The display routine can differentiate between file types and also
%		indicates control subjects read from formatted score files.
%
%   REVISIONS 5.3
%
%   SSM AUTO ROI TPR ZScores   5.3 8/5/04
%		A highly automated ROI TPR ZScore routine was provided to produce
%		values comparable to previous reference Z score values.
%		The user may add new directories containing key output files from 
%		PCA analysis to the ScAnVP networks directory for subsequent auto-TPR
%		scoring of new subjects.
%
%   SSM ROI ZScores 	5.3 8/1/04
%		ROI PCA and TPR Z scores are now offset from normal subject values.
%		Normals indeces are saved on output and indicated on plots.
%		User must specify a reference raw score file for Z score consistency.
%		
%   ROI PARAMETERS	5.3 7/26/04
%		SOR Plots now plot SOR-1 values.
%
%   SSM Mean Offset 	5.3 7/15/04
%		Option for VOX PCA using SRP offset from a predefined lnmean reference.
%
%   SSM Utilities	5.3 6/15/04
%		New voxel utility options allow the user to create SSM based
%		group log mean images, group threshold masks and exclusive
%		range masks from existing data or gis image files. 
%
%   Image Processing  	5.3 6/03/04
%		New Option enables user to exclude range of values from a selected
%		image file. The user can also create an exclusive mask. 
%
%   SSM Networks 	5.3 5/15/04
%		The PDRP GIS network images were corrected for flipped sign.
%		A lnmean reference image was provided.
%
%   SSM Results 	5.3 4/15/04
%		New options provide graphical display of SSM score/gis file results.
%
%   Multi-Image Display 5.3 3/30/04
%		Correction made for images that contain "." in file names.
%
%   ROI Mask            5.3 3/24/04
%		A bug was removed that prevented the file save operation.
%
%   SSM Routines        5.3 3/17/04
%		SSM routines have been updated so that they can read both ScAnVP
%		formatted 'srp' and 'ssf' text files as well as unformatted text input.
%		ROI based gis output files have also been formatted for output and input.
%
%   SSM Scores          5.3 3/11/04
%		SSF score file names now include the word Score in default names.
%		These files can now be automatically read for a wider range
%		of output formats. Also, the GIS No. is auto incremented for
%		sequential bar graph displays of score values. 
%
%   ROI GIS Mapping     5.3 3/03/04
%		A bug was removed that prevented pre-smoothing in Auto. mode.
%		Routine can now read standard SSM output formatted files.
%
%   Stat. Mapping       5.3 2/25/04
%		A correction was made to allow user name specifications for
%		output files necessitated by a bug not present in 5.1.
%
%
%   REVISIONS 5.2
%
%   SSM Scores		5.2 2/04/04
%		Display bar graphs of SSF scores for selected
%		GISs. Data is read from SSM analysis score output files.
%
%   Current Directory	5.2 11/26/03
%		A Current Directory Button was added to the main ScAnVP
%		Menu to invoke the Matlab file browser used to change the
%		current directory and view its contents. The file selection
%		browser defaults to the Matlab current directory on start up.
%		It serves as a default output directory.
%
%   File Names		5.2 11/24/03
%		Corrections were made to allow certain routines to read file
%		names properly in cases where the parent directory contains
%		a "." in the directory name.
%
%   Dynamic/Multi-image Display       5.2 11/13/03
%		A single plane section from multiple image sets or dynamic
%		sequences of the same subject can now be displayed using 
%		image view options.
%
%   Rotated Views       5.2 11/06/03
%		The Rotated image display option has been modified to 
%		allow rotations around any axis and angle. The rotated
%		views can be orthogonally sectioned and displayed or 
%		animated.
%
%   Crop/Zoom Images       5.2 11/03/03
%		The image volume can be zoomed and cropped using the
%		orthogonal image display. The new volume can then be saved.
%
%   Set New Origin       5.2 10/24/03
%		The origin can be reset for an image displayed by the 'imview'
%		routine by setting the origin to the view point and saving
%		the image. A separate utility can be used for sets of images. 
%
%   Convert GE PET      5.2 9/30/03
%		A bug involving the conversion of GE PET .iee
%		files with long names was removed.
%
%   Group Roi Reports   5.2 9/25/03
%		A bug involving Group Summary Reports for
%		images with 0 thresholded pixels was removed.
%
%   Hemi-Image/Mask     5.2 9/19/03
%		A routine was added to allow the user to filter
%		out the right or left half of an image or mask
%		by assigning zeros to the opposite side.
%
%   SSM/tpr/opca	5.2 9/12/03
%		Memory handling was improved to allow larger voxel set processing.
%		Other minor corrections were made.
%
%   Browser		5.2 9/12/03
%		The browser get_file was modified to include the scanvp directory
%		in previous directories for easy access to reference files such as
%		templates and networks.
%
%   REVISIONS 5.1
%
%   NEW DIRECTORIES  5.1 8/2003		
%		Three new directories are provided.
%		templates/ stores pre-defined regional templates.
%		networks/  stores pre-derived SSM-PCA GIS network profiles.
%		mri/ provides a normalized normal MRI ANALYZE reference image.
%	  	
%   PCA - ROI Based 5.1 7/2003
%		ROI based ssm pca analysis has been enabled as a Matlab
%		routine that requires as input summary output files in the
%		format created by ScAnVP's 'grouproi' composite summary reports
%		and creates several output files including SSF scores and GISs.
%	
%   TPR - ROI and VOX Based  5.1 7/2003
%		The Topographic Profile Rating (TPR) of new subject's with respect
%		to previously derived disease related topographic patterns (GISs)
%		has been enabled in this version as ROI or VOXEL based ScAnVP Matlab
%		routines with several input options for subject score determination. 
%
%   ORTHOGONAL PCA - ROI and VOX Based  5.1 7/2003
%		In this special application of SSM the covariant component of a 
%		specified pattern (GIS) is removed from the group data set or 
%		SRP before performing PCA analysis, to allow other less prominent
%		patterns to be determined in the orthogonal space.
%		need conversion.
%	
%   GROUP THRESHOLD MASKS 5.1 7/2003
%		Group threshold mask (0|1) images can now be created and applied to 
%		convert images as a standalone option of the Statistical Mapping
%		routines.
%
%   SSM-PCA Voxel Based 5.1 6/2003
%		Changes were made to ssmpca.c to make its GIS output similar
%		to that of the executable version provided by Dr. Marc Mentis
%		that has been in use since Nov. 19, 1998. However, there are
%		some notable differences. Natural log transformation is now
%		performed by the routine ssmpca.exe and is not an option.
%		Input data should be geometrically normalized but need not
%		have the same scalefactors. The mean log data image normalized
%		to whole brain is now printed out and is derived as the mean
%		image across subjects after each pixel value is replaced by 
%		its difference from the subject's mean.
%		Only significant pixels are evaluated based on an
%		optional input mask file. The creation of a default mask
%		provided for in the original code has been enabled and
%		assigned the customary lower threshold of .35 of max..
%		This value can be overriden by specifying the second argument
%		using three chars.: T[00-99]. The coordinates of the origin
%		of the normalized files is now retrieved and saved in the GIS
%		and SRP output headers. SRP files are now generated individually
%		for each subject. In addition to the routine printout, a summary
%		file (SSF_Scores.txt) is output containing the "%Variance
%		Accounted For" for the first 15 principal components, a
%		list of the file names and the corresponding SSF values.
%		An additional option allows SRP files to be input for PCA analysis
%
%   UNIX<-->DOS
%   Multiple Volumes 5.1 5/22/2003
%		ANALYZE image files that contain multiple volumes are now
%		saved as separate files by the UNIX<->DOS conversion process.
%		ScAnVP does not otherwise process such files.
%		Repeating the UNIX<->DOS conversion on the separated files will
%		convert them individually to the original DOS or UNIX format.
%		The two pass procedure can be used to separate a file that doesn't
%
%   Image Processing	5.1 3/17/2003
%		a) A Natural Log option has been added for image conversion.
%		b) The interactive naming option can now be overidden for some
%		batch operations by selecting 'auto'.
%
%   vprename.exe        5.1 2/24/2003
%		An option was added for automatic renaming of DTI files 
%
%   Notes               5.1 2/24/2003
%		The Notes option refers to revisions made before ScAnVP version 5.0.
%
%________________________________________________________________________________________
% vp_revisions.m  7.0w                Phoebe Spetsieris, Ph.D.  Feb. 01, 2016 
%

	vp_help('vp_revisions');
	
