function out1 = vp_roidrpt
%_______________________________________________________________________
% function vp_roidrpt.m		C.0 Phoebe Spetsieris  Feb. 23 1999
%
%  Display 2D statistics for all Regions of Interest (ROI) in a plane
%	Threshold Mode must be two dimensional fixed or variable modes
%	A fixed threshold minimum is defined for Threshold Mode 5 
%
%	No.:	 Lists Sequential Region No.
%	TYPE:	 Ellptical, Rectangular or Irregular
%	LABEL:	 Label Id (Standard Nos 1-100 and Non. Standard > 100),
%		 followed by R,L or Blank for Right, Left or Center Orientation.
%		 and Standard or Non-Standard Label Names
%	NPX:	 Number of Pixels in Roi.
%	THR(%):	 Region %Threshold (%of region Max relative to Global Min)
%	ThPX:	 Number of pixels within threshold limits.
%
%	MX/MN:   Maximum and mininum of threshold pixels
%	RMSD:	 Root mean square deviation of threshold pixels
%	Mean:	 Mean of threshold pixels
%	
%_______________________________________________________________________


global LabIds LabNames Thresholds PlaneNo
global FName Message herr Ecolor
global ThreshMode FixedThMin HelpMode HelpMsg

if HelpMode, vp_help(mfilename), return ; end;

Message=['..................................'];

txcolor1=[0 0 1];
txcolor=[0.6 0.2 0.5];

out1=0;
      
  if ThreshMode==2 | ThreshMode==4 ,
  	Message=['Invalid 3D Threshold Mode'];
	out1=-3;
  return, end;
  
  
  lh=findobj('Tag','roi');
  
  if isempty(lh)
  	Message=['REPORT: No Rois Found'];
	out1=-1;
  return, end;
  
  nr=size(lh);
  
  dy=50*nr(1);
  if dy < 200, dy=200; end;
 % if dy > 600, dy=600; end;
  
  %hroigui=findobj('Name','gROIgui');
  %set(hroigui,'Visible','off'); 
       
  delete(findobj('Name','REPORT'));
       
	
  hstat = figure('Color','w','Name','REPORT',...
	'NumberTitle','off','Position',[25,50,660,dy],...
	'Pointer','Watch',...
	'Units','Pixels','Visible','on');
	
   axis off;
	
   textstr=sprintf('ROI STATISTICS  %s       Plane: %d   NRois: %d',FName,PlaneNo,nr(1));
   %textstr=['ROI STATISTICS   ',FName,'    Plane: ',num2str(PlaneNo),'   NRois: ',num2str(nr(1))];
   text(0.0,1.0, textstr,...
	'FontName','Times','FontSize',12,'FontWeight','bold',...
	'VerticalAlignment','Middle',...
	'HorizontalAlignment','Left',...
	'Color',[0 0 0]);
	
   dy=1/(4+nr(1));
   pos=1.0-dy;
   textstr=['No.  TYPE      LABEL                      NPX   THR(%)  ThPX    MX/MN    RMSD    MEAN'];
   text(0.0,pos, textstr,...
	'FontName','Times','FontSize',10,'FontWeight','bold',...
	'VerticalAlignment','Middle',...
	'HorizontalAlignment','Left',...
	'Color',txcolor1);
	
   for i= nr(1):-1:1
   	pos=pos - dy;
	udata=get(lh(i),'UserData');
	nroi=udata(1);
	roityp=udata(2);
	
        textstr=strcat('No. ',num2str(nroi));
	if roityp == 1, type ='Re';
  	  elseif roityp==2, type = 'Ell';
	  else type= 'Irr';
	end
	%labname=deblank(LabNames(nroi,:));
	labname=sprintf('%.24s',LabNames(nroi,:));
	labid=sprintf('%.5s',LabIds(nroi,:));
	
       % Two dimensional rois only
       
	if (ThreshMode == 5) 
		% Fixed Minimum Value
        	[nt me sd ne mn mx]=vp_roifuns('stat',nroi,2,FixedThMin);
	else
		% Variable or Fixed Threshold
        	[nt me sd ne mn mx]=vp_roifuns('stat',nroi,0);
	end
	
	
	[textstr,Message]=sprintf('%d   %s   %s %s ',...
			nroi,type,labid,labname);
	text(0.0,pos, textstr,...
	'FontName','Times','FontSize',10,...
	'VerticalAlignment','Middle',...
	'HorizontalAlignment','Left',...
	'Color',txcolor);
	
	[textstr,Message]=sprintf('%5d    %5d      %5d     %.2f/%.2f    %.2f       %.2f',...
			ne,Thresholds(nroi),nt,mx,mn,sd,me);
	text(0.43,pos, textstr,...
	'FontName','Times','FontSize',10,...
	'VerticalAlignment','Middle',...
	'HorizontalAlignment','Left',...
	'Color',txcolor);
	
	
   end
   
   set(hstat,'Pointer','arrow');
   set(findobj('Name','gROIgui'),'Pointer','arrow');
   
   herr = uicontrol(hstat,'string', ['MSG: ...............................'],...
   'position',[75 7 420 20],...
   'CallBack',['set(herr,''string'',['' '',Message]);'],...
   'BackgroundColor',Ecolor);

   uicontrol(hstat,'String','UPDATE',...
   'Position',[75 35 80 20],...
   'CallBack',[' vp_roidrpt ;',...
   'set(herr,''string'',Message); '] );
       
   uicontrol(hstat,'String','SAVE',...
   'Position',[200 35 80 20],...
   'CallBack',['set(gcbf,''Pointer'',''watch'');',...
   '[out1,Message]=vp_roirpt(''save''); set(gcbf,''Pointer'',''arrow'');',...
   'set(herr,''string'',Message); drawnow ; '] );
       
   uicontrol(hstat,'String','RETURN',...
   'Position',[400 35 80 20],...
   'CallBack',['set(findobj(''Name'',''gROIgui''),''Visible'',''on''); ',...
   'delete(findobj(''Name'',''REPORT''));']);
   
   
   uicontrol(hstat,'string', 'Help',...
	'TooltipString','Help displayed in MATLAB window',...
	'BackgroundColor',Ecolor,...
   	'position',[550 7 80 15],'callback',...
	['set(herr,''string'',HelpMsg); vp_help(''vp_roidrpt'')']);
       
      
	



