function [out1,out2,out3,out4,out5,out6] = vp_roifuns(action, in1,in2,in3,in4,in5)
%_______________________________________________________________________
% vp_roifuns.m  	ScAnVP C.0	Phoebe Spetsieris  Jan.  29, 1999
%		 	Rev.5.2		P.S.   Sept. 24, 2003 
%		 	Rev.5.8		P.S.   Feb. 2, 2007
%		 	Rev.6.2		P.S.   Apr. 27, 2012
%
% Roi Functions
% Various roi routine functions:
%  Action
%  'labid':	Get Standard Region Names & id labeling numbers.
%		in1=sequential id, out1=standard label, out2=labname
%
%  'labname':	Get Region Name given the label id.
%		in1=standard label id, out1=labname
%
%  'gminmax':	Get the global data minimum and maximum.
%		out1=max, out2=min, out3=xyzdata, out4=status
%
%  'stat'	in1=0, Get statistics for all rois
%		in1= RoiNo, Get statistics for a single roi
%		in2=0, Threshold = given by Thresholds array for RoiNo.
%		in2=1, Threshold = in3, Max=in4, 3D Single roi only.
%		in2=2, Min=in3 (Fixed Minimum).
%		in5= Get statistics for vector array in in5
%		        
%		out1=number of Threshold Pixels,
%		out2=mean, out3=standard deviation
%		out4=number of pixels, out5=minimum th. px., out6=maximum.
%
%  'bytes'	Get number of bytes corresponding to MATLAB type
%		in1=MATLAB type, out1=number of bytes
%_______________________________________________________________________

global SCALE RoiOrient DATA RoiNo Thresholds
global Message SCALE FName MATYPE GMIN GMAX;


out1=0; out2=0; out3=0; out4=0; out5=0; out6=0;

if strcmp(action,'labid') 	
	switch in1
	   case 1
		labid=strcat('2',RoiOrient);
		labName='Hemisphere';
	   case 2
		labid=strcat('5',RoiOrient);
		labName=['Cerebellar Hemisphere'];
	   case 3
		labid=strcat('6',RoiOrient);
		labName=['Vermis'];
	   case 4
		labid=strcat('10',RoiOrient);
		labName=['Pons'];
	   case 5
		labid=strcat('15',RoiOrient);
		labName=['Midbrain'];
	   case 6
		labid=strcat('20',RoiOrient);
		labName=['Basal Ganglia'];
	   case 7
		labid=strcat('21',RoiOrient);
		labName=['Caudate Nucleus'];
	   case 8
		labid=strcat('22',RoiOrient);
		labName=['Putamen'];
	   case 9
		labid=strcat('25',RoiOrient);
		labName=['Thalamus'];
	   case 10
		labid=strcat('29',RoiOrient);
		labName=['Inferior Temporal'];
	   case 11
		labid=strcat('30',RoiOrient);
		labName=['Hippocampus'];
	   case 12
		labid=strcat('35',RoiOrient);
		labName=['Middle Temporal'];
	   case 13
		labid=strcat('36',RoiOrient);
		labName=['Superior Temporal'];
	   case 14
		labid=strcat('39',RoiOrient);
		labName=['Orbito-Frontal'];
	   case 15
		labid=strcat('40',RoiOrient);
		labName=['Operculum'];
	   case 16
		labid=strcat('45',RoiOrient);
		labName=['Posterior Temporal'];
	   case 17
		labid=strcat('50',RoiOrient);
		labName=['Anterior Cingulate'];
	   case 18
		labid=strcat('51',RoiOrient);
		labName=['Posterior Cingulate'];
	   case 19
		labid=strcat('54',RoiOrient);
		labName=['Middle Frontal'];
	   case 20
		labid=strcat('55',RoiOrient);
		labName=['Lateral Premotor'];
	   case 21
		labid=strcat('56',RoiOrient);
		labName=['Sensori-Motor'];
	   case 22
		labid=strcat('57',RoiOrient);
		labName=['Superior Frontal'];
	   case 23
		labid=strcat('60',RoiOrient);
		labName=['Calcerine'];
	   case 24
		labid=strcat('61',RoiOrient);
		labName=['Temporo-Occipital'];
	   case 25
		labid=strcat('65',RoiOrient);
		labName=['Cuneus'];
	   case 26
		labid=strcat('69',RoiOrient);
		labName=['Parieto-Occipital'];
	   case 27
		labid=strcat('70',RoiOrient);
		labName=['Inferior Parietal'];
	   case 28
		labid=strcat('75',RoiOrient);
		labName=['Paracentral'];
	   case 29
		labid=strcat('80',RoiOrient);
		labName=['White Matter'];
	   case 31
		labid=strcat('91',RoiOrient);
		labName=['Other Stndrd. Roi 1'];
	   case 32
		labid=strcat('92',RoiOrient);
		labName=['Other Stndrd. Roi 2'];
	   case 33
		labid=strcat('93',RoiOrient);
		labName=['Other Stndrd. Roi 3'];
	   case 34
		labid=strcat('94',RoiOrient);
		labName=['Other Stndrd. Roi 4'];
	   case 35
		labid=strcat('95',RoiOrient);
		labName=['Other Stndrd. Roi 5'];
	   case 36
		labid=strcat('96',RoiOrient);
		labName=['Other Stndrd. Roi 6'];
	   case 37
		labid=strcat('97',RoiOrient);
		labName=['Other Stndrd. Roi 7'];
	   case 38
		labid=strcat('98',RoiOrient);
		labName=['Other Stndrd. Roi 8'];
	   otherwise	
		labid='101';
		labName=['Non Standard Label'];
	end
	siz=size(labid);
	out1=[labid blanks(4-siz(2))];
	siz=size(labName);
	out2=[labName blanks(40-siz(2))];
	
elseif strcmp(action,'labname') 	
	switch in1
	   case 2
		labName='Hemisphere';
	   case 5
		labName=['Cerebellar Hemisphere'];
	   case 6
		labName=['Vermis'];
	   case 10
		labName=['Pons'];
	   case 15
		labName=['Midbrain'];
	   case 20
		labName=['Basal Ganglia'];
	   case 21
		labName=['Caudate Nucleus'];
	   case 22
		labName=['Putamen'];
	   case 25
		labName=['Thalamus'];
	   case 29
		labName=['Inferior Temporal'];
	   case 30
		labName=['Hippocampus'];
	   case 35
		labName=['Middle Temporal'];
	   case 36
		labName=['Superior Temporal'];
	   case 39
		labName=['Orbito-Frontal'];
	   case 40
		labName=['Operculum'];
	   case 45
		labName=['Posterior Temporal'];
	   case 50
		labName=['Anterior Cingulate'];
	   case 51
		labName=['Posterior Cingulate'];
	   case 54
		labName=['Middle Frontal'];
	   case 55
		labName=['Lateral Premotor'];
	   case 56
		labName=['Sensori-Motor'];
	   case 57
		labName=['Superior Frontal'];
	   case 60
		labName=['Calcerine'];
	   case 61
		labName=['Temporo-Occipital'];
	   case 65
		labName=['Cuneus'];
	   case 69
		labName=['Parieto-Occipital'];
	   case 70
		labName=['Inferior Parietal'];
	   case 75
		labName=['Paracentral'];
	   case 80
		labName=['White Matter'];
	   case 91
		labName=['Other Stndrd. Roi 2'];
	   case 92
		labName=['Other Stndrd. Roi 3'];
	   case 93
		labName=['Other Stndrd. Roi 4'];
	   case 94
		labName=['Other Stndrd. Roi 5'];
	   case 95
		labName=['Other Stndrd. Roi 6'];
	   case 96
		labName=['Other Stndrd. Roi 7'];
	   case 97
		labName=['Other Stndrd. Roi 8'];
	   case 98
		labName=['Other Stndrd. Roi 9'];
	   otherwise	
		labName=['Non Standard Label'];
	end
	siz=size(labName);
	out1=[labName blanks(40-siz(2))];
	
elseif strcmp(action,'gminmax') 
	
	FNimg = [FName '.img'];
	[out4, out3, GMIN, GMAX]=vp_volfuns('xyzdata',FNimg);
%		out1=max, out2=min, out3=xyzdata, out4=status

	out1=GMAX;
	out2=GMIN;

	%%[fid,Message] = fopen(FNimg,'r');
	%%if (fid ~= -1 )
	%%  xyzdata=[];
 
	%%  xyzdata= fread(fid,inf,MATYPE);

	%%  fclose(fid);
	%%  xyzdata = SCALE*xyzdata;
	%%  GMAX=max(xyzdata),
	%%  GMIN=min(xyzdata),
	%%  out1=GMAX;
	%%  out2=GMIN;
	%%  out3=xyzdata;
	%%  out4=0;
	%% else
	%%  vp_message(Message);
	%%  out1=0; out2=0; out3=-1;
	%%  out4=-1;
	%%  return;
	%% end
	
elseif strcmp(action,'stat') 
   if in1== 0
	
	if in2==1, 
	  out1=-1; out6=-1;
	  disp('for 3D statistics, can only handle 1 roi at a time');
	return; end;
	
	lh=findobj('Tag','roi');
	nr=size(lh);
	for i=(1:nr(1))
	  udata=get(lh(i),'UserData');
	  j=udata(1);
	  [out1(i) out2(i) out3(i) out4(i) out5(i) out6(i)]...
	  	=vp_roifuns('stat',j,in2,in3,in4);
			
	end
	
   else
     nargin;
     if (nargin < 6)
	lh=findobj('Tag','roi');
	nr=size(lh) ;
	bw=uint8(zeros(size(DATA)));
	for i=(1:nr(1))
		udata=get(lh(i),'UserData');
		if udata(1) == in1 
			x=get(lh(i),'XData');
			y=get(lh(i),'YData');
			bw=roipoly(DATA,x,y);
		end
	end
	
	datsiz=size(bw);
	nel=datsiz(1)*datsiz(2);
	
	%convert to (uchar) vector
	%convert to (datatype) vector
	ve(1)=DATA(1); j=1;
	for i=1:nel
		if bw(i) == 1
		  	ve(j)=DATA(i) ; j=j+1;
		end
	end;
	if(j==1),return, end; %out of bounds

     else 
	ve=in5; % input vector 
     end; %if 
	
	if in2 == 2 	% FIXED MINIMUM VALUE (in3)
        	tmax=max(ve);
		tmin=in3;
		
		% Calculate Effective Threshold
		if(tmax - GMIN ~= 0 )
		 %tmax; GMIN;
		 dmxmn=tmax-tmin; dmxGMN=tmax-GMIN; rat=dmxmn/tmax-GMIN; 
		 rndrat100=round(100*rat), corrndrat100= 100*(dmxmn/dmxGMN);
		 Thresholds(in1)=min(100, round(100*(tmax-tmin)/(tmax-GMIN)));
		 Thresholds(in1)=max(0, Thresholds(in1));
		else
		 if tmin == tmax,
		   Thresholds(in1)=100;
		 else
		   Thresholds(in1)=0;
		 end;
		end
		
	elseif in2 == 1	% Given 3DMAX(in4) and THRESHOLD(in3) 
		tmax=in4 ;
		tmin=tmax-(tmax-GMIN)*(in3/100);
		
			%tmin=tmax*(1-(in3/100));
			
	else	% DEFAULT
		% Given ROINO (in1), Threshold in array,
		% 2Dmax, Min based on GMIN
		
			%tmin=tmax*(1-(Thresholds(in1)/100));
		
        	tmax=max(ve);
		tmin=tmax-(tmax-GMIN)*(Thresholds(in1)/100);
	end
	k=1;
	ne=size(ve);
	vt=[];
	for i=1:ne(2)
	  if ve(i) >= tmin &  ve(i) <= tmax
	    vt(k)=ve(i); k=k+1;
	  end
	  
	end
	
	if ~isempty(vt)
		%vt=vt*SCALE;
		[out1 out2 out3]=vp_math('stat',vt);
		out5=min(vt); 
		%out6=tmax*SCALE;
		out6=tmax;
	end
	
	out4=ne(2); %PS total pixels in this roi
	
   end
   
elseif strcmp(action,'bytes') 	
	switch in1
	   case 'uchar' 
		out1=1;
	   case 'int16'
		out1=2;
	   case 'int32'
		out1=4;
	   case 'float'
		out1=4;
	   case 'double'
		out1=8;
	   otherwise	
	   	out1=1;
		out2=-1;
	end
end	



	
