function out1 = vp_roigrpt
%_______________________________________________________________________
% function vp_roigrpt.m		C.4.6 Phoebe Spetsieris  Jan. 2, 2001
%
%  	Display 2D statistics and GIS weight for all Regions of Interest (ROI)
%	in a plane. Threshold Mode must be two dimensional fixed or variable modes
%	modes. A fixed threshold minimum is defined for Threshold Mode 5 
%	Only regions for which a GIS weight is defined will be listed.
%
%	No.:	 Lists Sequential Region No.
%	Type:	 Ellptical, Rectangular or Irregular
%	Label:	 Label Id (Standard Nos 1-100 and Non. Standard > 100),
%		 followed by R,L or Blank for Right, Left or Center Orientation.
%		 and Standard or Non-Standard Label Names
%	NPX:	 Number of Pixels in Roi,
%	THR:	 Region %Threshold
%	ThPX:	 Number of pixels within threshold limits,
%
%	Max/Min: Maximum and mininum of threshold pixels
%	RMSD:	 Root mean square deviation of threshold pixels
%	Mean:	 Mean of threshold pixels
%	GIS :	 Gis region weight
%	
%_______________________________________________________________________


global LabIds LabNames Thresholds PlaneNo
global FName Message herr Ecolor
global ThreshMode FixedThMin HelpMode HelpMsg
global GisLab GisWeight GisOri

if HelpMode, vp_help(mfilename), return ; end;

Message=['..................................'];

txcolor1=[0 0 1];
txcolor=[0.6 0.2 0.5];

out1=0;
      
  if ThreshMode==2 | ThreshMode==4 ,
  	Message=['Invalid 3D Threshold Mode'];
	out1=-3;
  return, end;
  
  
  lh=findobj('Tag','roi');
  
  if isempty(lh)
  	Message=['REPORT: No Rois Found'];
	out1=-1;
  return, end;
  
  nr=size(lh);
  
       
  delete(findobj('Name','ROI/GIS REPORT'));
       
	
   nplgis = 0;
   ngis=size(GisLab);
   for i=(1:nr(1))
	    udata=get(lh(i),'UserData');
	    nroi=udata(1);
	  
     	    labid=LabIds(nroi,:);
	    [labno,ori]=strtok(labid,'LRC');
	    if isempty(ori), ori='C';
	    elseif length(ori) > 1, ori=ori(1); end;
	    
	    for j=1:ngis(1)
	     if strcmp(LabNames(nroi,:),GisLab(j,:))
	       if strcmp(ori,GisOri(j)), nplgis=nplgis+1; end;
	     end
	    end
   end
		
  if nplgis==0
  	Message=['REPORT: No Gis Rois Found'];
	out1=-1;
  return, end;
  
       
  dy=25*(nplgis+4);
  %if dy < 200, dy=200; end;
  
  hstat = figure('Color','w','Name','ROI/GIS REPORT',...
	'NumberTitle','off','Position',[25,50,740,dy],...
	'Pointer','Watch',...
	'Units','Pixels','Visible','on');
	
   axis off;
	
       
   textstr=sprintf('ROI STATISTICS  %s       Plane: %d   NRois: %d',FName,PlaneNo,nplgis);
   %textstr=sprintf('ROI STATISTICS  %s       Plane: %d   NRois: %d',FName,PlaneNo,nr(1));
   text(0.0,1.0, textstr,...
	'FontName','Times','FontSize',12,'FontWeight','bold',...
	'VerticalAlignment','Middle',...
	'HorizontalAlignment','Left',...
	'Color',[0 0 0]);
	
   dy=1/(4+nplgis);
   pos=1.0-dy;
   textstr=['No.  TYPE      LABEL                      NPX   THR(%)  ThPX    MX/MN    RMSD    MEAN    GISWeight'];
   text(0.0,pos, textstr,...
	'FontName','Times','FontSize',10,'FontWeight','bold',...
	'VerticalAlignment','Middle',...
	'HorizontalAlignment','Left',...
	'Color',txcolor1);
	
       
       
   for i= nr(1):-1:1
     udata=get(lh(i),'UserData');
     nroi=udata(1);
     roityp=udata(2);
	
     labid=LabIds(nroi,:);
     [labno,ori]=strtok(labid,'LRC');
     if isempty(ori), ori='C';
     elseif length(ori) > 1, ori=ori(1); end;
	    
     identroi=0;
	    
     for j=1:ngis(1)
        if strcmp(LabNames(nroi,:),GisLab(j,:))
	    if strcmp(ori,GisOri(j)), identroi=1; jgis=j; end;
	end
     end
	    
     if identroi,
        textstr=strcat('No. ',num2str(nroi));
	if roityp == 1, type ='Re';
  	  elseif roityp==2, type = 'Ell';
	  else type= 'Irr';
	end
	%labname=deblank(LabNames(nroi,:));
	labname=sprintf('%.24s',LabNames(nroi,:));
	labid=sprintf('%.5s',LabIds(nroi,:));
	
       % Two dimensional rois only
       
	if (ThreshMode == 5) 
		% Fixed Minimum Value
        	[nt me sd ne mn mx]=vp_roifuns('stat',nroi,2,FixedThMin);
	else
		% Variable or Fixed Threshold
        	[nt me sd ne mn mx]=vp_roifuns('stat',nroi,0);
	end
	
	
	[textstr,Message]=sprintf('%d   %s   %s %s ',...
			nroi,type,labid,labname);
   	pos=pos - dy;
	text(0.0,pos, textstr,...
	'FontName','Times','FontSize',10,...
	'VerticalAlignment','Middle',...
	'HorizontalAlignment','Left',...
	'Color',txcolor);
	
	[textstr,Message]=sprintf('%5d    %5d      %5d     %.2f/%.2f    %.2f       %.2f       %.2f',...
			ne,Thresholds(nroi),nt,mx,mn,sd,me,GisWeight(jgis));
	text(0.37,pos, textstr,...
	'FontName','Times','FontSize',10,...
	'VerticalAlignment','Middle',...
	'HorizontalAlignment','Left',...
	'Color',txcolor);
	
     end
	
	
   end
   
   set(hstat,'Pointer','arrow');
   set(findobj('Name','gROIgui'),'Pointer','arrow');
   
   herr = uicontrol(hstat,'string', ['MSG: ...............................'],...
   'position',[75 7 420 20],...
   'CallBack',['set(gco,''string'',['' '',Message]);'],...
   'BackgroundColor',Ecolor);

   uicontrol(hstat,'String','UPDATE',...
   'Position',[75 35 80 20],...
   'CallBack',[' vp_roigrpt ;',...
   'set(herr,''string'',Message); '] );
       
   %uicontrol(hstat,'String','SAVE',...
   %'Position',[200 35 80 20],...
   %'CallBack',['set(gcbf,''Pointer'',''watch'');',...
   %'[out1,Message]=vp_roirpt(''save''); set(gcbf,''Pointer'',''arrow'');',...
   %'set(herr,''string'',Message); drawnow ; '] );
       
   uicontrol(hstat,'String','RETURN',...
   'Position',[550 35 80 20],...
   'CallBack',['set(findobj(''Name'',''gROIgui''),''Visible'',''on''); ',...
   'delete(findobj(''Name'',''ROI/GIS REPORT''));']);
   
   
   uicontrol(hstat,'string', 'Help',...
	'TooltipString','Help displayed in MATLAB window',...
	'BackgroundColor',Ecolor,...
   	'position',[550 7 80 20],'callback',...
	'set(herr,''string'',HelpMsg); help vp_roigrpt;');
       
      
   drawnow;
    
	



