function [out1] = vp_roimap(action, in1, in2)
%
% function vp_roimap.m (action, in1, in2)
% 
% Displays map of all pixels within and including threshold limits within
% region(s) of interest. Threshold pixels are assigned a single color 
% corresponding to the maximum planar value regardless of their true value
% to visually distinguish them from other pixels.
% 			
% Threshold limits are determined as follows:
%     Max = region maximum.
%     Min = Max -(Max-GMIN)*(Threshold/100);
%     if ThreshMode==5, Min=Fixed Threshold Minimum
%
%	GMIN is the Global Minimum for all pixels on all planes and
%	Threshold is the Percent Threshold of the roi (0-100). 
%
% Map displays all regions if selected from the main roi menu and only the 
% selected region if picked from the roi submenu. Outlines can be set on or 
% off and various other user options are provided.
%
% Threshmode Mode must be two dimensional fixed or variable.
% action: display - displays map
% action: abort - Kills Map and set ROIgui Visibility ON
%	   
% in1=RoiNo: Process one roi.
% in1=0: Process all rois
%
% in2=0: roi outline off
% in2=1: roi outline on
%_______________________________________________________________________
% 		 	C.0 Phoebe Spetsieris  Feb 10. 1999

global DATA WTotal PlaneNo Thresholds DATAMIN DATAMAX VOX XYZOR
global ThreshMode FixedThMin HelpMode GMIN UFI LineOn
	
if HelpMode, vp_help(mfilename), return ; end;
      
out1=0;

if ThreshMode ==2 | ThreshMode == 4,
	disp('Not valid for 3D ThreshMode')
return, end;

if ~exist('in2'), LineOn=1; 
else, LineOn=in2; end;

delete(findobj('Tag','RoiMap'));

%FMap=findobj('Tag','RoiMap');
%if in1 ~=0 delete(FMap); end;
%FMap=findobj('Tag','RoiMap');

%if ~isempty(FMap)
%	set(FMap,'Visible','off','Pointer','watch');
%end


if strcmp(action,'abort') 
     
	set(findobj('Name','gROIgui'),'Visible','on');
	
elseif strcmp(action,'display') 
	
  h=waitbar(0,'Processing ROI Threshold Map ...');

  cm=get(findobj('Tag','image'),'Colormap');
  pos=get(findobj('Tag','image'),'Position');
	
  
  %if isempty(FMap)

	%sizex=512; sizey=512;
	sizex=pos(3); sizey=pos(4);
	if in1 ~= 0
		sizex=4*sizex/5; sizey=4*sizey/5;
	end
       
  waitbar(.2,h);
  % THRESHOLD MAP CONTROLS

	%'UserData',[in1,in2]
	
	FMap = figure('Color',[0 0 1]*.8,...
	'Name','Threshold MAP',...
	'NumberTitle','off',...
	'Position',[50,50,sizex,sizey],...
	'Resize','on',...
	'Colormap',cm,...
	'UserData',[in1,LineOn],...
	'Tag','RoiMap',...
	'Units','Pixels',...
	'Pointer','watch',...
	'Visible','off');
	
   	%uicontrol(FMap,'String','hot ',...
	%'Position',[165 10 45 25],...
	%'CallBack','colormap(hot)');

   	%uicontrol(FMap,'String','gray ',...
	%'Position',[120 10 45 25],...
	%'CallBack','colormap(gray)');
	
	vp_controls(gcf,mfilename,1);

	%updcb=['vp_roimap(''display'',get(findobj(''Tag'',''RoiMap''),''UserData''))'];
	updcb=['in=get(findobj(''Tag'',''RoiMap''),''UserData''); vp_roimap(''display'',in(1),in(2))'];
	%updcb=['vp_roimap(''display'',get(findobj(''Tag'',''RoiMap''),''UserData''),LineOn)'];
	
   	uicontrol(FMap,'String','UPDATE ',...
	 'Position',[sizex/2 + 5 4 55 15],...
	 'CallBack',updcb);

   	uicontrol(FMap,'String','CLEAR ',...
	'Position',[sizex/2+60 4 50 15],...
	'CallBack',['vp_roimap(''abort'');']);
	
   	%uicontrol(FMap,'String','COLOR ',...
	%'Position',[sizex/2 + 110 4 45 15],...
	%'CallBack','UFI=gcbf; vp_colgui;');

   	uicontrol(FMap,'String','Outline ON/OFF ',...
	'Position',[sizex/2+110 4 90 15],...
	'CallBack',['in=get(gcbf,''UserData''); if in(2), in(2)=0; else in(2)=1; end;',...
	 'set(gcbf,''UserData'',in); vp_roimap(''display'',in(1),in(2)); ']);

  %end

%	set(findobj('Name','gROIgui'),'Visible','off'); 
	
%        set(FMap,'Pointer','watch');
	lh=findobj('Tag','roi');
	nr=size(lh);
	bw=uint8(zeros(size(DATA)));
	
	
	for i=(1:nr(1))
	    udata=get(lh(i),'UserData');
	    nroi=udata(1);
		
  	    waitbar(min(1,(i-1)/nr(1) +.2), h);
	    
	    if(in1 == 0 | in1==nroi)
		
		x=get(lh(i),'XData');
		y=get(lh(i),'YData');
		pw=roipoly(DATA,x,y);
		
		
		if ThreshMode==5 | Thresholds(nroi) ~= 100
		
		  datsiz=size(pw);
		  nel=datsiz(1)*datsiz(2);
	
		  %convert to uchar vector
		  ve=[];
		  ve(1)=DATA(1); j=1;
		  for i=1:nel
		     if pw(i) == 1
		  	ve(j)=DATA(i) ; j=j+1;
		     end
		  end;
	
        	  tmax=max(ve);
		  %tmin=tmax*(1-(Thresholds(nroi)/100));
		  
		  if ThreshMode==5, tmin=FixedThMin,
		  else
		   tmin=tmax -(tmax-GMIN)*(Thresholds(nroi)/100);
		  end
	
		  for i=1:nel
	   	   if pw(i) == 1
	   		if DATA(i) < tmin,
	    			pw(i)=0;
	  		end
	   	   end
		  end;
		
		end % for if
		
		bw=bitor(bw,uint8(pw));
		
	    end
	end
	
	datsiz=size(bw);
	nel=datsiz(1)*datsiz(2);
	
	%convert to uchar
	%convert to Data values
	cw=DATA;
	for i=1:nel
		if bw(i) == 1
		   %cw(i)=255 ;
		   cw(i)=DATAMAX ;
		end	
	end;

	figure(FMap);
        %set(FMap,'Pointer','arrow','Colormap',cm,'Position',[50,50,pos(3),pos(4)]);
        set(FMap,'Pointer','arrow','Colormap',cm,'Position',[50,50,sizex,sizey]);
	
	%imaph=imagesc(cw,[0 255]);
	axes('Position',[0 0 1 1],'visible','off');
	imaph=imagesc(cw,[DATAMIN DATAMAX]);
	axis off image xy
	
	%Correct for aspect ratio
	vp_aspect(1,VOX);
		
	set(gca,'UserData',[1 PlaneNo VOX XYZOR]);
	
        if LineOn,
	  for i=(1:nr(1))
	    udata=get(lh(i),'UserData');
	    nroi=udata(1);
		
	    if(in1 == 0 | in1==nroi)
		
		x=get(lh(i),'XData');
		y=get(lh(i),'YData');
		line(x,y,'LineStyle','-.');
	    end
	  end
	end;
	
	PlaneNoStr=num2str(PlaneNo);
	
	if in1 ~= 0
	  thdl=text(.5,3,['Plane: ' num2str(PlaneNo) '  Roi: ' num2str(in1) '  Thresh:' num2str(Thresholds(in1)) ],'Color',[1.0 1.0 1.0]);
	else
	  thdl=text(.5,3,['Plane: ' num2str(PlaneNo)],'Color',[1.0 1.0 1.0]);
	end
	drawnow;
	
	waitbar(1,h); close(h);

	% save
	%cw=flipud(cw);
	%cw=cw';
	%out1=fwrite(in1,cw,'uchar');
	%WTotal=WTotal+out1;
	%if out1 ~= nel, Message=lasterr(''); end;
	
end	




