% vp_roissm.m
% Options for ROI Based SSM Statistical Analysis
%
% Options:
%
% A)  PCA    (SSM Principal Component Analysis)
%               Evaluation of GIS Group Invariant Subprofiles
%               and SSF Subject Scaling Factors.
%
% B)  TPR    (Topographic Profile Rating)
%               New Subject Score Evaluation.
%               I) Interactive Options, Reference, Methods, Log. etc.
%               II) Automatic: Predefined Methods and File References.
%               SEE COMMAND WINDOW OUTPUT FOR TPR HELP
%
% C)  O-PCA  (Orthogonal Principal Component Analysis)
%               Evaluate and optionally remove component 
%               covariance from an image data set and
%               perform PCA analysis in the orthogonal space.
%
% D)  UTIL   Select SSM based utilities:
%
%               Display SCORES:
%                 Display bar graphs of SSF subject scores for selected
%                 GISs. Values are read from SSF Score output files.
%               Display GIS-Network:
%                 Display bar graphs of SSM GIS region weights for selected
%                 GIS network. Values are read from SSM GIS output files.
%               GIS-MAP
%                 Create a GIS weighted PET/MRI brain map of a selected
%                 regional GIS network using values from SSM GIS output files.
%
% See Individual Help Routines or set "Help Mode" ON on main menu.
% For References see: help vp_ssm.m
%
% vp_roissm.m		ScAnVP 5.1		P. Spetsieris	4/30/03
%			rev. ScAnVP 5.2		P.S.	4/16/04
%			rev. ScAnVP 5.3		P.S.	8/5/04
%			rev. ScAnVP 5.4		P.S.	11/10/04
%			rev. ScAnVP 5.5		P.S.	6/23/05
%			rev. ScAnVP 6.4		P.S.	1/22/15
%_______________________________________________________________________
%

global HelpMode
global POpt
global FMenu Message Ecolor Op ImOpFactor Keyin
global hwaitbar AutoTPR Scattering

if HelpMode, vp_help(mfilename); help('vp_ssm_roitpr'); help('vp_ssm_autoroitpr'); return ; end;

out1=0;
ImOpFactor=1;
Message=['MSG:.................'];
%Bcolor=[0.8 .8 .8];
Bcolor=[0.8 .85 .95];
%Mcolor=[0.68 .65 .7];
%Mcolor=[0.60 .63 .75];
Mcolor=[0.56 .65 .70];
Mcolor=[0.56 .70 .70];
AutoTPR=0;
FWID=350;
FHGT=370;


tip1=['Principal Component Analysis'];
tip2=['Topographic Profile Rating (Automatic or Interactive Scoring)'];
tip3=['Orthogonal Principal Component Analysis (O-PCA)'];
tip4=['Select SSM ROI Utility: Display SCORES, Display GIS Bar Graph, Display GIS MAP'];

roissmopgui=findobj('Name','ROI SSM');
if ~isempty(roissmopgui)
	if(strcmp(get(roissmopgui,'Visible'),'on'))
		figure(roissmopgui);
	end
	return
end

%set(FMenu,'Pointer','Watch');

roissmopgui = figure('Color',Mcolor,'Name','ROI SSM','Tag','roissmopgui',...
'NumberTitle','off','Position',[100,200,FWID,FHGT],'UserData',0,...
'Units','Pixels');


uicontrol(roissmopgui,'Style','Text','String','Scaled Subprofile Model',...
	'FontName','Times','FontSize',18,...
	'FontWeight','Bold',...
	'FontAngle','Italic',...
	'BackgroundColor',Mcolor,...
	'Units','Normalized',...
	'Position',[.10 .75 .8 .2],'Tag','Empty',...
	'ForegroundColor',Txcolor)
	
uicontrol(roissmopgui,'Style','Text','String','(ROI Based SSM)',...
	'FontName','Times','FontSize',16,...
	'FontWeight','Bold',...
	'FontAngle','Italic',...
	'BackgroundColor',Mcolor,...
	'Units','Normalized',...
	'Position',[.26 .69 .5 .2],'Tag','Empty',...
	'ForegroundColor',Txcolor)
	
	
uicontrol(roissmopgui,'Style','Text','String','PRINCIPAL COMPONENT ANALYSIS',...
	'FontName','Times','FontSize',14,...
	'FontWeight','Bold',...
	'FontAngle','Italic',...
	'BackgroundColor',Mcolor,...
	'Units','Normalized',...
	'HorizontalAlignment','Left',...
	'Position',[.07 .59 .9 .15],'Tag','Empty',...
	'ForegroundColor',[1.0 1.0 0.0])
	

uicontrol(roissmopgui,'string', 'PCA',...
	'TooltipString',tip1,...
	'Units','Normalized',...
	'position',[25/FWID 234/FHGT 160/FWID 20/FHGT],...
	'BackgroundColor',Bcolor,'callback','vp_ssm_roipca');
	
uicontrol(roissmopgui,'string', 'ORTHOGONAL-PCA',...
	'TooltipString',tip3,...
	'Units','Normalized',...
	'position',[25/FWID 209/FHGT 160/FWID 20/FHGT],...
	'BackgroundColor',Bcolor,'callback','vp_ssm_roiOpca');
      
uicontrol(roissmopgui,'Style','Text','String','TOPOGRAPHIC PROFILE RATING',...
	'FontName','Times','FontSize',14,...
	'FontWeight','Bold',...
	'FontAngle','Italic',...
	'BackgroundColor',Mcolor,...
	'Units','Normalized',...
	'HorizontalAlignment','Left',...
	'Position',[.07 .38 .9 .15],'Tag','Empty',...
	'ForegroundColor',[1.0 1.0 0])
     
uicontrol(roissmopgui,'String','TPR',...
	'TooltipString',tip2,...
	'Units','Normalized',...
	'position',[25/FWID 157/FHGT 160/FWID 20/FHGT],...
	'BackgroundColor',Bcolor,...
    	'callback',['if AutoTPR, vp_ssm_autoroitpr, else, vp_ssm_roitpr; end;']);
	
	
uicontrol(roissmopgui,'Style','Text','String','ROI UTILITIES',...
	'FontName','Times','FontSize',14,...
	'FontWeight','Bold',...
	'FontAngle','Italic',...
	'BackgroundColor',Mcolor,...
	'Units','Normalized',...
	'HorizontalAlignment','Left',...
	'Position',[.26 .24 .9 .15],'Tag','Empty',...
	'ForegroundColor',[1.0 1.0 0.0])
    
uicontrol(roissmopgui,'String','DISPLAY SCORES',...
	'TooltipString','Display SSF File Scores for Selected GIS No.',...
	'Units','Normalized',...
	'position',[70/FWID 105/FHGT 170/FWID 20/FHGT],...
	'BackgroundColor',Bcolor,...
    	'callback',['vp_ssm_scores;']);
       
uicontrol(roissmopgui,'string', 'Scatter Points',...
	'TooltipString','Scatter Points or Display Vertically.',...
	'Style','checkbox','value',Scattering,...
	'Units','normalized',...
	'Position',[.7 .28 .26 .05],...
	'BackgroundColor',Bcolor,...
	'callback',['val=get(gco,''value'');',...
	 'if (val==0), Scattering=0; ',...
	 ' else, Scattering=1; ',...
	 'end;']);

uicontrol(roissmopgui,'String','GRAPH GIS WEIGHTS',...
	'TooltipString','Graph Selected GIS Region Weights',...
	'Units','Normalized',...
	'position',[70/FWID 80/FHGT 170/FWID 20/FHGT],...
	'BackgroundColor',Bcolor,...
    	'callback',['vp_readgis(1);']);
       
uicontrol(roissmopgui,'String','GIS TEMPLATE ROI BRAIN MAP',...
	'TooltipString','Create Template Regional GIS Weighted Brain Map',...
	'Units','Normalized',...
	'position',[70/FWID 55/FHGT 170/FWID 20/FHGT],...
	'BackgroundColor',Bcolor,...
    	'callback',['vp_GISimg;']);
       
uicontrol(roissmopgui,'String','GIS ATLAS ROI BRAIN MAP',...
	'TooltipString','Create Atlas Regional GIS Weighted Brain Map',...
	'Units','Normalized',...
	'position',[70/FWID 30/FHGT 170/FWID 20/FHGT],...
	'BackgroundColor',Bcolor,...
    	'callback',['vp_GISAimg;']);
       
uicontrol(roissmopgui,'string', 'HELP',...
	'TooltipString','Help displayed in MATLAB window',...
	'BackgroundColor',Ecolor,...
	'Units','Normalized',...
	'position',[280/FWID 290/FHGT 50/FWID 20/FHGT],...
	'callback',['vp_help(''vp_roissm'');',...
	' vp_note(''See HELP window. For Specific Options, Set Help Mode ON on Main Menu'');']);
	
uicontrol(roissmopgui,'String','QUIT',...
	'TooltipString','Quit and exit.',...
	'Units','Normalized',...
	'position',[280/FWID 5/FHGT 60/FWID 20/FHGT],...
	'CallBack',['delete(roissmopgui);',...
	'set(FMenu,''Pointer'',''Arrow'')';] );


