% function [out1] =vp_rotmovie(rotangle,rotaxis)
% Create a movie of a rotating 2D section of a volume around axis X,Y or Z.
%
% This function derives a 2D section passing through an axis of a 3D 
% volume XYZDATA and creates a movie of sequential sections at angular
% increments given by the rotangle for a full rotation around the axis 
% through a fixed point. 
%
% function vp_rotmovie  ScAnVP C.4.7.8	Sep. 12, 2002  P. Spetsieris
% Modified for  ScAnVP 5.2 by P.S. Nov. 3, 2003

function [out1] =vp_rotmovie(rotangle,rotaxis)

global XYZDATA DIM DATAMIN DATAMAX GCM CMin CMax PlaneX PlaneY PlaneZ

if isempty(XYZDATA) vp_note('No valid image data displayed',2), return, end;

if isempty(CMin), CMin=DATAMIN; end;
if isempty(CMax), CMax=DATAMAX; end;

h=waitbar(0.1,'Saving Movie Frames ...');
m=360/rotangle; 

i=1;
% pos=get(gcf,'position'); pos(3)=2*sz(1); pos(4)=2*sz(2); set(gcf,'position',pos);

figure('name',' Movie Plane','tag','MoviePlane');
 pos=get(gcf,'position'); pos(3)=2*max(DIM); pos(4)=2*max(DIM); set(gcf,'position',pos);
for phi=0:rotangle:360,
 [out1 planedat]=vp_rvolfuns('getplane',XYZDATA,phi,rotaxis,DIM,[PlaneX PlaneY PlaneZ]);
 sz=size(planedat);
 imagesc(planedat,[DATAMIN,DATAMAX]); axis xy image off;
 colormap(GCM); caxis([CMin CMax]);
 drawnow;
 M(:,i)=getframe;
 waitbar((i-.8)/m, h, ['Saving Movie Frame ',num2str(i)]);
 i=i+1;
end
waitbar(1,h); pause(1); close(h);

save 'rotmovie.mat' M
vp_note('File rotmovie.mat saved',2);
vp_movie('rotmovie.mat');

