% vp_rotview
% Display a rotated single section or movie around the Z axis.
%_______________________________________________________________________
% The user keys in an angle for counterclockwise rotation around
% the Z axis through the orthogonal view pt defined by the user.
% A single section or movie sequence can be displayed at
% angular intervals. The movie is saved in a default.mat file and is shown. 
% To avoid overwriting, the user should change the saved default movie name.
%_______________________________________________________________________
% vp_rotview    ScAnVP	C.4.7.8    P.Spetsieris	11/13/02
%			Rev. 5.2   by P.S.	10/14/03

global HelpMode FMenu Message Ecolor PlaneX PlaneY PlaneZ
global XYZDATA DIM DATAMIN DATAMAX GCM CMin CMax RotAngle

if HelpMode, vp_help(mfilename),  return ; end;

delete(findobj('Tag','rotviewgui'));

if isempty(XYZDATA) vp_note('No valid image data displayed',2), return, end;

if isempty(CMin), CMin=DATAMIN; end;
if isempty(CMax), CMax=DATAMAX; end;

IdentRotAngle=1;
RotAngle=0;
out1=0;
Message=['MSG:.................'];
Bcolor=[0.8 .8 .9];

rotviewgui = figure('Color',[0.8 .7 .7],'Name','Rotate View UI','Tag','rotviewgui',...
'NumberTitle','off','Position',[100,200,260,75],'UserData',0,...
'Units','Pixels');
	
uicontrol(rotviewgui,'style','text','string','SET ANGLE: ',...
	'position',[10 48 70 20],'BackgroundColor',[0.9 .8 .8],...
	'ToolTipString',['Enter rotation angle around Z axis']);

cbangreset=['ss=get(gco,''string''); [rotentry num]= sscanf(ss, ''%d'');',...
	 ' if num==1,RotAngle=rotentry'', Message=''RotAngle Read''; IdentRotAngle=1;',...
	 ' eval(pcbview);',...
	 ' else, vp_message(''Ivalid Entry''); IdentRotAngle=0;  end;  ',...
	 ' set(herr,''string'',['' '',Message]);  '];
	 
uicontrol(rotviewgui,'style','edit','string',['0'],'tag','rotangle',...
	'position',[80 50 68 20],'BackgroundColor',Bcolor,...
	'ToolTipString',['Enter rotation angle around Z axis'],...
	'CallBack', cbangreset );
	
% 'pos=get(gcf,''position''); pos(3)=2*sz(1); pos(4)=2*sz(2); set(gcf,''position'',pos);'

%pcbview=['figure(''name'',[''Rot'',num2str(RotAngle)],''tag'',''Rotated Section'');',...
%
pcbview=['firot=findobj(''name'',''Rot(Z)'');',...
 'if ~isempty(firot), pos=get(firot,''position''); delete(firot);',...
 'else, pos=[360,300,2*max(DIM),2*max(DIM)]; end;',...
 'figure(''name'',''Rot(Z)'',''tag'',''Rotated Section'',''position'',pos);',...
 'in5=[PlaneX PlaneY PlaneZ];',...
 '[out1 xzdat]=vp_rvolfuns(''getplane'',XYZDATA,RotAngle,3,DIM,in5); sz=size(xzdat);',...
 'imagesc(xzdat,[DATAMIN,DATAMAX]); axis xy image off;',...
 'colormap(GCM); caxis([CMin CMax]);',...
 'uicontrol(gcf,''style'',''text'',''string'',[''Rot:'', num2str(RotAngle)],''position'',[0 0 40 15]);',...
 'drawnow;'];
	
uicontrol(rotviewgui,'string', '-5',...
	'TooltipString','Decrease View Rotation Angle ','position',[150 50 20 20],...
	'callback',['RotAngle=RotAngle -5; eval(pcbview);',...
	'set(findobj(''tag'',''rotangle''),''string'',num2str(RotAngle));']);
	
uicontrol(rotviewgui,'string', 'DISPLAY',...
	'TooltipString','View a single slice at the rotated angle ',...
	'position',[170 50 60 20],'callback',pcbview);
	
uicontrol(rotviewgui,'string', '+5',...
	'TooltipString','Increase View Rotation Angle ','position',[230 50 20 20],...
	'callback',['RotAngle=RotAngle +5; eval(pcbview);',...
	'set(findobj(''tag'',''rotangle''),''string'',num2str(RotAngle));']);
	

uicontrol(rotviewgui,'String','MAKE MOVIE',...
	'TooltipString','Initiate Processing of Movie.',...
	'Position',[10 25 100 20],...
	'CallBack',[ 'if ~IdentRotAngle, set(herr,''string'',''ERR: Angle Not Defined''); return; end; ',...
	'set(FMenu,''Pointer'',''Watch'');',...
	'out1=vp_rotmovie(RotAngle);',...
	'if out1<0, set(herr,''string'',['' '',Message]); pause(2); ',...
	'else, set(herr,''string'',[''Movie Processed'']);  end;',...
	'set(FMenu,''Pointer'',''Arrow'')';] );
	
uicontrol(rotviewgui,'string', 'HELP',...
	'TooltipString','Help displayed in MATLAB window',...
	'BackgroundColor',Ecolor,...
	'position',[125 25 50 20],'callback','vp_help(''vp_rotview'');');
	
uicontrol(rotviewgui,'String','QUIT',...
	'TooltipString','Quit and exit.',...
	'Position',[190 25 60 20],...
	'CallBack',['delete(rotviewgui);',...
	'set(FMenu,''Pointer'',''Arrow'')';] );

herr = uicontrol(rotviewgui,'string', [' ',Message],...
	'TooltipString','Report error or message field',...
	'position',[10 0 240 20],...
	'CallBack',['set(herr,''string'',['' '',Message]);'],...
	'BackgroundColor',Ecolor);


eval(pcbview);
