% vp_rotvol
% Rotate volume around X,Y or Z axis and display Sections or movie
%_______________________________________________________________________
% The user keys in an angle for clockwise rotation around a specified 
% axis through the view point. A new cubic volume is defined using
% the maximum dimension. Orthogonal sections can be viewed
% and a new view point can be defined but the rotation point
% does not change until the command is reinitiated. 
% The new rotated image file can be saved on the orthogonal view menu.
% A movie sequence can be created displaying an orthogonal section at
% angular intervals given by the rotation angle around the active view
% point defined by the user. The movie is saved in a default.mat file
% and is shown by pressing play. To avoid overwriting, the user should
% change the saved default movie name.
%_______________________________________________________________________
% vp_rotvol    ScAnVP	C.4.7.8    P.Spetsieris	11/13/02
%			Rev. 5.2   by P.S.	10/21/03

global HelpMode FMenu Message Ecolor PlaneX PlaneY PlaneZ
global XYZDATA DIM DATAMIN DATAMAX GCM CMin CMax RotAngle
global XYZDATA0 DIM0 VOX0 XYZOR0 Dx Dy Dz MaxPlane MaxDim
global PlaneX0 PlaneY0 PlaneZ0

if HelpMode, vp_help(mfilename),  return ; end;

delete(findobj('Tag','rotviewgui'));

if isempty(XYZDATA) vp_note('No valid image data displayed',2), return, end;

%INITIALIZE
if isempty(CMin), CMin=DATAMIN; end;
if isempty(CMax), CMax=DATAMAX; end;

PlaneX0=PlaneX; PlaneY0=PlaneY; PlaneZ0=PlaneZ;
XYZDATA0=XYZDATA; DIM0=DIM; VOX0=VOX; XYZOR0=XYZOR; 
IdentRotAngle=1;
RotAngle=0;
RotAxis=3;
out1=0;
Message=['MSG:.................'];
Bcolor=[0.8 .8 .9];

rotviewgui = figure('Color',[0.8 .7 .7],'Name','Rotate View UI','Tag','rotviewgui',...
'NumberTitle','off','Position',[100,200,260,100],'UserData',0,...
'Units','Pixels');
	
uicontrol(rotviewgui,'style','text','string','ROT. AXIS: ',...
	'position',[10 74 70 20],'BackgroundColor',[0.85 .75 .75],...
	'ToolTipString',['Specify Rotation Axis X, Y or Z']);
	
pcbaxis=['RotAxis, if RotAxis==0, rotstr=get(findobj(''tag'',''edax''),''string''),',...
		'if strcmp(rotstr,''X''), RotAxis=1;',...
		'elseif strcmp(rotstr,''Y''), RotAxis=2;',... 	
		'elseif strcmp(rotstr,''Z''), RotAxis=3;',... 	
	'end; end; RotAxis,',...
	'if RotAxis==1, set(findobj(''tag'',''edax''),''string'',''X'');',...
	'elseif RotAxis==2, set(findobj(''tag'',''edax''),''string'',''Y'');',...
	'elseif RotAxis==3, set(findobj(''tag'',''edax''),''string'',''Z'');',...
	'elseif RotAxis==0, set(findobj(''tag'',''edax''),''string'',''?'');',...
	'set(herr,''string'',[''Specify Axis X,Y or Z '']);',... 
	'end;'];

uicontrol(rotviewgui,'style','edit','string',['Z'],'tag','edax',...
	'position',[80 74 45 20],'BackgroundColor',Bcolor,...
	'ToolTipString',['Select Rotation axis X, Y or Z'],...
	'CallBack', ['RotAxis=0; eval(pcbaxis);'] );

uicontrol(rotviewgui,'string',['X'],'tag','XAxis',...
	'position',[130 74 20 20],...
	'ToolTipString',['Rotate around X axis'],...
	'CallBack', ['RotAxis=1; eval(pcbaxis);'] );

uicontrol(rotviewgui,'string',['Y'],'tag','YAxis',...
	'position',[155 74 20 20],...
	'ToolTipString',['Rotate around Y axis'],...
	'CallBack',['RotAxis=2; eval(pcbaxis);'] );

uicontrol(rotviewgui,'string',['Z'],'tag','ZAxis',...
	'position',[180 74 20 20],...
	'ToolTipString',['Rotate around Z axis'],...
	'CallBack', ['RotAxis=3; eval(pcbaxis);'] );

uicontrol(rotviewgui,'string', 'HELP',...
	'TooltipString','Help displayed in MATLAB window',...
	'BackgroundColor',Ecolor,...
	'position',[205 74 45 20],'callback','vp_help(''vp_rotvol'');');
	
uicontrol(rotviewgui,'style','text','string','SET ANGLE: ',...
	'position',[10 48 70 20],'BackgroundColor',[0.85 .75 .75],...
	'ToolTipString',['Enter rotation angle around axis']);

%
%	 ' eval(pcbvol);',...
cbangreset=['ss=get(gco,''string''); [rotentry num]= sscanf(ss, ''%d'');',...
	 ' if num==1,RotAngle=rotentry'', Message=''RotAngle Read''; IdentRotAngle=1;',...
	 ' else, vp_message(''Ivalid Entry''); IdentRotAngle=0;  end;  ',...
	 ' set(herr,''string'',['' '',Message]);  '];
	 
uicontrol(rotviewgui,'style','edit','string',['0'],'tag','rotangle',...
	'position',[80 50 68 20],'BackgroundColor',Bcolor,...
	'ToolTipString',['Enter rotation angle around Z axis'],...
	'CallBack', cbangreset );
	

%pcbview=['firot=findobj(''name'',''Rot(Z)'');',...
% 'if ~isempty(firot), pos=get(firot,''position''); delete(firot);',...
% 'else, pos=[360,300,2*max(DIM),2*max(DIM)]; end;',...
% 'figure(''name'',''Rot(Z)'',''tag'',''Rotated Section'',''position'',pos);',...
% 'in5=[PlaneX PlaneY PlaneZ];',...
% '[out1 xzdat]=vp_rvolfuns(''getplane'',XYZDATA,RotAngle,3,DIM,in5); sz=size(xzdat);',...
% 'imagesc(xzdat,[DATAMIN,DATAMAX]); axis xy image off;',...
% 'colormap(GCM); caxis([CMin CMax]);',...
% 'uicontrol(gcf,''style'',''text'',''string'',[''Rot:'', num2str(RotAngle)],''position'',[0 0 40 15]);',...
% 'drawnow;'];
	

pcbvol=['in5=[PlaneX0 PlaneY0 PlaneZ0];',...
 'if(RotAxis<=0 | RotAxis > 3), set(herr,''string'',''Specify Axis, X,Y or Z''); return; end;',...
 '[out1 XYZDATA DIM VOX XYZOR]=vp_rvolfuns(''getvolume'',XYZDATA0,RotAngle,RotAxis,DIM0,in5); ',...
 'PlaneX=XYZOR(1); PlaneY=XYZOR(2); PlaneZ=XYZOR(3); Dx=VOX(1); Dy=VOX(2); Dz=VOX(3);',...
 'MaxPlane=DIM(3); MaxDim=DIM(3); set(hmaxpln,''string'',num2str(DIM(3)));',...
 'Opt=3; FI=figure(findobj(''tag'',''orthview'')); vp_imvorth ;',...
 'uicontrol(FI,''style'',''text'',''string'',[''Rot:'', num2str(RotAngle)],''position'',[0 0 40 15]);',...
 'drawnow;'];
	
uicontrol(rotviewgui,'string', '-5',...
	'TooltipString','Decrease View Rotation Angle ','position',[150 50 20 20],...
	'callback',['RotAngle=RotAngle -5; eval(pcbvol);',...
	'set(findobj(''tag'',''rotangle''),''string'',num2str(RotAngle));']);
	
uicontrol(rotviewgui,'string', 'DISPLAY',...
	'TooltipString','Redisplay volume at the rotated angle around Origin',...
	'position',[170 50 60 20],'callback',pcbvol);
	
uicontrol(rotviewgui,'string', '+5',...
	'TooltipString','Increase View Rotation Angle ','position',[230 50 20 20],...
	'callback',['RotAngle=RotAngle +5; eval(pcbvol);',...
	'set(findobj(''tag'',''rotangle''),''string'',num2str(RotAngle));']);
	

uicontrol(rotviewgui,'String','MAKE MOVIE',...
	'TooltipString','Initiate Processing of Movie.',...
	'Position',[10 25 100 20],...
	'CallBack',[ 'if (~IdentRotAngle | RotAngle==0), set(herr,''string'',''ERR: Angle Not Defined''); return; end; ',...
	'set(FMenu,''Pointer'',''Watch'');',...
	'out1=vp_rotmovie(RotAngle,RotAxis);',...
	'if out1<0, set(herr,''string'',['' '',Message]); pause(2); ',...
	'else, set(herr,''string'',[''Movie Processed'']);  end;',...
	'set(FMenu,''Pointer'',''Arrow'')';] );
	
uicontrol(rotviewgui,'String','RESET',...
 'TooltipString','RESET original angle',...
 'Position',[155 25 45 20],...
 'CallBack',['XYZDATA=XYZDATA0; DIM=DIM0; VOX=VOX0; XYZOR=XYZOR0; RotAngle=0;',...
 'set(findobj(''tag'',''rotangle''),''string'',num2str(RotAngle));',...
 'PlaneX=PlaneX0; PlaneY=PlaneY0; PlaneZ=PlaneZ0; Dx=VOX(1); Dy=VOX(2); Dz=VOX(3);',...
 'MaxPlane=DIM(3); MaxDim=DIM(3); set(hmaxpln,''string'',num2str(DIM(3)));',...
 'delete(rotviewgui); set(FMenu,''Pointer'',''Arrow'');',...
 'Opt=3; FI=figure(findobj(''tag'',''orthview'')); vp_imvorth ;',...
 'uicontrol(FI,''style'',''text'',''string'',[''Rot:'', num2str(RotAngle)],''position'',[0 0 40 15]);',...
 'drawnow;']);

uicontrol(rotviewgui,'String','QUIT',...
	'TooltipString','Quit and exit.',...
	'Position',[200 25 50 20],...
	'CallBack',['delete(rotviewgui);',...
	'set(FMenu,''Pointer'',''Arrow'')';] );

herr = uicontrol(rotviewgui,'string', [' ',Message],...
	'TooltipString','Report error or message field',...
	'position',[10 0 240 20],...
	'CallBack',['set(herr,''string'',['' '',Message]);'],...
	'BackgroundColor',Ecolor);


eval(pcbvol);
