function [out1,out2,out3,out4,out5] = vp_rvolfuns(action, in1,in2,in3,in4,in5)
%_______________________________________________________________________
% vp_rvolfuns.m  	ScAnVP 	C.4.7.8 Phoebe Spetsieris  Sept. 12, 2002
%			Rev. 5.2	by P.S.		   Oct. 14, 2003
%
% Various image volume rotation functions:
%
%  Input
%  in1=xyzdata, in2=angleno (degrees) in3=axisno,
%  in3=1 (rotate X), (2=rotate Y), (3=rotate Z),
%  in4=dim, in5=Rotation Pt. Coordinates
%
%  Output
%  out1=status
%  	Action
%  	'getplane':	out2=plndata
%  	'getvolume':	out2=nxyzdata out3=newdim out4=nvox out5=new origin
%_______________________________________________________________________

global DATA Message FName GMIN GMAX
global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN
global EXPTIM DURATION MATYPE Message GENTIM SUBID EXPDATE
global HelpMode

if HelpMode, vp_help(mfilename), return ; end;

	out1=0; out2=[]; out3=0; out4=0; out5=0; 
	if (strcmp(action,'getvolume') & in2==0)
	   % Zero angle, return input
	   out2=in1; out3=size(in1); out4=VOX; out5=in5;
	   return;
	end

	xyzdata=[]; 
	xyzdata=in1;
	dimp=size(xyzdata);
	angno=in2; axisno=in3; dim=in4;
	in5;
	xp0=in5(1);
	yp0=in5(2);
	zp0=in5(3);
        if isempty(xyzdata)
	  out1=-1;
	  vp_message('Empty Data input');
	  return;
	end
        if size(dimp) < 3
	  out1=-1;
	  vp_message('Data must be 3D');
	  return;
	end
	
	angno=-angno;
	cosangno=cos(angno*2*pi/360); sinangno=sin(angno*2*pi/360);
	%rotmat=zeros(3,3);
	
	newdim=[max(dim) max(dim) max(dim)];
	newvox=min(VOX);
	center=round(newdim/2);
	voxr=[newvox/VOX(1) newvox/VOX(2) newvox/VOX(3)];
	romatrx(1,:)=[cosangno sinangno];
	romatrx(2,:)=[-sinangno cosangno];
		
	if axisno == 1
		%rotmat(1,1)=1;
		%rotmat(2,2)=cosangno; rotmat(2,3)=sinangno; 
		%rotmat(3,2)=-sinangno; rotmat(3,3)=cosangno;
		
	   if strcmp(action,'getplane'), %look at new XY plane 
		dz=0;
		plndata=zeros(newdim(1),newdim(2));
		for ix=1:newdim(1)
		 dx=(ix-center(1))*voxr(1);
		 xp=dx+xp0; xp=round(xp);
		 for iy=1:newdim(2)
			%Place rotation Pt at center of new vol.
		 	dy=(iy-center(2))*voxr(2); 
			
			yp=cosangno*dy + yp0;
			zp=-sinangno*dy + zp0;
			yp=round(yp); zp=round(zp);
			if ( xp < 1 | xp > dimp(1) |... 
			 yp < 1 | yp > dimp(2) |...
			 zp < 1 | zp > dimp(3) ), 
			 plndata(ix,iy)=0;
		  	else, plndata(iy,ix)=xyzdata(xp,yp,zp);
			end
		  end
		end
	        out2=plndata;
		
	   elseif strcmp(action,'getvolume')
	        %vp_message('incomplete algorithm',3);
	        %return;
		nxyzdata=zeros(newdim);
		hwaitbar=waitbar(0,'Processing Rotation ...');
		%Place rotation Pt at center of new vol.
		for ix=1:newdim(1)
		 dx=(ix-center(1))*voxr(1);
		 xp=dx+xp0; xp=round(xp);
		 waitbar(ix/(newdim(1)+1),hwaitbar);
		 for iy=1:newdim(2)
		   dy=(iy-center(2))*voxr(2);
		   for iz=1:newdim(3)
		 	dz=(iz-center(3))*voxr(3);
		        %yzvect=romatrx*[dy dz]';
			%yp=yzvect(1) + yp0;
			%zp=yzvect(2) + zp0;
			yp=cosangno*dy + sinangno*dz + yp0;
			zp=-sinangno*dy + cosangno*dz + zp0;
			yp=round(yp); zp=round(zp); 
			if ( xp < 1 | xp > dimp(1) |... 
			 yp < 1 | yp > dimp(2) |...
			 zp < 1 | zp > dimp(3) ), 
			 nxyzdata(ix,iy,iz)=0;
		  	else, nxyzdata(ix,iy,iz)=xyzdata(xp,yp,zp);
			end
		    end % for iz
		  end % for iy
		end % for ix
		waitbar(1,hwaitbar); close(hwaitbar);
	        out2=nxyzdata; out3=newdim, out4=[newvox newvox newvox],
		out5=center,
	   end % for getvolume
	   
	elseif axisno == 2
		%rotmat(2,2)=1;
		%rotmat(1,1)=cosangno; rotmat(1,3)=-sinangno; 
		%rotmat(3,1)=sinangno; rotmat(3,3)=cosangno;
		
	   if strcmp(action,'getplane'), %look at new XY plane 
		%Place rotation Pt at center of new vol.
		dz=0;
		plndata=zeros(newdim(1),newdim(2));
		for iy=1:newdim(2)
		 dy=(iy-center(2))*voxr(2);
		 yp=dy+yp0; yp=round(yp);
		 for ix=1:newdim(1)
		 	dx=(ix-center(1))*voxr(1); 
			
			xp=cosangno*dx + xp0;
			zp=-sinangno*dx + zp0;
			xp=round(xp); zp=round(zp);
			if ( xp < 1 | xp > dimp(1) |... 
			 yp < 1 | yp > dimp(2) |...
			 zp < 1 | zp > dimp(3) ), 
			 plndata(ix,iy)=0;
		  	else, plndata(iy,ix)=xyzdata(xp,yp,zp);
			end
		  end
		end
	        out2=plndata;
		
	   elseif strcmp(action,'getvolume')
		nxyzdata=zeros(newdim);
		hwaitbar=waitbar(0,'Processing Rotation ...');
		%Place rotation Pt at center of new vol.
		%romatrx(1,2)=-romatrx(1,2);
		%romatrx(2,1)=-romatrx(2,1);
		for iy=1:newdim(2)
		 dy=(iy-center(2))*voxr(2);
		 yp=dy+yp0; yp=round(yp),
		 waitbar(iy/(newdim(2)+1),hwaitbar);
		 for ix=1:newdim(1)
		   dx=(ix-center(1))*voxr(1);
		   for iz=1:newdim(3)
		 	dz=(iz-center(3))*voxr(3);
		        %xzvect=romatrx*[dx dz]';
			%xp=xzvect(1) + xp0;
			%zp=xzvect(2) + zp0;
			xp=cosangno*dx + sinangno*dz + xp0;
			zp=-sinangno*dx + cosangno*dz + zp0;
			xp=round(xp); zp=round(zp); 
			if ( xp < 1 | xp > dimp(1) |... 
			 yp < 1 | yp > dimp(2) |...
			 zp < 1 | zp > dimp(3) ), 
			 nxyzdata(ix,iy,iz)=0;
		  	else, nxyzdata(ix,iy,iz)=xyzdata(xp,yp,zp);
			end
		    end % for iz
		  end % for ix
		end % for iy
		waitbar(1,hwaitbar); close(hwaitbar);
	        out2=nxyzdata; out3=newdim, out4=[newvox newvox newvox],
		out5=center,
	   end % for getvolume
	
	elseif axisno == 3
		%rotmat(3,1)=1;
		%rotmat(1,1)=cosangno; rotmat(1,2)=sinangno; 
		%rotmat(2,1)=-sinangno; rotmat(2,2)=cosangno;
		
	   if strcmp(action,'getplane'), 
		dy=0;
		plndata=zeros(newdim(3),newdim(1));
		for iz=1:newdim(3)
		 dz=(iz-center(3))*voxr(3);
		 zp=dz+zp0; zp=round(zp);
		 for ix=1:newdim(1)
			%Place rotation Pt at center of new vol.
		 	dx=(ix-center(1))*voxr(1); 
			
			%xp=cosangno*dx + sinangno*dy + dimp(1)/2;
			%yp=-sinangno*dx + cosangno*dy + dimp(2)/2;
			
			xp=cosangno*dx + xp0;
			yp=-sinangno*dx + yp0;
			xp=round(xp); yp=round(yp);
			if ( xp < 1 | xp > dimp(1) |... 
			 yp < 1 | yp > dimp(2) |...
			 zp < 1 | zp > dimp(3) ), 
			 plndata(iz,ix)=0;
		  	else, plndata(iz,ix)=xyzdata(xp,yp,zp);
			end
		  end
		end
	        out2=plndata;
		
	   elseif strcmp(action,'getvolume')
		nxyzdata=zeros(newdim);
		hwaitbar=waitbar(0,'Processing Rotation ...');
		for iz=1:newdim(3)
		 waitbar(iz/(newdim(3)+1),hwaitbar);
		 dz=(iz-center(3))*voxr(3);
		 zp=dz+zp0; zp=round(zp);
		 for iy=1:newdim(2)
		   dy=(iy-center(2))*voxr(2);
		   for ix=1:newdim(1)
			%Place rotation Pt at center of new vol.
		 	dx=(ix-center(1))*voxr(1);
			
			xp=cosangno*dx + sinangno*dy + xp0;
			yp=-sinangno*dx + cosangno*dy + yp0;
			xp=round(xp); yp=round(yp); 
			if ( xp < 1 | xp > dimp(1) |... 
			 yp < 1 | yp > dimp(2) |...
			 zp < 1 | zp > dimp(3) ), 
			 nxyzdata(ix,iy,iz)=0;
		  	else, nxyzdata(ix,iy,iz)=xyzdata(xp,yp,zp);
			end
		    end % for ix
		  end % for iy
		end % for iz
		waitbar(1,hwaitbar); close(hwaitbar);
	        out2=nxyzdata; out3=newdim, out4=[newvox newvox newvox],
		out5=center,
	   end % for getvolume
	end % for axis no 3
	
