function [out1, out2]=vp_savaslice(imop,fname,fidop,outop)
% Save an image slice as a single plane of an ANALYZE image.
%_______________________________________________________________________
% vp_savslice saves single or multi-slice data read from a figure 
% as an ANALYZE format image.
% Slices are scaled and converted to real values before saving.
%
% imop=1  :  open file, save a single slice, close file and save header.
% imop=2  :  open file, save a single slice
% imop=3  :  Save next slice
% imop=4  :  Close file and save header
%
% fname   :  file name
% fidop   :  file fid
%
% outop=1  :  Return DATA without writing image
% outop=2  :  Write image
% outop=3  :  Return DATA and write image
% out1   :  Return value
% out2   :  Return DATA
%_______________________________________________________________________
% vp_savaslice		ScAnVP C.4.7	P. Spetsieris	07/27/2001
%                   ScAnVP Rev. 7.0 P. Spetsieris   01/10/2016

global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN
global EXPTIM DURATION MATYPE GENTIM SUBID EXPDATE hrname
global HelpMode DisplayOrient InputOrient

if HelpMode, vp_help(mfilename), return ; end;

out1=0;
out2=0;

dim3=0;

plno=0;

dataop=2;
nargin,

if nargin > 3, dataop=outop; end;

if imop < 3 ,

	  fname=deblank(fname);
	
  	  %P=strtok(fname,'.');
    	  P=vp_nm('dnm',fname);

	  nameimg=[P '.img'],
	  fidop=fopen(nameimg,'w');

end;
	
if imop ~= 4,

	%h=waitbar(0,['Processing Save SLICE ' ...']);
	%waitbar(.5,h);

	SDATA=[];
	glmaxdat=0;
	
	vp_note('Pick Slice',2);

	[x,y]=ginput(1);

	if strcmp(get(gco,'type'),'image')
	  cdata=get(gco,'CDATA');
	  sz=size(cdata);
	  if length(sz) > 2,
	     out1=-1;
	     vp_message('Cannot Process 3D RGB ');
	     sz,
	     fclose(fidop);
	     delete(nameimg);
	     return;
	  end;
	   
	  cdata=cdata';
  
	  sz=size(cdata);
	  mx=max(max(cdata));
	  mn=min(min(cdata));

	  if (imop ==3),
	    if ( (sz(1) ~=DIM(1)) | (sz(2) ~= DIM(2) )),
	     out1=-1;
	     vp_message('Incompatible Dimensions ');
	     DIM, sz,
	     return;
	    else, DIM(3)=DIM(3)+1;
	    end
	  else
	    DIM(1)=sz(1); DIM(2)=sz(2); DIM(3)=1;
	  end
  
	  udata=get(gca,'UserData');
	  if ~isempty(udata),
	    viewno=udata(1); plno=udata(2); VOX=udata(3:5); ORIGIN=udata(6:8);
	  end
  
	else
	  out1=-1;
	  vp_message('Not an ''image'' point');
	  return;
	end

	SDATA=(double(cdata));

	if dataop ~=2, out2=SDATA; end;
	if dataop==1, return, end;

	%WRITE IMAGE

	SCALE=1;
	TYPE=64; %double

	DESCRIP=['ScAnVP SAVed Slice', num2str(plno)];

	glmaxdat=max(max(SDATA));
	if glmaxdat == 0,
	  vp_note(['WARNING: 0 maximum']);
	  waitfor(findobj('Name','note'));
	  %while(findobj('Name','Message')),pause(1),end;
	end

	datype='double';
	glmax=1;
	
   
    if (DisplayOrient~=InputOrient) % FLIP & save all views the same
                      % because can only be redisplayed as axial.
          SDATA = fliplr(SDATA');
          SDATA = SDATA';
    end;
     
	no=fwrite(fidop,SDATA,datype);
	if no <=0,
	  	vp_message(['Write ERROR no: ' num2str(no) ' pixels']) ;
		out1=-1;
		return;
	end
	
	%waitbar(1,h); pause(1); close(h);

end % imop not == 4
	
if imop ==1 | imop == 4

	 fclose(fidop);

	 SCALE=1.0;

	 if imop ==1
	   DIM(3)=1; % Write only one slice
	   ORIGIN(3)=1;
	 end

	 vp_hwrite(nameimg,DIM,VOX,SCALE,TYPE,OFFSET,ORIGIN,DESCRIP,EXPTIM,DURATION,GENTIM,SUBID,EXPDATE,glmax);
	 disp([nameimg ' File written']);

end %if imop


vp_note('Slice Processing Completed',2);
