function vp_scatterplot(scores,norms,nosubs,sub,labelx,labely,netnam)
% function vp_scatterplot(scores,norms,nosubs,sub,labelx,labely,netnam)
% Plots a scatter plot of scores including errorbars
%_______________________________________________________________________
% This function was written for plotting SSF scores but can be used
% to scatter plot other vectors including values for 3 different sets.
% SSF score vectors should includes reference subjects starting with
% controls, followed by other reference subjects and ending with new
% subjects. The number of subjects in each group is specified as well
% as X and Y axis labels. The mean and std of the control and  
% reference subjects are plotted alongside as errorbars.
% The plot legend specifies the mean and std for each subject set. 
% If controls are specified, P-values result from tests of the  
% hypothesis of equal means of the non-control groups with respect
% to the first (control) group using either a ttest2 (for samples 
% with equal variance) or tutest2 (unequal variances). Equal variance
% is tested using an ftest. A significance level=0.05 is assumed for
% all tests.
% For a single subject the p-value results from a t-test that the subject
% value is equal to the mean of the control sample within 0.05 significance.
%
% scores: Vector including all scores
% norms:  Number of controls
% nosubs: Total number of reference subjects
% sub:   Total number of new subjects
% netnam: Title, e.g. Network Name
%_______________________________________________________________________
% vp_scatterplot.m   ScAnVP ver. 5.7    P. Spetsieris   May 18, 2006
% 	 rev.   ScAnVP ver. 5.7.w    P. Spetsieris   Nov. 22, 2006
% 	 rev.   ScAnVP ver. 6.2      P. Spetsieris   Oct. 16, 2012
% 	 rev.   ScAnVP ver. 6.2.2    P. Spetsieris   Dec.  4, 2013

global P2 Scattering

% create scatter plot
%xpos=ones(length(scores) + 3, 1);
xpos=ones(length(scores), 1);
ebar=zeros(size(scores));

if Scattering % Cloud offset

 dx=1/(nosubs+sub); ddx=0;
 if norms > 0, ddx=dx*norms/2; 
   for i=1:norms, xpos(i)=1-ddx + (i-1)*dx; end; end; 
 for i=norms+1:nosubs, xpos(i)=3; end;
 if nosubs-norms > 0, ddx=dx*(nosubs-norms)/2; 
   for i=norms+1:nosubs, xpos(i)=3-ddx + (i-norms-1)*dx; end;end;
 if sub > 0
   ddx=dx*sub/2;
   for i=nosubs+1:nosubs+sub, xpos(i)=5-ddx + (i-nosubs-1)*dx; end;
 end

else % Vertical position 
 if norms > 0
   for i=1:norms, xpos(i)=1; end;  
 end;
 for i=norms+1:nosubs, xpos(i)=3; end;
 if sub > 0
   for i=nosubs+1:nosubs+sub, xpos(i)=5; end;
 end
end

if norms > 0
  i=i+1
  xpos(i)=1.5;
  scores(i)=mean(scores(1:norms));
  ebar(i)=std(scores(1:norms));
end

i=i+1;
xpos(i)=3.5;
scores(i)=mean(scores(norms+1:nosubs));
ebar(i)=std(scores(norms+1:nosubs));
if norms > 0
 [Hf2,Pf2]= ftest_levene(scores(1:norms), scores(norms+1:nosubs), .05), % test equal variances
 if Hf2 == 0, % equal variances
   ev2='(ev)';
   [H2,P2,CI2,STATS2]=ttest2(scores(1:norms),scores(norms+1:nosubs), .05),
 else
   ev2='(uev)';
   [H2,P2,CI2,STATS2]=tutest2(scores(1:norms),scores(norms+1:nosubs), .05), % unequal variances
 end
end

if sub > 0
  i=i+1;
  xpos(i)=5.5;
  scores(i)=mean(scores(nosubs+1:nosubs+sub));
  ebar(i)=std(scores(nosubs+1:nosubs+sub));
  if norms > 0
   if sub > 1
     [Hf3,Pf3]= ftest_levene(scores(1:norms), scores(nosubs+1:nosubs+sub), .05), % test equal variances
     if Hf3 == 0, % equal variances
        ev3='(ev)';
    	disp('t-test2 Compare 2 samples for equal means assuming equal variances');
   	[H3,P3,CI3,STATS3]=ttest2(scores(1:norms),scores(nosubs+1:nosubs+sub), .05),
     else
        ev3='(uev)';
    	disp('t-utest2 Compare 2 samples for equal means assuming unequal variances');
   	[H3,P3,CI3,STATS3]=tutest2(scores(1:norms),scores(nosubs+1:nosubs+sub), .05), % unequal variances
     end
   else
    ev3='(ps1)';
    % These tests are not really appropriate in this case but are left here for a test purpose
    disp('t-test Compare 2 samples for equal means assuming equal variances: t=(mean diff)/std(cntrls)*sqrt(1/nctrls + 1/nnew)');
    [H3,P3,CI3,STATS3]=ttest2(scores(1:norms),scores(nosubs+1:nosubs+sub), .05), % Test if 2 Sample Means are Equal
    % This test should be used if the population mean is known and we want to compare the sample mean
    disp('t-test compare value with control mean: t=(mean diff) * sqrt(nctrls)/std(cntrls)');
    [H3,P3,CI3,STATS3]=ttest(scores(1:norms),scores(nosubs+1:nosubs+sub), .05), % Test Control Mean == Value
   end
  end
end
hfigscat=figure;
%scatter(xpos',scores,'filled');
%scatter(xpos',scores);

errorbar(xpos(:,1),scores,ebar,'b.');
%set(gca,'Color',[0.94 0.92 0.95]);
set(gca,'FontSize',12);
set(gca,'FontWeight','Bold');
ch=get(gca,'Children');
%set(ch,'MarkerSize',20);
set(ch,'MarkerSize',22);
set(ch,'LineWidth',2);

%errorbar(xpos(:,1),scores,ebar,'bo');

%errorbar(xpos(:,1),scores,ebar,'kd');
if norms >0
 if sub> 0
   set(gca,'XLim',[-1,6]);
 else
   set(gca,'XLim',[-1,5]);
 end
else
 if sub> 0
  set(gca,'XLim',[0,6]);
 else
   set(gca,'XLim',[1,5]);
 end
end

set(gca,'XTickLabel',[]);

labelx=strrep(labelx,'_','-');
labely=strrep(labely,'_','-');
xlabel(labelx);
ylabel(labely);
%xlabel('CONTROLS               REF SUBJECTS              NEW SUBJECTS');
%ylabel('SSF SCORES');

legstr=[''];

%    legstr=[legstr, '   S:[',num2str(round(100*scores(i))/100),', ',num2str(round(100*ebar(i))/100),', ',num2str(round(100*P3)/100),ev3,']'];
if sub > 0
  if norms > 0
    legstr=[legstr, '   S:[',num2str(round(100*scores(i))/100),', ',num2str(round(100*ebar(i))/100),', ',num2str(round(10000*P3)/10000),ev3,']'];
  else
    legstr=[legstr, '   S:[',num2str(round(100*scores(i))/100),', ',num2str(round(100*ebar(i))/100),']'];
  end
  i=i-1;
end

if norms > 0
 legstr=['   R:[',num2str(round(100*scores(i))/100),', ',num2str(round(100*ebar(i))/100),', ',num2str(round(10000*P2)/10000),ev2,']',legstr];
else
 legstr=['   R:[',num2str(round(100*scores(i))/100),', ',num2str(round(100*ebar(i))/100),']',legstr];
end

if norms > 0
   i=i-1;
   legstr=['C:[',num2str(round(100*scores(i))/100),', ',num2str(round(100*ebar(i))/100),']',legstr];
end;

if norms > 0
 legstr=['Mean,STD,p(EM):   ',legstr];
else
 legstr=['Mean,STD:   ',legstr];
end
hlg=legend(legstr,'location','NorthOutside');
set(gcf,'name',netnam);


