% vp_screengui.m
% background screen color options
%___________________________________________________________________________
%
% Options are provided to set the active and default figure screen background
% color, and to allow inversion of background and text colors on hardcopy and 
% file output for any subsequently created figures.
%__________________________________________________________________________
% vp_screengui.m	ScAnVP  P. Spetsieris	April 3, 2008

global HelpMode hpFig GCM CM FI UFI Ecolor

if HelpMode, vp_help('vp_screengui'), return ; end;

Message0=['............................................ '];
Message=Message0;

Fcolor = [.8,.8,.9];
Bcolor = [.9,.8,.9];

if ~exist('UFI') | (exist('UFI') & UFI==0 ) 
 if ~exist('FI') | (exist('FI') & isempty(FI) ) 
	CFI=figure('Position',[370,150,5,256],...
	'Units','Pixels');
	data=[];
	for i=0:255, data(256-i)=i; end;
	data = data';
	imagesc(data,[0 255]);
	axis off;
 else CFI=FI; end;
else CFI=UFI;
end

screengui=findobj('Name','screengui');
if isempty(screengui)
	screengui = figure('Color','w','Name','screengui',...
	'Color',Fcolor,...
	'NumberTitle','off','Position',[220,50,190,225],...
	'Units','Pixels');
else
 figure(screengui);
 return;
end;
	
 
uicontrol(screengui,'string', 'Help',...
	'TooltipString',HelpMsg,...
	'BackgroundColor',Ecolor,...
	'position',[135 190 35 20],'callback','vp_help(''vp_screengui'');');


dfco=uicontrol(screengui,'string', '',...
	'TooltipString','Set Figure Screen Color',...
	'BackgroundColor',get(CFI,'color'),...
	'position',[10 150 170 15],...
	'callback',['figure(CFI); vp_scrncolor(CFI); set(gcbo,''BackgroundColor'',get(CFI,''color''))']);


uicontrol(screengui,'string', 'SET DEFAULT SCRN COL',...
	'TooltipString','Set New Default Background Screen Color',...
	'BackgroundColor',Fcolor,'callback',['vp_note(''PRESS BAR BELOW'',2)'],...
	'position',[10 165 170 15]);

uicontrol(screengui,'String','INVERT SCRN/TXT COL OUT',...
	'TooltipString','Invert screen and text color on new figures hardcopy output',...
	'Position',[10 120 175 20],...
	'CallBack','set(0,''DefaultFigureInvertHardCopy'',''on'')',...
	'BackgroundColor',Bcolor,...
	'ForegroundColor',Tcolor);

uicontrol(screengui,'String','RETAIN SCRN/TXT COL OUT',...
	'TooltipString','Retain screen and text color on new figures hardcopy output',...
	'Position',[10 100 175 20],...
	'CallBack','set(0,''DefaultFigureInvertHardCopy'',''off'')',...
	'BackgroundColor',Bcolor,...
	'ForegroundColor',Tcolor);

uicontrol(screengui,'String','WHITE',...
	'Position',[10 70 45 15],...
	'TooltipString','WHITE Color Background',...
	'BackgroundColor',[1 1 1],...
	'CallBack',['figure(CFI); col=[1 1 1]; set(CFI,''color'',col);']);

uicontrol(screengui,'String','GRAY 1',...
	'Position',[55 70 45 15],...
	'TooltipString','MEDIUM GRAY Color Background',...
	'BackgroundColor',[.7 .7 .7],...
	'CallBack',['figure(CFI); col=[.7 .7 .7]; set(CFI,''color'',col);']);

uicontrol(screengui,'String','GRAY 2',...
	'Position',[100 70 45 15],...
	'TooltipString','DARK GRAY Color Background',...
	'BackgroundColor',[.3 .3 .4],...
	'CallBack',['figure(CFI); col=[.3 .3 .4]; set(CFI,''color'',col);']);

uicontrol(screengui,'String','RED 1',...
	'Position',[10 55 45 15],...
	'TooltipString','Bright Red Color Background',...
	'BackgroundColor',[1.0 0 0],...
	'CallBack',['figure(CFI); col=[1.0 0 0 ]; set(CFI,''color'',col);']);

uicontrol(screengui,'String','RED 2',...
	'Position',[55 55 45 15],...
	'TooltipString','Medium RED Color Background',...
	'BackgroundColor',[.7 0 0],...
	'CallBack',['figure(CFI); col=[.7 0 0 ]; set(CFI,''color'',col);']);

uicontrol(screengui,'String','RED 3',...
	'Position',[100 55 45 15],...
	'TooltipString','DARK RED Color Background',...
	'BackgroundColor',[.4 0 0],...
	'CallBack',['figure(CFI); col=[0.4 0 0 ]; set(CFI,''color'',col);']);

uicontrol(screengui,'String','BLUE 2',...
	'Position',[10 40 45 15],...
	'TooltipString','Medium BLUE Color Background',...
	'BackgroundColor',[.2 .4 .6 ],...
	'CallBack',['figure(CFI); col=[.2 .4 .6 ]; set(CFI,''color'',col);']);

uicontrol(screengui,'String','CYAN',...
	'Position',[55 40 45 15],...
	'TooltipString','CYAN Color Background',...
	'BackgroundColor',[0 1 1],...
	'CallBack',['figure(CFI); col=[0 1.0 1.0 ]; set(CFI,''color'',col);']);

uicontrol(screengui,'String','GREEN',...
	'Position',[100 40 45 15],...
	'TooltipString','GREEN Color Background',...
	'BackgroundColor',[0.4 0.6 0.4],...
	'CallBack',['figure(CFI); col=[0.4 0.6 0.4]; set(CFI,''color'',col);']);

uicontrol(screengui,'String','BLUE 3',...
	'Position',[10 25 45 15],...
	'TooltipString','Dark BLUE Color Background',...
	'BackgroundColor',[0.2 0.3 0.4],...
	'CallBack',['figure(CFI); col=[.2 .3 .4]; set(CFI,''color'',col);']);

uicontrol(screengui,'String','CYAN 2',...
	'Position',[55 25 45 15],...
	'TooltipString','Medium CYAN Color Background',...
	'BackgroundColor',[0 .7 .7],...
	'CallBack',['figure(CFI); col=[0 .7 .7 ]; set(CFI,''color'',col);']);

uicontrol(screengui,'String','BLACK',...
	'Position',[100 25 45 15],...
	'TooltipString','BLACK Color Background',...
	'BackgroundColor',[0.2 .2 .2],...
	'CallBack',['figure(CFI); col=[0 0 0]; set(CFI,''color'',col);']);

uicontrol(screengui,'string', 'KEYIN',...
	'TooltipString','Set Background Screen Color',...
	'BackgroundColor',Ecolor,...
	'position',[10 5 45 15],'callback','vp_scrncolor(CFI);');

uicontrol(screengui,'string', 'EXIT',...
	'TooltipString','CANCEL',...
	'position',[140 5 35 15],'BackgroundColor',Bcolor,...
	'callback',['delete(screengui); if ~exist(''FI''), delete(CFI); end;']);
