% vp_semirange.m
% Set colormap semi-range limits and apply to handle
%
% The user can manipulate seperately the threshold range
% of the upper and lower segments of a bicolor colormap 
% such as 'GRAYHOT' which uses the lower gray colors for
% the background (MRI) image and the upper color segment
% for the foreground (statistical PET values).
%
%__________________________________________________________________________
% vp_semirange.m	C.4.6 	P. Spetsieris	 Mar. 17, 2000
%			Revision 5.1 by P.S. 5/21/03

global HelpMode 
global UFI UF0 UThMax UThMin LThMax LThMin Message hUmaxslider hUminslider 
global semirange hUThMin hUThMax hclaxis hims RaScl hudatmax hudatmin
global DATAMIN DATAMAX SCALE GLMIN GLMAX GCM CM

if HelpMode, vp_help(mfilename), return ; end;

delete(findobj('Name','rangegui'));
semirange=findobj('Name','semirange');
if ~isempty(semirange)
	if (UFI ~= UF0), delete(semirange); vp_semirange; return; 
	
	elseif(strcmp(get(semirange,'Visible'),'on'))
		figure(semirange);
		set(semirange,'colormap',get(UFI,'colormap'));
	end
	return
end


if ~exist('DATAMIN'),DATAMIN=SCALE*GLMIN; end;
if ~exist('DATAMAX'),DATAMAX=SCALE*GLMAX; end;

if (DATAMAX-DATAMIN)==0, vp_message('DATAMAX-DATAMIN =0'), return; end;
RaScl=200.0/(DATAMAX-DATAMIN);

UThMax=100;
UThMin=0;
LThMax=100;
LThMin=0;

UDMax=DATAMAX;
UDMin=(DATAMAX+DATAMIN)/2;

LDMax=UDMin-(UDMax-UDMin)/128 ;
LDMin=DATAMIN;
LRaScl=100.0/(LDMax-DATAMIN);

UDThMax=UDMax;
UDThMin=UDMin;
LDThMax=LDMax;
LDThMin=LDMin;



if ~exist('UFI')
	UFI=gcbf;
	UF0=UFI;
end


ch=get(UFI,'children');
len=length(ch);

if len==0, msg=['Valid Data Image - Not Found']; vp_message(msg); return; end;

axcb=['hims=[];',...
'for i=1:len, if strcmp(get(ch(i),''type''),''axes''),hims=[hims,ch(i)]; end; end;'];


GCM=get(UFI,'colormap');

frmcolor=[0.5 0.7 0.8];
Bcolor = [.8,1,1];


len=length(GCM);
cm1=GCM(1:round(len/2),:);
cm2=GCM(round(len/2)+1:len,:);
cm11=cm1; cm22=cm2;
len1=length(cm1); len2=length(cm2);
RaCol=(len/2-1)/100;
jthmin=1+UThMin*RaCol;
jthmax=1+UThMax*RaCol;

semirange = figure('Color',frmcolor,'Name','semirange',...
'NumberTitle','off','Position',[255,220,115,370],...
'colormap',get(UFI,'colormap'),...
'Units','Pixels');

cm2cb=[ 'jthmin=1+round(UThMin*RaCol); jthmax=1+round(UThMax*RaCol);',...
	'if jthmax <= jthmin, jthmax=min(jthmin+1,len2); end;',...
	'for j=1:jthmin, cm22(j,:)=cm2(1,:); end;',...
	'for j=jthmax:len2, cm22(j,:)=cm2(len2,:); end;',...
	'for j=jthmin+1:jthmax-1, i=1+round(((j-jthmin)*(len2-1))/(jthmax-jthmin));',...
	'cm22(j,:)=cm2(i,:); end;',...
	'CM=[cm11; cm22;]; colormap(CM);'];

eval(cm2cb); 

cm1cb=[ 'jthmin=1+round(LThMin*RaCol); jthmax=1+round(LThMax*RaCol);',...
	'if jthmax <= jthmin, jthmax=min(jthmin+1,len2); end;',...
	'for j=1:jthmin, cm11(j,:)=cm1(1,:); end;',...
	'for j=jthmax:len1, cm11(j,:)=cm1(len1,:); end;',...
	'for j=jthmin+1:jthmax-1, i=1+round(((j-jthmin)*(len1-1))/(jthmax-jthmin));',...
	'cm11(j,:)=cm1(i,:); end; CM=[cm11; cm22;]; colormap(CM);'];

eval(cm1cb); 

uicontrol(semirange,'Style','text','string',...
	 ['MAX,MIN ' sprintf('%.4f',DATAMAX) ',' sprintf('%.4f',DATAMIN)],...
	'position',[10 350 90 15],'BackgroundColor',frmcolor);
	
uicontrol(semirange,'Style','text','string', 'UPPER RANGE',...
	'position',[10 333 80 15],'BackgroundColor',frmcolor);
	
uicontrol(semirange,'Style','text','string', '%',...
	'position',[45 317 10 15],'BackgroundColor',frmcolor);
	
uicontrol(semirange,'Style','text','string', 'LOWER RANGE',...
	'position',[10 20 90 15],'BackgroundColor',frmcolor);
	
hudatmax=uicontrol(semirange,'Style','text','string', sprintf('%.4f',UDThMax),...
	'position',[70 305 40 15],'BackgroundColor',frmcolor);
	
hudatmin=uicontrol(semirange,'Style','text','string', sprintf('%.4f',UDThMin),...
	'position',[70 185 40 15],'BackgroundColor',frmcolor);
	
hldatmax=uicontrol(semirange,'Style','text','string', sprintf('%.4f',LDThMax),...
	'position',[70 170 40 15],'BackgroundColor',frmcolor);
	
hldatmin=uicontrol(semirange,'Style','text','string', sprintf('%.4f',LDThMin),...
	'position',[70 39 40 15],'BackgroundColor',frmcolor);
	
cbUThMax=['set(semirange,''colormap'',get(UFI,''colormap''));',...
	'UThMax=max([UThMin+1 str2num(get(hUThMax,''string''))]); ',...
	'if(UThMax < UThMin+1), UThMax=UThMin+1; end; if(UThMax > 100); UThMax=100; end;',...
	'set(hUThMax,''string'',UThMax);',...
	'set(hUmaxslider,''Value'',UThMax);',...
	'figure(semirange); eval(cm2cb);',...
	'set(hudatmax,''String'',sprintf(''%.4f'',UDMin+UThMax/RaScl));',...
	'figure(UFI); colormap(CM);'];
	
cbSliUThMax=['set(semirange,''colormap'',get(UFI,''colormap''));',...
	'UThMax=max([UThMin+1 ceil(get(gco,''Value''))]);, set(hUThMax,''string'',UThMax);',...
	'figure(semirange); eval(cm2cb);',...
	'set(hudatmax,''String'',sprintf(''%.4f'',UDMin+UThMax/RaScl));',...
	'figure(UFI); colormap(CM);'];
	
cbSliUThMin=['set(semirange,''colormap'',get(UFI,''colormap''));',...
	'UThMin=min([UThMax-1 ceil(get(gco,''Value''))]);, set(hUThMin,''string'',UThMin);',...
	'figure(semirange); eval(cm2cb);',...
	'set(hudatmin,''String'',sprintf(''%.4f'',UDMin+UThMin/RaScl));',...
	'figure(UFI); colormap(CM);'];
	
cbUThMin=['set(semirange,''colormap'',get(UFI,''colormap''));',...
	'UThMin=min([UThMax-1 str2num(get(hUThMin,''string''))]); ',...
	'if(UThMin < 0), UThMin=0; end; if(UThMin > UThMax-1); UThMin=UThMax-1; end;',...
	'set(hUThMin,''string'',UThMin);',...
	'set(hUminslider,''Value'',UThMin);',...
	'figure(semirange); eval(cm2cb);',...
	'set(hudatmin,''String'',sprintf(''%.4f'',UDMin+UThMin/RaScl));',...
	'figure(UFI); colormap(CM);'];
	
cbLThMax=['set(semirange,''colormap'',get(UFI,''colormap''));',...
	'LThMax=max([LThMin+1 str2num(get(hLThMax,''string''))]); ',...
	'if(LThMax < LThMin+1), LThMax=LThMin+1; end; if(LThMax > 100); LThMax=100; end;',...
	'set(hLThMax,''string'',LThMax);',...
	'set(hLmaxslider,''Value'',LThMax);',...
	'figure(semirange); eval(cm1cb);',...
	'set(hldatmax,''String'',sprintf(''%.4f'',LDMin+LThMax/LRaScl));',...
	'figure(UFI); colormap(CM);'];
	
cbSliLThMax=['set(semirange,''colormap'',get(UFI,''colormap''));',...
	'LThMax=max([LThMin+1 ceil(get(gco,''Value''))]);, set(hLThMax,''string'',LThMax);',...
	'figure(semirange); eval(cm1cb);',...
	'set(hldatmax,''String'',sprintf(''%.4f'',LDMin+LThMax/LRaScl));',...
	'figure(UFI); colormap(CM);'];
	

cbSliLThMin=['set(semirange,''colormap'',get(UFI,''colormap''));',...
	'LThMin=min([LThMax-1 ceil(get(gco,''Value''))]);, set(hLThMin,''string'',LThMin);',...
	'figure(semirange); eval(cm1cb);',...
	'set(hldatmin,''String'',sprintf(''%.4f'',LDMin+LThMin/LRaScl));',...
	'figure(UFI); colormap(CM);'];
	
		
cbLThMin=['set(semirange,''colormap'',get(UFI,''colormap''));',...
	'LThMin=min([LThMax-1 str2num(get(hLThMin,''string''))]); ',...
	'if(LThMin < 0), LThMin=0; end; if(LThMin > LThMax-1); LThMin=LThMax-1; end;',...
	'set(hLThMin,''string'',LThMin);',...
	'set(hLminslider,''Value'',LThMin);',...
	'figure(semirange); eval(cm1cb);',...
	'set(hldatmin,''String'',sprintf(''%.4f'',LDMin+LThMin/LRaScl));',...
	'figure(UFI); colormap(CM);'];
	
	
hUThMax=uicontrol(semirange,'style','edit','string',UThMax,...
	'position',[12 320 30 13],'BackgroundColor',Bcolor,'callback',cbUThMax);
	
hUmaxslider=uicontrol(semirange,'Style','slider', 'Position', [ 20 260 13 60], 'Min',0,'Max',100,...
	'TooltipString','Set Threshold % Range Maximum',...
	'Value',UThMax,'Callback',cbSliUThMax);
	
hUminslider=uicontrol(semirange,'Style','slider', 'Position', [20 200 13 60], 'Min',0,'Max',100,...
	'TooltipString','Set Threshold % Range Minimum',...
	'Value',UThMin,'Callback',cbSliUThMin);
	
hUThMin=uicontrol(semirange,'style','edit','string',UThMin,...
	'position',[12 190 30 13],'BackgroundColor',Bcolor,'callback',cbUThMin);
	
hLThMax=uicontrol(semirange,'style','edit','string',LThMax,...
	'position',[12 177 30 13],'BackgroundColor',Bcolor,'callback',cbLThMax);

hLmaxslider=uicontrol(semirange,'Style','slider', 'Position', [ 20 115 13 60], 'Min',0,'Max',100,...
	'TooltipString','Set Threshold % Range Maximum',...
	'Value',LThMax,'Callback',cbSliLThMax);
	
hLminslider=uicontrol(semirange,'Style','slider', 'Position', [20 55 13 60], 'Min',0,'Max',100,...
	'TooltipString','Set Threshold % Range Minimum',...
	'Value',LThMin,'Callback',cbSliLThMin);
	
hLThMin=uicontrol(semirange,'style','edit','string',LThMin,...
	'position',[12 39 30 13],'BackgroundColor',Bcolor,'callback',cbLThMin);


uicontrol(semirange,'String','RESET',...
	'Position',[10 5 40 15],...
	'CallBack',['figure(UFI); colormap(GCM);',...
	'delete(findobj(''name'',''semirange'')); vp_semirange;']);
	
uicontrol(semirange,'String','EXIT',...
	'Position',[55 5 40 15],...
	'CallBack','delete(gcbf);');
	

hclaxis=axes('position', [ 0.42 0.15 0.16 0.70]);

data=[];
for i=0:255, data(256-i)=DATAMIN + i*(DATAMAX-DATAMIN)/255; end;
data = data';
imagesc(data,[DATAMIN DATAMAX]);
axis off;

