function vp_smooth()
%__________________________________________________________________________
% function vp_smooth.m
% Smooth image using bilinear interpolation
%
% The smoothing operation is applied to the
% selected image figure. Text lines are replaced but
% other elements may be erased.
% This operation is for viewing only and should not
% be used on data undergoing analysis.
%__________________________________________________________________________
% function vp_smooth.m    ScAnVP C.4.6 	P. Spetsieris	Jan. 23, 2001
%                Revision 6.1 by P.S.	May. 24, 2011

global HelpMode 
global UFI

if HelpMode, vp_help(mfilename), return ; end;


vp_note('Warning: Smooth For Display Only',2);
if menu('May Corrupt Data','Smooth','Cancel') == 2, return, end;

if ~exist('UFI') 
	UFI=gcbf;
end

figure(UFI);

figdim=get(UFI,'position');

ch=get(UFI,'children');
len=length(ch);

if len==0, msg=['Valid Data Image - Not Found']; vp_message(msg); return; end;


str=[]; pos=[]; col=[]; foname=[]; fweight=[]; fsize=[]; fangle=[]; funits=[]; valign=[]; halign=[];
drawbar=0;
for i=len:-1:1, if strcmp(get(ch(i),'type'),'axes'),
   haxch=get(ch(i),'children'); lenaxch=length(haxch);
   for j=1:lenaxch,
    type=get(haxch(j),'type');
    if strcmp(type,'image'),
      nmtag=get(haxch(j),'tag');
      if ~strcmp(nmtag,'TMW_COLORBAR'),
	clims=get(ch(i),'CLIM');
	axpos=get(ch(i),'Position');
	dat=get(haxch(j),'CDATA');
	datmin=min(min(dat)); datmax=max(max(dat));
	if (datmax-datmin)==0, vp_message('datamax-datamin =0'), return; end;
	[datm,datn]=size(dat);
	%newdim=[axpos(3)*figdim(3)*(datm/datn),axpos(4)*figdim(4)];
	newdim=[axpos(3)*figdim(3)*(datm/datn),axpos(3)*figdim(3)];
	bidata=imresize(dat,newdim,'bilinear');
	newdim=size(bidata);
	
	udata=get(ch(i),'UserData');
	%chi=ch(i), hch=haxch(j),
	viewno=0; plno=0; vox=[0 0 0]; xyzor=[0 0 0];
  	if ~isempty(udata),
	  if length(udata)==8 ,
    		viewno=udata(1); plno=udata(2); vox=udata(3:5); xyzor=udata(6:8);
	  end;
	end
	
	axes(ch(i));
	
	imagesc(bidata,[datmin datmax]);
	caxis(clims);
	axis off image xy;
	viewno,
	vp_aspect(viewno,vox);
	
	newrat=[newdim(1)/datm, newdim(2)/datn] ;
	
	if viewno==1
	  vox=[vox(1)/newrat(1), vox(2)/newrat(2), vox(3)];
	  xyzor=[xyzor(1)*newrat(1), xyzor(2)*newrat(2), xyzor(3)];
    	elseif viewno==2,
	  vox=[vox(1), vox(2)/newrat(1), vox(3)/newrat(2)];
	  xyzor=[xyzor(1), xyzor(2)*newrat(1), xyzor(3)*newrat(2)];
    	elseif viewno==3,
	  vox=[vox(1)/newrat(1), vox(2), vox(3)/newrat(2)];
	  xyzor=[xyzor(1)*newrat(1), xyzor(2), xyzor(3)*newrat(2)];
    	end
	
	set(gca,'UserData',[viewno plno vox xyzor]);
	
	ntx=length(fsize);
        for k=1:ntx,
	 text(pos(k,1)*newrat(1),pos(k,2)*newrat(2),str(k,:),'FontName',foname(k,:),'FontWeight',fweight(k,:),'FontSize',fsize(k,:),...
	 'color',col(k,:),'FontAngle',fangle(k,:),...
	 'FontUnits',funits(k,:),'VerticalAlignment',valign(k,:),'HorizontalAlignment',halign(k,:));
	end
	str=[]; pos=[]; col=[]; foname=[]; fweight=[]; fsize=[]; fangle=[]; funits=[]; valign=[]; halign=[];
	if drawbar==1, try colorbar('v6','vert'); catch colorbar; end; drawbar=0; end;
       else
        drawbar=1;
       end; %not bar	
	  
     else
     	if strcmp(type,'text');
	 str=strvcat(str,get(haxch(j),'string'));
	 pos=[pos;get(haxch(j),'position')];
	 col=[col;get(haxch(j),'color')];
	 foname=strvcat(foname,get(haxch(j),'FontName'));
	 fweight=strvcat(fweight,get(haxch(j),'FontWeight'));
	 fsize=[fsize;get(haxch(j),'FontSize');];
	 fangle=strvcat(fangle,get(haxch(j),'FontAngle'));
	 funits=strvcat(funits,get(haxch(j),'FontUnits'));
	 valign=strvcat(valign,get(haxch(j),'VerticalAlignment'));
	 halign=strvcat(halign,get(haxch(j),'HorizontalAlignment'));
	 
	 %text(newdim(1)-1,newdim(2)-1,str,'FontName',foname,'FontWeight',fweight,'FontSize',fsize,...
	 %'color',col,'FontAngle',fangle,...
	 %'FontUnits',funits,'VerticalAlignment',valign,'HorizontalAlignment',halign);
	  
	end
        %haxch(j), ch(i),
     	%hcpy=copyobj(haxch(j),ch(i)),
	%get(hcpy),
     end;
     
    end;
    
end; end;

