
% Rendering of regional effects [SSM{Z/F}] on transverse sections
% FORMAT vp_spmtranslicesN 
%_______________________________________________________________________
%
% vp_spmtranslicesN is called by vp_spmtranslices and uses variable in working
% memory to create a complete set of transverse sections 2mm apart though
% the background image selected in spm_transverse.
% Regional foci from the selected SSM{Z/F} are rendered on this image.
% vp_spmtranslicesN is a complement to spm_transverse not in the original
% spm99b package and is based on the code written for spm_transverse.
%
%_______________________________________________________________________
% vp_spmtranslicesN.m   Modification of spm_transverse  Phoebe Spetsieris 3/22/99

%PS

if NSlices <=0, return; end;

Fgraph2=spm_figure('Create','SlicesNa','Graphics','on');
set(Fgraph2,'Pointer','watch') ;

subplot(6,6,1);
delete(gca),
spm_figure('DeletePageControls',Fgraph2)

% configure {128 level} colormap
%-----------------------------------------------------------------------
cmap   = get(Fgraph,'Colormap');
if size(cmap,1) ~= 128
	figure(Fgraph2)
	spm_figure('Colormap','gray-hot')
	cmap   = get(Fgraph2,'Colormap');
end

colormap(cmap);

%load Split
%colormap(split)


% extract data from SSM{t} [at one plane separation]
%-----------------------------------------------------------------------


if transv.blob.dim(3) > 1

  k=0;
  d=0;
  %dzmm=2;
  dzmm=transv.blob.vox(3);
  if (dzmm ~= 2)
  	disp('WARNING! Not SPM99b Normalized');
  end
  zmmax=86;
  
  if (dzmm==2 & NSlices==35) ; zmmax=84; end;
  
  for Zmm=-52: dzmm :zmmax
  
    k=k+1;
    
% get background slices and combine
%-----------------------------------------------------------------------
    
   if (NSlices==70 | k ~= floor(k/2)*2)

	Q      = find(abs(transv.blob.xyz(3,:) - xyz(3)- Zmm/dzmm) < 0.5);
	T1     = full(sparse(transv.blob.xyz(1,Q),...
			transv.blob.xyz(2,Q),transv.blob.t(Q),transv.blob.dim(1),transv.blob.dim(2)));
	T1     = spm_slice_vol(T1,inv(zoomM),dim([1 2]),hld);
	D      = zoomM*[1 0 0 0;0 1 0 0;0 0 1 -xyz(3)- Zmm/dzmm ;0 0 0 1]*A;
	D1     = spm_slice_vol(transv.V,inv(D),dim([1 2]),1);
	if k==1,
		d = max(T1(:));
		maxD=max(D1(:));
		
	else,
		d = max([d ; T1(:)]);
		maxD   = max([maxD ; D1(:)]);
	end
   end % if k


  end %for 



  k=0;
  m=0;
  for Zmm=-52:dzmm:zmmax
    k=k+1;
    
    if Zmm==20 & dzmm==2 & NSlices==70 , 
    	drawnow;
        Fgraph3=spm_figure('Create','SlicesNb','Graphics','on');
	set(Fgraph3,'Pointer','watch');
	subplot(6,6,1);
	delete(gca),
	spm_figure('DeletePageControls',Fgraph3)
	colormap(cmap);

	%load Split
	%colormap(split)
	m=0;
    end


%-----------------------------------------------------------------------

   if (NSlices==70 | k ~= floor(k/2)*2)
    	m=m+1;
   
	Q      = find(abs(transv.blob.xyz(3,:) - xyz(3)- Zmm/dzmm) < 0.5);
	T1     = full(sparse(transv.blob.xyz(1,Q),...
			transv.blob.xyz(2,Q),transv.blob.t(Q),transv.blob.dim(1),transv.blob.dim(2)));
	T1     = spm_slice_vol(T1,inv(zoomM),dim([1 2]),hld);
	D      = zoomM*[1 0 0 0;0 1 0 0;0 0 1 -xyz(3)- Zmm/dzmm ;0 0 0 1]*A;
	D1     = spm_slice_vol(transv.V,inv(D),dim([1 2]),1);
	
	D1 = D1/maxD;

	D      = length(cmap)/2;
	Q  = T1(:) > transv.blob.u; T1 = T1(Q)/d; D1(Q) = 1 + T1; T1 = D*D1;


%D      = length(colormap)/2;

    
% render activation foci on background images
%-----------------------------------------------------------------------
	subplot(6,6,m)
%image(rot90(spm_grid(Ttt)))
%	image(rot90(Ttt))

	image(rot90(T1));
	axis image; axis off;
	%title(sprintf('%0.0fmm',Zmm))
	title(sprintf('%0.0fmm',(xyzmm(3) + Zmm)));
	
    end %if NSlices
  end %for	

else
end


% unmap and reset pointer (and x locations if necessary)
%-----------------------------------------------------------------------
%if FLIP; XYZ(1,:) = -XYZ(1,:); L(1) = -L(1); end	% left = right
%spm_unmap(Vs);

% colorbar
%-----------------------------------------------------------------------
u     = get(gca,'Position');
D      = length(cmap)/2;
axes('position', [(u(1) + u(3) + 0.1) u(2) 0.01 u(3)])
image([0 d/32],[0 d],[1:D]' + D)

%if SSMZ str = 'Z value'; end;
%if SSMF str = 'F-value'; end;

str = [SSM.STAT ' value'];

axis xy; title(str,'FontSize',7); 

%ylabel(str);

set(gca,'XTickLabel',[])


set(Fgraph2,'Pointer','Arrow')

if dzmm==2 & NSlices==70 
	set(Fgraph3,'Pointer','Arrow')
end


