% vp_ssm_GisCombo
% Generate a resultant (logistic) combination of Voxel based SSM GIS images.
%__________________________________________________________________________
% This routine allows coefficients for linear addition of GIS images
% to be determined by logistic or linear regression of scores or by
% previous user specification. A combined image is output.
% For logistic and linear regression a combined score file and %vaf
% is automatically output. The included Total %Vaf calculator can be
% used independently for user specified coefficients and vaf values.
%
% It is assumed that a set of voxel based SSM GIS images are selected
% from a single SSM based PCA analysis to optimize combined score output.
% The routine calculates the linear sum of the images modified by 
% numerical constants (Cn coeff.) that are determined by logistic or 
% linear regression of the corresponding SSFscore file values or are
% user specified. By default input GIS images and coefficients will
% be vector normalized and the output image will be Z-scored. 
% Vector normalization of the output image is optional. 
% Only non-zero voxels of a user selected mask image file are
% included. If masking is set off, all non-zero voxels will be evaluated.
% Unless the vector normalization option is disabled, each voxel value 
% is divided by the subject's GIS vector norm (the square root of the
% sum of the values of the vector elements squared.)
% The multiple image addition of the scalar modified, normalized
% GIS image voxel values is evaluated and optionally Z-Scored or vector
% normalized to create an ouput GIS image for the set. An output value
% is set to zero if the mask value is zero. Only the non-zero voxels
% are consided in calculating the mean and standard deviation for
% Z-Scored output.
% The total %vaf calculation assumes orthogonal GIS input vectors
% and is performed on the specified or automatically determined vafs.
% The display reflects the output GIS image after processing.
% A corresponding SSF combined score file is also output unless coefficients
% are manually selected.
%__________________________________________________________________________
% based in part on vp_ssm_giscombo.m ScAnVP 5.8	P.S. Apr. 9, 2007  
% vp_ssm_LoGisCombo.m	ScAnVP ver. 6.1	P. Spetsieris	Mar. 9, 2010
% revision vp_ssm_GisCombo.m	ScAnVP ver. 6.2	P. Spetsieris Oct. 19, 2012

global FI FNames FName pgisaddgui PlaneNo0 PlaneNo hplane
global Cn NameLst OutImg 
global hSetname hmname hSecondname
global GMax1 GMin1 GMax3 GMin3 ProTime
global SetGNames 
global HelpMode Ecolor pgisaddgui
global MaskOn OutOp DatOp MskOp VecINop VecONop 
global CnOp Cn Lscores ORIGIN

if HelpMode, vp_help(mfilename), return ; end;

pgisaddgui=findobj('Name','Logistic Linear GIS Combination');
if ~isempty(pgisaddgui)
	if(strcmp(get(pgisaddgui,'Visible'),'on'))
		figure(pgisaddgui);
	end
	return
end

%vp_imframe; FIcombo=FI;

FName=[];
NameLst=[];
maskFName=' ';
SetGNames=[];
pimageopNames=[];
OutImg=[];  

WndNo=0;
WndScl=4;
PlaneNo=ORIGIN(3);
Message0=['... '];
Message=Message0;
DefSet=0;
DefMask=0;
num1=0; % Number of Files
Cn=ones(1,3);
num2=size(Cn,2); % Number of Scaling Factors
vafnum2=0;
Vafn=[];
GMin1=0;
GMax1=0;
ProTime=0;
MskOp=1;
DatOp=1;
VecINop=1; % Vector Input Normalization ON=1; OFF=0;
OutOp=1; % Output Normalization, ZScore=1; Vector Normalize=2; OFF=0;
CnOp=1; % Cn Determination Option, 2: Determine Logistically; 3: User Specify
VecONop=0; % Vector Output Normalization ON=1; OFF=0;
ZScoring=1; % Z-Score output image, ON=1; OFF=0;
AutoName=1; % automatic naming ON=1; OFF=0;
Pcombo=-1;

Bcolor = [.8,.8,.8];
Kcolor = [.8,1,1];
%Fcolor = [.80,.70,.80];
Fcolor = [.65,.60,.70];

MaskOn=1;

pgisaddgui = figure('Color',Fcolor,'Name','Logistic Linear GIS Combination',...
'NumberTitle','off','Position',[100,200,350,250],...
'Units','Pixels');
	
	
uicontrol(pgisaddgui,'string', 'HELP',...
	'Units','normalized',...
	'position',[265/350 222/250 60/350 20/250],'BackgroundColor',Ecolor,...
	'callback',['vp_help(''vp_ssm_giscombo'')']);
	
	%'if ~isempty(SetGNames), FName=SetGNames(1,:); FI=FIcombo; vp_fimage; set(hSetname,''string'',FName);',...
	%'if isempty(Message), DefSet=1; PlaneNo=max(PlaneNo-1,1); Message=[''Set :  '',FName]; end;',...
	%'if strcmp(Message,''Maximum Plane Reached''), vp_note(Message,3); DefSet=1; end;',...
%
pcbSet=[' SetGNames=get_file(Inf,''*.img'',''SELECT GIS IMAGE SET'',[]); ',...
	'if isempty(SetGNames), return; end; num1=size(SetGNames,1);',...
	'Cn=ones(1,num1); CnOp=1; num2=num1; set(hCn,''string'',num2str(Cn));',...
	'if ~isempty(SetGNames), FName=SetGNames(1,:); DefSet=1; set(hSetname,''string'',FName);',...
	'fi=0; scl=2; if num1>4, scl=1; end; for i=1:num1, fi=vp_fimg(SetGNames(i,:),PlaneNo,i,scl,fi); end;',...
	'FIcombo=fi; vp_note([''Specify Logistic or Linear Regression or Enter Coefficients'']); end;'];
	
uicontrol(pgisaddgui,'string', 'SELECT GIS IMAGE FILE SET',...
	'TooltipString','Pick Image file Set.',...
	'Units','normalized',...
	'position',[40/350 205/250 165/350 25/250],'BackgroundColor',Bcolor,'callback',pcbSet);
	
cbtextn= ['text(5/350,148/250,''Cn'',''Units'',''normalized'',''Fontweight'',''bold'',',...
	'''FontName'',''Times'',''FontSize'',12,''FontUnits'',''Normalized'',''HorizontalAlignment'',''right'');'] ;

cbtextvaf= ['text(5/350,125/250,''Vaf'',''Units'',''normalized'',''Fontweight'',''bold'',',...
	'''FontName'',''Times'',''FontSize'',12,''FontUnits'',''Normalized'',''HorizontalAlignment'',''right'');'] ;

	
cbCn=['Cn=str2num(get(hCn,''string'')); num2=size(Cn,2); CnOp=4; '];
cbVafn=['Vafn=str2num(get(hVafn,''string'')); vafnum2=size(Vafn,2); '];
cbTVaf=['if or(num2==0, vafnum2~=num2), vp_note(''Invalid No of Vaf, Coeff'',2), ',...
        'else VafnStr=num2str((Cn.*Cn)*Vafn''), set(hTVaf,''string'',VafnStr); end; '];

uicontrol(pgisaddgui,'string', 'TOTAL %Vaf',...
	'Units','normalized',...
	'position',[10/350 97/250 72/350 20/250],'BackgroundColor',Bcolor,...
	'TooltipString','Calculate Total %Vaf for Orthogonal Components: C1*C1*vaf1+ C2*C2*vaf2 ... Cn*Cn*vafn',...
	'callback', cbTVaf);
	
cbPcombo=['if Pcombo<0, vp_note(''Value Not Processed'',2), ',...
        'else set(hPcombo,''string'', num2str(Pcombo)); end; '];

uicontrol(pgisaddgui,'string', 'COMBINED P ',...
	'Units','normalized',...
	'position',[10/350 72/250 72/350 20/250],'BackgroundColor',Bcolor,...
	'TooltipString','Total Combined P value of 2 sample t-test',...
	'callback', cbPcombo);
	
hPcombo=uicontrol(pgisaddgui,'style','edit','string',' ',...
	'TooltipString','Display Total Combined P Value of t-test score comparison',...
	'Units','normalized',...
	'position',[83/350 73/250 85/350 20/250],'BackgroundColor',Kcolor,'callback',cbPcombo);


cbtextadd= ['text(0,205/250,[''OP=(C1*GIS1+C2*GIS2+... Cn*GISn)''],''Units'',''normalized'',''Fontweight'',''bold'',',...
	'''tag'',''poptext'',''FontName'',''Times'',''FontSize'',12,''FontUnits'',''normalized'',''HorizontalAlignment'',''Left'');'] ;


eval(cbtextn);
eval(cbtextadd);
eval(cbtextvaf);

axis off;


%'else, FName=maskFName; FI=FIcombo; vp_fimage;',...
%'if isempty(Message), DefMask=1; PlaneNo=max(PlaneNo-1,1); Message=[''MASK : '',FName]; end;',...
%'if strcmp(Message,''Maximum Plane Reached''), DefMask=1; end;',...
%
cbmaskname=['maskFName=get(hmname,''string''); Message=Message0;',...
	'if isempty(maskFName), DefMask=0; ',...
	'else, FName=maskFName; FI=vp_fimg(FName,PlaneNo,1,4,0);',...
	'figure(pgisaddgui); eval(cbtextn);  axis off;',...
	'if FI > 0, DefMask=1;  Message=[''MASK : '',FName]; end;',...
	'vp_note(Message,2); end;'];
	
cbmaskoff=['if MaskOn, MaskOn=0; maskFName=[]; set(hmoff,''string'',''SET MASK''); ',...
	'set(hmfile,''Visible'',''off''); set(hmname,''Visible'',''off'');',...
	'else, MaskOn=1; set(hmfile,''Visible'',''on''); set(hmname,''Visible'',''on'');',...
	'set(hmoff,''string'',''SET MASK OFF''); end;']; 
	
%cbOutMenu = ['OutOp=get(houtmenu,''Value'');';];
	
%	'else, FName=maskFName; FI=FIcombo; vp_fimage; set(hmname,''string'',FName);',...
%	'figure(pgisaddgui); eval(cbtextn); axis off;',...
%	'if isempty(Message), DefMask=1; PlaneNo=max(PlaneNo-1,1); Message=[''MASK : '',FName]; end;',...
%	'if strcmp(Message,''Maximum Plane Reached''), DefMask=1; vp_note(Message,3); end;',...
%	'end;'];
pcbmask=['maskFName=get_file(1,''.img'',''Please Select Mask File'',[]); ',...
	'if isempty(maskFName), DefMask=0; set(hmname,''string'',maskFName);',...
	'else, FName=maskFName; FI=vp_fimg(FName,PlaneNo,1,4,0);',...
	'figure(pgisaddgui); eval(cbtextn);  axis off;',...
	'if FI > 0, DefMask=1;  Message=[''MASK : '',FName]; end;',...
	'vp_note(Message,2); end;'];
	
hmoff=uicontrol(pgisaddgui,'string', 'SET MASK OFF',...
	'TooltipString','Set Mask On/Off',...
	'Units','normalized',...
	'position',[10/350 48/250 90/350 20/250],'BackgroundColor',Bcolor,...
	'callback',cbmaskoff);
	
hmfile=uicontrol(pgisaddgui,'string', 'MASK FILE',...
	'TooltipString','Pick Mask Image file.',...
	'Units','normalized',...
	'position',[10/350 48/250 75/350 20/250],'BackgroundColor',Bcolor,...
	'callback',pcbmask);
	
hmname=uicontrol(pgisaddgui,'style','edit','string',maskFName,...
	'TooltipString','Enter Mask Image file name.',...
	'Units','normalized',...
	'position',[85/350 48/250 240/350 22/250],'BackgroundColor',Kcolor,'callback',cbmaskname);

cbLogisCn=['if ~DefSet, vp_note([''ERR: GIS File Set Not Defined''],4); return; end;',...
	'if isempty(SetGNames), vp_note([''GIS File Set Not Defined''],4); return; end; ',...
	'[Cn,Lscores,Dev,OutImg, Vafn, Pcombo]=vp_GIS_coeff(SetGNames,''logis'');',...
	'if isempty(Cn) return; end; num1=length(Cn); CnStr=num2str(Cn);',...
        ' Tvaf=Vafn(num1+1), Vafn=Vafn(1:num1), set(hVafn,''string'',num2str(Vafn)); ',... 
        ' set(hTVaf,''string'',num2str(Tvaf));',...
        ' set(hANm,''Tag'',OutImg);',...
        ' set(hPcombo,''string'',num2str(Pcombo));',...
        ' set(hCn,''string'',CnStr); vp_note([''Must Press PROCESS to Create Additive GIS Image or QUIT '']); '];

cbLinCn=['if ~DefSet, vp_note([''ERR: GIS File Set Not Defined''],4); return; end;',...
	'if isempty(SetGNames), vp_note([''GIS File Set Not Defined''],4); return; end; ',...
	'[Cn,Lscores,Deviance,OutImg, Vafn, Pcombo]=vp_GIS_coeff(SetGNames,''linear'');',...
	'if isempty(Cn); return; end; num1=length(Cn); CnStr=num2str(Cn);',...
        ' Tvaf=Vafn(num1+1), Vafn=Vafn(1:num1), set(hVafn,''string'',num2str(Vafn)); ',... 
        ' set(hTVaf,''string'',num2str(Tvaf));',...
        ' set(hANm,''Tag'',OutImg);',...
        ' set(hPcombo,''string'',num2str(Pcombo));',...
        ' set(hCn,''string'',CnStr); vp_note([''Select PROCESS or QUIT '']); '];

hCn=uicontrol(pgisaddgui,'style','edit','string',' ',...
	'TooltipString','SET Coefficient Factors C1 C2 ... Cn',...
	'Units','normalized',...
	'position',[50/350 140/250 285/350 20/250],'BackgroundColor',Kcolor,'callback',cbCn);

hVafn=uicontrol(pgisaddgui,'style','edit','string',' ',...
	'TooltipString','SET %Vaf for Components vaf1 vaf2 ... vafn',...
	'Units','normalized',...
	'position',[50/350 120/250 285/350 20/250],'BackgroundColor',Kcolor,'callback',cbVafn);

hTVaf=uicontrol(pgisaddgui,'style','edit','string',' ',...
	'TooltipString','Calculate Total %Vaf for Components: C1*C1*vaf1+ C2*C2*vaf2 ... Cn*Cn*vafn',...
	'Units','normalized',...
	'position',[83/350 98/250 85/350 20/250],'BackgroundColor',Kcolor,'callback',cbTVaf);


hVNon=uicontrol(pgisaddgui,'String','Vector Input Normalization','Style','Checkbox',...
	'FontWeight','Normal',...
	'TooltipString','ON/OFF Switch-  (ON: Vector Normalization, Divide each image by the sqrt. of the sum of its elements squared )',...
	'Units','normalized',...
	'Position',[185/350 97/250 150/350 019/250],...
	'value',VecINop,...
	'CallBack',[ 'VecINop=get(gco,''value'');'],...
	'BackgroundColor',Bcolor,...
	'ForegroundColor',Tcolor);
	
uicontrol(pgisaddgui,'Style','popup','String',...
	'Select Logistic or User Spec| Logistic Regression of SSF Scores| Linear Regression of SSF Scores| User Specified Coefficients',...
	'TooltipString','Determine Cn coefficients using Logistic or Linear regression of SSF Scores or specify predetermined values',...
	'Units','normalized',...
	'Value',CnOp,'Position',[50/350 165/250 128/350 19/250],...
	'BackgroundColor',Bcolor,...
	'CallBack',[ 'CnOp=get(gco,''value''), CnDeterm=CnOp-1;',...
	' if CnDeterm==1, eval(cbLogisCn), elseif CnDeterm==2, eval(cbLinCn),',...
        '  else vp_note(''Specify Predetermined Cn Values in Alocated Space.''); end;']);
	
uicontrol(pgisaddgui,'Style','popup','String','Z-Score Output|Vector Output Normalization |No Transform',...
	'TooltipString','Z-Score, Vector Normalize or do Not transform the ouput GIS image',...
	'Units','normalized',...
	'Value',OutOp,'Position',[185/350 165/250 150/350 19/250],...
	'BackgroundColor',Bcolor,...
	'CallBack',[ 'OutOp=get(gco,''value''), if (OutOp==1), ZScoring=1, else ZScoring=0; end;',...
	' if (OutOp==2), VecONop=1, else VecONop=0; end;']);
	

hANm=uicontrol(pgisaddgui,'Style','Check','String','AUTO Naming',...
	'TooltipString','Automate Output Naming',...
	'Tag','GisNm.img',...
	'Units','normalized',...
	'Value',AutoName,'Position',[185/350 75/250 150/350 19/250],...
	'BackgroundColor',Bcolor,...
	'CallBack',[ 'AutoName=get(gco,''value''),']);
	

%pcbplane=['Message=Message0; PlaneNo=PlaneNo+1; FI=FIcombo; vp_fimage;',...
%'if isempty(Message), PlaneNo=max(PlaneNo-1,1); Message=Message0; end;',...
%'if strcmp(Message,''Maximum Plane Reached''), vp_note(Message,3); ',...
%
pcbplane=['Message=Message0; PlaneNo=PlaneNo+1;',...
	'if(ProTime > 0), FI=vp_fimg(FName,PlaneNo,1,4,FIcombo);',...
	'else, fi=0; scl=2; if num1>4, scl=1; end;',...
	' for i=1:num1, fi=vp_fimg(SetGNames(i,:),PlaneNo,i,scl,FIcombo); end; FI=fi; end;',...
	'if FI > 0,  set(hplane,''string'',PlaneNo); ',...
	'end; '];
	
uicontrol(pgisaddgui,'string', 'VIEW PLANE +',...
	'TooltipString','Display only',...
	'Units','normalized',...
	'position',[95/350 20/250 90/350 20/250],'BackgroundColor',Bcolor,'callback',pcbplane);

%'FI=FIcombo; vp_fimage;',...
%'if isempty(Message), PlaneNo=max(PlaneNo-1,1); Message=Message0; end;',...
%'set(hplane,''string'',PlaneNo); ',...
%'if strcmp(Message,''Maximum Plane Reached''), vp_note(Message,3); ',...

cbplane=['PlaneNo=str2num(get(hplane,''string'')); Message=Message0;',...
	'if(ProTime > 0), FI=vp_fimg(FName,PlaneNo,1,4,FIcombo);',...
	'else, fi=0; scl=2; if num1>4, scl=1; end;',...
	' for i=1:num1, fi=vp_fimg(SetGNames(i,:),PlaneNo,i,scl,FIcombo); end; FI=fi; end;',...
	'if FI > 0,  set(hplane,''string'',PlaneNo); ',...
	'end; '];

hplane=uicontrol(pgisaddgui,'style','edit','string',PlaneNo,...
	'TooltipString','Display only',...
	'Units','normalized',...
	'position',[185/350 20/250 60/350 20/250],'BackgroundColor',Kcolor,'callback',cbplane);

uicontrol(pgisaddgui,'String','PROCESS',...
	'TooltipString','Create Masked multi Operated Image',...
	'Units','normalized',...
	'Position',[10/350 20/250 60/350 25/250],...
	'CallBack',[ 'if ~DefSet, vp_note([''ERR: File Set Not Defined''],4); return; end; ',...
	'if ~DefMask & MaskOn, vp_note([''ERR: Mask Not Defined''],4); return; end; ',...
	'if (isempty(maskFName) & MaskOn), vp_note([''Mask Not Defined''],4); return; end; ',...
	'if CnOp==1, vp_note([''ERR: Coefficients Not Defined''],4); return; end; ',...
	'if isempty(SetGNames), vp_note([''File Set Not Defined''],4); return; end; ',...
	'if num1==0, vp_note([''Images Set 1 Not Defined''],4); return; end; ',...
	'if num1 ~= num2, vp_note([''Image Set and Number of Scaling Factors Differ''],4); return; end; ',...
	'if prod(Cn) == 0, vp_note([''Error: Some Factor Cn = 0''],4); return; end; ',...
	'set(findobj(''Name'',''Logistic Linear GIS Combination''),''Pointer'',''watch'');',...
	'if(ProTime==0), ProTime=1; else,',...
	'figure(findobj(''name'',''Logistic Linear GIS Combination'')); ProTime=ProTime+1; end;',...
	'OutImg=[];',...
	'eval(cbpimageoppro);',...
	' '] );
	
	

	%'if ~isempty(FName), FI=FIcombo; vp_fimage; ',...
	%'    if isempty(Message), PlaneNo=max(PlaneNo-1,1); end; end;',...
cbpimageoppro = ['VecINop, ZScoring, VecONop, (2*VecINop +3*(ZScoring +4*VecONop)), ',...
	'pimageopNames=char(SetGNames); dim3=0;',... 
	'if num1 == 1',...
        'vp_note([''Processing of '',num2str(num1),'':  GIS File:  '', pimageopNames(1,:)], 3);',...
	'elseif num1 > 2',...
        'vp_note([''Addition of '',num2str(num1),'':  GIS Files  '', pimageopNames(1,:), '', '',pimageopNames(2,:),'',...  ''], 3);',...
	'else,',...
        'vp_note([''Addition of '',num2str(num1),'':  GIS Files  '', pimageopNames(1,:), '' and '',pimageopNames(2,:)], 3);',...
	'end;',...
        'if AutoName==1, AutoName=2, OutImg=get(hANm,''Tag''), end; ',...
	'[out1, out2]=vp_mimpro(pimageopNames,''ADD'',2,Cn,0,AutoName,( 2*VecINop+3*(ZScoring+ 4*VecONop) ),maskFName);',...
	'if out1 < 0,',... 
	'disp([''vp_ssm_GisCombo ABORTED '']);',...
	'set(FMenu,''Pointer'',''Arrow'');',...
	'return; end;',...
	'if AutoName, FName=out2; else FName = OutImg; end;',...
	'if ~isempty(FName), FI=vp_fimg(FName,PlaneNo,1,4,0); ',...
	'  if FI > 0, figure(FIcombo); FIcombo=FI; pos=get(FI,''Position'');',...
	'    pos(1)=pos(1)+pos(3)/10; pos(2)=pos(2)-pos(4)/10; set(FI,''Position'',pos); figure(FI); ',...
	'       else vp_note([''Cannot Display File Name: '',FName],3); return; end;',...
	' else vp_note(''Error: Empty Output File Name'',3); return; end;',...
        'vp_note([num2str(num1),''GIS IMAGE PROCESSING COMPLETE '']);',...
	'Message=[''Note Parameters: VecINop, ZScoring, VecONop, (2*VecINop +3*(ZScoring +4*VecONop))''],',...
	'VecINop, ZScoring, VecONop, (2*VecINop +3*(ZScoring +4*VecONop)), ',...
	'set(FMenu,''Pointer'',''Arrow''); ',...
	'set(findobj(''Name'',''Logistic Linear GIS Combination''),''Pointer'',''arrow''); ',...
	' '];
	
	
uicontrol(pgisaddgui,'String','QUIT',...
	'Units','normalized',...
	'Position',[265/350 20/250 60/350 25/250],...
	'CallBack',['delete(pgisaddgui);','delete(FI);','set(FMenu,''Pointer'', ''Arrow'');']);
	
eval(cbmaskoff);
	

