% vp_ssm_means
% SSM Data Log Mean Image File Creation
%
% The user selects a set of Spatially  Normalized images and optional
% mask image or threshold. The default 'scanvp' PET gray mask can be
% selected. (Note, Mask must have the same overall dimensions as the 
% input images to avoid erroneous output.)  It then calls the 'vp_ssmpca' 
% MATLAB function to create a 'lnmean.img' file. Data is log transformed 
% and the mean of each subject is subtracted from the corresponding log 
% data before the group log mean image is evaluated. See help for 'PCA'
% for more details.
% (Note, earlier versions ran as a DOS executable option of ssmpca.exe)
%
% vp_ssm_means ScAnVP ver. 5.3 (DOS version)	P. Spetsieris, June 15, 2004
%		rev 5.7.w			P. Spetsieris, Nov. 08, 2006
%		rev 5.9				P. Spetsieris, Apr. 1, 2008
%		rev 6.2 (MATLAB version)	P. Spetsieris, Feb. 6, 2012
%-----------------------------------------------------------------------

global HelpMode NameLst POpt FMenu FName MaskOpt Keyin

if HelpMode, vp_help(mfilename), return ; end;

% get the images' filenames 

prompt=['SSM VOX Ln Mean- Select Spatially Normalized Images'];
filter='*.img';
NameLst=[];

if vp_filesui(Inf,filter,prompt,mfilename) < 0 ,return; end;

m= size(NameLst,1);

prompt=['Select [SAME SIZE Mask|Default Mask|Threshold <.35>|EXIT]'];
POpt=vp_opt('X',prompt,'Mask','Select Mask File','Default','Default PETmask','Thresh','Key Lower Threshold','EXIT','');

if POpt=='X', 
	vp_note('Program Exited',2); return;
elseif strcmp(POpt,'EXIT'),
	vp_note('Program Exited',2); return;
elseif strcmp(POpt,'Mask'),
	vp_note('Mask must have the same dimensions as the image files.',5);
	MaskOpt = get_file(1,'.img','Select Mask File Name',[]);
	if (isempty(MaskOpt) ) return, end;
elseif strcmp(POpt,'Thresh'),
	thresh = -1;
	while (thresh <0 | thresh >1)
 	  vp_keyin('Lower Threshold fract. of Max [0-1| q]','.35');
	  if (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
 	  return, else thresh=str2num(Keyin); end;
	  %if (thresh >=0 & thresh <=1)%
	  if and((thresh >=0), (thresh <=1))
	    nm=findstr(Keyin,'.');
	    if(size(Keyin,2) < nm+2)Keyin(1,nm+2)='0'; end;
	    MaskOpt = ['T',Keyin(1,nm+1),Keyin(1,nm+2)],
	  else
	    Message = ['Invalid Threshold: ',Keyin];
	    vp_message(Message); 
	  end
	end
else 
	w=which('scanvp'); MaskOpt=[w(1:(max(findstr(w,'\'))-4)),'masks\PETmask.img'],
	if (exist(MaskOpt) ~= 2), 
	    Message = ['Invalid Or Non-Existent Mask File: ', MaskOpt],
	    vp_message(Message); return; end; 
end;

Message = ['Thresh/Mask Option: ', MaskOpt];
vp_message(Message); 

vp_note('Data will be Log transformed by the ssmpca routine.',3);
h=waitbar(0.3,'Processing SSM Ln Mean');
set(FMenu,'Pointer','Watch');

for i=1:m
  FName=deblank(NameLst(i,:));
  len=size(FName,2);
  
  if i==1
  	%nm=vp_nm('nm',FName);
	%dirnm=pwd;
	%FNameLst=[dirnm,'\',nm,'lst.txt'],
	%

	studyname = vp_nm('nm',FName);
	vp_keyin('[Assign Output Mean Study Name | q]',studyname);
	if (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
	  Message=['Create Mean Task Exited '];
	  vp_message(Message);
	return, else studyname=Keyin; end;

	Message=['Mean Study Name: ', studyname];
	vp_message(Message);

	FNameLst=[pwd,'\', studyname,'lst.txt'],

	fid= fopen(FNameLst,'w');

	if (fid == -1)
	  Message=['Error opening ' P '. Check that you have write permission.'];
	  vp_message(Message);
	  error(Message);
	  return; %PS
	end
	fprintf(fid,'%s\r\n',[FName(1:(len-4)),'.hdr']);
  end
  %fwrite(fid,[FName(1:(len-4)),'.img'],'char' );
  fprintf(fid,'%s\r\n',[FName(1:(len-4)),'.img']);
end

fclose(fid);

%DosCmd = ['ssmpca ',FNameLst,' ',MaskOpt,' MEAN > meansoutput.txt'],
%[ret,w]=vp_dos(DosCmd),
 
OutFile=[pwd,'\meansoutput', studyname,'.txt'],
ret=vp_ssmpca(FNameLst, MaskOpt, 'MEAN', OutFile);

disp(' ');

waitbar(1,h); pause(1); close(h);

if (ret >=0 ),
 vp_note('END ssmpca Ln Mean - Check Matlab Window and meansoutput.txt');
else,
 vp_note('PROCESS FAILED, - Check Matlab Window and meansoutput.txt');
end;

set(FMenu,'Pointer','Arrow');


