% vp_ssm_roipca
% Perform ssm analysis on matrix of ROIs
%_______________________________________________________________________
% The user selects as input a GROUP SUMMARY COMPOSITE report (Name_SUM_c.txt
% or Name_SUM3D_c.txt) generated by  GROUP-ROI processing of a set of
% Talairach normalized subject patient and normal image files. Name, usually 
% the first subject's name, can be edited to represent the study name.
% Natural log transformation is performed in the Matlab routine prior 
% to processing. Logs of negative data values are set to zero. 
% Data normalization is performed as a two step procedure. The mean
% value over all regions is evaluated for each subject and used
% to generate within subject regional deviations from the mean. 
% The mean of these deviations is then evaluated for each region over
% all subjects and subtracted from the corresponding subject value 
% to generate the subject residual profile (SRP). GIS and SSF values
% are evaluated as follows: 
% The sub-by-sub covariance matrix is evaluated.
% Eigenvectors and eigenvalues of the covariance matrix are computed.
% The eigenvectors are scaled to carry the weight of their eigenvalue
% and represent reference subject scaling factors (REF SSF scores).
% The percentage of 'Variance Accounted For' for each eigenvector is computed.
% The eigenvector matrix is multiplied by the SRP to generate the gismatrix array.
% GIS vector weights are normalized to correspond to GIS Z-scores (weight - mean)/std.
% SSF REF scores are normalized over subjects and then offset by the mean
% SSF Z-score for normals or controls when specified.
% Relevant output files for SSF REF and Z-scores, SRP and GIS data are generated.
% Results are saved in the input file directory. Results include a file
% containing the evaluated PCA's GIS vectors (Name_gis.txt), SRP (Name_srp.txt),
% REF Scores (Name_ssfRScores.txt) listing SSF values for all subjects and
% principal components and the "%Variance Accounted For" for those components
% and Z-Scores (Name_ssfZScores.txt). Subject Scores for a selected GIS vector
% can be displayed and the corresponding GIS weights and scores saved individually.
% Selected GIS files along with the output Name_lmean.txt file can be saved in a
% ScAnVP\networks\Name directory for subsequent AUTOmated evaluation of new subject
% scores using the TPR routine.
%
%_______________________________________________________________________
% ssm_roi  (main)               Marc Mentis, M.D.          6/11/1999
% ssm_roi (revision)            Yilong Ma, Ph.D.           4/24/2003
% vp_ssm_roipca (revision)      ScAnVP 5.1   P.Spetsieris  5/02/2003
%				ScAnVP 5.3   P.Spetsieris  7/29/2004
%				ScAnVP 5.8   P.Spetsieris  6/07/2007
%_______________________________________________________________________

global POpt FMenu NameLst Keyin

%Query for roimatrix name 
%roimatrix_name=spm_listm;  

prompt=['Select Composite Summary Group ROI file'];
if vp_filesui(1,'*_c*.txt',prompt,mfilename) < 0 ,return; end;
roimatrix_name=NameLst(1,:);
  
%roimatrix_name= get_file(1,'*.txt','Composite Summary GROUP ROI file',[ ]);  
%if isempty(roimatrix_name)
%  set(FMenu,'Pointer','Arrow');
%  return;
%end

length_name = length(roimatrix_name);
k = findstr(roimatrix_name,'\');
pwdd = roimatrix_name(1:max(k));
p=max([findstr(roimatrix_name,'SUM') 0]);
if p==0
  name = roimatrix_name(1:length_name-4);
else
  if roimatrix_name(p-1)=='_'
    name = roimatrix_name(1:p-2);
  else
    name = roimatrix_name(1:p-1);
  end
end
refname=name;
gis_name = strcat(name, '_gis.txt');
srp_name = strcat(name, '_srp.txt');
ssf_name = strcat(name, '_ssfRScores.txt');
%PS add
Zssf_name = strcat(name, '_ssfZScores.txt');
lmean_name = strcat(name, '_lmean.txt');
mean_name = strcat(name, '_mean.txt');

[file_list,roi_list,roimatrix]=vp_read_grprpt([roimatrix_name]);
if isempty(roimatrix)
  set(FMenu,'Pointer','Arrow');
  vp_message('Error: Could Not Read Report'); return;
end
roimatrix=roimatrix';

voxno=size(roimatrix,1);
subs=size(roimatrix,2);
if (subs <= 1)
  set(FMenu,'Pointer','Arrow');
  vp_message(['Error: Number Of Subjects (',num2str(subs),') Must Be > 1']);
  return;
else
  prompt1=['Read ',num2str(subs),' Subjects, ',num2str(voxno),' Regions. '];
end

% Specify Controls Option
prompt=['Specify Controls? '];
POpt='Help';
while (strcmp(POpt,'Help'))
   POpt=vp_opt('X',prompt,'SPECIFY CONTROLS','','NO CONTROLS','','EXIT','','Help','');
   if(strcmp(POpt,'X'))return; end;
   if(strcmp(POpt,'EXIT'))return; end;
   if(strcmp(POpt,'Help')),
    vp_note('Specify Control Subjects Images or Choose No CONTROLS ');
   end
end
  
if (strcmp(POpt,'SPECIFY CONTROLS'))
 nnorms=1; %determine later
else
 % No Specific Controls
 nnorms=0; norm1=0; norm2=0; Zoffset(subs)=0;
end


if nnorms > 0

 no=1;
 while no~= 2 % Must enter at least two numbers even if the same
   Keyin=['1 - ',num2str(subs)];
   prompt=['Specify Control Subject Index Range Within subjects [n1-n2] | q]   <',Keyin,'>   '];
   vp_keyin(prompt,Keyin);

   if (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
	      return;
   else
      
    Keyin=strrep(Keyin,' ','');
    [nn,no]=sscanf(Keyin,'%d-%d'),
    norm1=nn(1)
    if no ==2  norm2=nn(2) 
        if (norm1 < 1 | norm1 > subs), vp_note('Error: Number norm1 out of range',2);
          no=1;
        elseif (norm2 < 1 | norm2 > subs), vp_note('Error: Number norm2 out of range',2);
          no=1;
        elseif (norm1 == 1 & norm2 == subs), vp_note('Error: All subjects cannot be controls',2);
          no=1;
        end %if
    end; %if
   end %if 
 end % while
	
end

if nnorms > 0
  vp_note(['Control Subject Range: ',num2str(norm1),' - ',num2str(norm2)],2);
end

log_transform=1; % PS add log transformation option
prompt=[prompt1,' Log-transform the data? neg. values & logs will be set to zero [Y|N|EXIT]'];
POpt=vp_opt('X',prompt,'YES','Perform Natural Log Transformation','NO','Pre Transformed Data','EXIT','');
if (POpt=='X' | strcmp(POpt,'EXIT')), 
	set(FMenu,'Pointer','Arrow');
	vp_note('Program Exited',2); return;
elseif strcmp(POpt,'NO'), log_transform=0,
else log_transform=1;
end;

if log_transform
  roimatrix(find(roimatrix<=0))=exp(0); % PS Set all values <=0
  roimatrix=log(roimatrix); % PS perform log transformation
end;

hwaitbar=waitbar(0,'Processing ROI SSM PCA ...');
waitbar(.2,hwaitbar);
%Compute within image mean vector
meanvect=mean(roimatrix);

waitbar(.3,hwaitbar);

%Compute within-subject deviations from mean of image
%i.e., normalize to whole brain
meanmat=ones(voxno,subs);
for x=1:subs
   meanmat(:,x)=meanvect(1,x)*meanmat(:,x);
end
devs=roimatrix-meanmat;

waitbar(.4,hwaitbar);

%Compute mean image of voxels across subjects
%Needs to be NORMALIZED IMAGES i.e. devs
mean_vec=mean(devs');

%PS Save Row Vector mean image for subsequent TPR analysis
%PS
if log_transform
  save(lmean_name,'mean_vec','-ascii');
else
  save(mean_name,'mean_vec','-ascii');
end

%Compute subject deviations from mean image
mean_vec=mean_vec';
mean_vecmat=ones(voxno,subs);
for x=1:voxno
   mean_vecmat(x,:)=mean_vec(x,1)*mean_vecmat(x,:);
end
devs=devs-mean_vecmat;
srp=devs';

waitbar(.5,hwaitbar);

%Compute sub-by-sub Covariance matrix
%Tcovar=devs'*devs;
Tcovar=cov(devs);

waitbar(.6,hwaitbar);

%Compute Eigenvector (SSF) and Eigenvalue of Covariance matrix
[eigenvect eigenval]=eig(Tcovar);
eigenval=diag(eigenval);

%Convert Eigenvector (SSF) to carry weight of eigenvalue
%(SSF * sqrt(eigenvalue))
sqrt_eigenval=sqrt(eigenval');
sqrt_eigenvalmat=[]; %PS initialize
for x=1:subs
   sqrt_eigenvalmat(x,:)=sqrt_eigenval(1,:);
end
n_eigenvect=eigenvect.*sqrt_eigenvalmat;
ssf=n_eigenvect;

waitbar(.7,hwaitbar);

%Compute Percentage Variance Accounted For
percentvar=eigenval/sum(eigenval);
percentvar=percentvar';

%Multiply eigenvector matrix by devs to generate gismatrix array
gismatrix=eigenvect'*devs';
gismatrix=gismatrix';
%Divide gismatrix by theta (sqrt eigenval)
    %eigenvalmat=ones(voxno,subs);
    %for x=1:voxno
        %eigenvalmat(x,:)=sqrt(eigenval');
     %end
    %gismatrix=gismatrix./eigenvalmat;
           
waitbar(.8,hwaitbar);


gis0=fliplr(gismatrix); % PS non-normalized gismatrix
%Normalize eigenvectors (Z-score region weights)
for x=1:subs
   gismatrix(:,x)=(gismatrix(:,x)-mean(gismatrix(:,x)))./std(gismatrix(:,x)); 
end

% first principal component first
gis = fliplr(gismatrix);
ssf = fliplr(ssf);
vaf = 100*fliplr(percentvar);

waitbar(.9,hwaitbar);

% write relevant output files
vp_write_ssmfile(gis_name,subs,vaf,roi_list,gis,2)
vp_write_ssmfile(ssf_name,subs,vaf,file_list,ssf,1,norm1,norm2)
vp_write_srpfile(srp_name,voxno,file_list,srp)

save gismatrix.txt gis -ascii -tabs
save srp.txt srp -ascii -tabs
save ssfRScores.txt ssf -ascii -tabs
save percentvar.txt vaf -ascii -tabs 

clear mean_vec mean_vecmat meanmat meanvect x
disp(' '); disp('');disp(' '); disp(''); 
disp ('   ***************************************************     ')
disp(' ');
disp('             RESULTS OF ROI SSM ANALYSIS')
disp(' ');
disp('Unitized Subject SSF Scores (by columns):')
eigenvect
disp('Eigenvalues:')
eigenval'
disp('Subject SSF Scores carrying weight of eigenvalue (by columns):')
n_eigenvect
disp('Percentage variance accounted for by each SSF/GIS:')
percentvar
disp('Normalized GIS values are in variable "gismatrix" (by column).')
disp('Subject Residual Profiles are in variable "srp" (sub-by-roi matrix).')
disp('Weighted SSF scores are in variable "ssf" (One column per ssf).')
disp(' '); disp('');
disp ('   ***************************************************     ')

waitbar(1,hwaitbar); pause(1); close(hwaitbar);


%p=max([findstr(roimatrix_name,'SUM') 0]);
%if p==0
%  name = roimatrix_name(1:length_name-4);
%else
%  name = roimatrix_name(1:p-1);
%end
%gis_name = strcat(name, '_gis.txt');
%srp_name = strcat(name, '_srp.txt');
%ssf_name = strcat(name, '_ssfRScores.txt');

num_gis=size(ssf,2);

%PS
ssfpcafig=figure('name',['PCA REF SCORES for GIS 1 VAF(',num2str(vaf(1)),'%)']);

%yo=max(ssf(:,1))/4;
if norm2 > 0
  %bar(ssf(:,1)); xlabel('Subject  (c: control)'); ylabel('SSF SCORE  (for GIS1)');
  bar(ssf(:,1)); xlabel('SUBJECT  (Control: __ __ )'); ylabel('SSF SCORE  (for GIS1)');
  %for i=norm1:norm2, text(i,yo,'c','color','r'); end; %Mark controls

  ypos=get(gca,'Ytick'); if ypos(2) >=0, ypos=(ypos(1)+ypos(2))/2, else ypos=ypos(2); end;
  text(norm1-.5,ypos,'<','color','b');  %Mark controls
  text(norm2,ypos,'>','color','b');  %Mark controls
  line([norm1-.5,norm2],[ypos,ypos],'LineStyle','--');
else
  bar(ssf(:,1)); xlabel('SUBJECT '); ylabel('SSF SCORE  (for GIS1)');
end

%PS add Z transformation option
%Normalize SSF Scores (Z-score for each of the (n=subs) eigenvectors over subjects)
for x=1:num_gis % for each eigenvector
   Zssfs(:,x)=(ssf(:,x)-mean(ssf(:,x)))./std(ssf(:,x)); 
end

%Zssfs(norm1:norm2,:),

% Offset calculated for each gis

Zoffset=0; Zoffset(1:num_gis)=0;
if norm2 > 0
 if norm2 ~= norm1
  Zoffset=mean(Zssfs(norm1:norm2,:)),
 else
  Zoffset=Zssfs(norm1,:),
 end
end

%Zssfs=Zssfs-Zoffset;
for x=1:num_gis
  Zssfs(:,x)=Zssfs(:,x)-Zoffset(x)*ones(subs,1);
end

vp_write_ssmfile(Zssf_name,subs,vaf,file_list,Zssfs,3,norm1,norm2);
zscorefig=figure('name',['PCA Z SCORES for GIS 1 VAF(',num2str(vaf(1)),'%)']);

%yo=max(Zssfs(:,1))/4;
if norm2 > 0
  %bar(Zssfs(:,1)); xlabel('Subject (c: control)'); ylabel('Z SCORE  (for GIS1)');
  bar(Zssfs(:,1)); xlabel('SUBJECT  (Control: __ __ )'); ylabel('Z SCORE  (for GIS1)');
  %for i=norm1:norm2, text(i,yo,'c','color','c'); end; %Mark controls
  ypos=get(gca,'Ytick'); if ypos(2) >=0, ypos=(ypos(1)+ypos(2))/2, else ypos=ypos(2); end;
  text(norm1-.5,ypos,'<','color','b');  %Mark controls
  text(norm2,ypos,'>','color','b');  %Mark controls
  line([norm1-.5,norm2],[ypos,ypos],'LineStyle','--');
else
  bar(Zssfs(:,1)); xlabel('SUBJECT'); ylabel('Z SCORE  (for GIS1)');
end


pos=get(ssfpcafig,'position');
set(ssfpcafig,'position',[pos(1)+40, pos(2)-60, pos(3), pos(4)]);


%  Select Other Gis #
ngis=1; ngis0=1;
Keyin=num2str(ngis);
num_gis =num_gis -1; % skip the last one


netnam=['GIS ',num2str(ngis)];

if norm2 > 0
  labelx=['CONTROLS                SUBJECTS'];
else
  labelx=['             SUBJECTS'];
end

labely=['SCATTERPLOT -  Z SCORES for ',netnam];
vp_scatterplot(Zssfs(:,ngis),norm2,subs,0,labelx,labely,netnam);


while ~(isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
  
  if ~strcmp(Keyin, 'Skip'),
    prompt=[' Save GIS Network ' num2str(ngis), ' Scores ? [Y|N|EXIT]'];
    POpt=vp_opt('X',prompt,'YES','Save GIS Scores, Weights','NO','SKIP','EXIT','');
    if (POpt=='X' | strcmp(POpt,'EXIT')), 
	Keyin='';
    elseif strcmp(POpt,'NO'),
    else 
        % Save Gis Network
	vp_write_ssmfile([refname,'_gis',num2str(ngis),'.txt'],ngis,vaf(ngis),roi_list,gis(:,ngis),2)
        % Save Gis Reference Scores
	vp_write_ssmfile([refname,'_RScores',num2str(ngis),'.txt'],ngis,vaf(ngis),file_list,ssf(:,ngis),1,norm1,norm2)
	vp_write_ssmfile([refname,'_ZScores',num2str(ngis),'.txt'],ngis,vaf(ngis),file_list,Zssfs(:,ngis),3,norm1,norm2)
    end;
  end;

  if ~(isempty(Keyin)),
    if ngis > num_gis -1, ngis= num_gis -1; end;
    if (ngis < 1 ), ngis = 0; end;
    Keyin=num2str(ngis+1);
    prompt=['Display SCORES GIS No.? [1-',num2str(num_gis),'| q]'];
    vp_keyin(prompt,Keyin);

    if (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
    else
      ngis=str2num(Keyin);
      if (ngis > num_gis | ngis < 1), vp_note('Error: Number out of range',2);
        ngis= ngis0; Keyin=['Skip'];
      else
        % Display bar graph
	netnam=['GIS ',num2str(ngis)];
        ssfpcafig=figure('name',['PCA REF SCORES for ',netnam,' VAF(',num2str(vaf(ngis)),'%)']); bar(ssf(:,ngis));
	%yo=max(ssf(:,ngis))/4;
	if norm2 > 0
	  %for i=norm1:norm2, text(i,yo,'c','color','r'); end; %Mark controls
          xlabel('SUBJECT  (Control: __ __ )'); ylabel(['PCA SCORE  -  GIS ',num2str(ngis)]);
  	  ypos=get(gca,'Ytick'); if ypos(2) >=0, ypos=(ypos(1)+ypos(2))/2, else ypos=ypos(2); end;
	  text(norm1-.5,ypos,'<','color','b');  %Mark controls
	  text(norm2,ypos,'>','color','b');  %Mark controls
	  line([norm1-.5,norm2],[ypos,ypos],'LineStyle','--');
	else
          xlabel('SUBJECT'); ylabel(['PCA SCORE  -  ',netnam]);
	end

	%supress
	%labely=['SCATTERPLOT - SCORES for ',netnam];
	%vp_scatterplot(ssf(:,ngis),norm2,subs,0,labelx,labely,netnam);
     
        zscorefig=figure('name',['PCA Z SCORES for ',netnam,' VAF(',num2str(vaf(ngis)),'%)']); bar(Zssfs(:,ngis));
	%yo=max(Zssfs(:,ngis))/4;

	if norm2 > 0
	  %for i=norm1:norm2, text(i,yo,'c','color','c'); end; %Mark controls
          xlabel('SUBJECT  (Control: __ __ )'); ylabel(['PCA Z SCORE  -  GIS ',num2str(ngis)]);
  	  ypos=get(gca,'Ytick'); if ypos(2) >=0, ypos=(ypos(1)+ypos(2))/2, else ypos=ypos(2); end;
	  text(norm1-.5,ypos,'<','color','b');  %Mark controls
	  text(norm2,ypos,'>','color','b');  %Mark controls
	  line([norm1-.5,norm2],[ypos,ypos],'LineStyle','--');
	else
          xlabel('SUBJECT'); ylabel(['PCA Z SCORE - GIS ',num2str(ngis)]);
	end

        pos=get(ssfpcafig,'position');
        set(ssfpcafig,'position',[pos(1)+40, pos(2)-60, pos(3), pos(4)]);
	
	labely=['SCATTERPLOT - Z SCORES for ',netnam];
	vp_scatterplot(Zssfs(:,ngis),norm2,subs,0,labelx,labely,netnam)
        ngis0=ngis;
      end
    end 
  
  end %if ~
end


set(FMenu,'Pointer','Arrow');
vp_message(['END CHECK: ',gis_name,', ',srp_name,', ',ssf_name,', ']);
