% vp_ssm_roitprpro
% ROI based SSM Interactive Topographic Profile Rating (TPR)
% Performs evaluation of new subject(s) SSM subject scores for a specific GIS
%_______________________________________________________________________
% In this interactive version of TPR, the user may determine new subject scores 
% for a previously derived GIS topographic profile using REFERENCE data to
% scale results or using the new group data to RECALIBRATE reference scores.
% The user selects as input a new GROUP SUMMARY COMPOSITE roi report 
% name_SUM(3D)_c.txt) generated by GROUP-ROI processing of ONE or more (ns)
% new Talairach normalized subject image files to be scored for their
% manifestation of the previously derived disease specific GIS.
% If previous reference data is used, a single subject or a new group can
% be evaluated with no difference in individual subject scores when obtained
% singularly or as part of a composite group. With the 'recalibration'
% option scores may shift depending on the new group selected as reference.
% Subject groups do not necessarily include subjects from the previous study.
% The reference group must be carefully selected to avoid a significant shift.
% Natural log transformation of the report data is usually performed in the
% routine unless the non-log option is selected. Logs of negative data values
% are set to zero.
% The user must select the GIS text file containing the definition of the  
% disease specific topographic profile. (The GIS is defined in terms of its
% relative, Z-scored weights for the (nr) regions used in the PCA analysis.)
% Data normalization to derive the new subject residiual profile (SRP) is
% performed as a two step procedure. First the mean value over all regions
% is evaluated for each subject and used to generate within subject regional
% deviations from the mean. Second the subject's difference from the group mean
% deviations profile is evaluated as described below to generate the SRP. 
% To derive subject scores for the GIS on the same scale as the original study,
% the user must either input the text file (study_lmean.txt) containing the
% (log) data group mean regional profile to be used as a reference from which
% the SRP values will be calculated or specify a reference GROUP SUMMARY COMPOSITE
% roi report to be used to evaluate this mean. If such a file is not available
% or if the user needs to recalibrate reference scores for the GIS, the new group data 
% can be used to generate the mean assuming that a large enough number of subjects
% including controls (similar to the original reference study used to generate the
% GIS profile) is used. Once the specified or evaluated group mean regional profile
% of the reference data is subtracted from the corresponding new subject values to
% generate the new subject residual profile (SRP), the new SSF subject scores are
% evaluated using the following calculation:
% 
% 	          SSF=SRP*GIS/fact, fact=norm(GIS)*sqrt(nr-1),
%
% where SSF is an nsx1 vector, SRP is a nsxnr matrix and GIS is a nrx1 vector.
% An output file containing the new SSF scores for each new subject is generated
% and plotted. Z scores can then be calculated based on derived or input reference
% subject scores. Control subjects are read from the input file or specified. 
% Results are saved in the input file directory.
%
%_______________________________________________________________________
%
% vp_ssm_roitpr                 ScAnVP 5.1   P.Spetsieris   5/29/2003
%                  (revision)    ScAnVP 5.3   P.Spetsieris   3/15/2004
%                  (revision)    ScAnVP 5.4   P.Spetsieris   5/18/2005
% vp_ssm_roitprpro (revision)    ScAnVP 5.6   P.Spetsieris   11/18/2005
%                  (revision)    ScAnVP 5.8   P.Spetsieris   5/30/2007
%_______________________________________________________________________

global POpt FMenu Keyin NameLst

if HelpMode, vp_help(mfilename); return ; end;

%REFscores=1;
%prompt=['INTERACTIVE TPR: Derive NEW SSF Scores Based on REFERENCE DATA or RECALIBRATE?    [ Y=REFERENCE | N=RECALIBRATE| EXIT]'];
%POpt=vp_opt('X',prompt,'YES-REF','USE REFERENCE','NO-RECAL','RECALIBRATE','HELP','','EXIT','');
%if (POpt=='X' | strcmp(POpt,'EXIT') ), 
%        set(FMenu,'Pointer','Arrow');
%	vp_note('Program Exited',2); return;
%elseif(strcmp(POpt,'HELP')),
%  vp_help('vp_ssm_roitpr'); vp_ssm_roitpr; 
%  return; 
%elseif strcmp(POpt,'NO-RECAL'), REFscores=0,
%else REFscores=1;
%end

if REFscores
  prompt=['Specify Composite Summary NEW (One or Multi-Subject Group) ROI file'];
else
  prompt=['Specify Composite Summary NEW GROUP ROI file'];
end

%if vp_filesui(1,'*_c*.txt',prompt,mfilename) < 0 ,return; end;
if vp_filesui(1,'*_c*.txt',prompt,mfilename) < 0 ,return; end;
roimatrix_name=NameLst(1,:);

length_name = length(roimatrix_name);
k = findstr(roimatrix_name,'\');
pwdd = roimatrix_name(1:max(k));
p=max([findstr(roimatrix_name,'SUM') 0]);
if p==0
 outnm = roimatrix_name(1:length_name-4);
else
 if roimatrix_name(p-1)=='_'
   outnm = roimatrix_name(1:p-2);
 else
   outnm = roimatrix_name(1:p-1);
 end
end
ssf_name = strcat(outnm, '_tprScores.txt');
Zssf_name = strcat(outnm, '_tprZScores.txt');

if REFscores==0,
  lmean_name = strcat(outnm, '_tprlmean.txt');
  mean_name = strcat(outnm, '_tprmean.txt');
end

[file_list,roi_list,roimatrix]=vp_read_grprpt([roimatrix_name]);
if isempty(roimatrix)
  set(FMenu,'Pointer','Arrow');
  vp_message(['Error: Could Not Read New Report: ',roimatrix_name]); return;
end
roimatrix=roimatrix'; 
voxno=size(roimatrix,1);
sub=size(roimatrix,2);

if (~REFscores & sub <= 1)
  set(FMenu,'Pointer','Arrow');
  vp_message(['ERROR Subjects=',num2str(sub),...
  ' Enter GROUP file to RECALIBRATE scores or select REFERENCE option']);
  return;
end
  
if (~REFscores & sub <= 5)
  set(FMenu,'Pointer','Arrow');
  vp_message(['WARNING (Subjects=',num2str(sub),...
  ')  Limited number of subjects chosen for RECALIBRATE scores option']);
end
  
readref_mean=0; % PS add read reference mean option

if REFscores
  reffile_name= get_file(1,'*.txt','REFERENCE GROUP (SUM) ROI or (MEAN) file',[ ]);  
  if isempty(reffile_name), return; end;

  %PS test if ref_file is a group report or log data mean.
  fd=fopen(reffile_name);
  line1=fgets(fd); line2=fgets(fd); fclose(fd);
  if line2==-1 %EOF - Assume Group Mean File
   mean_refimg=load([reffile_name]);
   readref_mean=1;
   refvoxno=size(mean_refimg,2);
  else readref_mean=0;
  end

  if readref_mean==0
   [refile_list,ref_list,refmatrix]=vp_read_grprpt([reffile_name]);
   if isempty(refmatrix)
    set(FMenu,'Pointer','Arrow');
    vp_message(['Error: Could Not Read Reference Report: ',reffile_name]); return;
   end
   refmatrix=refmatrix';
   refvoxno=size(refmatrix,1);
  end
else % RECALIBRATE 
end %REFscores

log_transform=1; % PS add log transformation option
prompt=['Log-transform the data? neg. values & logs will be set to zero [Y|N|EXIT]'];
POpt=vp_opt('X',prompt,'YES','Perform Natural Log Transformation','NO','Pre Transformed Data','EXIT','');
if (POpt=='X' | strcmp(POpt,'EXIT')), 
	set(FMenu,'Pointer','Arrow');
	vp_note('Program Exited',2); return;
elseif strcmp(POpt,'NO'), log_transform=0,
else log_transform=1;
end;

if log_transform
  roimatrix(find(roimatrix<=0))=exp(0); % PS Set all values <=0
  roimatrix=log(roimatrix); % PS perform log transformation
  if REFscores
   if readref_mean==0
     refmatrix(find(refmatrix<=0))=exp(0); % PS Set all values <=0
     refmatrix=log(refmatrix); % PS perform log transformation
   end
  end %if REF`
end;

hwaitbar=waitbar(0,'Processing ROI TPR ...');
waitbar(.2,hwaitbar);

if REFscores
 if voxno ~= refvoxno,
   set(FMenu,'Pointer','Arrow');
   vp_message('Error: Number of new regions do not agree with ref'); return;
 end

 if readref_mean==0
    refsub=size(refmatrix,2);
    refmeanvect=mean(refmatrix);
    meanrefmat=ones(refvoxno,refsub);
    for x=1:refsub
       meanrefmat(:,x)=refmeanvect(1,x)*meanrefmat(:,x);
    end
    refdevs=refmatrix-meanrefmat;
    %Compute mean image of voxels across ref subjects
    mean_refimg=mean(refdevs');
 end
end %if REF

%Compute within image mean vector
meanvect=mean(roimatrix);

waitbar(.3,hwaitbar);

%Compute within-subject deviations from mean of image
%i.e., normalize to whole brain
meanmat=ones(voxno,sub);
for x=1:sub
   meanmat(:,x)=meanvect(1,x)*meanmat(:,x);
end
devs=roimatrix-meanmat;

waitbar(.4,hwaitbar);

%Compute new subject deviations from mean reference image
if REFscores
  mean_refimg=mean_refimg';
%  mean_refimgmat=ones(voxno,sub);
%  for x=1:voxno
%     mean_refimgmat(x,:)=mean_refimg(x,1)*mean_refimgmat(x,:);
%  end
%  devs=devs-mean_refimgmat;

else
  if sub<=1,
   set(FMenu,'Pointer','Arrow');
   vp_message('Error: Number of Subjects must be > 1 or SELECT REFERENCE DATA OPTION'); return;
  end
  %Compute mean image of voxels across all new subjects
  mean_refimg=mean(devs,2);
end %REFscores

%PS Save Row Vector mean image for subsequent (AUTO)TPR analysis
%PS
if ~REFscores
  mean_vec=mean_refimg';
  if log_transform
    save(lmean_name,'mean_vec','-ascii');
  else
    save(mean_name,'mean_vec','-ascii');
  end
end


for k=1:sub, devs(:,k)=devs(:,k)-mean_refimg; end;
srp=devs';

waitbar(.5,hwaitbar);

%INSERT GIS2SSF CODE HERE

%generate SSF values for a known GIS pattern based
%on SRP calculated in the new population.

%PS 
% disp('Enter Name of Gis values i.e. gis (roi-by-1 matrix)');
% disp('Enter Name of SRP i.e. SRP (sub-by-roi matrix)');

%PS gis_name=spm_listm;
%gis_name= get_file(1,'*gis*.txt','Enter GIS file name (nroi-by-ngis matrix)',[ ]);  
gis_name= get_file(1,'*gis*.txt','Enter GIS file name',[ ]);  
if isempty(gis_name), return; end;

%PS srp_name=spm_listm;
%gismatrix=load([gis_name]);
[gisout gismatrix]=vp_readgis(0,gis_name);
if (gisout < 0), 
  vp_message('Error reading GIS'); return; end;

%PS 
nm_gis = size(gismatrix,2); % PS
if nm_gis > 1
  prompt=['GIS NO.? [1-',num2str(nm_gis),'| q]'];
  %vp_keyin('GIS NO.? [no.| q]','1');
  vp_keyin(prompt,'1');
  if (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
  return, end;
  ngis=str2num(Keyin);
  ngisno=ngis;
  ngisch=num2str(ngis);
else
  nm=vp_nm('nm',gis_name);
  ln=length(nm);
  ngisch=nm(ln);
  ngisno=str2num(ngisch);
  if isempty(ngisno), ngisno=1; ngisch='1'; end;
  ngis=1;
end

gis=gismatrix(:,ngis);

%PS num_roi = length(gis);
num_roi = size(gis,1); % PS
if voxno ~= num_roi,
  set(FMenu,'Pointer','Arrow');
  vp_message('Error: Number of GIS regions do not agree'); return;
end


%PS fd = fopen(srp_name,'r');
% determine the number of files
% j = 0; 
% while 1
%    line = fgets(fd);
%    j = j+1;
%    if ~ischar(line), break, end
% end
% num_sub = j-1;
        
% read srp matrix
%PS frewind(fd);
%PS for i = 1:num_sub,
%PS    [A, B] = fscanf(fd,'%s',1);
%PS    file_list{i} = A;
%PS    for j = 1:num_roi,
%PS       [C, D] = fscanf(fd,'%f',1);
%PS       srp(i,j) = C;
%PS    end
%PS end

% calculate new ssf
ssf=srp*gis;

%PS normalize ssf values
ssf=ssf/(norm(gis)*sqrt(num_roi -1));

%write_srp_file(ssf_name,1,file_list,ssf)
if REFscores
  vp_write_srpfile(ssf_name,1,file_list,ssf)
else
  ssf_name = strcat(outnm, '_tprRScores',ngisch,'.txt');
  Zssf_name = strcat(outnm, '_tprZScores',ngisch,'.txt');
  % Save Gis Recalibrated Scores below
end


waitbar(1,hwaitbar); pause(1); close(hwaitbar);

disp ('   ***************************************************     ')
disp(' ');
disp('             RESULTS OF GIS2SSM TPR')
disp(' ');
disp('Newly Calculated SSF')
ssf
ssftprfig=figure('name',['TPR SCORES GIS ',num2str(ngis)]); bar(ssf); xlabel('New Subject'); ylabel('New Subject SSF SCORE');
pos=get(ssftprfig,'position');
if sub < 15
  pos(3)=max(pos(3)/3, pos(3)*(sub/15)); % use 15 as a standard number of subjects
end

set(ssftprfig,'position',pos);
    

% END GIS2SSF CODE

% PS add Z transformation option
if sub >= 1 %all cases

 if REFscores % Always Z-transform for Recalibration Option
   prompt=['Z-transform SSF Scores Based on Reference Scores? [Y|N|EXIT]'];
   POpt=vp_opt('X',prompt,'YES','Calculate Z Scores','NO','Don''t Z Score','EXIT','');
   if (POpt=='X' | strcmp(POpt,'EXIT') | strcmp(POpt,'NO')), 
        set(FMenu,'Pointer','Arrow');
	vp_note('Program Exited',2); return;
   end
 end %prompt
  
% Z transformation 

 getscorefile=0; 
 
 if (~getscorefile & ~readref_mean)
    
        if (~REFscores)
	  refsub=sub;
	end

	no=1;
	while no~= 2 % Must enter at least two numbers (can be the same) or enter zero
	 Keyin=['1 - ',num2str(refsub)];
	 %Keyin=['1 - '];
	 prompt=['Calculate Z SCORES, Specify 0 or Control Subject Ref. Index Range [n1-n2] | 0 | q]   <',Keyin,'>   '];
	 vp_keyin(prompt,Keyin);

	 if (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
	      return;
	 elseif (strcmp(Keyin,'0') ),
	      norm1=0; norm2=0; no=2;
	 else
      
	      Keyin=strrep(Keyin,' ','');
	      [nn,no]=sscanf(Keyin,'%d-%d'),
	      norm1=nn(1)
	      if no ==2  norm2=nn(2) 
	        if (norm1 < 1 | norm1 > refsub), vp_note('Error: Number norm1 out of range',2);
	          no=1;
	        elseif (norm2 < 1 | norm2 > refsub), vp_note('Error: Number norm2 out of range',2);
	          no=1;
	        elseif (norm1 == 1 & norm2 == refsub), vp_note('Error: All subjects cannot be controls',2);
	          no=1;
	        end %if
	      end; %if
	 end; %if 
	end % while
    
        if norm2 > 0
	  vp_note(['Control Subject Range: ',num2str(norm1),' - ',num2str(norm2)],2);
        end
	

        if (~REFscores)
	  ssfscores=ssf;
	else
	  for k=1:refsub, refdevs(:,k)=refdevs(:,k)-mean_refimg; end;
	  srp=refdevs';
	  ssfscores=srp*gis;
	  %ssfscores=ssfscores/(norm(gis))^2;
	  ssfscores=ssfscores/(norm(gis)*sqrt(num_roi - 1));
	end
        [nosubs, num_gis]=size(ssfscores),
        ngis=1;
	
 end % if ~readref_mean
 if (readref_mean | getscorefile)
  
   %ssffile=[dnm,'Scores.txt'];
   ngis0=ngis;
   
   while (~strcmp(POpt,'ACCEPT'))
     ssffile= get_file(1,'*RScores*.txt','Specify REFERENCE Score file',[ ]);  
     [mode, ssffile, ngis, ssfscores, Zssfs, norm1, norm2] =vp_ssm_scores(-2,ssffile)
      [nosubs, num_gis]=size(ssfscores),

      if num_gis ~= 1,
        if ngis ~= ngis0,
          prompt=(['Mismatch Error: Score File Gis: ',num2str(ngis), '  Reference Gis: ',num2str(ngis0)]);
          POpt=vp_opt('X',prompt,'ACCEPT','Calculate Z Scores','RETRY','Don''t Z Score','EXIT','');
          if (POpt=='X' | strcmp(POpt,'EXIT') ), 
	     vp_note('Program Exited',2); return;
          else 
	  end %if POpt
	else
          POpt='ACCEPT';
        end %if ngis
      else
        POpt='ACCEPT';
      end %if num_gis
      
      if (norm1==0 | norm2==0)
         vp_note(['No Control Subjects Specified'],2);
      %  vp_message(['Invalid Reference File: ',ssffile,' Control Subjects Not Specified']);

	%no=1;
	%while no~= 2 % Must enter at least two numbers even if the same
	% Keyin=['1 - ',num2str(nosubs)];
	% prompt=['Specify Control Subject Index Range Within [n1-n2] | q]   <',Keyin,'>   '];
	% vp_keyin(prompt,Keyin);

	% if (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
	%   set(FMenu,'Pointer','Arrow');
	%   vp_message(['END CHECK: ',ssf_name,', ']);
	%      return;
	% else
      
	%      Keyin=strrep(Keyin,' ','');
	%      [nn,no]=sscanf(Keyin,'%d-%d'),
	%      norm1=nn(1)
	%      if no ==2  norm2=nn(2) 
	%        if (norm1 < 1 | norm1 > nosubs), vp_note('Error: Number norm1 out of range',2);
	%          no=1;
	%        elseif (norm2 < 1 | norm2 > nosubs), vp_note('Error: Number norm2 out of range',2);
	%          no=1;
	%        elseif (norm1 == 1 & norm2 == nosubs), vp_note('Error: All ref. subjects cannot be controls',2);
	%          no=1;
	%        end %if norm1
	%      end; %if no==2
	% end %if isempty 
	%end % while no~=2
	
      else
 	vp_note(['Control Subject Range: ',num2str(norm1),' - ',num2str(norm2)],2);
      end; % if norm1
      
   end %while
 end % if readref_mean
    
 
 %Normalize SSF Scores (Z-score for gis over ref subjects)
 Zssfs=zeros(size(ssfscores));
 Zssfs(:,ngis)=(ssfscores(:,ngis)-mean(ssfscores(:,ngis)))./std(ssfscores(:,ngis)); 

 % Offset calculated for each gis

 Zoffset=0; Zoffset(1:num_gis)=0;
 if norm2 > 0
   if norm2 ~= norm1
      Zoffset=mean(Zssfs(norm1:norm2,:)),
   else
      Zoffset=Zssfs(norm1,:),
   end
 end
    
 %Zssfs=Zssfs-Zoffset;
 Zssfs(:,ngis)=Zssfs(:,ngis)-Zoffset(ngis)*ones(nosubs,1);
 if REFscores
 
   %Use the same mean, std and offset calculated for the reference to get the new Zscores.

   %Zssf=zscore(ssf),
   %Zssf=(ssf - mean(ssf))./std(ssf),
   Zssf=(ssf - mean(ssfscores(:,ngis)))./std(ssfscores(:,ngis)); 
   Zssf=Zssf-Zoffset(ngis)*ones(sub,1);;
   
 else
   Zssf=Zssfs;
 end
    
 zscorefig=figure('name','TPR Z SCORES'); bar(Zssf); xlabel('New Subject'); ylabel('New Subject Z SCORE');
 if REFscores
   vp_write_srpfile(Zssf_name,1,file_list,Zssf)
 else
   vp_write_ssmfile(ssf_name,ngisno,-1,file_list,ssf,1,norm1,norm2)
   vp_write_ssmfile(Zssf_name,ngisno,-1,file_list,Zssf,3,norm1,norm2)
 end
 
 vp_dispfile(Zssf_name);
    
 if REFscores
   pos=get(zscorefig,'position');
   pos(3)=max(pos(3)/3, pos(3)*(sub/nosubs));
   set(zscorefig,'position',pos);
   
   %Display Combined Scores (Group + New Subjects)
   ZCssf=[Zssfs(:,ngis); Zssf;];
   ZCscorefig=figure('name','TPR COMBINED Z SCORES'); bar(ZCssf);
   yo=max(ZCssf)/4;
   if norm2 > 0
     xlabel('Reference and New Subject(s), c:controls, s: new subjects'); ylabel('COMBINED GROUP Z SCORES');
     for i=norm1:norm2, text(i,yo,'c','color','r'); end; %Mark controls
   else
     xlabel('Reference and New Subject(s), s: new subjects'); ylabel('COMBINED GROUP Z SCORES');
   end
   for i=nosubs+1:nosubs+sub, text(i,yo,'s','color','m'); end; %Mark new subjects
   set(gca,'color',[1.0 1.0 .9]);
   pos=get(ZCscorefig,'position');
   pos(1)=pos(1)+ 2*pos(3)/3;
   set(ZCscorefig,'position',pos);
 
 else
   yo=max(Zssf)/4;
   figure(zscorefig);
   if norm2 > 0
     for i=norm1:norm2, text(i,yo,'c','color','r'); end; %Mark controls
   end
   set(gca,'color',[1.0 .9 .9]);
 end %if REFscores
    
end % if sub


 DiagnOpt=0; % OMIT REPORT
 if REFscores
  if ( (norm2>0) & DiagnOpt)
 % write diagnostic report
   netnam=vp_nm('dnm',gis_name);
   if nm_gis > 1
    netnam=[netnam,ngisch];
   end

   DIAGNrpt_name = strcat(outnm, '_DIAGNrpt.txt');
 
   Keyin='0'; clear cycle;
   %Min Z for Total TRUE Max
   diagntype=4;
   imls=file_list;
   vp_ssm_prediagnrpt;
 
   %vp_DIAGNrpt(DIAGNrpt_name,netnam,file_list,Zssf,'ROI based Z Scores',Zssfs(:,ngis),norm1,norm2);
 
   vp_MDiagnRpt(DIAGNrpt_name,netnam,imls,Zssf,'VOXEL based Z Scores',Zssfs(:,ngis),norm1,norm2,nosubs,diagntype,ZRadius,1);
   vp_dispfile(DIAGNrpt_name);
 
   vp_message(['END CHECK: ',ssf_name,' and ',DIAGNrpt_name]);
  end;
   
 else
  vp_message(['END CHECK: ',ssf_name]);
 end


set(FMenu,'Pointer','Arrow');
