% vp_ssm_voxpcapro  Copyright (C) 2003-2016 Center for Neurosciences, FIMR. 
% User pre and post processing interface to SSM-PCA analysis.
%_______________________________________________________________________
% vp_ssm_voxpcapro chcks input parameters, invokes ssmpca and checks
% graphical output.
%
% The program prompts for a name to be assigned to output files.
% The routine then runs the dos command to perform the analysis:
% 'ssmpca names.lst [Thresh | mask] | [SRP mask]  > pcaoutput.txt'
% Natural log transformation is by default performed in the ssmpca routine
% for raw data. If requested, a 'NOLOG' command line option can be specified.
% Results are saved in the user directory. Results include the evaluated
% PCA's (GIS images), the data mask used by the routine, the group mean image
% of the (log transformed) data (where each subject's image is normalized by 
% subtracting the subject's voxel mean), the subject residual profile images 
% (deviations from the group mean), a SSM summary text file (Name_VScores.txt) 
% listing SSF reference (REF) scores for all subjects for the first 16 principal
% components and the "%Variance Accounted For"  for those components.
% The output SSF REF Scores are then read in by the MATLAB routine and SSF
% Z-Scores are calculated for each of the eigenvectors over subjects.
% If controls are specified, the Z-Scores are offset by the mean Z-Score over
% controls.Individual GIS REF and Z-Score files can be saved.
% The scatterplot legend specifies the mean and std for each subject set. 
% p-values result from tests of the hypothesis of equal means of the 
% non-control group with respect to the first (control) group using either
% a ttest2 (for samples with equal variance) or tutest2 (unequal variances).
% Equal variance is tested using an ftest. A significance level=0.05
% is assumed.
%
%_______________________________________________________________________
% vp_ssm_pca		4.7.8	P. Spetsieris	10/01/2002
% vp_ssm_voxpca		Revision 5.8	May 08, 2007
% vp_ssm_voxpcapro	Rev 5.8	May  09, 2007 P.S.
% 			Rev 5.9 Mar  10, 2008 P.S.
% 			Rev 6.2 Jan  13, Apr 4, Nov. 12, 2012 P.S.
%			Rev 6.2.1 Apr. 29, 2013 P.S.
%_______________________________________________________________________


global HelpMode NameLst ANameLst POpt FMenu FName FNames MaskOpt Keyin
global Ecolor RawData Prompt Filter CNameLst LogTrans GraphOut FixedThresh 
global LSrpSave ORIGIN

if HelpMode, vp_help(mfilename), return ; end;

NameLst= ANameLst; % Reserve ANameLst for any re-entry.
PlaneNo=ORIGIN(3);

FNames='';
if ~isempty(CNameLst)
  nnorms= size(CNameLst,1);
  FNames=cellstr(CNameLst);
else
  nnorms=0;
end;

m= size(NameLst,1);
if nnorms > 0
  NameLst=cellstr(NameLst);
  for i=1:m, FNames(nnorms+i,:)=NameLst(i,:); end; 
  NameLst=char(FNames),
end

m= size(NameLst,1),
if vp_checkNIFU(NameLst,5) %Exit for UNIX and .nii files
 set(FMenu,'Pointer','Arrow');
return, end;

studyname = vp_nm('nm',NameLst(1,:));
vp_keyin('[Assign Output Files Study Name | q]',studyname);
if (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
  return,
  set(findobj('Name','SSM VOXEL PCA'),'Pointer','Arrow');
else studyname=Keyin; end;

%if (isempty(MaskOpt) & RawData),
%
if and(~ischar(MaskOpt),RawData),
  MaskOpt=sprintf('T%.02d',FixedThresh); %T followed by 2 digits
  if ((length(MaskOpt) ~=3) | ~isempty(findstr(MaskOpt,'e'))),
    vp_note(['INVALID Threshold: ',num2str(FixedThresh),', Should be integer 0:99'],3);
    set(findobj('Name','SSM VOXEL PCA'),'Pointer','Arrow');
  return; end;
end;    
   
%prompt1=['Subjects: ',num2str(m),' Controls: 1 - ',num2str(nnorms)];

MaskOpt,

if (RawData & LogTrans)
 vp_note('Data will be Log transformed by the ssmpca routine.',2);
end;
h=waitbar(0.3,'Processing SSM PCA - WAIT for Results');
set(FMenu,'Pointer','Watch');

for i=1:m
  FName=deblank(NameLst(i,:));
  len=size(FName,2);
  
%  waitbar((i-.8)/m,h);
  if i==1
  	%dirnm=vp_nm('dir',FName);
	%FNameLst=[FName(1:(len-4)),'lst.txt'],
	dirnm=pwd;
	FNameLst=[dirnm,'\', studyname,'lst.txt'],
	fid= fopen(FNameLst,'w');

	if (fid == -1)
	  Message=['Error opening ' P '. Check that you have write permission.'];
	  vp_message(Message);
	  error(Message);
	  return; %PS
 	  set(findobj('Name','SSM VOXEL PCA'),'Pointer','Arrow');
	end
	if nnorms > 0
	  fprintf(fid,'%s\r\n',[FName(1:(len-4)),'.hdr   CONTROLS: ',num2str(nnorms)]);
	else
	  fprintf(fid,'%s\r\n',[FName(1:(len-4)),'.hdr']);
	end
	%fwrite(fid,[FName(1:(len-4)),'.hdr'],'char' );
  end
  %fwrite(fid,[FName(1:(len-4)),'.img'],'char' );
  fprintf(fid,'%s\r\n',[FName(1:(len-4)),'.img']);
end

fclose(fid);

if LogTrans, LogOpt='LOG', else, LogOpt='NOLOG', end;
ret=0;
MaskOpt,
disp('PROCESSING - WAIT FOR RESULTS');
waitbar(1,h); pause(1); close(h);

if RawData
 OutFile=[dirnm,'\pcaoutput', studyname,'.txt'],
 %DosCmd = ['ssmpca ',FNameLst,' ',MaskOpt,' ',LogOpt,' > ', OutFile],
 if LSrpOut, 
   ret=vp_ssmpca(FNameLst,MaskOpt,LogOpt,'SRPOUT',OutFile);
 else
   ret=vp_ssmpca(FNameLst,MaskOpt,LogOpt,OutFile);
 end;

else
 OutFile=[dirnm,'\srppcaoutput', studyname,'.txt'],
 %DosCmd = ['ssmpca ',FNameLst,' SRP ',MaskOpt,' > ', OutFile],

 if ~ischar(MaskOpt), MaskOpt=''; end;

 if LSrpOut, 
   ret=vp_ssmpca(FNameLst,['SRP ',MaskOpt],'SRPOUT',OutFile);
 else
   ret=vp_ssmpca(FNameLst,['SRP ',MaskOpt],OutFile);
 end
end

%[s,w]=vp_dos(DosCmd);
disp(' ');

%if (s >=0 ),
if (ret >=0 ),
 vp_note(['PROCESS END ssmpca- Check Matlab Window and ', OutFile]);
else,
 %vp_note('PROCESS FAILED, - Check Matlab Window and *output.txt');
 vp_note(['PROCESS FAILED, - Check Matlab Window and ',OutFile]);
 set(FMenu,'Pointer','Arrow');
 set(findobj('Name','SSM VOXEL PCA'),'Pointer','Arrow');
 out1=POpt;
 return;
end;


if GraphOut

% Z transformation, read REF Score file.
ssffile=[dirnm,'\',studyname,'_VScores.txt'];
[mode, ssffile, ngis, ssf, Zssfs, norm1, norm2, vaf] =vp_ssm_scores(-2,ssffile)
[sub, num_gis]=size(ssf),
%if (norm1==0 | norm2==0)
%  set(FMenu,'Pointer','Arrow');
%  set(findobj('Name','SSM VOXEL PCA'),'Pointer','Arrow');
%  vp_message(['Invalid Reference File: ',ssffile,' Control Subjects Not Specified']);
%return; end;

if norm2 > 0
  labelx=['CONTROLS                SUBJECTS'];
else
  labelx=['                SUBJECTS'];
end

ssfpcafig=figure('name',['PCA SCORES for GIS 1 VAF(',num2str(vaf(1)),'%)']);
bar(ssf(:,1)); ylabel('SSF SCORE  (for GIS1)');

%yo=max(ssf(:,1))/4;
%%yo=0;

%%if norm2 > 0
  %for i=norm1:norm2, text(i,yo,'-','color','c'); end; %Mark controls
%%  for i=1:norm1:norm2, text(i,yo,'*','color','w'); end; %Mark controls
%%  for i=1:norm1:norm2, text(i+.1,yo,'*','color','k'); end; %Mark controls
%%  xlabel('Subject  (* : control)');
%%else
%%  xlabel('Subject ');
%%end

if norm2 ~= 0
  %ypos=min(ssf(:,1))/2;
  ypos=get(gca,'Ytick'); if ypos(2) >=0, ypos=(ypos(1)+ypos(2))/2, else ypos=ypos(2); end;
  text(norm1-.5,ypos,'<','color','b');  %Mark controls
  text(norm2,ypos,'>','color','b');  %Mark controls
  line([norm1-.5,norm2],[ypos,ypos],'LineStyle','--');
  xlabel('SUBJECT   (Control: __ __ )'); 
else
  xlabel('SUBJECT ');
end

 
% create scatter plot
labely=['SCATTERPLOT - SSF SCORES for GIS 1'];
%vp_scatterplot(ssf(:,1),norm2,sub,0,labelx,labely,'GIS 1')
vp_scatterplot(ssf(:,1),norm2,sub,0,labelx,labely,['GIS 1 VAF(',num2str(vaf(1)),'%)'])

%PS add Z transformation option
%Normalize SSF Scores (Z-score for each of the (n=num_gis) eigenvectors over subjects)
for x=1:num_gis % for each eigenvector
   Zssfs(:,x)=(ssf(:,x)-mean(ssf(:,x)))./std(ssf(:,x)); 
end

%Zssfs(norm1:norm2,:),
% Offset calculated for each gis

if norm2 ~=0
 if norm2 ~= norm1
  Zoffset=mean(Zssfs(norm1:norm2,:)),
 else
  Zoffset=Zssfs(norm1,:),
 end
 %Zssfs=Zssfs-Zoffset;
 for x=1:num_gis
    Zssfs(:,x)=Zssfs(:,x)-Zoffset(x)*ones(sub,1);
    disp('Z SCORES OFFSET FROM CONTROL MEAN Z SCORE');
 end
end %if norm2=0

refname=[dirnm,'\',studyname];
Zssf_name=[refname,'_VZScores.txt'];
vp_write_ssmfile(Zssf_name,num_gis,vaf,NameLst,Zssfs,5,norm1,norm2);
zscorefig=figure('name',['PCA Z SCORES for GIS 1 VAF(',num2str(vaf(1)),'%)']); bar(Zssfs(:,1)); ylabel('Z SCORE  (for GIS1)');

%yo=max(Zssfs(:,1))/4;
%%yo=0;

%%if norm2 > 0
  %for i=norm1:norm2, text(i,yo,'-','color','c'); end; %Mark controls
%%  for i=1:norm1:norm2, text(i,yo,'*','color','w'); end; %Mark controls
%%  for i=1:norm1:norm2, text(i+.1,yo,'*','color','k'); end; %Mark controls
%%  xlabel('Subject  (* : control)');
%%else
%%  xlabel('Subject ');
%%end

if norm2 ~= 0
  %ypos=min(Zssfs(:,1))/2;
  ypos=get(gca,'Ytick'); if ypos(2) >=0, ypos=(ypos(1)+ypos(2))/2, else ypos=ypos(2); end;
  text(norm1-.5,ypos,'<','color','b');  %Mark controls
  text(norm2,ypos,'>','color','b');  %Mark controls
  line([norm1-.5,norm2],[ypos,ypos],'LineStyle','--');
  xlabel('SUBJECT   (Control: __ __ )'); 
else
  xlabel('SUBJECT ');
end


pos=get(ssfpcafig,'position');
set(ssfpcafig,'position',[pos(1)+40, pos(2)-60, pos(3), pos(4)]);
figure(ssfpcafig);

labely=['SCATTERPLOT - Z SCORES for GIS 1'];
vp_scatterplot(Zssfs(:,1),norm2,sub,0,labelx,labely,['GIS 1 VAF(',num2str(vaf(1)),'%)'])

workdir=pwd;
pos1=get(gcf,'position');
gisnam=[workdir,'\',studyname,'_gis001.img'], 
if ~isempty(gisnam), FI=vp_fimg(gisnam,PlaneNo,1,4,0); 
pos2=get(gcf,'position');
set(gcf,'position',[pos1(1)-pos2(3), pos2(2), pos2(3), pos2(4)]);
end;

%  Select Other Gis #
ngis=1; ngis0=1;
Keyin=num2str(ngis);

while ~(isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
  
  if ~strcmp(Keyin, 'Skip'),
    prompt=[' Save GIS Network ' num2str(ngis), ' Scores ? [Y|N|EXIT]'];
    POpt=vp_opt('X',prompt,'YES','Save GIS Scores','NO','SKIP','EXIT','');
    if (POpt=='X' | strcmp(POpt,'EXIT')), 
	Keyin='';
    elseif strcmp(POpt,'NO'),
    else 
        % Save Gis Reference Scores
	vp_write_ssmfile([refname,'_VScores',num2str(ngis),'.txt'],ngis,vaf(ngis),NameLst,ssf(:,ngis),4,norm1,norm2)
	vp_write_ssmfile([refname,'_ZScores',num2str(ngis),'.txt'],ngis,vaf(ngis),NameLst,Zssfs(:,ngis),5,norm1,norm2)
    end;
  end;

  if ~(isempty(Keyin)),
    if ngis > num_gis -1, ngis= num_gis -1; end;
    if (ngis < 1 ), ngis = 0; end;
    Keyin=num2str(ngis+1);
    prompt=['Display SCORES GIS No.? [1-',num2str(num_gis),'| q]'];
    vp_keyin(prompt,Keyin);

    if (isempty(Keyin) | strcmp(Keyin,'q') | strcmp(Keyin,'quit')),
    else
      ngis=str2num(Keyin);
      if (ngis > num_gis | ngis < 1), vp_note('Error: Number out of range',2);
        ngis= ngis0; Keyin=['Skip'];
      else
        % Display bar graph
	netnam=['GIS ',num2str(ngis)];
        ssfpcafig=figure('name',['PCA SCORES for ',netnam,' VAF(',num2str(vaf(ngis)),'%)']); bar(ssf(:,ngis));
	%yo=max(ssf(:,ngis))/4;

	%%yo=0;
	%%if norm2 > 0
	  %for i=norm1:norm2, text(i,yo,'-','color','c'); end; %Mark controls
	%%  for i=1:norm1:norm2, text(i,yo,'*','color','w'); end; %Mark controls
	%%  for i=1:norm1:norm2, text(i+.1,yo,'*','color','k'); end; %Mark controls
        %%  xlabel('Subject  (*: control)');
        %%  ylabel(['PCA SCORE  -  ',netnam]);
	%%else
        %%  xlabel('Subject'); ylabel(['PCA SCORE  -  ',netnam]);
	%%end


	if norm2 ~= 0
	  %ypos=min(ssf(:,ngis))/2;
          ypos=get(gca,'Ytick'); if ypos(2) >=0, ypos=(ypos(1)+ypos(2))/2, else ypos=ypos(2); end;
	  text(norm1-.5,ypos,'<','color','b');  %Mark controls
	  text(norm2,ypos,'>','color','b');  %Mark controls
	  line([norm1-.5,norm2],[ypos,ypos],'LineStyle','--');
	  xlabel('SUBJECT   (Control: __ __ )'); 
          ylabel(['PCA SCORE  -  ',netnam]);
	else
	  xlabel('SUBJECT ');
          ylabel(['PCA SCORE  -  ',netnam]);
	end

	
	labely=['SCATTERPLOT - SCORES for ',netnam];
	vp_scatterplot(ssf(:,ngis),norm2,sub,0,labelx,labely,[netnam,' VAF(',num2str(vaf(ngis)),'%)'])
     

     
        zscorefig=figure('name',['PCA Z SCORES for ',netnam,' VAF(',num2str(vaf(ngis)),'%)']); bar(Zssfs(:,ngis));
	%yo=max(Zssfs(:,ngis))/4;

	%%yo=0;
	%%if norm2 > 0
	  %for i=norm1:norm2, text(i,yo,'-','color','c'); end; %Mark controls
	%%  for i=1:norm1:norm2, text(i,yo,'*','color','w'); end; %Mark controls
	%%  for i=1:norm1:norm2, text(i+.1,yo,'*','color','k'); end; %Mark controls
        %%  xlabel('Subject  (* : control)');
	%%  ylabel(['PCA Z SCORE  -  GIS ',num2str(ngis)]);
	%%else
        %%  xlabel('Subject'); ylabel(['PCA Z SCORE - GIS ',num2str(ngis)]);
	%%end

	if norm2 ~= 0
	  ypos=min(Zssfs(:,ngis))/2;
	  text(norm1-.5,ypos,'<','color','b');  %Mark controls
	  text(norm2,ypos,'>','color','b');  %Mark controls
	  line([norm1-.5,norm2],[ypos,ypos],'LineStyle','--');
	  xlabel('SUBJECT   (Control: __ __ )'); 
	  ylabel(['PCA Z SCORE  -  GIS ',num2str(ngis)]);
	else
	  xlabel('SUBJECT ');
	  ylabel(['PCA Z SCORE  -  GIS ',num2str(ngis)]);
	end


        pos=get(ssfpcafig,'position');
        set(ssfpcafig,'position',[pos(1)+40, pos(2)-60, pos(3), pos(4)]);
	
	labely=['SCATTERPLOT - Z SCORES for ',netnam];
	%vp_scatterplot(Zssfs(:,ngis),norm2,sub,0,labelx,labely,netnam)
	vp_scatterplot(Zssfs(:,ngis),norm2,sub,0,labelx,labely,[netnam,' VAF(',num2str(vaf(ngis)),'%)'])
        ngis0=ngis;

	pos1=get(gcf,'position');
        gisnam=[workdir,'\',studyname,'_gis',vp_num3str(ngis), '.img'], 
	if ~isempty(gisnam), FI=vp_fimg(gisnam,PlaneNo,1,4,0); end;
	pos2=get(gcf,'position');
	set(gcf,'position',[pos1(1)-pos2(3), pos2(2), pos2(3), pos2(4)]);

      end
    end 
  
  end %if ~
end

end % for GraphOut

set(FMenu,'Pointer','Arrow');
set(findobj('Name','SSM VOXEL PCA'),'Pointer','Arrow');

