% function out1=vp_surfplot;
%
% Pick a region on a data image and display a surface value plot
%
% This 'imview' and utilities option creates a 3D plot of the
% values of a rectangular planar surface area. The plane may
% be in any orthogonal view. Coordinates are in mm from the image
% origin specified in the file header. 
% The region is defined by holding the left button down and 
% entering the lower left and upper right diagonal points.
% For square regions use the right button.
%_______________________________________________________________________
% vp_surfplot.m  		4.7.6 Phoebe Spetsieris  Dec. 9, 2001

function [out1] = vp_surfplot

global HelpMode UFI hSurf
global VOX ORIGIN HelpMsg

if HelpMode, vp_help(mfilename), return ; end;

out1=0; 
viewno=0;

TxColor=[0.8 0.2 1];
	
%if (~exist('FI') | isempty(FI) ), 
if  isempty(UFI),  
  UFI=gcf;
  %vp_message('no data image found');
  %out1=-1;
  %return;
end 
      
figure(UFI);
       
vp_note('Define ROI with Left Button Down',1);

found=0;
while found==0,
 rect=getrect(UFI),
 anynegs=rect > 0 ;
 if min(anynegs)==0
   vp_note('Please Reenter Diagonal Points',2);
 else
   found=1;
 end
end

x=round(rect(1)); y=round(rect(2)); wid=round(rect(3)); hgt=round(rect(4));
pixrect=[x y wid hgt],

if strcmp(get(gco,'type'),'image')
  cdata=get(gco,'CDATA');
  cdata=cdata';
  
  sz=size(cdata),
  mx=max(max(cdata));
  mn=min(min(cdata));
  
  %x=round(x), y=round(y),
  %value=cdata(x,y),

  rdata=zeros(wid,hgt);

  i1=x, i2=x+wid-1; j1=y; j2=j1+hgt-1;
  for i=i1:i2, for j=j1:j2, m=i-i1+1; n=j-j1+1;
  rdata(m,n)=cdata(i,j); end; end;
 
  sz=size(rdata);
  wid=sz(1), hgt=sz(2),
  
  rmx=max(max(rdata));
  rmn=min(min(rdata));
  
  udata=get(gca,'UserData');
  if ~isempty(udata),
  
    viewno=udata(1); plno=udata(2); vox=udata(3:5); xyzor=udata(6:8);
    if viewno==1
  	xmm=(x-xyzor(1))*vox(1); ymm=(y-xyzor(2))*vox(2);
	zmm=(plno-xyzor(3))*vox(3);
	widmm=vox(1)*wid; hgtmm=vox(2)*hgt;
	for ix=1:wid, xi(ix)=xmm+(ix-1)*vox(1); end;
	for iy=1:hgt, yi(iy)=ymm+(iy-1)*vox(2); end;
    elseif viewno==2,
  	ymm=(x-xyzor(2))*vox(2); zmm=(y-xyzor(3))*vox(3);
	xmm=(plno-xyzor(1))*vox(1);
	widmm=vox(2)*wid; hgtmm=vox(3)*hgt;
	for ix=1:wid, xi(ix)=ymm+(ix-1)*vox(2); end;
	for iy=1:hgt, yi(iy)=zmm+(iy-1)*vox(3); end;
    elseif viewno==3,
  	xmm=(x-xyzor(1))*vox(1); zmm=(y-xyzor(3))*vox(3);
	ymm=(plno-xyzor(2))*vox(2);
	widmm=vox(1)*wid; hgtmm=vox(3)*hgt;
	for ix=1:wid, xi(ix)=xmm+(ix-1)*vox(1); end;
	for iy=1:hgt, yi(iy)=zmm+(iy-1)*vox(3); end;
    end
  else
  	if isempty(ORIGIN), ORIGIN=[1 1 1]; end;
  	if isempty(VOX), VOX=[1 1 1]; end;
  	xmm=(x-ORIGIN(1))*VOX(1); ymm=(y-ORIGIN(2))*VOX(2);
	for ix=1:wid, xi(ix)=xmm+(ix-1)*VOX(1); end;
	for iy=1:hgt, yi(iy)=ymm+(iy-1)*VOX(2); end;
  end
  
else
	out1=-1;
	vp_message('Not an ''image'' ');
	return;
end

hSurf=figure('name','surface plot');
vp_controls(gcf,mfilename,1);

mfactor=1;
keyin=vp_keyin('Enter DATA Multiplier','1');
if ~isempty(keyin), mfactor=str2num(keyin); rdata=rdata*mfactor; end;
surf(yi,xi,rdata); shading interp; 

set(gca,'ydir','reverse');

xstr='X'; if viewno == 2, xstr='Y'; end;
keyin=vp_keyin('Key Axis 1 Label',xstr);
if ~isempty(keyin), xstr=keyin; ylabel(xstr); end;

ystr='Y'; if viewno > 1, ystr='Z'; end;
keyin=vp_keyin('Key Axis 2 Label',ystr);
if ~isempty(keyin), ystr=keyin; xlabel(ystr); end;

zstr='Value';
keyin=vp_keyin('Key Axis 3 Label',zstr);
if ~isempty(keyin), zstr=keyin; zlabel(zstr); end;


%xtick=get(gca,'xtick');
%xticklabel=get(gca,'xticklabel');
%dx=xtick(2)-xtick(1);
%lenx=length(xtick);

%ytick=get(gca,'ytick');
%yticklabel=get(gca,'yticklabel');
%dy=ytick(2)-ytick(1);
%leny=length(ytick);

%if viewno==1
% for i=1:lenx,xticklabel(i,:)=num2str(ymm+(i-1)*dx*vox(2)) , end;
% xticklabel;
% set(gca,'xticklabel',xticklabel);
% for i=1:leny,yticklabel(i,:)=num2str(xmm+(i-1)*dy*vox(1)) ; end;
% yticklabel;
% set(gca,'yticklabel',yticklabel);
%end;
  
  
himv=findobj('Name','surfplotui');

position=[200,200,450,100];

if ~isempty(himv); position=get(himv,'Position'); delete(himv); end;


        himv = figure('Color','w','Name','surfplotui',...
	'NumberTitle','off','Position',position,...
	'Units','Pixels','Visible','on');
	
	axis off;
	
	uicontrol(himv,'String','HELP',...
	'Position',[360 position(4)-18 55 18],...
	'TooltipString',HelpMsg,...
	'callback','vp_help(''vp_surfplot'');');

	uicontrol(himv,'String','PLOT',...
	 'Position',[45 10 55 20],...
	 'TooltipString','Plot values of 2D region',...
	 'CallBack','vp_surfplot;');
	
	 
	uicontrol(himv,'String','AXIS ON',...
	 'Position',[110 10 55 20],...
	 'TooltipString','Set the axis on surface plot',...
	 'CallBack','fn=findobj(''name'',''surface plot''); figure(fn(length(fn))); axis on;');
	
	uicontrol(himv,'String','AXIS OFF',...
	 'Position',[170 10 55 20],...
	 'TooltipString','Set the axis off surface plot',...
	 'CallBack','fn=findobj(''name'',''surface plot''); figure(fn(length(fn))); axis off;');
	
	uicontrol(himv,'String','GRID ON',...
	 'Position',[235 10 55 20],...
	 'TooltipString','Set the grid on surface plot - axis must be on',...
	 'CallBack','fn=findobj(''name'',''surface plot''); figure(fn(length(fn))); grid on;');
	
	uicontrol(himv,'String','GRID OFF',...
	 'Position',[295 10 55 20],...
	 'TooltipString','Set the grid on surface plot - axis must be off',...
	 'CallBack','fn=findobj(''name'',''surface plot''); figure(fn(length(fn))); grid off;');
	
	uicontrol(himv,'String','RETURN',...
	'Position',[360 10 55 20],...
	'CallBack',[' ; ',...
	'delete(findobj(''Name'',''surfplotui''));'] );

	
	%coord=[' (',num2str(x) ', ' num2str(y),')'];
	
	%coord=[' (',num2str(x) ',' num2str(y),', ' ',...
	% ' num2str(round(wid)) ',' num2str(round(hgt)),')'];
	
	coord=[' (',num2str(x) ',' num2str(y),', ' num2str(wid) ',' num2str(hgt),')'];

	if viewno == 1, view ='Axial XY,  ';
	elseif viewno==2, view = 'Sagittal YZ,  ';
	elseif viewno==3, view = 'Coronal XZ,  ';
	else view= 'Not Defined,   ';
	end
	
        textstr=['View: ', view, 'ROI x,y,wid,hgt ',coord,' (pix)'];
	text(0.0,.78, textstr,...
	'FontName','Times','FontSize',10,...
	'VerticalAlignment','Middle',...
	'HorizontalAlignment','Left',...
	'Color',TxColor);

	if viewno~=0,
	
	  %textstr=['PlaneNo :   ',num2str(plno), '  ', coord ];
	  if viewno==1,
	    textstr=['PlaneNo :   ',num2str(plno),',  Z= ',num2str(zmm),'mm'];
	  elseif viewno==2, 
	    textstr=['PlaneNo :   ',num2str(plno),',  X= ',num2str(xmm),'mm'];
	  elseif viewno==3, 
	    textstr=['PlaneNo :   ',num2str(plno),',  Y= ',num2str(ymm),'mm'];
	  end;
	  text(0.0,.96, textstr,...
	  'FontName','Times','FontSize',10,...
	  'VerticalAlignment','Middle',...
	  'HorizontalAlignment','Left',...
	  'Color',TxColor);
	
	  textstr=['X= ',num2str(xmm),'mm, Y= ',...
		num2str(ymm),'mm, Z= ',num2str(zmm), 'mm,',...
		' WID= ', num2str(widmm),'mm, HGT= ',num2str(hgtmm), '(mm)'];
	  text(0.0,.60, textstr,...
	  'FontName','Times','FontSize',10,...
	  'VerticalAlignment','Middle',...
	  'HorizontalAlignment','Left',...
	  'Color',TxColor);
	end
	
	
	textstr=['Min,Max Reg (',num2str(rmn),',',num2str(rmx),')', ',  Min,Max Img (', num2str(mn),...
	', ',num2str(mx),')'];

	text(0.0,.40, textstr,...
	'FontName','Times','FontSize',10,...
	'VerticalAlignment','Middle',...
	'HorizontalAlignment','Left',...
	'Color',TxColor);

       
	








