/*
 vp_unixcvt.c
 Converts a unix format ANALYZE header and image

 Reads Analyze format header and convert from UNIX
 format to DOS format and vice-versa 	P.SPETSIERS  2/14/97

 Modification:
 Checks for data bytes. If greater than 8bits per byte,
 also converts the corresponding image data file. P.S. 9/20/01
 Add ability to save multiple volumes. P.S. 5/20/03
*/

#include <stdio.h>
#include "dbh.h"  
#include "mex.h"

void mexFunction(
	int nlhs, mxArray *plhs[],
	int nrhs, const mxArray *prhs[])
{
struct  dsr hdr;	/* analyze data base structure */
FILE *fp,*fp1,*fopen();
int i,ret,no,buflen ;
short int origin[3] ;
char *filename, *fileout, *fileseed;
double *y ;
int len,bitpix,nbytes,dimX,dimY,dimZ,dimXs,dimYs,dimZs ;
int novols, volno, swapbytes;
unsigned char *dat, *pdat ;

  swapbytes=0;

  if (nrhs !=1) {
    mexErrMsgTxt("Only one input (Analyze header file name) allowed.");
  }

  if (!mxIsChar(prhs[0]) )
		mexErrMsgTxt("Arguments must be strings.");

  if (mxGetM(prhs[0]) != 1 )
		mexErrMsgTxt("Arguments must have one row.");


  buflen = mxGetN(prhs[0]) + 1;
  filename = (char *)mxCalloc(buflen, sizeof(char));
  fileseed = (char *)mxCalloc(buflen, sizeof(char));
  fileout = (char *)mxCalloc(buflen+2, sizeof(char));

  if(!mxGetString(prhs[0], filename, buflen)){
	mexPrintf("File: %s\n",filename);
  }
  else
	mexErrMsgTxt("could not read argument\n");

  if ((fp=fopen(filename,"rb"))==0) /*filename */
  {
   strcat(filename,".hdr");
   if ((fp=fopen(filename,"rb"))==0){ /*filename */
        printf ("unable to open for read: %s\n",filename);
        mexErrMsgTxt("Unable to open header file");
        /*exit(0);*/
   }
  }

  if((ret=fread(&hdr,sizeof(struct dsr),1,fp)) !=1)
  {
    printf("error reading %s return %d \n",filename,ret);
    mexErrMsgTxt("Unable to read header file");
  }
  fclose(fp);

  printf("\nKEY\n");
  swap_bytes(&hdr.hk.sizeof_hdr,4);
  printf("size of header: %d\n",hdr.hk.sizeof_hdr);
  printf("data_type: %s\n",hdr.hk.data_type);
  printf("db_name: %s\n",hdr.hk.db_name);
  swap_bytes(&hdr.hk.extents,4);
  printf("extents: %d\n",hdr.hk.extents);
  swap_bytes(&hdr.hk.session_error,2);
  printf("hdr.hk.regular : %c\n",hdr.hk.regular );
  printf("hdr.hk.hkey_un0 : %c\n",hdr.hk.hkey_un0 );
  
  printf("\nDIMENSIONS\n");
  dimX=hdr.dime.dim[1]; dimY=hdr.dime.dim[2]; dimZ=hdr.dime.dim[3];
  novols=hdr.dime.dim[4];
  for(i=0; i< 8; i++)
	swap_bytes(&hdr.dime.dim[i],2);
  printf("No. of dimensions: %d\n",hdr.dime.dim[0] );
  printf("dimX: %d\n",hdr.dime.dim[1] );
  printf("dimY: %d\n",hdr.dime.dim[2] );
  printf("dimZ: %d\n",hdr.dime.dim[3] );

  dimXs=hdr.dime.dim[1]; dimYs=hdr.dime.dim[2]; dimZs=hdr.dime.dim[3];

  printf("Scan Duration (secs) : %d\n",hdr.dime.dim[5] );
  for(i=5; i< 8; i++)
  	printf("hdr.dime.dim[%d]: %d\n",i,hdr.dime.dim[i]);
  swap_bytes(&hdr.dime.unused1,2);
  swap_bytes(&hdr.dime.datatype,2);
  swap_bytes(&hdr.dime.bitpix,2);
  swap_bytes(&hdr.dime.dim_un0,2);
  printf("Bits per pixel : %d\n",hdr.dime.bitpix );
  bitpix=hdr.dime.bitpix;
  if ( (bitpix==8) || (bitpix == 16) || (bitpix ==32) || (bitpix==64) )
  {  novols=hdr.dime.dim[4]; }
  printf("No. of Volumes : %d (actual: %d)\n",hdr.dime.dim[4],novols );

  printf("dim_un0 : %d\n",hdr.dime.dim_un0 );
  for(i=0; i< 8; i++)
  	swap_bytes(&hdr.dime.pixdim[i],4);
  printf("pixdem DX,DY,DZ : %8.4f %8.4f  %8.4f\n",hdr.dime.pixdim[1],hdr.dime.pixdim[2],hdr.dime.pixdim[3]);
  for(i=4; i< 8; i++)
  	printf("hdr.dime.pixdim[%i]: %8.4f\n",i,hdr.dime.pixdim[i]);
  swap_bytes(&hdr.dime.vox_offset,4);
  printf("pixel offset : %8.4f\n",hdr.dime.vox_offset);
  swap_bytes(&hdr.dime.funused1,4);
  printf("Scale : %8.4f\n",hdr.dime.funused1);
  swap_bytes(&hdr.dime.funused2,4);
  swap_bytes(&hdr.dime.funused3,4);
  swap_bytes(&hdr.dime.cal_max,4);
  swap_bytes(&hdr.dime.cal_min,4);
  swap_bytes(&hdr.dime.compressed,4);
  swap_bytes(&hdr.dime.verified,4);
  swap_bytes(&hdr.dime.glmax,4);
  swap_bytes(&hdr.dime.glmin,4);
  printf("global max : %d\n",hdr.dime.glmax );
  printf("global min : %d\n",hdr.dime.glmin );

  printf("\nHISTORY\n");
  printf("description: %s\n",hdr.hist.descrip);
  printf("aux_file: %s\n",hdr.hist.aux_file);
  printf("orient: %c\n",hdr.hist.orient);
  cpy_buf((unsigned char*)hdr.hist.originator,(unsigned char*)origin,6);
  for(i=0; i< 3; i++)
	swap_bytes(&origin[i],2);
  cpy_buf((unsigned char*)origin,(unsigned char*)hdr.hist.originator,6);
  printf("origin: %d  %d  %d\n",
	origin[0],origin[1],origin[2]);
  printf("generated: %s\n",hdr.hist.generated);
  printf("scannum: %s\n",hdr.hist.scannum);
  printf("patient_id: %s\n",hdr.hist.patient_id);
  printf("exp_date: %s\n",hdr.hist.exp_date);
  printf("exp_time: %s\n",hdr.hist.exp_time);
  printf("descrip: %s\n",hdr.hist.descrip);
  swap_bytes(&hdr.hist.views,4);
  swap_bytes(&hdr.hist.vols_added,4);
  swap_bytes(&hdr.hist.start_field,4);
  swap_bytes(&hdr.hist.field_skip,4);
  swap_bytes(&hdr.hist.omax,4);
  swap_bytes(&hdr.hist.omin,4);
  swap_bytes(&hdr.hist.smax,4);
  swap_bytes(&hdr.hist.smin,4);
  printf("_______\n");

  plhs[0] = mxCreateDoubleMatrix(1,1, mxREAL);
  y = mxGetPr(plhs[0]);
  *y = 1 ;

  strcpy(fileout,filename);
  strcpy(fileseed,filename);
  if (novols > 1) {
  	len=strlen(filename); fileseed[len-4]='\0';
  	hdr.dime.dim[4]=1; /* output separate volumes */
  }

  for (volno=1; volno < novols+1; volno++) {

    if (novols > 1) {
      sprintf(fileout,"%s%d.hdr",fileseed,volno);
    }
    if ((fp=fopen(fileout,"wb"))==0) /*filename */
    {
        printf ("unable to write: %s\n",fileout);
        *y = 0;
	fclose(fp);
        mexErrMsgTxt("Unable to open header file");
    }

    else{
      if((ret=fwrite(&hdr,sizeof(struct dsr),1,fp)) !=1)
      {
        printf("error writing to %s %d \n",fileout,ret);
        *y = 0;
	fclose(fp);
        mexErrMsgTxt("Unable to write header file");
      }
    }
        
    fclose(fp);

/* Fix Image Data if more than one byte per pixel */
    if (bitpix!=8 && bitpix !=2048) swapbytes=1;

    if (swapbytes || novols > 1){

  	len=strlen(filename);
  	filename[len-1]='g'; filename[len-2]='m'; filename[len-3]='i';
  	len=strlen(fileout);
  	fileout[len-1]='g'; fileout[len-2]='m'; fileout[len-3]='i';

	if ( (bitpix == 16) || (bitpix ==32) || (bitpix==64) ) {
	    dimX=dimXs; dimY=dimYs; dimZ=dimZs;
	}
	else if( bitpix ==4096) {
	    bitpix=16;
	}
	else if( bitpix == 8192) {
	    bitpix=32;
	}
	else if( bitpix == 16384) {
	    bitpix=64;
	}

	nbytes=bitpix/8 ;
	len=dimX*dimY*dimZ; /* pixels */
	no=dimX*dimY*dimZ*nbytes; /* bytes */
	if (volno == 1){
   	  if ((fp1=fopen(filename,"rb"))==0){ /*filename */
           printf ("unable to open for read : %s\n",filename);
    	   mexErrMsgTxt("Unable to open for read .img file");
	  }

	  dat = (unsigned char *)mxCalloc(no, sizeof(unsigned char));
	}
  	if((ret=fread(dat,1,no,fp1)) != no )
  	{
   	 printf("error reading %s return %d \n",filename,ret);
  	  if((ret=fread(&dat,1,1,fp1)) !=1)
  	  {
   	   printf("error reading one byte from %s return %d \n",filename,ret);
	 
	  }
  	 fclose(fp1);
    	 mexErrMsgTxt("Unable to read .img file");
  	}
  	if ((fp=fopen(fileout,"wb"))==0) /*filename */
 	{
	 printf ("unable to open for write : %s\n",fileout);
         mexErrMsgTxt("Unable to open .img file for write");
	}
	else {

	  /* swap data bytes */
	  if (swapbytes){
	    pdat = dat;
	    for (i=0; i< len; i++) {
	      swap_bytes(pdat,nbytes);
	      pdat +=nbytes;
	    }
	  }

    	  if((ret=fwrite(dat,1,no,fp)) !=no)
    	  {
        	printf("error writing to %s %d \n",fileout,ret);
  		fclose(fp);
         	mexErrMsgTxt("Unable to write .img file");
    	  }
  	  fclose(fp);
	}

    } /* end if swapbytes */
  
  } /* end for volno */
  if (swapbytes || novols > 1)fclose(fp1);

return ;

/**/
}


/*
 * swap_bytes.c
 *
 * convert value by swapping bytes
*/
swap_bytes(val,nbytes)
unsigned char *val ;
int nbytes ;
{
       int i;
       unsigned char sav[8];

       if(nbytes > 8)
       {
	   printf("swap_bytes: no of bytes can not exceed 8\n",nbytes);
	   return(-1);
       }
       for(i=0; i<nbytes; i++)(sav[i] = val[i]) ;
       for(i=0; i<nbytes; i++)(val[i] = sav[nbytes-1-i]) ;

       return(0);
}


/* 
 * cpy_buf.c
 *
 * This function copies a given no. of bytes in buf1 to buf2
 */

cpy_buf(buf1,buf2,count)
unsigned char buf1[];
unsigned char buf2[];
int count;	/* No. of bytes */
{
	register int  j ;

		/* copy values */
		for(j = 0 ; j < count ; j++ ){
				buf2[j] = buf1[j] ;

		}

	return(0);
}

