function [out1,out2,out3,out4] = vp_volfuns(action, in1,in2,in3,in4,in5)
%function [out1,out2,out3,out4] = vp_volfuns(action, in1,in2,in3,in4,in5)
%_______________________________________________________________________
% vp_volfuns.m  	ScAnVP C.4.7.3 Phoebe Spetsieris  Nov. 30, 2001
%   			REV  5.5 P.S May 25, 2005
%   			REV  5.6 P.S Nov 03, 2005
%   			REV  6.2 P.S Apr 23, 2012
%   			REV  6.2.1 P.S Apr 27, 2013
%
% Various image volume functions:
%  Action
%
%  'remclusters2':	Remove clusters less than a certain diameter
%			from 2 dimensional data
%			in1= xyzdata, in2=diameter of cluster in voxels, 
%			in3= background value 
%			out1=status, out2=xyzdata, out3=coordinate list
%
%  'xyzdata':		Get the xyzdata and min, max of an image in1
%			in2=orientation 0 as in file, 1=flipped
%			out1=status, out2=xyzdata, out3=min, out4=max
%
%  'volvect':		Get the volume vector and min, max of an image in1
%			out1=status, out2=volvect, out3=min, out4=max
%
%  'valxyz':		Get the significant non-zero value, coordinate
%			and mm coordinate arrays of an image in1.
%			out1=status, out2=value array, out3=xyz voxel coord,
%			out4=xyz mm coord.
%
%  'mergedata':		Merge two volumes
%			in1= xyzdata1, in2=xyzdata2, in3=operation; 
%			in3= 1, Replace volume 1 values == 0 with volume 2
%			in3= 2, Replace volume 1 values <= in4 with volume 2
%			in3= 3, Replace volume 1 values == 0 with constant in5
%			in3= 4, Replace volume 1 values <= in4 with constant in5
%
%			out1=status, out2= merged xyzdata
%
%  'excludata':		Exclude pixels in volume1 that are common to volume2
%			in1= xyzdata1, in2=xyzdata2, in3=precision; 
%			in3=voxel dimension; Excluded pixels set to 0;
%			Voxels from each image must lie within a 3D prism of
%			radius precision -1 to be considered common.
%			out1=status, out2= resulting xyzdata
%
%  'getarea':		in1=xyzdata, in2=position, out1=status, out2=xyzdata
%  'getplane':		in1=xyzdata, in2=planeno; in3=viewno, in4=dim;
%			out1=status, out2=xydata
%_______________________________________________________________________

global DATA Message FName GMIN GMAX VAL_OFFSET
global DIM VOX SCALE TYPE OFFSET ORIGIN DESCRIP GLMAX GLMIN
global EXPTIM DURATION MATYPE Message GENTIM SUBID EXPDATE
global HelpMode

if HelpMode, vp_help(mfilename), return ; end;

out1=0; out2=[]; out3=0; out4=0; 

if strcmp(action,'remclusters') 	
 vp_note('Only works for 2 Dimensions, call vp_cvolfuns instead.');	
 out1=-1;
 return;

elseif strcmp(action,'remclusters2') 	
	
coord=[]; nc=0;
xyzdata=[];

%grow area by one pixel on each side
dim=size(in1),
if length(dim) ~=2, out1=-1; vp_message('data not 2D'); return; end;
xyzdata=zeros(dim+2);
for i=1:dim(1), for j=1:dim(2),
 xyzdata(i+1,j+1)=in1(i,j);
end; end;
dim=size(xyzdata);

cldiam=round(in2);
if cldiam > min(dim)-2, out1=-1; vp_message('cluster dimensions too big'); return; end;
backvalue=in3;
barfract=0.01;

h=waitbar(barfract,['Removing clusters size ',num2str(cldiam),' voxels.']);

% add a voxel and another is added in the for loop 
cldiam= cldiam+1;

%limits

i2=max((dim(1)-cldiam-1),1); % rows vary Y direction
j2=max((dim(2)-cldiam-1),1); % columns vary X direction

 %hr=rectangle('position', [0 0 cldiam+1 cldiam+1]);
  
 j3=0;
 for j=1:j2;
 savedatax=0;
 if j > j3;
  for i=1:i2;
  if i==1, i3=0; end;
  
  savedatay=0;
  if i > i3;
    %find all non zero surface pixels (at least one coord must be on the perimeter)
    %delete(hr); hr=rectangle('position',[j-1 i-1 cldiam+1 cldiam+1]);
    for sy=i: cldiam : i+cldiam; for sx=j:j+cldiam;
     %[sx, sy, xyzdata(sy,sx)],
     if xyzdata(sy,sx) ~= backvalue, savedatay=1;
        nc=nc+1; coord(nc,:)=[sx,sy,xyzdata(sy,sx)];
	break; end;
    end;  if savedatay==1, break, end; end;
    %note='stop point 1',
    if savedatay==0; 
      for sx=j: cldiam: j+cldiam; for sy=i:i+cldiam;
       %[sx, sy, xyzdata(sy,sx)],
       if xyzdata(sy,sx) ~= backvalue, savedatay=1;
        nc=nc+1; coord(nc,:)=[sx, sy, xyzdata(sy, sx)];
	break; end;
      end;  if savedatay==1,break,end; end;
      %note='stop point 2',
    end
    if savedatay==0; % Set all internal values to backround 
      %note='setting 0 all values between limits: ';
      %pos=[j, i, cldiam, cldiam];
      for sy=i:i+cldiam; for sx=j:j+cldiam;
       %[sx sy xyzdata(sy,sx)] ,
       xyzdata(sy,sx) = backvalue;
      end; end;
      %xyzdata,
      i=i+cldiam-1; % jump x
    else,
      savedatax=1; 
    end;
    i3=i;
  end; %if i3
  end %for i
  if savedatax==0; % jump y
    j=j+cldiam-1;
  end;
  j3=j;
  barfract=max(barfract,j/(dim(2)+2));
  barfract=min(1,barfract);
  waitbar(barfract,h);
 end; %if j3
 end %for j

waitbar(1,h); pause(1); close(h);

dim=dim-2,
out2=zeros(dim);

% strip off the outer border pixels
for i=1:dim(1), for j=1:dim(2),
 out2(i,j)=xyzdata(i+1,j+1);
end; end;

out3=coord;

return;

elseif strcmp(action,'xyzdata') 
	
	%fname=deblank(in1);
	%fname=strtok(fname,'.');
	fname=vp_nm('dnm',in1);
        vp_hread([fname '.hdr']);
  
	[fid,Message] = fopen([fname '.img'],'r');
	xyzdata=[];
 
	if (fid ~= -1 )

          if nargin < 3, in2=0; end;
          if in2 ~= 0 % Flip file X Axis orientation
	    for i=1:DIM(3)
	      DATA= fread(fid,[DIM(1),DIM(2)],MATYPE);
              DATA=fliplr(DATA');
	      xyzdata(:,:,i)= DATA';
	    end %for i
            out2=reshape(xyzdata,DIM(1)*DIM(2)*DIM(3),1);

          else % read directly
	    out2= fread(fid,DIM(1)*DIM(2)*DIM(3),MATYPE);
	  end

	  fclose(fid);
	  
	  out1=1;
	  out2=SCALE*out2;
	  if VAL_OFFSET ~=0, out2=out2+VAL_OFFSET; end; 
	  out3=min(out2);
	  out4=max(out2);
	  out2=reshape(out2,DIM(1:3));

	  %out3=min(min(min(out2)));
	  %out4=max(max(max(out2)));

	else
	  vp_message(Message);
	  out1=-1;
	  return;
	end
	
elseif strcmp(action,'volvect') 
	
	%fname=deblank(in1);
	%fname=strtok(fname,'.');
	fname=vp_nm('dnm',in1);
        vp_hread([fname '.hdr']);
  
	[fid,Message] = fopen([fname '.img'],'r');
	volvect=[];
 
	if (fid ~= -1 )
	   volvect= fread(fid,DIM(1)*DIM(2)*DIM(3),MATYPE);
	
	  fclose(fid);
	  
	  out1=1;
	  out2=SCALE*volvect;
	  if VAL_OFFSET ~=0, out2=out2+VAL_OFFSET; end; 
	  out3=min(out2);
	  out4=max(out2);

	else
	  vp_message(Message);
	  out1=-1;
	  return;
	end
	
elseif strcmp(action,'valxyz') 
	
	%fname=deblank(in1);
	%fname=strtok(fname,'.');
	fname=vp_nm('dnm',in1);
        vp_hread([fname '.hdr']);
  
	[fid,Message] = fopen([fname '.img'],'r');
	xyzdata=[]; valdata=[]; xyz=[]; xyzmm=[];
 
	n=0; or=ORIGIN;
	if (fid ~= -1 )
	  for k=1:DIM(3)
	   xyzdata(:,:,k)= fread(fid,[DIM(1),DIM(2)],MATYPE);
	  end %for i
	
	  fclose(fid);
	  
	 % remove slow - recode in matlab below;
	 %for i=1:DIM(1), for j=1:DIM(2), for k=1:DIM(3)
	  %if xyzdata(i,j,k) ~=0,
	    %n=n+1;
	    %valdata(1,n)= xyzdata(i,j,k);
	    %xyz(:,n)= [i j k]';
	    %xyzmm(:,n)= [(i-or(1))*VOX(1) (j-or(2))*VOX(2) (k-or(3))*VOX(3)]';
	  %end;
	 %end; end; end;
	  
	 for p=1:DIM(3)
	  [i j v]=find(xyzdata(:,:,p));
	  
	  sz=length(v);
	  valdata(1,n+1:n+sz)=v';
	  k=p*ones(1,sz)';
	  xyz(:,n+1:n+sz)=[i j k]';
	  xyzmm(:,n+1:n+sz)= [(i-or(1))*VOX(1) (j-or(2))*VOX(2) (k-or(3))*VOX(3)]';
	  n=n+sz;
	 end;
	  
	 
	  out1=1;
	  out2=SCALE*valdata;
	  if VAL_OFFSET ~=0, out2=out2+VAL_OFFSET; end;
	  out3=xyz;
	  out4=xyzmm;

	else
	  vp_message(Message);
	  out1=-1;
	  return;
	end
	
elseif strcmp(action,'getarea') 
	
	xyzdata=[]; 
	xyzdata=in1';
	
        if ~isempty(xyzdata)
	 i1=in2(1); i2=in2(1)+ in2(3)-1;
	 j1=in2(2); j2=in2(2)+ in2(4)-1;
	 if (i2 < i1 | j2 < j2 | i1 < 1 | j1 < 1),
	  out1=-1; vp_message('invalid position');
	 return; end;
	
         for i=i1:i2, for j=j1:j2, out2(i-i1+1,j-j1+1)=xyzdata(i,j); end; end;

	 out2=out2';
	 
	else
	  out1=-1;
	  vp_message('Empty Data input');
	  return;
	end
	
elseif strcmp(action,'getplane') 
	xyzdata=[]; 
	xyzdata=in1;
	planeno=in2; viewno=in3; dim=in4;
        if isempty(xyzdata)
	  out1=-1;
	  vp_message('Empty Data input');
	  return;
	end
	
	if viewno == 1
		xydata=zeros(dim(1),dim(2));
		xydata	= xyzdata(:,:,planeno);
		
	elseif viewno == 2
		xydata=zeros(dim(2),dim(3));
		for ix=1:dim(2)
		  for iy=1:dim(3)
		  	xydata(ix,iy)=xyzdata(planeno,ix,iy);
		  end
		end
	elseif viewno == 3
		xydata=zeros(dim(1),dim(3));
		for ix=1:dim(1)
		  for iy=1:dim(3)
		  	xydata(ix,iy)=xyzdata(ix,planeno,iy);
		  end
		end
	end
	
	xydata = xydata';
	out2=xydata;
	 
elseif strcmp(action,'mergedata') 
	data1=[]; data2=[]; 
	data1=in1; data2=in2;
	opt=in3; dim=size(data1);
	if opt ~= 1, 
	  vp_message('Can only handle option 1');
	  return;
	end
	%if length(dim) ~=2, 
	%  out1=-1;
	%  vp_message('Can only handle 2D data');
	%  return;
	%end
	
        if (isempty(data1) | isempty(data2))
	  out1=-1;
	  vp_message('Empty Data input');
	  return;
	end
	
	if opt == 1
	%  out2=data2;
	%  for i=1:dim(1), for j=1:dim(2),
	%   if data1(i,j) ~= 0, out2(i,j)=data1(i,j); end;
	%  end; end;
	  datz=(data1 == 0); out2=data1 + datz.*data2;
	end
	
elseif strcmp(action,'excludata') 
	data1=[]; data2=[]; 
	data1=in1; data2=in2;
	pprec=in3; dim=size(data1),
	if length(dim) ~=3, 
	  out1=-1;
	  vp_message('Can only handle 3D data');
	  return;
	end
        if (isempty(data1) | isempty(data2))
	  out1=-1;
	  vp_message('Empty Data input');
	  return;
	end
	
        adata=data1 ~= 0; bdata=data2 ~= 0;
	
	h=waitbar(0,'PROCESSING Volume');
	
	if pprec > 1
	   for k=1:pprec:dim(3), for i=1:pprec:dim(1), for j=1:pprec:dim(2),
	     waitbar(k/dim(3),h);
	     setzerof=0; setzerob=0;
	     for m=i:i+pprec-1, for n=j:j+pprec-1, for p=k:k+pprec-1,
	        mm=min(m,dim(1)); nn=min(n,dim(2)); pp=min(p,dim(3));
		%if adata(mm,nn,pp) ~= 0, setzerof=1; break; end;
		if data1(mm,nn,pp) ~= 0, setzerof=1; break; end;
	     end;
	     if setzerof==1,break,end; end;
	     if setzerof==1,break,end; end;
	     
	     for m=i:i+pprec-1, for n=j:j+pprec-1, for p=k:k+pprec-1,
	        mm=min(m,dim(1)); nn=min(n,dim(2)); pp=min(p,dim(3));
		%if bdata(mm,nn,pp) ~= 0, setzerob=1; break; end;
		if data2(mm,nn,pp) ~= 0, setzerob=1; break; end;
	     end;
	     if setzerob==1,break,end; end;
	     if setzerob==1,break,end; end;
	     
	     if setzerof==1;
	       for m=i:i+pprec-1, for n=j:j+pprec-1, for p=k:k+pprec-1,
	        mm=min(m,dim(1)); nn=min(n,dim(2)); pp=min(p,dim(3));
		adata(mm,nn,pp) = 1 ;
	       end; end; end;
	     end;
	     if setzerob==1;
	       for m=i:i+pprec-1, for n=j:j+pprec-1, for p=k:k+pprec-1,
	        mm=min(m,dim(1)); nn=min(n,dim(2)); pp=min(p,dim(3));
		bdata(mm,nn,pp) = 1 ;
	       end; end; end;
	     end;
	   end; end; end;
	end
	
	xdata=~(adata & bdata);
	
	out2=data1.*xdata;
	
	close(h);
	
	%for i=1:dim(1), for j=1:dim(2), for k=1:dim(3),
	%   if xdata(i,j,k) ~= 0, out2(i,j,k)=0; end;
	%end; end; end;
	
end	
