% function vp_write_XYZfile(name,Title,XYZlabels,XYZvalues,filenames )
%
% This function creates an output text file (name) of data values given in columns
% of matrix XYZvalues and optional filenames corresponding to values in each row.
% 
% Labels for each column are given in XYZlabels. 
% The last entry filenames is a character set (e.g. list of file names), values correspond to each file.
% 
% vp_write XYfile ScAnVP 6.0 P.Spetsieris, Ph.D 1/23/2009
% rev. 6.2 (add optional file name column) 11/29/2011
% vp_write_XYZfile ScAnVP 6.4  P.Spetsieris, Ph.D.   5/28/15
%_______________________________________________________________________
function vp_write_XYZfile(name,Title, XYZlabels, XYZvalues, filenames)

global HelpMode 

if HelpMode, vp_help(mfilename), return ; end;

fd = fopen(name,'wt');
   
%No of files is no of rows of XYZvalues matrix
nofiles = size(XYZvalues, 1),
%No of columns is no of columns of XYZvalues matrix
nocols = size(XYZvalues, 2),

%Check if filenames entered 
if ~isnumeric(filenames)
  fileflag=1;
else
  fileflag=0;
end

%if (size(XYZlabels,1) < size(XYZlabels,2)), XYZlabels=XYZlabels'; end;
nol = size(XYZlabels, 1);
if (nol ~= nocols)vp_note(['No. of Labels and Columns conflict, Labels: ',num2str(nol), 'Columns: ',num2str(nocols)], 4); return; end;

fprintf(fd,'\n     %s\n\n',Title);

for i=1:nocols
  fprintf(fd,'     %s',XYZlabels(i,:));
end

if fileflag, fprintf(fd,'       Name\n');
else fprintf(fd,'\n'); end;

for i=1:nofiles
  fprintf(fd,'%10.3f',XYZvalues(i,1));
  for j=2:nocols
     fprintf(fd,'  %10.3f',XYZvalues(i,j));
  end
  if fileflag, fprintf(fd,'     %s\n',filenames{i});
  else fprintf(fd,'\n'); end;
end

fprintf(fd,'\n');
fclose(fd);
