% function vp_write_XYfile(name,Title,Xlabel,Ylabel,Xvalues,Yvalues, Zvalues)
%
% This function creates an output text file (name) of X, Y values and optional Z values.  
% If Zvalues is a character set (e.g. list of file names), values correspond to each file.
% 
% vp_write_XYfile ScAnVP 6.0  P.Spetsieris, Ph.D.     1/23/2009
%  rev. 6.2 (add optional file name column) 11/29/2011
%_______________________________________________________________________
function vp_write_XYfile(name,Title, Xlabel, Ylabel, Xvalues, Yvalues, Zvalues)

global HelpMode 

if HelpMode, vp_help(mfilename), return ; end;

fd = fopen(name,'wt');
   
no = length(Xvalues);
noy = length(Yvalues);
if (noy ~= no)vp_note(['No. of X and Y values conflict, X: ',num2str(no), 'Y: ',num2str(noy)], 4); return; end;
fprintf(fd,'%s\n',Title);

if (size(Xvalues,1) < size(Xvalues,2)), Xvalues=Xvalues'; Yvalues=Yvalues'; end;
if nargin < 7, 
  fprintf(fd,'     %s   %s\n',Xlabel,Ylabel);
  for i = 1:no
     fprintf(fd,'%10.3f   %10.3f\n',Xvalues(i,1),Yvalues(i,1));
  end   
else
  if ~isnumeric(Zvalues)
    fprintf(fd,'     %s   %s       Name\n',Xlabel,Ylabel);
    for i = 1:no
     fprintf(fd,'%10.3f   %10.3f    %s\n',Xvalues(i,1),Yvalues(i,1), Zvalues{i});
    end   
  else
    noz = length(Zvalues);
    if (noz ~= no)vp_note(['No. of X, Y  and Z values conflict, X,Y: ',num2str(no), ', Z: ',num2str(noz)], 4); return; end;
    if (size(Zvalues,1) < size(Zvalues,2)), Zvalues=Zvalues'; end;
    fprintf(fd,'     %s   %s\n',Xlabel,Ylabel); %Should incorporate Z label in Y
    for i = 1:no
     fprintf(fd,'%10.3f   %10.3f   %10.3f\n',Xvalues(i,1),Yvalues(i,1),Zvalues(i,1));
    end   
  end
end;

fprintf(fd,'\n');
fclose(fd);
