% function vp_write_ssmfile(name,pc_max,vaf,nm_list,ssforgis,mode,n1,n2)
%
% This function creates an SSM output file (name) corresponding to the first
% pc_max number of principal components listed in order of their Variance
% Accounted For (vaf) of the subject scores (SSF's) for each subject or
% the GIS weights corresponding to each region name.
% If only one component, pc_max refers to the number of the component.
%
% mode=1:  Create ROI SSF REF Score output file
% mode=2:  Create ROI GIS output file
% mode=3:  Create ROI Z Score SSF output file
% mode=4:  Create VOX SSF REF Score output file
% mode=5:  Create VOX Z Score SSF output file
% n1, n2:  Control subject index range
% 
% write_ssm_file                          Yilong Ma, Ph.D.     04/24/2003
% vp_write_ssmfile (revision) ScAnVP 5.1  P.Spetsieris, Ph.D.  05/08/2003
%			 rev. ScAnVP 5.3  P.Spetsieris, Ph.D.  07/28/2004
%			 rev. ScAnVP 5.4  P.Spetsieris, Ph.D.  12/21/2004
%			 rev. ScAnVP 6.2  P.Spetsieris, Ph.D.  01/30/2012
%_______________________________________________________________________
function ret=vp_write_ssmfile(name,pc_max,vaf,nm_list,ssforgis,mode,n1,n2)

global HelpMode 

if HelpMode, vp_help(mfilename), return ; end;

ret=0;
chnm_list=char(nm_list);
sub = size(chnm_list,1);
noc = size(ssforgis,2); % No. of components
mxfield=size(chnm_list,2);
mxfield=max(mxfield,length('%Variance_Accounted_For'));
skipstr=char(' '.*ones(1,mxfield));
if nargin < 7, n1=0; n2=0; end;
%if nargin < 8, n2=0; end;
if nargin < 8, if n1==0, n2=0, else n2=n1; n1=1; end; end;

if n2 < n1, ret=-1; vp_note(['Invalid control index range: ', num2str(n1),'-',num2str(n2)]); return; end;

fd = fopen(name,'wt'); if fd <=0, ret=-3; 
 vp_note(['File Open Error: ', name]); return; end;
if mode==1 % ROI REF Score file
  if n2 > 0, % Controls Specified
   if noc == 1 % Single Component
      fprintf(fd,'SSM ROI Based Analysis- SSF REF Scores for Principal Component %d, Subjects 1-%d, Controls %d-%d\n\n',pc_max,sub,n1,n2);
   else % Multiple Components
      fprintf(fd,'SSM ROI Based Analysis- SSF REF Scores for Principal Components 1-%d, Subjects 1-%d, Controls %d-%d\n\n',pc_max,sub,n1,n2);
   end
  else % Controls Not Specified
   if noc == 1 % Single Component
      fprintf(fd,'SSM ROI Based Analysis- SSF Scores for Principal Component %d, Subjects 1-%d\n\n',pc_max,sub);
   else % Multiple Components
      fprintf(fd,'SSM ROI Based Analysis- SSF Scores for Principal Components 1-%d, Subjects 1-%d\n\n',pc_max,sub);
   end
  end
elseif mode==2 % ROI GIS file
  if noc == 1
    fprintf(fd,'SSM ROI Based Analysis- GIS Weights for Principal Component %d, Regions 1-%d\n\n',pc_max,sub);
  else
    fprintf(fd,'SSM ROI Based Analysis- GIS Weights for Principal Components 1-%d, Regions 1-%d\n\n',pc_max,sub);
  end
elseif mode==3 % Z Score ROI type 
  if n2 > 0, % Controls Specified 
   if noc == 1 % Single Component
     fprintf(fd,'SSM ROI Based Analysis- SSF Z Scores for Principal Component %d, Subjects 1-%d, Controls %d-%d\n\n',pc_max,sub,n1,n2);
   else % Multiple Components
     fprintf(fd,'SSM ROI Based Analysis- SSF Z Scores for Principal Components 1-%d, Subjects 1-%d, Controls %d-%d\n\n',pc_max,sub,n1,n2);
   end
  else % Controls Not Specified
   if noc == 1 % Single Component
     fprintf(fd,'SSM ROI Based Analysis- SSF Z Scores for Principal Component %d, Subjects 1-%d\n\n',pc_max,sub);
   else % Multiple Components
     fprintf(fd,'SSM ROI Based Analysis- SSF Z Scores for Principal Components 1-%d, Subjects 1-%d\n\n',pc_max,sub);
   end
  end
elseif mode==4 % VOX REF Score file
  if n2 > 0, % Controls Specified
   if noc == 1 % Single Component
      fprintf(fd,'SSM VOX Based Analysis- SSF REF Scores for Principal Component %d, Subjects 1-%d, Controls %d-%d\n\n',pc_max,sub,n1,n2);
   else % Multiple Components
      fprintf(fd,'SSM VOX Based Analysis- SSF REF Scores for Principal Components 1-%d, Subjects 1-%d, Controls %d-%d\n\n',pc_max,sub,n1,n2);
   end
  else % Controls Not Specified
   if noc == 1 % Single Component
      fprintf(fd,'SSM VOX Based Analysis- SSF Scores for Principal Component %d, Subjects 1-%d\n\n',pc_max,sub);
   else % Multiple Components
      fprintf(fd,'SSM VOX Based Analysis- SSF Scores for Principal Components 1-%d, Subjects 1-%d\n\n',pc_max,sub);
   end
  end
elseif mode==5 % Z Score VOX type 
  if n2 > 0, % Controls Specified 
   if noc == 1 % Single Component
      fprintf(fd,'SSM VOX Based Analysis- SSF Z Scores for Principal Component %d, Subjects 1-%d, Controls %d-%d\n\n',pc_max,sub,n1,n2);
   else % Multiple Components
      fprintf(fd,'SSM VOX Based Analysis- SSF Z Scores for Principal Components 1-%d, Subjects 1-%d, Controls %d-%d\n\n',pc_max,sub,n1,n2);
   end
  else % Controls Not Specified
   if noc == 1 % Single Component
      fprintf(fd,'SSM VOX Based Analysis- SSF Z Scores for Principal Component %d, Subjects 1-%d\n\n',pc_max,sub);
   else % Multiple Components
      fprintf(fd,'SSM VOX Based Analysis- SSF Z Scores for Principal Components 1-%d, Subjects 1-%d\n\n',pc_max,sub);
   end
  end
else
 vp_note('INVALID mode for SSM file output'); ret=-2;
 return;
end
chskip=mxfield-length('Principal_Component');
fprintf(fd,'%c%c','Principal_Component',skipstr(1:chskip));
   fprintf(fd,'\t');
   if noc==1
      fprintf(fd,'%12d',pc_max);
   else
    for j = 1:pc_max
      fprintf(fd,'%12d',j);
    end
   end
   fprintf(fd,'\n');
   
chskip=mxfield-length('%Variance_Accounted_For');
fprintf(fd,'%c%c','%Variance_Accounted_For',skipstr(1:chskip));
fprintf(fd,'\t');
if noc==1
  fprintf(fd,'%10.3f',vaf);
else
  for j = 1:pc_max
    fprintf(fd,'%10.3f',vaf(j));
  end
end
fprintf(fd,'\n\n');

%sub = length(nm_list);
for i = 1:sub
   %fprintf(fd,'%c',nm_list{i});
   chskip=(mxfield-size(chnm_list(i,:),2)) ;
   fprintf(fd,['%c%c'],chnm_list(i,:),skipstr(1:chskip));
   fprintf(fd,['\t']);
   if noc==1
        fprintf(fd,'%10.3f',ssforgis(i,1));
   else
     for j = 1:pc_max
        fprintf(fd,'%10.3f',ssforgis(i,j));
     end
   end
   fprintf(fd,'\n');
end   
fclose(fd);
