% vp_xyzmarker.m
% Places temporary geometric markers of type Rectangle, Circle, Triangle or
% Ellipse at user X Y Z coordinates of the display specified in mm or at a
% position pointed to by the user. The default radius of the marker is
% approx. 8mm.. Coordinates correspond to Talairach or MNI values for
% normalized images in Neurological display assuming the correct "Input"
% orientation of the file on disk is specified on the ScAnVP menu.
%
% ScAnVP	Ver. 6.3	P. Spetsieris 11/7/13
%           Rev. 7.8	P. Spetsieris 1/18/16
	
global XYZOR PLNO VIEWNO VOX
global HelpMode UFI 
if HelpMode, vp_help(mfilename), return ; end;

if  or(isempty(UFI),UFI==0),  
 % UFI=gcf;
 vp_note('Display and Pick Image First', 3);
 return;
end 
      
figure(UFI);
%figure(gcf);
       
viewno=0; marktype=0;

TxColor=[0.8 0.2 1];

ts='0';

while(marktype ~= -1)
    
 % vp_note('Click on Image to Place Marker (Diam: ~8mm) ',3);
 
 prompt=['Click on Image to Place Marker (Diam: ~8mm) '];
 optO=['CLICK on image to place marker or to key in Coordinates in X,Y,Z mm from Origin'];
 POpt=vp_opt('X',prompt,'CLICK',optO,'EXIT','','Help','');

 if(strcmp(POpt,'X')), break; return; end;
 if(strcmp(POpt,'EXIT')), break; return; end;
 if(strcmp(POpt,'Help')),
  vp_help('vp_xyzmarker'); vp_xyzmarker; 
  break; end;
%if(strcmp(POpt,'CLICK')), end; %Continue   

 [x,y]=ginput(1);

 if strcmp(get(gco,'type'),'image')
  
  x=round(x), y=round(y),
  udata=get(gca,'UserData');
  if ~isempty(udata),
  
    viewno=udata(1); plno=udata(2); vox=udata(3:5); xyzor=udata(6:8);
    VIEWNO=viewno, PLNO=plno, VOX=vox, XYZOR=xyzor,
    if viewno==1
  	xmm=(x-xyzor(1))*vox(1); ymm=(y-xyzor(2))*vox(2);
	zmm=(plno-xyzor(3))*vox(3);
    elseif viewno==2,
  	ymm=(x-xyzor(2))*vox(2); zmm=(y-xyzor(3))*vox(3);
	xmm=(plno-xyzor(1))*vox(1);
    elseif viewno==3,
  	xmm=(x-xyzor(1))*vox(1); zmm=(y-xyzor(3))*vox(3);
	ymm=(plno-xyzor(2))*vox(2);
    end
    %%vp_note([num2str(xmm) ', ' num2str(ymm) ', ' num2str(zmm)],3);
  end
  
 else
	out1=-1;
    x=round(x), y=round(y),
    if VIEWNO==1
  	xmm=(x-XYZOR(1))*VOX(1); ymm=(y-XYZOR(2))*VOX(2);
	zmm=(PLNO-XYZOR(3))*VOX(3);
    elseif VIEWNO==2,
  	ymm=(x-XYZOR(2))*VOX(2); zmm=(y-XYZOR(3))*VOX(3);
	xmm=(PLNO-XYZOR(1))*VOX(1);
    elseif VIEWNO==3,
  	xmm=(x-XYZOR(1))*VOX(1); zmm=(y-XYZOR(3))*VOX(3);
	ymm=(PLNO-XYZOR(2))*VOX(2);
    end
    %%vp_note([num2str(xmm) ', ' num2str(ymm) ', ' num2str(zmm)  ' Not an ''image'' point'],3);
 end

 
  xyzspec=[num2str(xmm) ' ' num2str(ymm) ' ' num2str(zmm), ' ' num2str(marktype)];
  xyzmm=vp_keyin('Press OK or Key in Values to Overide Defaults X Y Z plus Type 0=CIRC., 1=RECT., 2=TRNGL., 3=ELL. : ', xyzspec);
  if isempty(xyzmm), break; end;
  [xs, ys, zs, ts]=strread(xyzmm,'%s%s%s%s','delimiter',' '),
  if ~isempty(xs), xmm=str2num(char(xs)); end;
  if ~isempty(ys), ymm=str2num(char(ys)); end;
  if ~isempty(zs), zmm=str2num(char(zs)); end;
  if ~isempty(ts), marktype=str2num(char(ts)); end;

  if ~isempty(xyzmm),

    if VIEWNO==1
  	%xmm=(x-XYZOR(1))*VOX(1); ymm=(y-XYZOR(2))*VOX(2);
        x=(xmm/VOX(1)) + XYZOR(1);
        y=(ymm/VOX(2)) + XYZOR(2);
        plno=(zmm/VOX(3)) + XYZOR(3),
	%zmm=(PLNO-XYZOR(3))*VOX(3),
    elseif VIEWNO==2,
  	%ymm=(x-XYZOR(2))*VOX(2); zmm=(y-XYZOR(3))*VOX(3);
        x=(ymm/VOX(2)) + XYZOR(2);
        y=(zmm/VOX(3)) + XYZOR(3);
	%xmm=(PLNO-XYZOR(1))*VOX(1);
        plno=(xmm/VOX(1)) + XYZOR(1),
    elseif VIEWNO==3,
  	%xmm=(x-XYZOR(1))*VOX(1); zmm=(y-XYZOR(3))*VOX(3);
        x=(xmm/VOX(1)) + XYZOR(1);
        y=(zmm/VOX(3)) + XYZOR(3);
	%ymm=(PLNO-XYZOR(2))*VOX(2);
        plno=(ymm/VOX(2)) + XYZOR(2),
    end
    x, y, plno,
    x=round(x), y=round(y),
  
    if(marktype==0)
        hm=rectangle('position',[x-4 y-4 8 8],'Curvature',[1 1]);
        set(hm, 'LineWidth', 2.5);
    elseif(marktype==1)
        hm=rectangle('position',[x-4 y-4 8 8],'Curvature',[0 0]);
        set(hm, 'LineWidth', 2.5);
    elseif(marktype==2) %Place Isosceles triangle centered at x,y, radius 4
        xtri=[x-4.62, x+4.6, x, x-4.62]; ytri=[y-4, y-4, y+4, y-4];
        hm=line(xtri,ytri),
        set(hm, 'LineWidth', 2.5);
        set(hm, 'Color', [0 0 0]);
    elseif(marktype==3)
        hm=rectangle('position',[x-3 y-4.5 6 9],'Curvature',[1 1]);
        set(hm, 'LineWidth', 2.5);
    else
	vp_note(['Unrecognized Type',num2str(marktype),' Reset to 0.'],3);
        markertype=0;
        hm=rectangle('position',[x-4 y-4 8 8],'Curvature',[0 0]);
        set(hm, 'LineWidth', 2.5);
    end
    
    %%vp_note([num2str(x) ', ' num2str(y)],3);

  end;

end %while(marktype ~= -1)
